package android.net.dhcp;

public class DhcpResultsInfoDBManager {
    private static final int DHCP_RESULTS_DB_SIZE = 50;
    private static final java.lang.String TAG = "DhcpResultsInfoDBManager";
    private static android.net.dhcp.DhcpResultsInfoDBManager mDataBaseManager;
    private android.database.sqlite.SQLiteDatabase mDatabase;
    private android.net.dhcp.DhcpResultsInfoDBHelper mHelper;
    private java.lang.Object mdbLock = new java.lang.Object();

    public DhcpResultsInfoDBManager(android.content.Context context) {
        this.mHelper = new android.net.dhcp.DhcpResultsInfoDBHelper(context);
        this.mDatabase = this.mHelper.getWritableDatabase();
    }

    public static android.net.dhcp.DhcpResultsInfoDBManager getInstance(android.content.Context context) {
        if (mDataBaseManager == null) {
            mDataBaseManager = new android.net.dhcp.DhcpResultsInfoDBManager(context);
        }
        return mDataBaseManager;
    }

    private boolean deleteHistoryRecord(java.lang.String dbTableName, java.lang.String apssid) {
        synchronized (this.mdbLock) {
            if (this.mDatabase != null) {
                if (this.mDatabase.isOpen()) {
                    if (apssid == null) {
                        android.util.Log.e("DhcpResultsInfoDBManager", "deleteHistoryRecord null error.");
                        return false;
                    }
                    try {
                        this.mDatabase.delete(dbTableName, "apSSID like ?", new java.lang.String[]{apssid});
                        return true;
                    } catch (android.database.SQLException e) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("deleteHistoryRecord error:");
                        stringBuilder.append(e);
                        android.util.Log.e("DhcpResultsInfoDBManager", stringBuilder.toString());
                        return false;
                    }
                }
            }
            android.util.Log.e("DhcpResultsInfoDBManager", "deleteHistoryRecord database error.");
            return false;
        }
    }

    public boolean deleteDhcpResultsInfoRecord(java.lang.String apssid) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("deleteApInfoRecord delete record of ssid:");
        stringBuilder.append(apssid);
        android.util.Log.d("DhcpResultsInfoDBManager", stringBuilder.toString());
        return deleteHistoryRecord("DhcpResults", apssid);
    }

    private boolean checkHistoryRecordExist(java.lang.String dbTableName, java.lang.String apssid) {
        boolean ret = false;
        android.database.Cursor c = null;
        java.lang.StringBuilder stringBuilder;
        try {
            android.database.sqlite.SQLiteDatabase sQLiteDatabase = this.mDatabase;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("SELECT * FROM ");
            stringBuilder2.append(dbTableName);
            stringBuilder2.append(" where apSSID like ?");
            c = sQLiteDatabase.rawQuery(stringBuilder2.toString(), new java.lang.String[]{apssid});
            int rcdCount = c.getCount();
            if (rcdCount > 0) {
                ret = true;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkHistoryRecordExist read from:");
            stringBuilder.append(dbTableName);
            stringBuilder.append(", get record: ");
            stringBuilder.append(rcdCount);
            android.util.Log.d("DhcpResultsInfoDBManager", stringBuilder.toString());
            if (c != null) {
                c.close();
            }
            return ret;
        } catch (android.database.SQLException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkHistoryRecordExist error:");
            stringBuilder.append(e);
            android.util.Log.e("DhcpResultsInfoDBManager", stringBuilder.toString());
            if (c != null) {
                c.close();
            }
            return false;
        } catch (java.lang.Throwable th) {
            if (c != null) {
                c.close();
            }
            throw th;
        }
    }

    private boolean updateDhcpResultsInfoRecord(android.net.dhcp.DhcpResultsInfoRecord dbr) {
        android.content.ContentValues values = new android.content.ContentValues();
        values.put("apSSID", dbr.apSSID);
        values.put("IP", dbr.staIP);
        values.put("DHCPServer", dbr.apDhcpServer);
        values.put("EX1", "ex1");
        values.put("EX2", "ex2");
        try {
            int rowChg = this.mDatabase.update("DhcpResults", values, "apSSID like ?", new java.lang.String[]{dbr.apSSID});
            if (rowChg == 0) {
                android.util.Log.e("DhcpResultsInfoDBManager", "updateDhcpResultsInfoRecord update failed.");
                return false;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateDhcpResultsInfoRecord update succ, rowChg=");
            stringBuilder.append(rowChg);
            android.util.Log.d("DhcpResultsInfoDBManager", stringBuilder.toString());
            return true;
        } catch (android.database.SQLException e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("updateDhcpResultsInfoRecord error:");
            stringBuilder2.append(e);
            android.util.Log.e("DhcpResultsInfoDBManager", stringBuilder2.toString());
            return false;
        }
    }

    private boolean insertDhcpResultsInfoRecord(android.net.dhcp.DhcpResultsInfoRecord dbr) {
        try {
            this.mDatabase.execSQL("INSERT INTO DhcpResults VALUES(?, ?, ?, ?, ?)", new java.lang.Object[]{dbr.apSSID, dbr.staIP, dbr.apDhcpServer, "ex1", "ex2"});
            android.util.Log.i("DhcpResultsInfoDBManager", "insertDhcpResultsInfoRecord add a record succ.");
            return true;
        } catch (android.database.SQLException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("insertDhcpResultsInfoRecord error:");
            stringBuilder.append(e);
            android.util.Log.e("DhcpResultsInfoDBManager", stringBuilder.toString());
            return false;
        }
    }

    public boolean addOrUpdateDhcpResultsInfoRecord(android.net.dhcp.DhcpResultsInfoRecord dbr) {
        synchronized (this.mdbLock) {
            if (this.mDatabase != null && this.mDatabase.isOpen()) {
                if (dbr != null) {
                    boolean updateDhcpResultsInfoRecord;
                    if (dbr.apSSID == null) {
                        android.util.Log.e("DhcpResultsInfoDBManager", "addOrUpdateApInfoRecord null error.");
                        return false;
                    } else if (checkHistoryRecordExist("DhcpResults", dbr.apSSID)) {
                        updateDhcpResultsInfoRecord = updateDhcpResultsInfoRecord(dbr);
                        return updateDhcpResultsInfoRecord;
                    } else {
                        updateDhcpResultsInfoRecord = insertDhcpResultsInfoRecord(dbr);
                        return updateDhcpResultsInfoRecord;
                    }
                }
            }
            android.util.Log.e("DhcpResultsInfoDBManager", "addOrUpdateApInfoRecord error.");
            return false;
        }
    }

    /* JADX WARNING: Missing block: B:17:0x0033, code:
            return null;
     */
    /* JADX WARNING: Missing block: B:23:0x0063, code:
            if (r2 != null) goto L_0x0065;
     */
    public android.util.LruCache<java.lang.String, android.net.dhcp.DhcpResultsInfoRecord> getAllDhcpResultsInfo() {
        /*
        r7 = this;
        r0 = r7.mdbLock;
        monitor-enter(r0);
        r1 = new android.util.LruCache;	 Catch:{ all -> 0x0096 }
        r2 = 50;
        r1.<init>(r2);	 Catch:{ all -> 0x0096 }
        r2 = r7.mDatabase;	 Catch:{ all -> 0x0096 }
        r3 = 0;
        if (r2 == 0) goto L_0x008d;
    L_0x000f:
        r2 = r7.mDatabase;	 Catch:{ all -> 0x0096 }
        r2 = r2.isOpen();	 Catch:{ all -> 0x0096 }
        if (r2 != 0) goto L_0x0019;
    L_0x0017:
        goto L_0x008d;
    L_0x0019:
        r2 = r3;
        r4 = r7.mDatabase;	 Catch:{ Exception -> 0x006b }
        r5 = "SELECT * FROM DhcpResults";
        r4 = r4.rawQuery(r5, r3);	 Catch:{ Exception -> 0x006b }
        r2 = r4;
        if (r2 != 0) goto L_0x0034;
    L_0x0025:
        r4 = "DhcpResultsInfoDBManager";
        r5 = "query database error.";
        android.util.Log.e(r4, r5);	 Catch:{ Exception -> 0x006b }
        if (r2 == 0) goto L_0x0032;
    L_0x002f:
        r2.close();	 Catch:{ all -> 0x0096 }
    L_0x0032:
        monitor-exit(r0);	 Catch:{ all -> 0x0096 }
        return r3;
    L_0x0034:
        r3 = r2.moveToNext();	 Catch:{ Exception -> 0x006b }
        if (r3 == 0) goto L_0x0063;
    L_0x003a:
        r3 = new android.net.dhcp.DhcpResultsInfoRecord;	 Catch:{ Exception -> 0x006b }
        r4 = "apSSID";
        r4 = r2.getColumnIndex(r4);	 Catch:{ Exception -> 0x006b }
        r4 = r2.getString(r4);	 Catch:{ Exception -> 0x006b }
        r5 = "IP";
        r5 = r2.getColumnIndex(r5);	 Catch:{ Exception -> 0x006b }
        r5 = r2.getString(r5);	 Catch:{ Exception -> 0x006b }
        r6 = "DHCPServer";
        r6 = r2.getColumnIndex(r6);	 Catch:{ Exception -> 0x006b }
        r6 = r2.getString(r6);	 Catch:{ Exception -> 0x006b }
        r3.<init>(r4, r5, r6);	 Catch:{ Exception -> 0x006b }
        r4 = r3.apSSID;	 Catch:{ Exception -> 0x006b }
        r1.put(r4, r3);	 Catch:{ Exception -> 0x006b }
        goto L_0x0034;
    L_0x0063:
        if (r2 == 0) goto L_0x0085;
    L_0x0065:
        r2.close();	 Catch:{ all -> 0x0096 }
        goto L_0x0085;
    L_0x0069:
        r3 = move-exception;
        goto L_0x0087;
    L_0x006b:
        r3 = move-exception;
        r4 = "DhcpResultsInfoDBManager";
        r5 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0069 }
        r5.<init>();	 Catch:{ all -> 0x0069 }
        r6 = "queryDhcpResultsInfo error:";
        r5.append(r6);	 Catch:{ all -> 0x0069 }
        r5.append(r3);	 Catch:{ all -> 0x0069 }
        r5 = r5.toString();	 Catch:{ all -> 0x0069 }
        android.util.Log.e(r4, r5);	 Catch:{ all -> 0x0069 }
        if (r2 == 0) goto L_0x0085;
    L_0x0084:
        goto L_0x0065;
    L_0x0085:
        monitor-exit(r0);	 Catch:{ all -> 0x0096 }
        return r1;
    L_0x0087:
        if (r2 == 0) goto L_0x008c;
    L_0x0089:
        r2.close();	 Catch:{ all -> 0x0096 }
    L_0x008c:
        throw r3;	 Catch:{ all -> 0x0096 }
    L_0x008d:
        r2 = "DhcpResultsInfoDBManager";
        r4 = "getAllDhcpResultsInfo database error.";
        android.util.Log.e(r2, r4);	 Catch:{ all -> 0x0096 }
        monitor-exit(r0);	 Catch:{ all -> 0x0096 }
        return r3;
    L_0x0096:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0096 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: android.net.dhcp.DhcpResultsInfoDBManager.getAllDhcpResultsInfo():android.util.LruCache<java.lang.String, android.net.dhcp.DhcpResultsInfoRecord>");
    }
}
