package android.net.dhcp;

public class HWArpPacket {
    private static final int ARP_LENGTH = 28;
    private static final int ETHERNET_TYPE = 1;
    private static final int IPV4_LENGTH = 4;
    private static final int MAC_ADDR_LENGTH = 6;
    private static final int MAX_LENGTH = 1500;
    private static final java.lang.String TAG = "HWArpPacket";
    private final byte[] L2_BROADCAST;
    private java.lang.String mInterfaceName;
    private java.net.InetAddress mMyAddr = null;
    private final byte[] mMyMac = new byte[6];
    private final libcore.net.RawSocket mSocket;

    public HWArpPacket(java.lang.String interfaceName, java.net.InetAddress myAddr, java.lang.String mac) throws java.net.SocketException {
        this.mInterfaceName = interfaceName;
        if (mac != null) {
            for (int i = 0; i < 6; i++) {
                this.mMyMac[i] = (byte) java.lang.Integer.parseInt(mac.substring(i * 3, (i * 3) + 2), 16);
            }
        }
        if (myAddr instanceof java.net.Inet6Address) {
            throw new java.lang.IllegalArgumentException("IPv6 unsupported");
        }
        this.L2_BROADCAST = new byte[6];
        java.util.Arrays.fill(this.L2_BROADCAST, (byte) -1);
        this.mSocket = new libcore.net.RawSocket(this.mInterfaceName, (short) 2054);
        this.mMyAddr = myAddr;
    }

    public boolean doArp(int timeoutMillis, java.net.Inet4Address requestedAddress, boolean fillSenderIp) {
        java.nio.ByteBuffer buf = java.nio.ByteBuffer.allocate(1500);
        byte[] desiredIp = requestedAddress.getAddress();
        long timeout = android.os.SystemClock.elapsedRealtime() + ((long) timeoutMillis);
        buf.clear();
        buf.order(java.nio.ByteOrder.BIG_ENDIAN);
        int i = 1;
        buf.putShort((short) 1);
        buf.putShort((short) 2048);
        buf.put((byte) 6);
        byte b = (byte) 4;
        buf.put((byte) 4);
        buf.putShort((short) 1);
        buf.put(this.mMyMac);
        byte[] address = (!fillSenderIp || this.mMyAddr == null) ? new byte[4] : this.mMyAddr.getAddress();
        buf.put(address);
        buf.put(new byte[6]);
        buf.put(desiredIp);
        buf.flip();
        this.mSocket.write(this.L2_BROADCAST, buf.array(), 0, buf.limit());
        byte[] recvBuf = new byte[1500];
        while (android.os.SystemClock.elapsedRealtime() < timeout) {
            if (this.mSocket.read(recvBuf, 0, recvBuf.length, -1, (int) (timeout - android.os.SystemClock.elapsedRealtime())) >= 28 && recvBuf[0] == (byte) 0 && recvBuf[i] == i) {
                if (recvBuf[2] == (byte) 8 && recvBuf[3] == (byte) 0 && recvBuf[b] == (byte) 6 && recvBuf[5] == b && recvBuf[6] == (byte) 0 && recvBuf[7] == (byte) 2 && recvBuf[14] == desiredIp[0] && recvBuf[15] == desiredIp[1] && recvBuf[16] == desiredIp[2] && recvBuf[17] == desiredIp[3] && !isMyMac(this.mMyMac, recvBuf)) {
                    android.util.Log.d("HWArpPacket", "doArp() return true ");
                    return true;
                }
                i = 1;
            }
            b = (byte) 4;
        }
        android.util.Log.d("HWArpPacket", "doArp() return false ");
        return false;
    }

    public void close() {
        try {
            this.mSocket.close();
        } catch (java.io.IOException e) {
        }
    }

    public boolean isMyMac(byte[] myMac, byte[] recvBuf) {
        if (recvBuf[8] == myMac[0] && recvBuf[9] == myMac[1] && recvBuf[10] == myMac[2] && recvBuf[11] == myMac[3] && recvBuf[12] == myMac[4] && recvBuf[13] == myMac[5]) {
            android.util.Log.d("HWArpPacket", "isMyMac return true");
            return true;
        }
        android.util.Log.d("HWArpPacket", "isMyMac return false");
        return false;
    }
}
