package android.net.dhcp;

public class HwDhcpClient extends android.net.dhcp.DhcpClient {
    public static final java.lang.String ACTION_DHCP_OFFER_INFO = "com.hw.wifipro.action.DHCP_OFFER_INFO";
    public static final java.lang.String ACTION_INVALID_DHCP_OFFER_RCVD = "com.hw.wifipro.action.INVALID_DHCP_OFFER_RCVD";
    public static final java.lang.String FLAG_DHCP_OFFER_INFO = "com.hw.wifipro.FLAG_DHCP_OFFER_INFO";
    private static final java.lang.String HW_WIFI_SELF_CURING = "net.wifi.selfcuring";
    public static final int SCE_STATE_IDLE = 0;
    public static final int SCE_STATE_RECONNECT = 103;
    private static final java.lang.String TAG = "HwDhcpClient";
    private static android.util.LruCache<java.lang.String, android.net.dhcp.DhcpResultsInfoRecord> mDhcpResultsInfoCache = new android.util.LruCache(50);
    private static java.lang.Object mLock = new java.lang.Object();
    private static boolean mReadDBDone = false;
    private java.lang.String mPendingSSID = null;
    private java.lang.String regularMac = ":[\\w]{1,}:[\\w]{1,}:";

    public HwDhcpClient(android.content.Context context, com.android.internal.util.StateMachine controller, java.lang.String iface) {
        super(context, controller, iface);
    }

    public static android.net.dhcp.DhcpClient makeHwDhcpClient(android.content.Context context, com.android.internal.util.StateMachine controller, java.lang.String intf) {
        android.net.dhcp.DhcpClient client = new android.net.dhcp.HwDhcpClient(context, controller, intf);
        client.start();
        return client;
    }

    public void putPendingSSID(java.lang.String pendingSSID) {
        this.mPendingSSID = pendingSSID;
    }

    public static void getAllDhcpResultsInfofromDB(android.content.Context context) {
        android.net.dhcp.DhcpResultsInfoDBManager dbMgr = android.net.dhcp.DhcpResultsInfoDBManager.getInstance(context);
        synchronized (mLock) {
            mDhcpResultsInfoCache = dbMgr.getAllDhcpResultsInfo();
        }
        mReadDBDone = true;
    }

    public boolean getReadDBDone() {
        return mReadDBDone;
    }

    public android.net.dhcp.DhcpResultsInfoRecord getDhcpResultsInfoRecord() {
        if (this.mPendingSSID == null) {
            return null;
        }
        java.lang.String pendingSSID = this.mPendingSSID;
        synchronized (mLock) {
            if (mDhcpResultsInfoCache != null) {
                android.net.dhcp.DhcpResultsInfoRecord dhcpResultsInfoRecord = (android.net.dhcp.DhcpResultsInfoRecord) mDhcpResultsInfoCache.get(pendingSSID);
                return dhcpResultsInfoRecord;
            }
            return null;
        }
    }

    public void updateDhcpResultsInfoCache(android.net.DhcpResults result) {
        java.lang.StringBuffer ipstr = new java.lang.StringBuffer();
        java.lang.StringBuffer dhcpServerstr = new java.lang.StringBuffer();
        ipstr.append(result.ipAddress);
        dhcpServerstr.append(result.serverAddress);
        android.net.dhcp.DhcpResultsInfoRecord dhcpResultsInfo = new android.net.dhcp.DhcpResultsInfoRecord(this.mPendingSSID, ipstr.toString(), dhcpServerstr.toString());
        if (this.mPendingSSID != null) {
            java.lang.String pendingSSID = this.mPendingSSID;
            synchronized (mLock) {
                mDhcpResultsInfoCache.put(pendingSSID, dhcpResultsInfo);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateDhcpResultsInfoCache add record for ");
                stringBuilder.append(pendingSSID.replaceAll(this.regularMac, ":**:**:"));
                logd(stringBuilder.toString());
            }
            return;
        }
        logd("updateDhcpResultsInfoCache error PendingSSID is null");
    }

    public void removeDhcpResultsInfoCache() {
        if (this.mPendingSSID != null) {
            java.lang.String pendingSSID = this.mPendingSSID;
            synchronized (mLock) {
                mDhcpResultsInfoCache.remove(pendingSSID);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("removeDhcpResultsInfoCache remove record for ");
                stringBuilder.append(pendingSSID.replaceAll(this.regularMac, ":**:**:"));
                logd(stringBuilder.toString());
            }
            return;
        }
        logd("removeDhcpResultsInfoCache error PendingSSID is null");
    }

    public void sendDhcpOfferPacket(android.content.Context context, android.net.dhcp.DhcpPacket dhcpPacket) {
        if (dhcpPacket != null && (dhcpPacket instanceof android.net.dhcp.DhcpOfferPacket)) {
            android.content.Intent intent = new android.content.Intent("com.hw.wifipro.action.DHCP_OFFER_INFO");
            java.lang.String dhcpResultsStr = dhcpResults2String(dhcpPacket.toDhcpResults());
            if (dhcpResultsStr != null) {
                intent.setFlags(67108864);
                intent.putExtra("com.hw.wifipro.FLAG_DHCP_OFFER_INFO", dhcpResultsStr);
                context.sendBroadcastAsUser(intent, android.os.UserHandle.ALL);
            }
        }
    }

    private java.lang.String dhcpResults2String(android.net.DhcpResults dhcpResults) {
        if (dhcpResults == null || dhcpResults.ipAddress == null || dhcpResults.ipAddress.getAddress() == null || dhcpResults.dnsServers == null) {
            return null;
        }
        java.lang.StringBuilder lastDhcpResults = new java.lang.StringBuilder();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(java.lang.String.valueOf(-1));
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.domains == null ? "" : dhcpResults.domains);
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.ipAddress.getAddress().getHostAddress());
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.ipAddress.getPrefixLength());
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.ipAddress.getFlags());
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.ipAddress.getScope());
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(dhcpResults.gateway != null ? dhcpResults.gateway.getHostAddress() : "");
        stringBuilder.append("|");
        lastDhcpResults.append(stringBuilder.toString());
        java.util.Iterator it = dhcpResults.dnsServers.iterator();
        while (it.hasNext()) {
            java.net.InetAddress dnsServer = (java.net.InetAddress) it.next();
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(dnsServer.getHostAddress());
            stringBuilder2.append("|");
            lastDhcpResults.append(stringBuilder2.toString());
        }
        return lastDhcpResults.toString();
    }

    private boolean isWifiSelfCuring() {
        return java.lang.String.valueOf(0).equals(android.os.SystemProperties.get("net.wifi.selfcuring", java.lang.String.valueOf(0))) ^ 1;
    }

    private int getSelfCuringState() {
        return java.lang.Integer.parseInt(android.os.SystemProperties.get("net.wifi.selfcuring", java.lang.String.valueOf(0)));
    }

    public void forceRemoveDhcpCache() {
        removeDhcpResultsInfoCache();
    }

    public boolean isInvalidIpAddr(android.net.DhcpResults results) {
        if (!(results == null || results.ipAddress == null || results.ipAddress.getAddress() == null)) {
            if (results.gateway != null) {
                if (isWifiSelfCuring() && getSelfCuringState() == 103) {
                    byte[] rcvIpAddr = results.ipAddress.getAddress().getAddress();
                    int intCurrAddr3 = rcvIpAddr[3] & 255;
                    int netmaskLength = results.ipAddress.getPrefixLength();
                    boolean ipEqualsGw = results.ipAddress.getAddress().getHostAddress().equals(results.gateway.getHostAddress());
                    boolean invalidIp = rcvIpAddr.length == 4 && (intCurrAddr3 == 0 || intCurrAddr3 == 1 || intCurrAddr3 == 255);
                    if (ipEqualsGw || (netmaskLength == 24 && invalidIp)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("the rcv dhcp offer has ip addr invalid, addr = ");
                        stringBuilder.append(intCurrAddr3);
                        logd(stringBuilder.toString());
                        return true;
                    }
                }
                return false;
            }
        }
        return false;
    }

    public void notifyInvalidDhcpOfferRcvd(android.content.Context context, android.net.DhcpResults offer) {
        if (offer != null) {
            android.content.Intent intent = new android.content.Intent("com.hw.wifipro.action.INVALID_DHCP_OFFER_RCVD");
            java.lang.String dhcpResultsStr = dhcpResults2String(offer);
            if (dhcpResultsStr != null) {
                intent.setFlags(67108864);
                intent.putExtra("com.hw.wifipro.FLAG_DHCP_OFFER_INFO", dhcpResultsStr);
                context.sendBroadcastAsUser(intent, android.os.UserHandle.ALL);
            }
        }
    }
}
