package com.android.server;

public class BluetoothParaManager {
    private static final int BT_PARA_FILE_MAX_SIZE = 10485760;
    private static final java.lang.String BT_PARA_FILE_WARNING = "BT_PARA_FILE_WARNING";
    private static final java.lang.String BT_PARA_UPDATE_ACTION = "com.huawei.android.bluetooth.ACTION_BT_PARA_UPDATE";
    private static final java.lang.String BT_PARA_UPDATE_PERMISSION = "com.huawei.android.bluetooth.permission.BT_PARA_UPDATE";
    private static final java.lang.String EMCOM_PARA_READY_ACTION = "huawei.intent.action.ACTION_EMCOM_PARA_READY";
    private static final java.lang.String EXTRA_EMCOM_PARA_READY_REC = "EXTRA_EMCOM_PARA_READY_REC";
    private static final int MASKBIT_PARATYPE_NONCELL_BT = 4;
    private static final int PARATYPE_NONCELL_BT = 16;
    private static final int PARA_PATHTYPE_COTA = 1;
    private static final int PARA_UPGRADE_FILE_NOTEXIST = 0;
    private static final int PARA_UPGRADE_RESPONSE_FILE_ERROR = 6;
    private static final int PARA_UPGRADE_RESPONSE_UPGRADE_ALREADY = 4;
    private static final int PARA_UPGRADE_RESPONSE_UPGRADE_FAILURE = 9;
    private static final int PARA_UPGRADE_RESPONSE_UPGRADE_PENDING = 7;
    private static final int PARA_UPGRADE_RESPONSE_UPGRADE_SUCCESS = 8;
    private static final int PARA_UPGRADE_RESPONSE_VERSION_MISMATCH = 5;
    private static final java.lang.String RECEIVE_EMCOM_PARA_UPGRADE_PERMISSION = "huawei.permission.RECEIVE_EMCOM_PARA_UPGRADE";
    private static final java.lang.String TAG = "BluetoothParaManager";
    private static java.lang.String mCotaFilePath = "";
    private static final java.lang.String mCotaParaCfgDir = "emcom/noncell";
    private static java.lang.String mSysFilePath = "";
    private android.bluetooth.BluetoothAdapter mAdapter = null;
    private final android.content.ContentResolver mContentResolver;
    private android.content.Context mContext;
    private int mCotaConfigVersion = 0;
    private java.io.File mCotaFile;
    private java.lang.String mCpSavedEmuiVersion = "";
    private int mSavedConfigVersion = 0;
    private boolean mSendBroadcastToApk = false;
    private int mSysConfigVersion = 0;
    private java.io.File mSysFile;
    private java.lang.String mSystemEmuiVersion = "";
    private int mToBeSavedBtInteropVersion = 0;
    private final android.content.BroadcastReceiver myReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent == null) {
                com.android.server.HwLog.w("BluetoothParaManager", "BT_PARA onReceive: intent is null");
                return;
            }
            java.lang.String action = intent.getAction();
            if (action == null) {
                com.android.server.HwLog.w("BluetoothParaManager", "BT_PARA onReceive: get null for intent.getAction()");
                return;
            }
            if (action.equals("huawei.intent.action.ACTION_EMCOM_PARA_READY")) {
                int cotaParaBitRec = intent.getIntExtra("EXTRA_EMCOM_PARA_READY_REC", 0);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BT_PARA onReceive: cotaParaBitRec:");
                stringBuilder.append(cotaParaBitRec);
                com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
                if ((cotaParaBitRec & 16) == 0) {
                    com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA onReceive: broadcast is not for bt");
                    return;
                }
                com.android.server.BluetoothParaManager.this.getCoteParaFilePath();
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BT_PARA broadcast mSysFilePath:");
                stringBuilder.append(com.android.server.BluetoothParaManager.mSysFilePath);
                com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BT_PARA broadcast mCotaFilePath:");
                stringBuilder.append(com.android.server.BluetoothParaManager.mCotaFilePath);
                com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
                com.android.server.BluetoothParaManager.this.mSysFile = new java.io.File(com.android.server.BluetoothParaManager.mSysFilePath);
                com.android.server.BluetoothParaManager.this.mCotaFile = new java.io.File(com.android.server.BluetoothParaManager.mCotaFilePath);
                new com.android.server.BluetoothParaManager.ParseBtInteropXmlThread(true).start();
            }
        }
    };

    class ParseBtInteropXmlThread extends java.lang.Thread {
        boolean mIsCotaBroadcast;

        ParseBtInteropXmlThread(boolean cotaBroadcast) {
            this.mIsCotaBroadcast = cotaBroadcast;
        }

        /* JADX WARNING: Missing block: B:40:0x01d7, code:
            return;
     */
        public synchronized void run() {
            /*
            r6 = this;
            monitor-enter(r6);
            r0 = "BluetoothParaManager";
            r1 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01e7 }
            r1.<init>();	 Catch:{ all -> 0x01e7 }
            r2 = "BT_PARA start parse BtInterop config file: is cota ";
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r2 = r6.mIsCotaBroadcast;	 Catch:{ all -> 0x01e7 }
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r1 = r1.toString();	 Catch:{ all -> 0x01e7 }
            com.android.server.HwLog.d(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mSysFile;	 Catch:{ all -> 0x01e7 }
            r1 = r1.getConfigVersion(r2);	 Catch:{ all -> 0x01e7 }
            r0.mSysConfigVersion = r1;	 Catch:{ all -> 0x01e7 }
            r0 = "BluetoothParaManager";
            r1 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01e7 }
            r1.<init>();	 Catch:{ all -> 0x01e7 }
            r2 = "BT_PARA mSysConfigVersion:";
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mSysConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r1 = r1.toString();	 Catch:{ all -> 0x01e7 }
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mCotaFile;	 Catch:{ all -> 0x01e7 }
            r1 = r1.getConfigVersion(r2);	 Catch:{ all -> 0x01e7 }
            r0.mCotaConfigVersion = r1;	 Catch:{ all -> 0x01e7 }
            r0 = "BluetoothParaManager";
            r1 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01e7 }
            r1.<init>();	 Catch:{ all -> 0x01e7 }
            r2 = "BT_PARA mCotaConfigVersion:";
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r1 = r1.toString();	 Catch:{ all -> 0x01e7 }
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.getSavedConfigVersion();	 Catch:{ all -> 0x01e7 }
            r0.mSavedConfigVersion = r1;	 Catch:{ all -> 0x01e7 }
            r0 = "BluetoothParaManager";
            r1 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01e7 }
            r1.<init>();	 Catch:{ all -> 0x01e7 }
            r2 = "BT_PARA mSavedConfigVersion:";
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mSavedConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1.append(r2);	 Catch:{ all -> 0x01e7 }
            r1 = r1.toString();	 Catch:{ all -> 0x01e7 }
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = r6.mIsCotaBroadcast;	 Catch:{ all -> 0x01e7 }
            if (r0 != 0) goto L_0x0114;
        L_0x009e:
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r0 = r0.mSysConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mSavedConfigVersion;	 Catch:{ all -> 0x01e7 }
            if (r0 > r1) goto L_0x00c4;
        L_0x00ac:
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r0 = r0.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mSavedConfigVersion;	 Catch:{ all -> 0x01e7 }
            if (r0 <= r1) goto L_0x00bb;
        L_0x00ba:
            goto L_0x00c4;
        L_0x00bb:
            r0 = "BluetoothParaManager";
            r1 = "BT_PARA not need to parse xml";
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            goto L_0x01d6;
        L_0x00c4:
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r0 = r0.mSysConfigVersion;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            if (r0 < r1) goto L_0x00f3;
        L_0x00d2:
            r0 = "BluetoothParaManager";
            r1 = "BT_PARA need update system file";
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mSysConfigVersion;	 Catch:{ all -> 0x01e7 }
            r0.mToBeSavedBtInteropVersion = r1;	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mSysFile;	 Catch:{ all -> 0x01e7 }
            r2 = r6.mIsCotaBroadcast;	 Catch:{ all -> 0x01e7 }
            r0.updateBtInteropDataFromFile(r1, r2);	 Catch:{ all -> 0x01e7 }
            goto L_0x01d6;
        L_0x00f3:
            r0 = "BluetoothParaManager";
            r1 = "BT_PARA need update cota file";
            com.android.server.HwLog.i(r0, r1);	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            r0.mToBeSavedBtInteropVersion = r1;	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = r1.mCotaFile;	 Catch:{ all -> 0x01e7 }
            r2 = r6.mIsCotaBroadcast;	 Catch:{ all -> 0x01e7 }
            r0.updateBtInteropDataFromFile(r1, r2);	 Catch:{ all -> 0x01e7 }
            goto L_0x01d6;
        L_0x0114:
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1 = 0;
            r0.mSendBroadcastToApk = r1;	 Catch:{ all -> 0x01e7 }
            r0 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r0 = r0.mCotaFile;	 Catch:{ all -> 0x01e7 }
            r2 = r0.length();	 Catch:{ all -> 0x01e7 }
            r0 = (int) r2;
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ SecurityException -> 0x01d8 }
            r2 = r2.mCotaFile;	 Catch:{ SecurityException -> 0x01d8 }
            r2 = r2.exists();	 Catch:{ SecurityException -> 0x01d8 }
            if (r2 != 0) goto L_0x0158;
        L_0x0131:
            r2 = "BluetoothParaManager";
            r3 = new java.lang.StringBuilder;	 Catch:{ SecurityException -> 0x01d8 }
            r3.<init>();	 Catch:{ SecurityException -> 0x01d8 }
            r4 = "BT_PARA cotafile does not exist: ";
            r3.append(r4);	 Catch:{ SecurityException -> 0x01d8 }
            r4 = com.android.server.BluetoothParaManager.this;	 Catch:{ SecurityException -> 0x01d8 }
            r4 = r4.mCotaFile;	 Catch:{ SecurityException -> 0x01d8 }
            r4 = r4.exists();	 Catch:{ SecurityException -> 0x01d8 }
            r3.append(r4);	 Catch:{ SecurityException -> 0x01d8 }
            r3 = r3.toString();	 Catch:{ SecurityException -> 0x01d8 }
            com.android.server.HwLog.e(r2, r3);	 Catch:{ SecurityException -> 0x01d8 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ SecurityException -> 0x01d8 }
            r2.responseForParaUpdate(r1);	 Catch:{ SecurityException -> 0x01d8 }
            monitor-exit(r6);
            return;
            r1 = 10485760; // 0xa00000 float:1.469368E-38 double:5.180654E-317;
            r2 = 6;
            if (r0 < r1) goto L_0x017b;
        L_0x015e:
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01e7 }
            r3.<init>();	 Catch:{ all -> 0x01e7 }
            r4 = "BT_PARA cotaFileLength is too large: ";
            r3.append(r4);	 Catch:{ all -> 0x01e7 }
            r3.append(r0);	 Catch:{ all -> 0x01e7 }
            r3 = r3.toString();	 Catch:{ all -> 0x01e7 }
            r1.btParaFileError(r3);	 Catch:{ all -> 0x01e7 }
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r1.responseForParaUpdate(r2);	 Catch:{ all -> 0x01e7 }
            monitor-exit(r6);
            return;
        L_0x017b:
            r1 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = r3.mCotaFile;	 Catch:{ all -> 0x01e7 }
            r4 = "EMUI";
            r5 = "emui_version";
            r1 = r1.getVersion(r3, r4, r5);	 Catch:{ all -> 0x01e7 }
            if (r1 != 0) goto L_0x019b;
        L_0x018d:
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r4 = "BT_PARA get config file EMUI version failed.";
            r3.btParaFileError(r4);	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3.responseForParaUpdate(r2);	 Catch:{ all -> 0x01e7 }
            monitor-exit(r6);
            return;
        L_0x019b:
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r2 = r2.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = r3.mSavedConfigVersion;	 Catch:{ all -> 0x01e7 }
            if (r2 <= r3) goto L_0x01c9;
        L_0x01a9:
            r2 = "BluetoothParaManager";
            r3 = "BT_PARA cotaFile is newer than saved, need to parse";
            com.android.server.HwLog.i(r2, r3);	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = r3.mCotaConfigVersion;	 Catch:{ all -> 0x01e7 }
            r2.mToBeSavedBtInteropVersion = r3;	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = r3.mCotaFile;	 Catch:{ all -> 0x01e7 }
            r4 = r6.mIsCotaBroadcast;	 Catch:{ all -> 0x01e7 }
            r2.updateBtInteropDataFromFile(r3, r4);	 Catch:{ all -> 0x01e7 }
            goto L_0x01d6;
        L_0x01c9:
            r2 = "BluetoothParaManager";
            r3 = "BT_PARA cotaFile is not latest not need to parse ";
            com.android.server.HwLog.i(r2, r3);	 Catch:{ all -> 0x01e7 }
            r2 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3 = 4;
            r2.responseForParaUpdate(r3);	 Catch:{ all -> 0x01e7 }
        L_0x01d6:
            monitor-exit(r6);
            return;
        L_0x01d8:
            r2 = move-exception;
            r3 = "BluetoothParaManager";
            r4 = "BT_PARA mCotaFile exist or not exception";
            com.android.server.HwLog.e(r3, r4);	 Catch:{ all -> 0x01e7 }
            r3 = com.android.server.BluetoothParaManager.this;	 Catch:{ all -> 0x01e7 }
            r3.responseForParaUpdate(r1);	 Catch:{ all -> 0x01e7 }
            monitor-exit(r6);
            return;
        L_0x01e7:
            r0 = move-exception;
            monitor-exit(r6);
            throw r0;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.android.server.BluetoothParaManager.ParseBtInteropXmlThread.run():void");
        }
    }

    public BluetoothParaManager(android.content.Context context) {
        this.mContext = context;
        this.mContentResolver = this.mContext.getContentResolver();
        getCoteParaFilePath();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BT_PARA mSysFilePath:");
        stringBuilder.append(mSysFilePath);
        com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BT_PARA mCotaFilePath:");
        stringBuilder.append(mCotaFilePath);
        com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
        this.mSysFile = new java.io.File(mSysFilePath);
        this.mCotaFile = new java.io.File(mCotaFilePath);
        try {
            this.mSystemEmuiVersion = getProperty("ro.build.version.emui", "").substring(getProperty("ro.build.version.emui", "").lastIndexOf("_") + 1);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("BT_PARA emuiVersionString:");
            stringBuilder.append(this.mSystemEmuiVersion);
            com.android.server.HwLog.i("BluetoothParaManager", stringBuilder.toString());
        } catch (java.lang.Exception e) {
            this.mSystemEmuiVersion = "";
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA: FATAL ERROR - get system EMUI version failed");
        }
        android.content.IntentFilter intentFilter = new android.content.IntentFilter();
        intentFilter.addAction("huawei.intent.action.ACTION_EMCOM_PARA_READY");
        this.mContext.registerReceiver(this.myReceiver, intentFilter, "huawei.permission.RECEIVE_EMCOM_PARA_UPGRADE", null);
        compareEmuiVersion();
    }

    private void getCoteParaFilePath() {
        com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA getCoteParaFilePath() start");
        try {
            java.lang.String[] cfgFileInfo = huawei.cust.HwCfgFilePolicy.getDownloadCfgFile("emcom/noncell", "emcom/noncell/bt_interop.xml");
            java.lang.StringBuilder stringBuilder;
            if (cfgFileInfo == null) {
                com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA Both default and cota config files not exist");
            } else if (cfgFileInfo[0].contains("/cota")) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BT_PARA cota config file path is: ");
                stringBuilder.append(cfgFileInfo[0]);
                com.android.server.HwLog.i("BluetoothParaManager", stringBuilder.toString());
                mCotaFilePath = cfgFileInfo[0];
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BT_PARA system config file path is: ");
                stringBuilder.append(cfgFileInfo[0]);
                com.android.server.HwLog.i("BluetoothParaManager", stringBuilder.toString());
                mSysFilePath = cfgFileInfo[0];
            }
        } catch (java.lang.NoClassDefFoundError e) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA getCoteParaFilePath NoClassDefFoundError exception");
        } catch (java.lang.Exception e2) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA getCoteParaFilePath other exception");
        }
    }

    private void compareEmuiVersion() {
        this.mCpSavedEmuiVersion = android.provider.Settings.Global.getString(this.mContentResolver, "hw_bluetooth_interop_emui_version");
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BT_PARA contentProvider saved Emui is:");
        stringBuilder.append(this.mCpSavedEmuiVersion);
        com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
        if (this.mCpSavedEmuiVersion == null) {
            com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA contentProvider saved Emui is null");
            new com.android.server.BluetoothParaManager.ParseBtInteropXmlThread(false).start();
        } else if (this.mCpSavedEmuiVersion.equals(this.mSystemEmuiVersion)) {
            com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA contentProvider saved Emui is equals system emui version");
            new com.android.server.BluetoothParaManager.ParseBtInteropXmlThread(false).start();
        } else {
            java.lang.String systemFileEmuiVersion = getVersion(this.mSysFile, "EMUI", "emui_version");
            java.lang.String cotaFileEmuiVersion = getVersion(this.mCotaFile, "EMUI", "emui_version");
            if (systemFileEmuiVersion == null) {
                if (cotaFileEmuiVersion == null) {
                    com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA two files not exist");
                    cleanContentProvider();
                    return;
                }
            }
            com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA at least has one file exist");
            cleanContentProvider();
            new com.android.server.BluetoothParaManager.ParseBtInteropXmlThread(false).start();
        }
    }

    private void cleanContentProvider() {
        android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interop_version", null);
        android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_addr_list", null);
        android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_name_list", null);
        android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_manu_list", null);
        android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interop_emui_version", this.mSystemEmuiVersion);
        com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA clean ContentProvider success");
    }

    public void responseForParaUpdate(int result) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BT_PARA response result: ");
        stringBuilder.append(result);
        com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
        try {
            java.lang.Class<?> class1 = java.lang.Class.forName("android.emcom.EmcomManager");
            java.lang.Object objInstance = class1.getDeclaredMethod("getInstance", new java.lang.Class[0]).invoke(class1, new java.lang.Object[0]);
            if (objInstance != null) {
                class1.getDeclaredMethod("responseForParaUpgrade", new java.lang.Class[]{java.lang.Integer.TYPE, java.lang.Integer.TYPE, java.lang.Integer.TYPE}).invoke(objInstance, new java.lang.Object[]{java.lang.Integer.valueOf(16), java.lang.Integer.valueOf(1), java.lang.Integer.valueOf(result)});
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("BT_PARA response done with result: ");
                stringBuilder2.append(result);
                com.android.server.HwLog.i("BluetoothParaManager", stringBuilder2.toString());
            } else {
                com.android.server.HwLog.w("BluetoothParaManager", "BT_PARA objInstance() is null");
            }
        } catch (java.lang.NoSuchMethodException e) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA response exception: NoSuchMethod");
        } catch (java.lang.IllegalAccessException e2) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA response exception: IllegalAccessException");
        } catch (java.lang.ClassNotFoundException e3) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA response exception: EmcomManager not found");
        } catch (java.lang.Exception e4) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA response exception");
        }
    }

    private int getSavedConfigVersion() {
        int savedBtInteropVersion = 0;
        try {
            java.lang.String savedConfigVersionString = android.provider.Settings.Global.getString(this.mContentResolver, "hw_bluetooth_interop_version");
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("BT_PARA contentProvider saved config version is:");
            stringBuilder.append(savedConfigVersionString);
            com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
            if (savedConfigVersionString != null) {
                savedBtInteropVersion = java.lang.Integer.parseInt(savedConfigVersionString);
            } else {
                com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA savedConfigVersionString is null");
            }
            return savedBtInteropVersion;
        } catch (java.lang.NumberFormatException e) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA savedConfigVersionString :invalid string:");
            return 0;
        } catch (java.lang.Exception e2) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA getSavedConfigVersion:invalid string:");
            return 0;
        } catch (Throwable th) {
            return 0;
        }
    }

    private int getConfigVersion(java.io.File file) {
        int btInteropVersion = 0;
        java.lang.String emuiVersionString = "";
        try {
            if (file.exists()) {
                if (getVersion(file, "EMUI", "emui_version") == null) {
                    btParaFileError("BT_PARA get file EMUI is null");
                } else if (getVersion(file, "EMUI", "config_version") == null) {
                    btParaFileError("BT_PARA get file BT is null");
                } else {
                    java.lang.String btVersionString = getVersion(file, "EMUI", "config_version").trim();
                    if ("".equals(btVersionString)) {
                        btParaFileError("BT_PARA btVersionString: empty string");
                    } else {
                        btInteropVersion = java.lang.Integer.parseInt(btVersionString);
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("BT_PARA file btInteropVersion:");
                        stringBuilder.append(btInteropVersion);
                        com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
                    }
                }
                return 0;
            }
            com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA file not exist");
            return btInteropVersion;
        } catch (java.lang.NumberFormatException e) {
            btParaFileError("BT_PARA btVersionString: invalid string");
            return 0;
        } catch (java.lang.Exception e2) {
            btParaFileError("BT_PARA getConfigVersion Exception:");
            return 0;
        } catch (Throwable th) {
            return 0;
        }
    }

    private void updateBtInteropDataFromFile(java.io.File btInteropFile, boolean isCotaBroadcast) {
        java.io.InputStream btInteropIs = null;
        try {
            if (btInteropFile.exists()) {
                btInteropIs = new java.io.FileInputStream(btInteropFile);
                if (btInteropIs.available() == 0) {
                    if (isCotaBroadcast) {
                        responseForParaUpdate(6);
                    }
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA inputstream available() is 0");
                    try {
                        btInteropIs.close();
                    } catch (java.io.IOException e) {
                        com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA btInteropFile close IOException:");
                    }
                    return;
                }
                parserXMLPULL(btInteropIs, isCotaBroadcast);
                if (isCotaBroadcast) {
                    if (this.mSendBroadcastToApk) {
                        this.mAdapter = android.bluetooth.BluetoothAdapter.getDefaultAdapter();
                        if (this.mAdapter.getState() != 12) {
                            if (this.mAdapter.getState() != 11) {
                                com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA bt state is not state on or state_turning_on not need to send broadcast");
                                responseForParaUpdate(7);
                                this.mSendBroadcastToApk = false;
                            }
                        }
                        android.content.Intent intent = new android.content.Intent();
                        intent.setAction("com.huawei.android.bluetooth.ACTION_BT_PARA_UPDATE");
                        this.mContext.sendBroadcast(intent, "com.huawei.android.bluetooth.permission.BT_PARA_UPDATE");
                        com.android.server.HwLog.i("BluetoothParaManager", "BT_PARA send broadcast to app done");
                        this.mSendBroadcastToApk = false;
                    } else {
                        btParaFileError("BT_PARA xml file format is incorrect");
                        responseForParaUpdate(6);
                    }
                }
                try {
                    btInteropIs.close();
                } catch (java.io.IOException e2) {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA btInteropFile close IOException:");
                }
                return;
            }
            if (isCotaBroadcast) {
                com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA ERROR - cota file does not exist");
                responseForParaUpdate(0);
            }
            if (btInteropIs != null) {
                try {
                    btInteropIs.close();
                } catch (java.io.IOException e3) {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA btInteropFile close IOException:");
                }
            }
        } catch (java.io.FileNotFoundException e4) {
            if (isCotaBroadcast) {
                responseForParaUpdate(0);
            }
            btParaFileError("BT_PARA updateBtInteropDataFromFile FileNotFoundException");
            if (btInteropIs != null) {
                btInteropIs.close();
            }
        } catch (java.io.IOException e5) {
            if (isCotaBroadcast) {
                responseForParaUpdate(6);
            }
            btParaFileError("BT_PARA updateBtInteropDataFromFile IOException");
            if (btInteropIs != null) {
                btInteropIs.close();
            }
        } catch (java.lang.Exception e6) {
            if (isCotaBroadcast) {
                responseForParaUpdate(6);
            }
            btParaFileError("BT_PARA updateBtInteropDataFromFile Exception");
            if (btInteropIs != null) {
                btInteropIs.close();
            }
        } catch (Throwable th) {
            if (btInteropIs != null) {
                try {
                    btInteropIs.close();
                } catch (java.io.IOException e7) {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA btInteropFile close IOException:");
                }
            }
        }
    }

    private java.lang.String getVersion(java.io.File file, java.lang.String versionTag, java.lang.String attributeTag) {
        java.lang.String result = null;
        java.io.InputStream is = null;
        if (versionTag == null) {
            com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA versionTag is null");
            return null;
        }
        try {
            if (file.exists()) {
                org.xmlpull.v1.XmlPullParser versionParser = org.xmlpull.v1.XmlPullParserFactory.newInstance().newPullParser();
                is = new java.io.FileInputStream(file);
                if (is.available() != 0) {
                    versionParser.setInput(is, "UTF-8");
                    for (int type = versionParser.getEventType(); type != 1; type = versionParser.next()) {
                        if (type == 2 && versionTag.equals(versionParser.getName())) {
                            result = versionParser.getAttributeValue(null, attributeTag);
                            break;
                        }
                    }
                } else {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA getVersion: is.available() == 0");
                    try {
                        is.close();
                    } catch (java.io.IOException e) {
                        com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException:");
                    }
                    return null;
                }
            }
            if (is != null) {
                try {
                    is.close();
                } catch (java.io.IOException e2) {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException:");
                }
            }
        } catch (org.xmlpull.v1.XmlPullParserException e3) {
            btParaFileError("BT_PARA getVersion Parser Exception");
            if (is != null) {
                is.close();
            }
        } catch (java.io.IOException e4) {
            btParaFileError("BT_PARA getVersion IOException");
            if (is != null) {
                is.close();
            }
        } catch (java.lang.Exception e5) {
            btParaFileError("BT_PARA getVersion Exception");
            if (is != null) {
                is.close();
            }
        } catch (Throwable th) {
            if (is != null) {
                try {
                    is.close();
                } catch (java.io.IOException e6) {
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException:");
                }
            }
        }
        return result;
    }

    private void parserXMLPULL(java.io.InputStream is, boolean isCotaBroadcast) {
        java.io.IOException iOException;
        java.io.InputStream inputStream = is;
        boolean z = isCotaBroadcast;
        try {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("parserXMLPULL: isCota ");
            stringBuilder.append(z);
            com.android.server.HwLog.d("BluetoothParaManager", stringBuilder.toString());
            if (is.available() == 0) {
                if (z) {
                    responseForParaUpdate(6);
                }
                com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA ERROR - file does not exist");
                if (inputStream != null) {
                    try {
                        is.close();
                    } catch (java.io.IOException e) {
                        iOException = e;
                        com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException in parserXMLPULL:");
                    }
                }
                return;
            }
            java.lang.String addr_str = null;
            java.lang.String name_str = null;
            java.lang.String manufacture_str = null;
            java.lang.Object platformName = "";
            java.lang.String tag_name = "";
            java.lang.String databasesName = "";
            java.lang.String releaseName = "";
            java.lang.String configName = "";
            boolean firstHalfFormateCorrect = false;
            org.xmlpull.v1.XmlPullParserFactory xpf = org.xmlpull.v1.XmlPullParserFactory.newInstance();
            org.xmlpull.v1.XmlPullParser parser = xpf.newPullParser();
            parser.setInput(inputStream, "UTF-8");
            int type = parser.getEventType();
            while (type != 1) {
                org.xmlpull.v1.XmlPullParserFactory xpf2;
                java.lang.String addr_str2;
                if (type != 0) {
                    switch (type) {
                        case 2:
                            xpf2 = xpf;
                            addr_str2 = addr_str;
                            xpf = parser.getName();
                            if ("databases".equals(xpf)) {
                                databasesName = "databases";
                            }
                            if ("release".equals(xpf) && "databases".equals(databasesName)) {
                                releaseName = "release";
                            }
                            if ("config".equals(xpf) && "release".equals(releaseName)) {
                                configName = "config";
                            }
                            if ("platform".equals(xpf) && "config".equals(configName)) {
                                platformName = "platform";
                                firstHalfFormateCorrect = true;
                            }
                            if ("platform".equals(platformName)) {
                                if ("interop_addr".equals(xpf)) {
                                    addr_str2 = handleString(parser.nextText());
                                }
                                if ("interop_name".equals(xpf)) {
                                    name_str = handleString(parser.nextText());
                                }
                                if ("interop_manufacture".equals(xpf)) {
                                    manufacture_str = handleString(parser.nextText());
                                    addr_str = manufacture_str;
                                }
                            }
                            org.xmlpull.v1.XmlPullParserFactory tag_name2 = xpf;
                            break;
                        case 3:
                            java.lang.String platformName2;
                            java.lang.String str;
                            xpf2 = xpf;
                            if (!("platform".equals(parser.getName()) == null || "platform".equals(platformName) == null)) {
                                platformName2 = "";
                            }
                            if (!("config".equals(parser.getName()) == null || !firstHalfFormateCorrect || "".equals(platformName2) == null)) {
                                configName = "";
                            }
                            if (!("release".equals(parser.getName()) == null || !firstHalfFormateCorrect || "".equals(configName) == null)) {
                                releaseName = "";
                            }
                            if ("databases".equals(parser.getName()) == null || !firstHalfFormateCorrect || "".equals(releaseName) == null) {
                                addr_str2 = addr_str;
                                str = platformName2;
                            } else {
                                com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA xml file formate is correct");
                                str = platformName2;
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interop_version", "0");
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_addr_list", addr_str);
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_name_list", name_str);
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interoperability_manu_list", manufacture_str);
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interop_emui_version", this.mSystemEmuiVersion);
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                addr_str2 = addr_str;
                                stringBuilder2.append(this.mToBeSavedBtInteropVersion);
                                stringBuilder2.append("");
                                android.provider.Settings.Global.putString(this.mContentResolver, "hw_bluetooth_interop_version", stringBuilder2.toString());
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("BT_PARA contentprovider saved xml config version is:");
                                stringBuilder3.append(this.mToBeSavedBtInteropVersion);
                                com.android.server.HwLog.w("BluetoothParaManager", stringBuilder3.toString());
                                xpf = "";
                                if (z) {
                                    this.mSendBroadcastToApk = true;
                                }
                                databasesName = xpf;
                            }
                            platformName = str;
                            break;
                        case 4:
                            xpf2 = xpf;
                            break;
                        default:
                            xpf2 = xpf;
                            com.android.server.HwLog.w("BluetoothParaManager", "BT_PARA parse file - default clause, unexpected.");
                            break;
                    }
                    addr_str2 = addr_str;
                } else {
                    xpf2 = xpf;
                    addr_str2 = addr_str;
                }
                addr_str = addr_str2;
                type = parser.next();
                xpf = xpf2;
            }
            if (inputStream != null) {
                try {
                    is.close();
                } catch (java.io.IOException e2) {
                    iOException = e2;
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException in parserXMLPULL:");
                }
            }
        } catch (org.xmlpull.v1.XmlPullParserException e3) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA parserXMLPULL exception: XmlPullParserException");
            if (inputStream != null) {
                is.close();
            }
        } catch (java.io.IOException e4) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA parserXMLPULL exception: IOException");
            if (inputStream != null) {
                is.close();
            }
        } catch (java.lang.Exception e5) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA parserXMLPULL exception: Exception");
            if (inputStream != null) {
                is.close();
            }
        } catch (java.lang.Throwable th) {
            java.lang.Throwable th2 = th;
            if (inputStream != null) {
                try {
                    is.close();
                } catch (java.io.IOException e22) {
                    java.io.IOException iOException2 = e22;
                    com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA is close IOException in parserXMLPULL:");
                }
            }
        }
    }

    private java.lang.String handleString(java.lang.String string) {
        java.lang.String result = "";
        if (string != null) {
            try {
                for (java.lang.String entry : string.split("\n")) {
                    java.lang.String entry2 = entry2.trim();
                    if ("".equals(entry2)) {
                        com.android.server.HwLog.d("BluetoothParaManager", "BT_PARA handleString entry is null ");
                    } else if (entry2.charAt(entry2.length() - 1) == ';') {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(result);
                        stringBuilder.append(entry2);
                        result = stringBuilder.toString();
                    }
                }
            } catch (java.lang.Exception e) {
                btParaFileError("BT_PARA handleString Exception");
            } catch (Throwable th) {
            }
        }
        return result;
    }

    private void btParaFileError(java.lang.String msg) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BT_PARA_FILE_WARNING ");
        stringBuilder.append(msg);
        com.android.server.HwLog.e("BluetoothParaManager", stringBuilder.toString());
    }

    public static java.lang.String getProperty(java.lang.String key, java.lang.String defaultValue) {
        java.lang.String value = defaultValue;
        try {
            java.lang.Class<?> c = java.lang.Class.forName("android.os.SystemProperties");
            return (java.lang.String) c.getMethod("get", new java.lang.Class[]{java.lang.String.class, java.lang.String.class}).invoke(c, new java.lang.Object[]{key, "unknown"});
        } catch (java.lang.Exception e) {
            com.android.server.HwLog.e("BluetoothParaManager", "BT_PARA getProperty: e:");
        } catch (Throwable th) {
        }
        return value;
    }
}
