package com.android.server.GcmFixer;

public class GcmHeartBeatFixer {
    private static final java.lang.String ACTION_BACKGROUND_DATA_CHANGED = "com.huawei.systemmanager.changedata";
    private static final boolean FEATURE_GCM_FIXER = android.os.SystemProperties.getBoolean("ro.config.pg_gcm_fixer", true);
    private static final java.lang.String GMS_PACKAGE_NAME = "com.google.android.gms";
    private static final int INTERNAL_POWERGENIE = 300000;
    private static final int INTERNAL_WINDOW = 60000;
    private static final int INTERVAL_MOBILE_HB = android.os.SystemProperties.getInt("persist.sys.gcm.mobile", 300000);
    private static final int INTERVAL_WIFI_HB = android.os.SystemProperties.getInt("persist.sys.gcm.wifi", 300000);
    private static final boolean IS_SUPPORT_BACKGROUNDDATA = android.os.SystemProperties.getBoolean("ro.config.bg_data_switch", false);
    private static final java.lang.String TAG = "GcmHeartBeatFixer";
    private static int sGmsUid = -1;
    private static boolean sHasReceiverRegistered = false;
    private static com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState sNetworkState = com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState.UNKNOWN;

    private enum NetworkState {
        UNKNOWN,
        CONNECTED,
        DISCONNECTED
    }

    public static void scheduleHeartbeatRequest(android.content.Context context, boolean fromNetworkStateChange, boolean adjust) {
        if (!FEATURE_GCM_FIXER) {
            android.util.Slog.i("GcmHeartBeatFixer", "Gcm fixer is close...");
        } else if (isChinaMarket()) {
            android.util.Slog.i("GcmHeartBeatFixer", "China market version, just return...");
        } else {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("scheduleHeartbeatRequest, fromNetworkStateChange: ");
            stringBuilder.append(fromNetworkStateChange);
            android.util.Slog.i("GcmHeartBeatFixer", stringBuilder.toString());
            android.net.NetworkInfo activeNetworkInfo = ((android.net.ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
            if (IS_SUPPORT_BACKGROUNDDATA) {
                init(context);
                if (!isMobileAccessRestrict(context) && activeNetworkInfo != null && activeNetworkInfo.isConnected() && activeNetworkInfo.getType() == 0) {
                    android.util.Slog.i("GcmHeartBeatFixer", "gms bacground mobile data is disabled!");
                    cancelHeartbeatRequest(context);
                    return;
                }
            }
            if (activeNetworkInfo == null || !activeNetworkInfo.isConnected()) {
                if (!(fromNetworkStateChange && sNetworkState == com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState.DISCONNECTED)) {
                    sNetworkState = com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState.DISCONNECTED;
                    cancelHeartbeatRequest(context);
                }
            } else if (!(fromNetworkStateChange && sNetworkState == com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState.CONNECTED)) {
                int intervalMillis;
                sNetworkState = com.android.server.GcmFixer.GcmHeartBeatFixer.NetworkState.CONNECTED;
                if (activeNetworkInfo.getType() == 1) {
                    intervalMillis = INTERVAL_WIFI_HB;
                } else {
                    intervalMillis = INTERVAL_MOBILE_HB;
                }
                setNextHeartbeatRequest(context, intervalMillis, adjust);
            }
        }
    }

    private static void setNextHeartbeatRequest(android.content.Context context, int intervalMillis, boolean adjust) {
        long triggerAtMillis;
        int i = intervalMillis;
        android.app.AlarmManager alarmManager = (android.app.AlarmManager) context.getSystemService("alarm");
        long currentTime = java.lang.System.currentTimeMillis();
        if (adjust && i == 300000) {
            long elapsedTime = android.os.SystemClock.elapsedRealtime();
            long t_elapsedTime = ((elapsedTime / ((long) i)) + 1) * ((long) i);
            long diff = t_elapsedTime - elapsedTime;
            triggerAtMillis = currentTime + diff;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("currentTime: ");
            stringBuilder.append(currentTime);
            stringBuilder.append(" elapsedTime:");
            stringBuilder.append(elapsedTime);
            stringBuilder.append(" t_elapsedTime:");
            stringBuilder.append(t_elapsedTime);
            stringBuilder.append(" triggerAtMillis:");
            stringBuilder.append(triggerAtMillis);
            stringBuilder.append(" diff:");
            stringBuilder.append(diff);
            android.util.Slog.i("GcmHeartBeatFixer", stringBuilder.toString());
        } else {
            triggerAtMillis = currentTime + ((long) i);
        }
        long triggerAtMillis2 = triggerAtMillis;
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("setNextHeartbeatRequest at: ");
        stringBuilder2.append(android.text.format.DateFormat.format("yyyy-MM-dd hh:mm:ss", triggerAtMillis2));
        android.util.Slog.i("GcmHeartBeatFixer", stringBuilder2.toString());
        android.app.PendingIntent broadcastPendingIntent = getBroadcastPendingIntent(context);
        if (android.os.Build.VERSION.SDK_INT >= 19) {
            alarmManager.setWindow(0, triggerAtMillis2, 60000, broadcastPendingIntent);
        } else {
            alarmManager.set(0, triggerAtMillis2, broadcastPendingIntent);
        }
    }

    private static void cancelHeartbeatRequest(android.content.Context context) {
        android.util.Slog.d("GcmHeartBeatFixer", "cancelHeartbeatRequest...");
        ((android.app.AlarmManager) context.getSystemService("alarm")).cancel(getBroadcastPendingIntent(context));
    }

    private static android.app.PendingIntent getBroadcastPendingIntent(android.content.Context context) {
        return android.app.PendingIntent.getBroadcast(context, 0, new android.content.Intent("com.android.intent.action.HEARTBEAT_FIXER"), 0);
    }

    public static boolean isChinaMarket() {
        if (android.os.SystemProperties.getInt("ro.config.hw_optb", 0) == 156) {
            return true;
        }
        return false;
    }

    private static void init(android.content.Context content) {
        if (!sHasReceiverRegistered) {
            sHasReceiverRegistered = true;
            try {
                sGmsUid = content.getPackageManager().getPackageUid("com.google.android.gms", 0);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("sGmsUid =");
                stringBuilder.append(sGmsUid);
                android.util.Slog.i("GcmHeartBeatFixer", stringBuilder.toString());
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                android.util.Slog.e("GcmHeartBeatFixer", "gms not found");
            }
            android.content.BroadcastReceiver backgroundDataReceiver = new android.content.BroadcastReceiver() {
                public void onReceive(android.content.Context receiverContext, android.content.Intent intent) {
                    if ("com.huawei.systemmanager.changedata".equals(intent.getAction())) {
                        android.net.NetworkInfo activeNetworkInfo = ((android.net.ConnectivityManager) receiverContext.getSystemService("connectivity")).getActiveNetworkInfo();
                        if (activeNetworkInfo != null && activeNetworkInfo.isConnected()) {
                            java.lang.String pkgName = intent.getStringExtra("packagename");
                            if ("com.google.android.gms".equals(pkgName)) {
                                boolean mobileAccess = intent.getIntExtra("switch", 0) == 1;
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("com.huawei.systemmanager.changedata mobileAccess = ");
                                stringBuilder.append(mobileAccess);
                                android.util.Slog.i("GcmHeartBeatFixer", stringBuilder.toString());
                                if (activeNetworkInfo.getType() != 0) {
                                    android.util.Slog.i("GcmHeartBeatFixer", "wifi connection not control");
                                } else if (!mobileAccess) {
                                    android.util.Slog.i("GcmHeartBeatFixer", "com.huawei.systemmanager.changedata, gms bacground mobile data disabled! cancel heartbeat.");
                                    com.android.server.GcmFixer.GcmHeartBeatFixer.cancelHeartbeatRequest(receiverContext);
                                } else if (mobileAccess) {
                                    android.util.Slog.i("GcmHeartBeatFixer", "com.huawei.systemmanager.changedata, gms bacground mobile data enabled and trigger heartbeat!");
                                    android.content.Intent GTALK_HEART_BEAT_INTENT = new android.content.Intent("com.google.android.intent.action.GTALK_HEARTBEAT");
                                    android.content.Intent MCS_MCS_HEARTBEAT_INTENT = new android.content.Intent("com.google.android.intent.action.MCS_HEARTBEAT");
                                    receiverContext.sendBroadcast(GTALK_HEART_BEAT_INTENT);
                                    receiverContext.sendBroadcast(MCS_MCS_HEARTBEAT_INTENT);
                                    com.android.server.GcmFixer.GcmHeartBeatFixer.scheduleHeartbeatRequest(receiverContext, false, true);
                                }
                            } else {
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("com.huawei.systemmanager.changedata  ignore pkgName ");
                                stringBuilder2.append(pkgName);
                                android.util.Slog.i("GcmHeartBeatFixer", stringBuilder2.toString());
                            }
                        }
                    }
                }
            };
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("com.huawei.systemmanager.changedata");
            content.registerReceiver(backgroundDataReceiver, filter, "android.permission.CONNECTIVITY_INTERNAL", null);
            android.util.Slog.i("GcmHeartBeatFixer", " init complete!");
        }
    }

    private static boolean isMobileAccessRestrict(android.content.Context context) {
        return (android.net.HwNetworkPolicyManager.from(context).getHwUidPolicy(sGmsUid) & 1) == 0;
    }
}
