package com.android.server;

public class HwAttestationService extends com.huawei.attestation.IHwAttestationService.Stub {
    private static final java.lang.String EMMC_CONFIG_FILE = "/sys/block/mmcblk0/device/cid";
    private static final java.lang.String HW_DEVICE_ATTESTATION_ACCESS = "com.huawei.deviceattestation.HW_DEVICE_ATTESTATION_ACCESS";
    private static int MAX_SING_DTAT_LEN = 512;
    private static int OPEN_REASE_MATCH_NUM = 0;
    private static final java.lang.String PERMISSION_DEVICE_ATTESTATION = "com.huawei.permission.MANAGE_DEVICE_ATTESTATION";
    private static final java.lang.String PERMISSION_DEVICE_READ_PHONE_STATE = "android.permission.READ_PHONE_STATE";
    private static final java.lang.String TAG = "HwAttestationService";
    private int lastError = 0;
    private android.content.Context mContext;
    private com.android.server.HwSignature mSignTool;

    public HwAttestationService(android.content.Context context) {
        this.mContext = context;
        this.mSignTool = com.android.server.HwSignature.getInstance();
    }

    public int getLastError() {
        return this.lastError;
    }

    public byte[] getDeviceID(int deviceIdType) {
        if (!checkCallingPermission(android.os.Binder.getCallingUid()) && this.mContext.checkCallingPermission("android.permission.READ_PHONE_STATE") == -1) {
            android.util.Log.e("HwAttestationService", "permission denied");
            this.lastError = -5;
            return null;
        } else if (deviceIdType != 1) {
            return null;
        } else {
            byte[] emmcid = readEMMCIDByNative();
            if (emmcid.length > MAX_SING_DTAT_LEN) {
                return null;
            }
            return emmcid;
        }
    }

    public int getPublickKey(int keyIndex, byte[] keyBuf) {
        this.lastError = 0;
        if (keyIndex != 1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("not supprot keyIndex:");
            stringBuilder.append(keyIndex);
            android.util.Log.e("HwAttestationService", stringBuilder.toString());
            this.lastError = -4;
            return 0;
        } else if (keyBuf == null) {
            this.lastError = -4;
            return 0;
        } else {
            int actLen = this.mSignTool.getPublicKey(1, keyBuf);
            if (actLen <= 0) {
                this.lastError = -6;
            }
            return actLen;
        }
    }

    public byte[] getAttestationSignature(int keyIndex, int deviceIdType, java.lang.String signatureType, byte[] challenge) {
        if (!checkCallingPermission(android.os.Binder.getCallingUid()) && this.mContext.checkCallingPermission("android.permission.READ_PHONE_STATE") == -1) {
            android.util.Log.e("HwAttestationService", "permission denied");
            this.lastError = -5;
            return null;
        } else if (deviceIdType == 1) {
            return getAttestationSignatureByEMMCId(keyIndex, signatureType, challenge);
        } else {
            return null;
        }
    }

    public byte[] getAttestationSignatureWithPkgName(int keyIndex, int deviceIdType, java.lang.String signatureType, byte[] challenge, java.lang.String packageName) {
        if (packageName == null) {
            this.lastError = -4;
            return null;
        } else if (!checkCallingPermission(packageName)) {
            android.util.Log.e("HwAttestationService", "permission denied");
            this.lastError = -5;
            return null;
        } else if (deviceIdType == 1) {
            return getAttestationSignatureByEMMCId(keyIndex, signatureType, challenge, packageName);
        } else {
            return null;
        }
    }

    public byte[] getAttestationSignatureByEMMCId(int keyIndex, java.lang.String signatureType, byte[] challenge, java.lang.String packageName) {
        java.lang.String str = signatureType;
        byte[] bArr = challenge;
        java.lang.String str2 = packageName;
        if (keyIndex != 1) {
            this.lastError = -4;
            return null;
        }
        if (!(str == null || bArr == null)) {
            if (str2 != null) {
                if (str.getBytes(java.nio.charset.Charset.defaultCharset()).length <= MAX_SING_DTAT_LEN) {
                    if (bArr.length <= MAX_SING_DTAT_LEN) {
                        java.lang.String[] pkgList = this.mContext.getPackageManager().getPackagesForUid(android.os.Binder.getCallingUid());
                        java.lang.String[] strArr;
                        if (pkgList == null) {
                        } else if (pkgList.length == 0) {
                            strArr = pkgList;
                        } else {
                            boolean isCheckPkgName = false;
                            for (java.lang.String pkg : pkgList) {
                                if (str2.equals(pkg)) {
                                    isCheckPkgName = true;
                                    break;
                                }
                            }
                            if (!isCheckPkgName) {
                            } else if (str2.getBytes(java.nio.charset.Charset.defaultCharset()).length > MAX_SING_DTAT_LEN) {
                                strArr = pkgList;
                            } else {
                                byte[] emmcid = readEMMCIDByNative();
                                if (emmcid.length > MAX_SING_DTAT_LEN) {
                                    this.lastError = -3;
                                    return null;
                                } else if (this.mSignTool.checkKeyStatus(1) != 0) {
                                    this.lastError = -2;
                                    return null;
                                } else {
                                    this.lastError = 0;
                                    return this.mSignTool.signMessage(1, str2.getBytes(java.nio.charset.Charset.defaultCharset()), str2.getBytes(java.nio.charset.Charset.defaultCharset()).length, emmcid, emmcid.length, str.getBytes(java.nio.charset.Charset.defaultCharset()), str.getBytes(java.nio.charset.Charset.defaultCharset()).length, bArr, bArr.length);
                                }
                            }
                            this.lastError = -4;
                            return null;
                        }
                        this.lastError = -4;
                        return null;
                    }
                }
                this.lastError = -4;
                return null;
            }
        }
        this.lastError = -4;
        return null;
    }

    public byte[] getAttestationSignatureByEMMCId(int keyIndex, java.lang.String signatureType, byte[] challenge) {
        java.lang.String str = signatureType;
        byte[] bArr = challenge;
        if (keyIndex != 1) {
            this.lastError = -4;
            return null;
        }
        if (str != null) {
            if (bArr != null) {
                if (str.getBytes(java.nio.charset.Charset.defaultCharset()).length <= MAX_SING_DTAT_LEN) {
                    if (bArr.length <= MAX_SING_DTAT_LEN) {
                        java.lang.String pkgName = getPackageName(android.os.Binder.getCallingUid());
                        if (pkgName == null) {
                            this.lastError = -4;
                            return null;
                        } else if (pkgName.getBytes(java.nio.charset.Charset.defaultCharset()).length > MAX_SING_DTAT_LEN) {
                            this.lastError = -4;
                            return null;
                        } else {
                            byte[] emmcid = readEMMCIDByNative();
                            if (emmcid.length > MAX_SING_DTAT_LEN) {
                                this.lastError = -3;
                                return null;
                            } else if (this.mSignTool.checkKeyStatus(1) != 0) {
                                this.lastError = -2;
                                return null;
                            } else {
                                this.lastError = 0;
                                return this.mSignTool.signMessage(1, pkgName.getBytes(java.nio.charset.Charset.defaultCharset()), pkgName.getBytes(java.nio.charset.Charset.defaultCharset()).length, emmcid, emmcid.length, str.getBytes(java.nio.charset.Charset.defaultCharset()), str.getBytes(java.nio.charset.Charset.defaultCharset()).length, bArr, bArr.length);
                            }
                        }
                    }
                }
                this.lastError = -4;
                return null;
            }
        }
        this.lastError = -4;
        return null;
    }

    private java.lang.String getPackageName(int uid) {
        java.lang.String[] pkg = this.mContext.getPackageManager().getPackagesForUid(uid);
        if (pkg != null) {
            if (pkg.length != 0) {
                return pkg[0];
            }
        }
        return null;
    }

    private boolean checkCallingPermission(int uid) {
        boolean isCheckPermission = false;
        android.content.pm.PackageManager pm = this.mContext.getPackageManager();
        if (pm != null) {
            try {
                boolean z = false;
                if ((pm.getApplicationInfo(getPackageName(uid), 0).flags & 1) != 0) {
                    z = true;
                }
                isCheckPermission = z;
                if (!isCheckPermission && pm.checkSignatures(getPackageName(uid), "android") >= 0) {
                    isCheckPermission = true;
                }
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                android.util.Log.e("HwAttestationService", "NameNotFoundException in HwAttestationService.checkCallingPermission()", e);
            }
        }
        return isCheckPermission;
    }

    private boolean checkCallingPermission(java.lang.String pkgName) {
        boolean isCheckPermission = false;
        android.content.pm.PackageManager pm = this.mContext.getPackageManager();
        if (pm != null) {
            boolean z = false;
            try {
                if ((pm.getApplicationInfo(pkgName, 0).flags & 1) != 0) {
                    z = true;
                }
                isCheckPermission = z;
                if (!isCheckPermission && pm.checkSignatures(pkgName, "android") >= 0) {
                    isCheckPermission = true;
                }
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                android.util.Log.e("HwAttestationService", "NameNotFoundException in HwAttestationService.checkCallingPermission()", e);
            }
        }
        return isCheckPermission;
    }

    private byte[] readEMMCID() throws java.io.IOException {
        java.io.BufferedReader br = null;
        java.lang.StringBuffer sb = null;
        try {
            java.io.File file = new java.io.File("/sys/block/mmcblk0/device/cid");
            if (!file.exists() || file.isDirectory()) {
                throw new java.io.FileNotFoundException();
            }
            br = new java.io.BufferedReader(new java.io.FileReader(file));
            sb = new java.lang.StringBuffer();
            for (java.lang.String temp = br.readLine(); temp != null; temp = br.readLine()) {
                sb.append(temp);
            }
            try {
                br.close();
            } catch (java.io.File file2) {
                android.util.Log.e("HwAttestationService", "IOException in HwAttestationService.readEMMCID()", file2);
            }
            if (sb != null) {
                return sb.toString().getBytes(java.nio.charset.Charset.defaultCharset());
            }
            return null;
        } catch (java.io.IOException e) {
            android.util.Log.e("HwAttestationService", "IOException in HwAttestationService.readEMMCID()", e);
            if (br != null) {
                br.close();
            }
        } catch (Throwable th) {
            if (br != null) {
                try {
                    br.close();
                } catch (java.io.IOException e2) {
                    android.util.Log.e("HwAttestationService", "IOException in HwAttestationService.readEMMCID()", e2);
                }
            }
        }
    }

    private byte[] readEMMCIDByNative() {
        java.lang.String emmcid = com.huawei.information.HwDeviceInfo.getEMMCID();
        if (emmcid != null) {
            try {
                return emmcid.getBytes("UTF-8");
            } catch (java.io.UnsupportedEncodingException e) {
                e.printStackTrace();
            }
        }
        return new byte[0];
    }

    public int getDeviceCertType(int keyIndex) {
        this.lastError = 0;
        if (this.mContext.checkCallingPermission("com.huawei.permission.MANAGE_DEVICE_ATTESTATION") == -1) {
            android.util.Log.e("HwAttestationService", "permission denied");
            this.lastError = -5;
            return -1;
        } else if (keyIndex != 1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("not supprot keyIndex:");
            stringBuilder.append(keyIndex);
            android.util.Log.e("HwAttestationService", stringBuilder.toString());
            this.lastError = -4;
            return -1;
        } else {
            int certType = this.mSignTool.getDeviceCertType(keyIndex);
            if (certType < 0) {
                this.lastError = -7;
            }
            return certType;
        }
    }

    public int getDeviceCert(int keyIndex, int certType, byte[] certBuf) {
        this.lastError = 0;
        if (this.mContext.checkCallingPermission("com.huawei.permission.MANAGE_DEVICE_ATTESTATION") == -1) {
            android.util.Log.e("HwAttestationService", "permission denied");
            this.lastError = -5;
            return -1;
        } else if (keyIndex != 1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("not supprot keyIndex:");
            stringBuilder.append(keyIndex);
            android.util.Log.e("HwAttestationService", stringBuilder.toString());
            this.lastError = -4;
            return -1;
        } else if (certBuf == null) {
            android.util.Log.e("HwAttestationService", "certBuf is null");
            this.lastError = -4;
            return -1;
        } else {
            int certLen = this.mSignTool.getDeviceCert(keyIndex, certType, certBuf);
            if (certLen <= 0) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("getDeviceCert get cert fail: ");
                stringBuilder2.append(certLen);
                android.util.Log.e("HwAttestationService", stringBuilder2.toString());
                this.lastError = -8;
            }
            return certLen;
        }
    }
}
