package com.android.server;

public class HwAutoUpdate {
    private static final java.lang.String COMMOND_FILE = "/cache/recovery/command";
    private static final int SAFE_BATTERY_LEVEL = 50;
    private static final java.lang.String TAG = "HwAutoUpdate";
    private static final java.lang.String UPDATE_POWEROFF = "update_poweroff";
    private static final java.lang.String UPDATE_REBOOT = "update_reboot";
    private static com.android.server.HwAutoUpdate mInstance = null;

    private static class AutoupdateCommand {
        static final java.lang.String KEY_AUTOUPDATE = "--autoupdate";
        static final java.lang.String KEY_REBOOT = "--reboot";
        static final java.lang.String KEY_UPDATEPACKAGE = "--update_package";
        static final java.lang.String KEY_USER_FREESIZE = "--user_freesize";
        private java.lang.String autoupdate;
        private java.lang.String reboot;
        private java.lang.String update_package;
        private long user_freesize;

        private AutoupdateCommand() {
            this.user_freesize = 0;
        }

        public void setUpdatePackage(java.lang.String update_package) {
            this.update_package = update_package.trim();
        }

        public void setAutoDate(java.lang.String autoupdate) {
            this.autoupdate = autoupdate.trim();
        }

        public void setReboot(java.lang.String reboot) {
            this.reboot = reboot.trim();
        }

        public void setUserFreeSize(java.lang.String user_freesize) {
            try {
                this.user_freesize = java.lang.Long.parseLong(user_freesize.trim());
            } catch (java.lang.NumberFormatException e) {
                android.util.Log.i("HwAutoUpdate", "auto update command parse user_freesize error");
                this.user_freesize = -1;
            }
        }

        public java.lang.String getUpdatePackage() {
            return this.update_package;
        }

        public boolean isAutoUpdate() {
            if (this.autoupdate == null) {
                return false;
            }
            return "TRUE".equals(this.autoupdate.toUpperCase(java.util.Locale.ENGLISH));
        }

        public java.lang.String getReboot() {
            return this.reboot;
        }

        public long getUserFreeSize() {
            return this.user_freesize;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder command = new java.lang.StringBuilder();
            if (!android.text.TextUtils.isEmpty(this.update_package)) {
                command.append("--update_package");
                command.append("=");
                command.append(this.update_package);
                command.append("\r\n");
            }
            if (!android.text.TextUtils.isEmpty(this.autoupdate)) {
                command.append("--autoupdate");
                command.append("=");
                command.append(this.autoupdate);
                command.append("\r\n");
            }
            if (!android.text.TextUtils.isEmpty(this.reboot)) {
                command.append("--reboot");
                command.append("=");
                command.append(this.reboot);
                command.append("\r\n");
            }
            command.append("--user_freesize");
            command.append("=");
            command.append(this.user_freesize);
            command.append("\r\n");
            return command.toString();
        }
    }

    public static com.android.server.HwAutoUpdate getInstance() {
        if (mInstance == null) {
            mInstance = new com.android.server.HwAutoUpdate();
        }
        return mInstance;
    }

    public boolean isAutoSystemUpdate(android.content.Context context, boolean reboot) {
        int automatic = android.provider.Settings.Global.getInt(context.getContentResolver(), "ota_disable_automatic_update", 0);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("automatic switch ");
        stringBuilder.append(automatic);
        android.util.Log.i("HwAutoUpdate", stringBuilder.toString());
        if (automatic != 0) {
            return false;
        }
        if (getBatteryLevelValue(context) > 50) {
            com.android.server.HwAutoUpdate.AutoupdateCommand autoupdateCommand = getCommand("/cache/recovery/command");
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("autoupdateCommand : ");
            stringBuilder2.append(autoupdateCommand.toString());
            android.util.Log.d("HwAutoUpdate", stringBuilder2.toString());
            if (autoupdateCommand.isAutoUpdate() && isUserFreeSizeEnough(autoupdateCommand)) {
                java.lang.StringBuilder reboot_reason = new java.lang.StringBuilder();
                reboot_reason.append("--reboot");
                reboot_reason.append("=");
                reboot_reason.append(reboot ? "update_reboot" : "update_poweroff");
                writeRebootReason("/cache/recovery/command", reboot_reason.toString());
                return true;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("current batteryLevel: ");
        stringBuilder.append(getBatteryLevelValue(context));
        stringBuilder.append(" <= safe value(50%), return");
        android.util.Log.d("HwAutoUpdate", stringBuilder.toString());
        return false;
    }

    private com.android.server.HwAutoUpdate.AutoupdateCommand getCommand(java.lang.String filePath) {
        return getCommondFormFile(filePath);
    }

    private com.android.server.HwAutoUpdate.AutoupdateCommand getCommondFormFile(java.lang.String filePath) {
        java.io.BufferedReader reader = null;
        java.io.FileInputStream in = null;
        com.android.server.HwAutoUpdate.AutoupdateCommand autoupdateCommand = new com.android.server.HwAutoUpdate.AutoupdateCommand();
        try {
            in = new java.io.FileInputStream(filePath);
            reader = new java.io.BufferedReader(new java.io.InputStreamReader(in, "UTF-8"));
            while (true) {
                java.lang.String readLine = reader.readLine();
                java.lang.String line = readLine;
                if (readLine == null) {
                    break;
                }
                parseCommand(line, autoupdateCommand);
            }
            try {
                in.close();
            } catch (java.io.IOException e) {
                android.util.Log.w("HwAutoUpdate", "getCommondFormFile FileInputStream close error");
            }
            try {
                reader.close();
            } catch (java.io.IOException e2) {
                android.util.Log.w("HwAutoUpdate", "getCommondFormFile BufferedReader close error");
            }
        } catch (java.io.IOException e3) {
            android.util.Log.e("HwAutoUpdate", "getCommondFormFile ", e3);
            if (in != null) {
                try {
                    in.close();
                } catch (java.io.IOException e4) {
                    android.util.Log.w("HwAutoUpdate", "getCommondFormFile FileInputStream close error");
                }
            }
            if (reader != null) {
                reader.close();
            }
        } catch (Throwable th) {
            if (in != null) {
                try {
                    in.close();
                } catch (java.io.IOException e5) {
                    android.util.Log.w("HwAutoUpdate", "getCommondFormFile FileInputStream close error");
                }
            }
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e6) {
                    android.util.Log.w("HwAutoUpdate", "getCommondFormFile BufferedReader close error");
                }
            }
        }
        return autoupdateCommand;
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0068  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0068  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0068  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0068  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0062  */
    private void parseCommand(java.lang.String r9, com.android.server.HwAutoUpdate.AutoupdateCommand r10) {
        /*
        r8 = this;
        r0 = android.text.TextUtils.isEmpty(r9);
        if (r0 == 0) goto L_0x0007;
    L_0x0006:
        return;
    L_0x0007:
        r0 = "=";
        r0 = r9.split(r0);
        r1 = r0.length;
        r2 = 2;
        if (r2 != r1) goto L_0x007b;
    L_0x0011:
        r1 = 0;
        r3 = r0[r1];
        r4 = -1;
        r5 = r3.hashCode();
        r6 = -1453042472; // 0xffffffffa96454d8 float:-5.069976E-14 double:NaN;
        r7 = 1;
        if (r5 == r6) goto L_0x004c;
    L_0x001f:
        r6 = -22157200; // 0xfffffffffeade870 float:-1.1558166E38 double:NaN;
        if (r5 == r6) goto L_0x0042;
    L_0x0024:
        r1 = 653154497; // 0x26ee58c1 float:1.6538624E-15 double:3.227011984E-315;
        if (r5 == r1) goto L_0x0038;
    L_0x0029:
        r1 = 1465075013; // 0x57534545 float:2.32294464E14 double:7.238432325E-315;
        if (r5 == r1) goto L_0x002f;
    L_0x002e:
        goto L_0x0056;
    L_0x002f:
        r1 = "--reboot";
        r1 = r3.equals(r1);
        if (r1 == 0) goto L_0x0056;
    L_0x0037:
        goto L_0x0057;
    L_0x0038:
        r1 = "--user_freesize";
        r1 = r3.equals(r1);
        if (r1 == 0) goto L_0x0056;
    L_0x0040:
        r2 = 3;
        goto L_0x0057;
    L_0x0042:
        r2 = "--update_package";
        r2 = r3.equals(r2);
        if (r2 == 0) goto L_0x0056;
    L_0x004a:
        r2 = r1;
        goto L_0x0057;
    L_0x004c:
        r1 = "--autoupdate";
        r1 = r3.equals(r1);
        if (r1 == 0) goto L_0x0056;
    L_0x0054:
        r2 = r7;
        goto L_0x0057;
    L_0x0056:
        r2 = r4;
    L_0x0057:
        switch(r2) {
            case 0: goto L_0x0074;
            case 1: goto L_0x006e;
            case 2: goto L_0x0068;
            case 3: goto L_0x0062;
            default: goto L_0x005a;
        };
    L_0x005a:
        r1 = "HwAutoUpdate";
        r2 = "can not parse command";
        android.util.Log.w(r1, r2);
        goto L_0x007a;
    L_0x0062:
        r1 = r0[r7];
        r10.setUserFreeSize(r1);
        goto L_0x007a;
    L_0x0068:
        r1 = r0[r7];
        r10.setReboot(r1);
        goto L_0x007a;
    L_0x006e:
        r1 = r0[r7];
        r10.setAutoDate(r1);
        goto L_0x007a;
    L_0x0074:
        r1 = r0[r7];
        r10.setUpdatePackage(r1);
    L_0x007a:
        goto L_0x0082;
    L_0x007b:
        r1 = "HwAutoUpdate";
        r2 = "Error command";
        android.util.Log.w(r1, r2);
    L_0x0082:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.HwAutoUpdate.parseCommand(java.lang.String, com.android.server.HwAutoUpdate$AutoupdateCommand):void");
    }

    private void writeRebootReason(java.lang.String filePath, java.lang.String reason) {
        java.io.BufferedWriter writer = null;
        try {
            writer = new java.io.BufferedWriter(new java.io.OutputStreamWriter(new java.io.FileOutputStream(new java.io.File(filePath), true), "UTF-8"));
            writer.write(reason);
            try {
                writer.close();
            } catch (java.lang.Exception e) {
                android.util.Log.e("HwAutoUpdate", "writeRebootReason writer close error");
            }
        } catch (java.io.IOException e2) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("writeRebootReason error : ");
            stringBuilder.append(e2);
            android.util.Log.e("HwAutoUpdate", stringBuilder.toString());
            if (writer != null) {
                writer.close();
            }
        } catch (Throwable th) {
            if (writer != null) {
                try {
                    writer.close();
                } catch (java.lang.Exception e3) {
                    android.util.Log.e("HwAutoUpdate", "writeRebootReason writer close error");
                }
            }
        }
    }

    private int getBatteryLevelValue(android.content.Context context) {
        android.os.BatteryManager batteryManager = (android.os.BatteryManager) context.getSystemService("batterymanager");
        if (batteryManager == null) {
            android.util.Log.e("HwAutoUpdate", "batteryManager is null error");
            return -1;
        }
        int batteryLevel = batteryManager.getIntProperty(4);
        if (batteryLevel >= 0) {
            return batteryLevel;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getBatteryLevelValue failed, batteryLevel: ");
        stringBuilder.append(batteryLevel);
        android.util.Log.e("HwAutoUpdate", stringBuilder.toString());
        return -1;
    }

    private boolean isUserFreeSizeEnough(com.android.server.HwAutoUpdate.AutoupdateCommand autoupdateCommand) {
        long needUserFreeSize = autoupdateCommand.getUserFreeSize();
        if (-1 == needUserFreeSize) {
            return false;
        }
        if (0 == needUserFreeSize || getAvailableSize(android.os.Environment.getDataDirectory().getPath()) >= needUserFreeSize) {
            return true;
        }
        android.util.Log.i("HwAutoUpdate", "free size not enough");
        return false;
    }

    private long getAvailableSize(java.lang.String path) {
        try {
            android.os.StatFs state = new android.os.StatFs(path);
            long blocksize = (long) state.getBlockSize();
            long availableBlocks = (long) state.getAvailableBlocks();
            long availableSize = blocksize * availableBlocks;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getAvailableSize path : ");
            stringBuilder.append(path);
            stringBuilder.append(" availableSize =  (");
            stringBuilder.append(blocksize);
            stringBuilder.append("*");
            stringBuilder.append(availableBlocks);
            stringBuilder.append(") = ");
            stringBuilder.append(availableSize);
            android.util.Log.d("HwAutoUpdate", stringBuilder.toString());
            return availableSize;
        } catch (java.lang.IllegalArgumentException e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("getAvailableSize error : ");
            stringBuilder2.append(path);
            android.util.Log.e("HwAutoUpdate", stringBuilder2.toString(), e);
            return 0;
        }
    }
}
