package com.android.server;

public class HwBastetService extends com.android.server.SystemService {
    private static final int ACTION_BASTET_SET_DSCP = 10;
    private static final int ACTION_BASTET_UNSET_DSCP = 11;
    private static final int ACTION_BASTET_UPDATE_CONFIG = 9;
    private static final int ACTION_BOOT_COMPLETED = 3;
    private static final int ACTION_PACKAGE_ADDED = 4;
    private static final int ACTION_PACKAGE_CHANGED = 5;
    private static final int ACTION_PACKAGE_FIRST_LAUNCH = 7;
    private static final int ACTION_PACKAGE_REMOVED = 8;
    private static final int ACTION_PACKAGE_RESTARTED = 6;
    private static final int ACTION_SCREEN_OFF = 2;
    private static final int ACTION_SCREEN_ON = 1;
    private static final int ACTION_SEND_HEARTBEAT = 0;
    private static final int ACTION_SEND_NRT = 1;
    private static final int ACTION_UNKNOWN = 0;
    private static final java.lang.String BASTET_ACTION_SEND_HEARTBEAT = "com.huawei.android.bastet.ACTION_SEND_HEARTBEAT";
    private static final java.lang.String BASTET_ACTION_SEND_NRT = "com.huawei.android.bastet.ACTION_SEND_NRT";
    private static final java.lang.String BASTET_DSCP_SET_ACTION = "huawei.intent.action.PUSH_HW_BASTET_SET_DSCP_ACTION";
    private static final java.lang.String BASTET_DSCP_UNSET_ACTION = "huawei.intent.action.PUSH_HW_BASTET_UNSET_DSCP_ACTION";
    private static final java.lang.String BASTET_SERVICE = "BastetService";
    private static final int CONNECT_INTERVAL = 5000;
    private static final int CONNECT_TIMES = 5;
    private static final java.lang.String HW_BASTET_PARTNER_PATH = "/data/bastet/hw_bastet_partner.xml";
    private static final int INTENT_PACKAGE_NAME_OFFSET = 8;
    private static final int INVALID_UID = -1;
    private static final int MESSAGE_BROADCAST_ACTION = 1;
    private static final int MESSAGE_CHECK_SERVICE_TIMEOUT = 2;
    private static final int MESSAGE_PARSE_ACC_APP_LIST = 3;
    private static final int MESSAGE_UNKNOWN = 0;
    private static final java.lang.String PROPEL_HW_BASTET_CONFIG_ACTION = "huawei.intent.action.PUSH_HW_BASTET_CONFIG_ACTION";
    private static final java.lang.String PROPEL_TYPE_EXTRA = "pushType";
    private static final int PROPEL_TYPE_PARTNER = 1;
    private static final int PROPEL_TYPE_UNKNOWN = 0;
    private static final java.lang.String PROPEL_TYPE_UPDATE_BASTET_PARTNER = "hw_bastet_partner";
    private static final java.lang.String PROPEL_URI_EXTRA = "uri";
    private static final java.lang.String TAG = "HwBastetService";
    private java.util.ArrayList<java.lang.String> mAccAppList = new java.util.ArrayList();
    private android.app.AlarmManager mAlarmManager;
    private final android.content.BroadcastReceiver mAlarmReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            if (action != null) {
                if (action.equals("com.huawei.android.bastet.ACTION_SEND_NRT")) {
                    com.android.server.HwBastetService.this.handleNotifyNrt();
                } else if (action.equals("com.huawei.android.bastet.ACTION_SEND_HEARTBEAT")) {
                    com.android.server.HwBastetService.this.handleAlarmTimeout(0);
                }
            }
        }
    };
    private android.os.IBinder mBastetService;
    private int mConnectTimes = 0;
    private android.content.Context mContext;
    private android.os.IBinder.DeathRecipient mDeathRecipient = new android.os.IBinder.DeathRecipient() {
        public void binderDied() {
            android.util.Log.e("HwBastetService", "Bastet service has died!");
            synchronized (com.android.server.HwBastetService.this) {
                if (com.android.server.HwBastetService.this.mBastetService != null) {
                    com.android.server.HwBastetService.this.mBastetService.unlinkToDeath(this, 0);
                    com.android.server.HwBastetService.this.mBastetService = null;
                    com.android.server.HwBastetService.this.mIBastetManager = null;
                }
                com.android.server.HwBastetService.this.mHrtAppList.clear();
                com.android.server.HwBastetService.this.mAccAppList.clear();
            }
            com.android.server.HwBastetService.this.mAlarmManager.cancel(com.android.server.HwBastetService.this.mNrtPendingIntent);
            com.android.server.HwBastetService.this.mAlarmManager.cancel(com.android.server.HwBastetService.this.mHeartBeatPendingIntent);
            com.android.server.HwBastetService.this.mConnectTimes = 0;
            com.android.server.HwBastetService.this.checkBastetService();
        }
    };
    private int mForegroundUid = -1;
    private android.os.Handler mHandler;
    private android.app.PendingIntent mHeartBeatPendingIntent = null;
    private java.util.ArrayList<java.lang.Integer> mHrtAppList = new java.util.ArrayList();
    protected com.huawei.android.bastet.IBastetListener mIBastetListener = new com.huawei.android.bastet.IBastetListener.Stub() {
        public void onProxyIndicateMessage(int proxyId, int err, int ext) throws android.os.RemoteException {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onProxyIndicateMessage: proxyId=");
            stringBuilder.append(proxyId);
            stringBuilder.append(", err=");
            stringBuilder.append(err);
            stringBuilder.append(", ext=");
            stringBuilder.append(ext);
            android.util.Log.e("HwBastetService", stringBuilder.toString());
            switch (err) {
                case -23:
                    cancelAlarm(ext);
                    return;
                case -22:
                    com.android.server.HwBastetService.this.mAlarmManager.setExact(2, android.os.SystemClock.elapsedRealtime() + ((long) ext), com.android.server.HwBastetService.this.mHeartBeatPendingIntent);
                    return;
                case -21:
                    com.android.server.HwBastetService.this.removeHrtApp(ext);
                    return;
                case -20:
                    com.android.server.HwBastetService.this.addHrtApp(ext);
                    return;
                case -18:
                    com.android.server.HwBastetService.this.mAlarmManager.setExact(2, android.os.SystemClock.elapsedRealtime() + ((long) ext), com.android.server.HwBastetService.this.mNrtPendingIntent);
                    if (com.android.server.HwBastetService.this.mTelephonyManager != null) {
                        com.android.server.HwBastetService.this.mTelephonyManager.listen(com.android.server.HwBastetService.this.mPhoneStateListener, 128);
                        return;
                    }
                    return;
                default:
                    return;
            }
        }

        private void cancelAlarm(int operation) {
            android.app.PendingIntent pi;
            switch (operation) {
                case 0:
                    pi = com.android.server.HwBastetService.this.mHeartBeatPendingIntent;
                    break;
                case 1:
                    pi = com.android.server.HwBastetService.this.mNrtPendingIntent;
                    break;
                default:
                    return;
            }
            if (pi == null) {
                android.util.Log.e("HwBastetService", "cancelAlarm opration is null");
            } else {
                com.android.server.HwBastetService.this.mAlarmManager.cancel(pi);
            }
        }
    };
    private com.huawei.android.bastet.IBastetManager mIBastetManager;
    private int mLastAccUid = -1;
    private int mLastHrtUid = -1;
    private android.app.PendingIntent mNrtPendingIntent = null;
    private com.huawei.pgmng.PGPlug mPGPlug;
    private com.android.server.HwBastetService.PgEventProcesser mPgEventProcesser = new com.android.server.HwBastetService.PgEventProcesser(this, null);
    private android.telephony.PhoneStateListener mPhoneStateListener = new android.telephony.PhoneStateListener() {
        public void onDataActivity(int direction) {
            if (direction == 1 || direction == 3) {
                com.android.server.HwBastetService.this.handleNotifyNrt();
            }
        }
    };
    private final android.content.BroadcastReceiver mReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            if (action != null) {
                int actionId = parseAction(action, intent);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BroadcastReceiver ");
                stringBuilder.append(action);
                android.util.Log.d("HwBastetService", stringBuilder.toString());
                if (actionId != 0) {
                    android.os.Message msg = com.android.server.HwBastetService.this.mHandler.obtainMessage();
                    msg.what = 1;
                    msg.arg1 = actionId;
                    switch (actionId) {
                        case 4:
                        case 5:
                        case 6:
                        case 7:
                        case 8:
                            msg.obj = intent.getDataString().substring(8);
                            break;
                        case 9:
                            java.lang.String value = intent.getStringExtra("pushType");
                            if (value != null && value.equals("hw_bastet_partner")) {
                                msg.arg2 = 1;
                            }
                            msg.obj = intent.getStringExtra("uri");
                            break;
                        default:
                            break;
                    }
                    com.android.server.HwBastetService.this.mHandler.sendMessage(msg);
                }
            }
        }

        private int parseAction(java.lang.String action, android.content.Intent intent) {
            if (action.equals("android.intent.action.SCREEN_ON")) {
                return 1;
            }
            if (action.equals("android.intent.action.SCREEN_OFF")) {
                com.android.server.HwBastetService.this.setAppBackground();
                return 2;
            } else if (action.equals("android.intent.action.BOOT_COMPLETED")) {
                com.android.server.HwBastetService.this.initPgPlugThread();
                return 3;
            } else if (action.equals("huawei.intent.action.PUSH_HW_BASTET_CONFIG_ACTION")) {
                return 9;
            } else {
                if (action.equals("android.intent.action.PACKAGE_ADDED")) {
                    return 4;
                }
                if (action.equals("android.intent.action.PACKAGE_CHANGED")) {
                    return 5;
                }
                if (action.equals("android.intent.action.PACKAGE_RESTARTED")) {
                    return 6;
                }
                if (action.equals("android.intent.action.PACKAGE_FIRST_LAUNCH")) {
                    return 7;
                }
                if (action.equals("android.intent.action.PACKAGE_REMOVED")) {
                    com.android.server.HwBastetService.this.removeHrtApp(intent.getDataString().substring(8));
                    return 8;
                } else if (action.equals("huawei.intent.action.PUSH_HW_BASTET_SET_DSCP_ACTION")) {
                    return 10;
                } else {
                    if (action.equals("huawei.intent.action.PUSH_HW_BASTET_UNSET_DSCP_ACTION")) {
                        return 11;
                    }
                    return 0;
                }
            }
        }
    };
    private android.telephony.TelephonyManager mTelephonyManager;
    private android.os.HandlerThread mThread;

    private class HwBastetHandler extends android.os.Handler {
        public HwBastetHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 0:
                    android.util.Log.e("HwBastetService", "MESSAGE_UNKNOWN");
                    return;
                case 1:
                    com.android.server.HwBastetService.this.doBroadcastMessage(msg);
                    return;
                case 2:
                    com.android.server.HwBastetService.this.checkBastetService();
                    return;
                case 3:
                    com.android.server.HwBastetService.this.parseAccAppList(msg);
                    return;
                default:
                    return;
            }
        }
    }

    private class PgEventProcesser implements com.huawei.pgmng.IPGPlugCallbacks {
        private PgEventProcesser() {
        }

        /* synthetic */ PgEventProcesser(com.android.server.HwBastetService x0, com.android.server.HwBastetService.AnonymousClass1 x1) {
            this();
        }

        public void onDaemonConnected() {
        }

        public void onConnectedTimeout() {
        }

        public boolean onEvent(int actionID, java.lang.String msg) {
            if (com.huawei.pgmng.PGAction.checkActionType(actionID) == 1 && com.huawei.pgmng.PGAction.checkActionFlag(actionID) == 3) {
                com.android.server.HwBastetService.this.filterAccApp(msg, com.android.server.HwBastetService.this.filterHrtApp(msg));
            }
            return true;
        }
    }

    public void onStart() {
        android.util.Log.i("HwBastetService", "start HwBastetService");
        initBroadcastReceiver();
        initHandlerThread();
        initTelephonyService();
        getBastetService();
    }

    public HwBastetService(android.content.Context context) {
        super(context);
        android.util.Log.i("HwBastetService", "HwBastetService");
        this.mContext = context;
    }

    private void initGenericReceiver() {
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("android.intent.action.SCREEN_ON");
        filter.addAction("android.intent.action.SCREEN_OFF");
        filter.addAction("android.intent.action.BOOT_COMPLETED");
        this.mContext.registerReceiver(this.mReceiver, filter);
    }

    private void initPackageReceiver() {
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("android.intent.action.PACKAGE_ADDED");
        filter.addAction("android.intent.action.PACKAGE_REMOVED");
        filter.addAction("android.intent.action.PACKAGE_CHANGED");
        filter.addAction("android.intent.action.PACKAGE_RESTARTED");
        filter.addAction("android.intent.action.PACKAGE_FIRST_LAUNCH");
        filter.addDataScheme("package");
        this.mContext.registerReceiver(this.mReceiver, filter);
    }

    private void initPropelReceiver() {
        this.mContext.registerReceiver(this.mReceiver, new android.content.IntentFilter("huawei.intent.action.PUSH_HW_BASTET_CONFIG_ACTION"));
    }

    private void initAlarmReceiver() {
        this.mAlarmManager = (android.app.AlarmManager) this.mContext.getSystemService("alarm");
        if (this.mAlarmManager == null) {
            android.util.Log.e("HwBastetService", "Failed to get alarm service");
            return;
        }
        this.mNrtPendingIntent = android.app.PendingIntent.getBroadcast(this.mContext, 0, new android.content.Intent("com.huawei.android.bastet.ACTION_SEND_NRT", null), 0);
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("com.huawei.android.bastet.ACTION_SEND_NRT");
        this.mHeartBeatPendingIntent = android.app.PendingIntent.getBroadcast(this.mContext, 0, new android.content.Intent("com.huawei.android.bastet.ACTION_SEND_HEARTBEAT", null), 0);
        filter.addAction("com.huawei.android.bastet.ACTION_SEND_HEARTBEAT");
        this.mContext.registerReceiver(this.mAlarmReceiver, filter);
    }

    private void initDscpReceiver() {
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("huawei.intent.action.PUSH_HW_BASTET_SET_DSCP_ACTION");
        filter.addAction("huawei.intent.action.PUSH_HW_BASTET_UNSET_DSCP_ACTION");
        this.mContext.registerReceiver(this.mReceiver, filter);
    }

    private void initTelephonyService() {
        this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        if (this.mTelephonyManager == null) {
            android.util.Log.e("HwBastetService", "Failed to get telephony service");
        }
    }

    private void initBroadcastReceiver() {
        initGenericReceiver();
        initPackageReceiver();
        initPropelReceiver();
        initAlarmReceiver();
        initDscpReceiver();
    }

    private void handleNotifyNrt() {
        try {
            getBastetService();
            synchronized (this) {
                if (this.mIBastetManager != null) {
                    this.mIBastetManager.notifyNrtTimeout();
                }
            }
        } catch (android.os.RemoteException e) {
            e.printStackTrace();
        }
        this.mAlarmManager.cancel(this.mNrtPendingIntent);
        if (this.mTelephonyManager != null) {
            this.mTelephonyManager.listen(this.mPhoneStateListener, 0);
        }
    }

    private void handleAlarmTimeout(int operation) {
        try {
            getBastetService();
            synchronized (this) {
                if (this.mIBastetManager != null) {
                    this.mIBastetManager.notifyAlarmTimeout(operation);
                }
            }
        } catch (android.os.RemoteException e) {
            e.printStackTrace();
        }
    }

    private void initHandlerThread() {
        this.mThread = new android.os.HandlerThread("HwBastetHandlerThread");
        this.mThread.start();
        this.mHandler = new com.android.server.HwBastetService.HwBastetHandler(this.mThread.getLooper());
    }

    private boolean getBastetService() {
        synchronized (this) {
            if (this.mBastetService == null) {
                this.mBastetService = android.os.ServiceManager.getService("BastetService");
                if (this.mBastetService == null) {
                    android.util.Log.e("HwBastetService", "Failed to get bastet service!");
                    return false;
                }
                try {
                    this.mBastetService.linkToDeath(this.mDeathRecipient, 0);
                    this.mIBastetManager = com.huawei.android.bastet.IBastetManager.Stub.asInterface(this.mBastetService);
                    if (this.mIBastetManager.initHwBastetService(this.mIBastetListener) != 0) {
                        android.util.Log.e("HwBastetService", "initHwBastetService Failed!");
                    }
                } catch (android.os.RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
        return true;
    }

    private boolean checkBastetService() {
        boolean isConnected = false;
        if (this.mConnectTimes != 0) {
            isConnected = getBastetService();
        }
        this.mConnectTimes++;
        if (!isConnected && this.mConnectTimes < 5) {
            android.os.Message timeoutMsg = this.mHandler.obtainMessage();
            timeoutMsg.what = 2;
            this.mHandler.sendMessageDelayed(timeoutMsg, 5000);
        } else if (isConnected) {
            this.mConnectTimes = 0;
        } else if (this.mConnectTimes >= 5) {
            android.util.Log.e("HwBastetService", "checkBastetService failed");
        }
        return isConnected;
    }

    private static java.io.InputStream getInputStreamByUri(android.content.Context context, android.net.Uri uri) {
        java.io.InputStream in = null;
        try {
            return context.getContentResolver().openInputStream(uri);
        } catch (java.io.FileNotFoundException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Uri :(");
            stringBuilder.append(uri);
            stringBuilder.append(") not found");
            android.util.Log.w("HwBastetService", stringBuilder.toString());
            return null;
        }
    }

    private static java.io.File getBastetFile(java.lang.String path) {
        if (path != null) {
            if (path.length() != 0) {
                java.io.File file = new java.io.File(path);
                if (file.exists()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("File Path: ");
                    stringBuilder.append(path);
                    stringBuilder.append(" is already exists.");
                    android.util.Log.i("HwBastetService", stringBuilder.toString());
                } else {
                    java.lang.StringBuilder stringBuilder2;
                    try {
                        java.io.File bastetDir = file.getParentFile();
                        if (bastetDir.exists() || bastetDir.mkdirs()) {
                            bastetDir.setExecutable(true, false);
                            bastetDir.setReadable(true, false);
                            if (file.createNewFile()) {
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("File Path: ");
                                stringBuilder3.append(path);
                                stringBuilder3.append(" is created!");
                                android.util.Log.i("HwBastetService", stringBuilder3.toString());
                                file.setExecutable(false);
                                file.setReadable(true, false);
                                file.setWritable(true);
                            } else {
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("File Path: ");
                                stringBuilder2.append(path);
                                stringBuilder2.append(" is already exists.");
                                android.util.Log.i("HwBastetService", stringBuilder2.toString());
                            }
                        } else {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("Failed to create file:");
                            stringBuilder2.append(bastetDir);
                            android.util.Log.e("HwBastetService", stringBuilder2.toString());
                            return null;
                        }
                    } catch (java.io.IOException e) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("Unable to prepare bastet file: ");
                        stringBuilder2.append(file);
                        android.util.Log.w("HwBastetService", stringBuilder2.toString(), e);
                        e.printStackTrace();
                        return null;
                    }
                }
                return file;
            }
        }
        return null;
    }

    private boolean copyBastetXml(java.lang.String destPath, android.net.Uri srcUri) {
        boolean ret = false;
        java.io.InputStream in = getInputStreamByUri(this.mContext, srcUri);
        java.io.File file = getBastetFile(destPath);
        if (file != null) {
            if (in != null) {
                java.io.FileWriter fw = null;
                java.io.Reader input = null;
                try {
                    fw = new java.io.FileWriter(file);
                    input = new java.io.InputStreamReader(in, java.nio.charset.Charset.defaultCharset());
                    char[] buffer = new char[1024];
                    while (true) {
                        int read = input.read(buffer);
                        int length = read;
                        if (read == -1) {
                            break;
                        }
                        fw.write(buffer, 0, length);
                    }
                    android.util.Log.i("HwBastetService", "Copy file: /data/bastet/hw_bastet_partner.xml success.");
                    ret = true;
                    try {
                        input.close();
                    } catch (java.io.IOException e) {
                        android.util.Log.e("HwBastetService", "close input error");
                    }
                    try {
                        fw.close();
                    } catch (java.io.IOException e2) {
                        android.util.Log.e("HwBastetService", "close fw error");
                    }
                } catch (java.io.IOException e3) {
                    android.util.Log.e("HwBastetService", "Failed to copy file!", e3);
                    e3.printStackTrace();
                    if (input != null) {
                        try {
                            input.close();
                        } catch (java.io.IOException e4) {
                            android.util.Log.e("HwBastetService", "close input error");
                        }
                    }
                    if (fw != null) {
                        fw.close();
                    }
                } catch (Throwable th) {
                    if (input != null) {
                        try {
                            input.close();
                        } catch (java.io.IOException e5) {
                            android.util.Log.e("HwBastetService", "close input error");
                        }
                    }
                    if (fw != null) {
                        try {
                            fw.close();
                        } catch (java.io.IOException e6) {
                            android.util.Log.e("HwBastetService", "close fw error");
                        }
                    }
                }
                return ret;
            }
        }
        android.util.Log.w("HwBastetService", "Cannot update bastet xml, Bastet file or inputstream is null!");
        if (in != null) {
            try {
                in.close();
            } catch (java.io.IOException e7) {
                android.util.Log.e("HwBastetService", "close inputstream error");
            }
        }
        return false;
    }

    private boolean updateBastetConfig(int type, java.lang.String strUri) {
        if (1 != type) {
            return false;
        }
        android.net.Uri uri = android.net.Uri.parse(strUri);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Update Xml Uri :");
        stringBuilder.append(uri);
        android.util.Log.i("HwBastetService", stringBuilder.toString());
        return copyBastetXml("/data/bastet/hw_bastet_partner.xml", uri);
    }

    private void doBroadcastMessage(android.os.Message msg) {
        int actionId = msg.arg1;
        java.lang.String name = msg.obj;
        switch (actionId) {
            case 1:
            case 2:
            case 3:
            case 10:
            case 11:
                break;
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
                try {
                    getBastetService();
                    synchronized (this) {
                        if (this.mIBastetManager != null) {
                            this.mIBastetManager.packageChangedReceived(actionId, name);
                        }
                    }
                    return;
                } catch (android.os.RemoteException e) {
                    e.printStackTrace();
                    return;
                }
            case 9:
                if (!updateBastetConfig(msg.arg2, name)) {
                    return;
                }
                break;
            default:
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Unknown action id: ");
                stringBuilder.append(actionId);
                android.util.Log.e("HwBastetService", stringBuilder.toString());
                return;
        }
        try {
            getBastetService();
            synchronized (this) {
                if (this.mIBastetManager != null) {
                    this.mIBastetManager.broadcastReceived(actionId);
                }
            }
        } catch (android.os.RemoteException e2) {
            e2.printStackTrace();
        }
    }

    private void parseAccAppList(android.os.Message msg) {
        java.lang.String appString = msg.getData().getString("applist");
        if (appString == null) {
            android.util.Log.e("HwBastetService", "parseAccAPPList the AppList is NULL.");
            return;
        }
        java.lang.String[] appList = appString.split(";");
        int n = appList.length;
        for (int i = 0; i < n; i++) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("parseAccAPPList AppList[");
            stringBuilder.append(i);
            stringBuilder.append("] is ");
            stringBuilder.append(appList[i]);
            android.util.Log.d("HwBastetService", stringBuilder.toString());
            synchronized (this) {
                this.mAccAppList.add(appList[i]);
            }
        }
    }

    private void addHrtApp(int uid) {
        synchronized (this) {
            boolean found = false;
            int len = this.mHrtAppList.size();
            for (int i = 0; i < len; i++) {
                if (uid == ((java.lang.Integer) this.mHrtAppList.get(i)).intValue()) {
                    found = true;
                    break;
                }
            }
            if (!found) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("add hrt uid: ");
                stringBuilder.append(uid);
                android.util.Log.e("HwBastetService", stringBuilder.toString());
                this.mHrtAppList.add(java.lang.Integer.valueOf(uid));
                if (uid == this.mForegroundUid) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("foreground uid: ");
                    stringBuilder.append(uid);
                    android.util.Log.i("HwBastetService", stringBuilder.toString());
                    setAppActivity(0, uid);
                }
            }
        }
    }

    private void removeHrtApp(int uid) {
        synchronized (this) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("uid: ");
            stringBuilder.append(uid);
            android.util.Log.e("HwBastetService", stringBuilder.toString());
            int len = this.mHrtAppList.size();
            for (int i = 0; i < len; i++) {
                if (uid == ((java.lang.Integer) this.mHrtAppList.get(i)).intValue()) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("remove hrt uid: ");
                    stringBuilder2.append(uid);
                    android.util.Log.i("HwBastetService", stringBuilder2.toString());
                    this.mHrtAppList.remove(i);
                    break;
                }
            }
        }
    }

    private void removeHrtApp(java.lang.String name) {
        synchronized (this) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("name: ");
            stringBuilder.append(name);
            android.util.Log.e("HwBastetService", stringBuilder.toString());
            int len = this.mHrtAppList.size();
            int i = 0;
            try {
                int uid = this.mContext.getPackageManager().getPackageUid(name, 0);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("len: ");
                stringBuilder2.append(len);
                stringBuilder2.append(", name: ");
                stringBuilder2.append(name);
                stringBuilder2.append(", uid: ");
                stringBuilder2.append(uid);
                android.util.Log.e("HwBastetService", stringBuilder2.toString());
                while (i < len) {
                    if (uid == ((java.lang.Integer) this.mHrtAppList.get(i)).intValue()) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("remove hrt uid: ");
                        stringBuilder2.append(uid);
                        android.util.Log.i("HwBastetService", stringBuilder2.toString());
                        this.mHrtAppList.remove(i);
                        break;
                    }
                    i++;
                }
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                e.printStackTrace();
            }
        }
    }

    private boolean filterHrtApp(java.lang.String msg) {
        java.lang.String[] splits = msg.split("\t");
        java.lang.String pkgName = null;
        boolean found = false;
        try {
            if (splits.length > 0) {
                pkgName = splits[0];
            }
        } catch (java.lang.Exception e) {
        }
        try {
            int uid = this.mContext.getPackageManager().getPackageUid(pkgName, 0);
            synchronized (this) {
                this.mForegroundUid = uid;
                int len = this.mHrtAppList.size();
                if (len > 0) {
                    for (int i = 0; i < len; i++) {
                        if (uid == ((java.lang.Integer) this.mHrtAppList.get(i)).intValue()) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("foreground uid: ");
                            stringBuilder.append(uid);
                            android.util.Log.i("HwBastetService", stringBuilder.toString());
                            setAppActivity(0, uid);
                            found = true;
                            break;
                        }
                    }
                    if (!found && this.mLastHrtUid > 0) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("background uid: ");
                        stringBuilder2.append(this.mLastHrtUid);
                        android.util.Log.i("HwBastetService", stringBuilder2.toString());
                        setAppActivity(1, this.mLastHrtUid);
                    }
                }
            }
        } catch (android.content.pm.PackageManager.NameNotFoundException e2) {
            e2.printStackTrace();
        }
        return found;
    }

    private void filterAccApp(java.lang.String msg, boolean isFound) {
        if (msg != null) {
            java.lang.String[] splits = msg.split("\t");
            java.lang.String pkgName = null;
            if (splits.length > 0) {
                pkgName = splits[0];
            }
            try {
                int uid = this.mContext.getPackageManager().getPackageUid(pkgName, 0);
                synchronized (this) {
                    boolean found = false;
                    int len = this.mAccAppList.size();
                    if (len > 0) {
                        for (int i = 0; i < len; i++) {
                            if (((java.lang.String) this.mAccAppList.get(i)).equals(pkgName)) {
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("filterAccApp foreground uid: ");
                                stringBuilder.append(uid);
                                android.util.Log.i("HwBastetService", stringBuilder.toString());
                                setAppActivity(0, uid);
                                this.mLastAccUid = uid;
                                found = true;
                                break;
                            }
                        }
                        if (!(found || isFound || this.mLastAccUid <= 0)) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("filterAccApp background uid: ");
                            stringBuilder2.append(this.mLastAccUid);
                            android.util.Log.i("HwBastetService", stringBuilder2.toString());
                            setAppActivity(1, this.mLastAccUid);
                            this.mLastAccUid = -1;
                        }
                    }
                }
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                e.printStackTrace();
            }
        }
    }

    private void setAppActivity(int activity, int uid) {
        try {
            getBastetService();
            synchronized (this) {
                if (this.mIBastetManager != null) {
                    this.mIBastetManager.hrtAppActivity(activity, uid);
                }
            }
            if (activity == 0) {
                this.mLastHrtUid = uid;
            } else if (activity == 1) {
                this.mLastHrtUid = -1;
            }
        } catch (android.os.RemoteException e) {
            e.printStackTrace();
        }
    }

    private void setAppBackground() {
        synchronized (this) {
            if (this.mLastHrtUid > 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("background uid: ");
                stringBuilder.append(this.mLastHrtUid);
                android.util.Log.i("HwBastetService", stringBuilder.toString());
                setAppActivity(1, this.mLastHrtUid);
            }
        }
    }

    private void initPgPlugThread() {
        this.mPGPlug = new com.huawei.pgmng.PGPlug(this.mPgEventProcesser, "HwBastetService");
        new java.lang.Thread(this.mPGPlug, "HwBastetService").start();
    }
}
