package com.android.server;

public class HwGeneralService extends huawei.android.os.IHwGeneralManager.Stub {
    private static java.lang.String CFG_FILE_SCREEN = "/sys/class/graphics/fb0/panel_info";
    private static java.lang.String FILE_PATH = "sys/touchscreen/supported_func_indicater";
    private static final int NOT_SUPPORT_SDLOCK = -1;
    public static final int RESULT_NOT_SUPPORT = -10;
    static final java.lang.String TAG = "HwGeneralService";
    private static final boolean mIsForcetouchDisabled = android.os.SystemProperties.getBoolean("ro.config.disable_force_touch", false);
    android.os.IDeviceIdleController dic = null;
    private boolean init = false;
    private android.content.Context mContext;
    private android.os.Handler mHandler;
    private com.android.server.VibetonzProxy.IVibetonzImpl mIVibetonzImpl = this.mVibetonzProxy.getInstance();
    private int mIsCurveScreen = -1;
    private boolean mIsSupportForce = false;
    private float mLimit = 0.0f;
    private android.database.ContentObserver mPressLimitObserver;
    private final android.content.ContentResolver mResolver;
    private com.android.server.VibetonzProxy mVibetonzProxy = new com.android.server.VibetonzProxy();

    static {
        try {
            java.lang.System.loadLibrary("general_jni");
        } catch (java.lang.UnsatisfiedLinkError e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Load general libarary failed >>>>>");
            stringBuilder.append(e);
            android.util.Slog.e("HwGeneralService", stringBuilder.toString());
        }
    }

    public HwGeneralService(android.content.Context context, android.os.Handler handler) {
        this.mContext = context;
        this.mHandler = handler;
        if (getSDLockSupport()) {
            com.android.server.HwSdLockService.getInstance(context);
        }
        if (getCryptsdSupport()) {
            com.android.server.HwSdCryptdService.getInstance(context);
        }
        this.mResolver = context.getContentResolver();
        initObserver(handler);
    }

    public int setSDLockPassword(java.lang.String pw) {
        if (getSDLockSupport()) {
            return com.android.server.HwSdLockService.getInstance(this.mContext).setSDLockPassword(pw);
        }
        return -1;
    }

    public int clearSDLockPassword() {
        if (getSDLockSupport()) {
            return com.android.server.HwSdLockService.getInstance(this.mContext).clearSDLockPassword();
        }
        return -1;
    }

    public int unlockSDCard(java.lang.String pw) {
        if (getSDLockSupport()) {
            return com.android.server.HwSdLockService.getInstance(this.mContext).unlockSDCard(pw);
        }
        return -1;
    }

    public void eraseSDLock() {
        if (getSDLockSupport()) {
            com.android.server.HwSdLockService.getInstance(this.mContext).eraseSDLock();
        }
    }

    public int getSDLockState() {
        if (getSDLockSupport()) {
            return com.android.server.HwSdLockService.getInstance(this.mContext).getSDLockState();
        }
        return -1;
    }

    public java.lang.String getSDCardId() {
        if (getSDLockSupport()) {
            return com.android.server.HwSdLockService.getInstance(this.mContext).getSDCardId();
        }
        return null;
    }

    private boolean getSDLockSupport() {
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            boolean state = android.os.SystemProperties.getBoolean("ro.config.support_sdcard_lock", true);
            return state;
        } finally {
            android.os.Binder.restoreCallingIdentity(ident);
        }
    }

    public void startFileBackup() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.HUAWEI_SYSTEM_NODE_ACCESS", null);
        android.os.SystemProperties.set("ctl.start", "filebackup");
    }

    public int forceIdle() {
        if (1000 != android.os.Binder.getCallingUid()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("HwGeneralService:forceIdle, permission not allowed. uid = ");
            stringBuilder.append(android.os.Binder.getCallingUid());
            android.util.Slog.e("HwGeneralService", stringBuilder.toString());
            return -1;
        }
        if (this.dic == null) {
            this.dic = android.os.IDeviceIdleController.Stub.asInterface(android.os.ServiceManager.getService("deviceidle"));
        }
        if (this.dic != null) {
            try {
                return this.dic.forceIdle();
            } catch (android.os.RemoteException e) {
            }
        }
        return -1;
    }

    public boolean isSupportForce() {
        if (!this.init) {
            initForce();
            this.init = true;
            if (mIsForcetouchDisabled) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mIsForcetouchDisabled = ");
                stringBuilder.append(mIsForcetouchDisabled);
                android.util.Log.i("HwGeneralService", stringBuilder.toString());
                this.mIsSupportForce = false;
            }
        }
        return this.mIsSupportForce;
    }

    public boolean isCurveScreen() {
        if (this.mIsCurveScreen == -1) {
            initScreenState();
        }
        return this.mIsCurveScreen == 1;
    }

    private void parseScreenParams(java.lang.String strParas) {
        java.lang.String[] params = strParas.split(",");
        for (java.lang.String param : params) {
            int pos = param.indexOf(":");
            if (pos > 0) {
                if (pos < param.length()) {
                    java.lang.String key = param.substring(0, pos).trim();
                    java.lang.String val = param.substring(pos + 1).trim();
                    if ("curved".equalsIgnoreCase(key)) {
                        this.mIsCurveScreen = val.equals("1");
                    }
                }
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("parseScreenParams ");
        stringBuilder.append(this.mIsCurveScreen);
        stringBuilder.append(" ");
        stringBuilder.append(strParas);
        android.util.Log.i("HwGeneralService", stringBuilder.toString());
    }

    private void initScreenState() {
        java.lang.StringBuilder stringBuilder;
        java.io.IOException e;
        java.lang.String str;
        java.io.BufferedReader reader = null;
        java.lang.String line = null;
        this.mIsCurveScreen = 0;
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("sercie initScreenState");
        stringBuilder2.append(this.mIsCurveScreen);
        android.util.Log.v("HwGeneralService", stringBuilder2.toString());
        java.io.FileInputStream fis = null;
        try {
            fis = new java.io.FileInputStream(CFG_FILE_SCREEN);
            reader = new java.io.BufferedReader(new java.io.InputStreamReader(fis, "UTF-8"));
            java.lang.String readLine = reader.readLine();
            line = readLine;
            if (readLine != null) {
                parseScreenParams(line);
            }
            try {
                reader.close();
            } catch (java.io.IOException e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("initScreenState reader close exception: ");
                stringBuilder.append(e2);
                android.util.Log.e("HwGeneralService", stringBuilder.toString());
            }
            try {
                fis.close();
            } catch (java.io.IOException e3) {
                e2 = e3;
                str = "HwGeneralService";
                stringBuilder = new java.lang.StringBuilder();
            }
        } catch (java.io.FileNotFoundException e4) {
            android.util.Log.e("HwGeneralService", "initScreenState file not found exception.");
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e22) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initScreenState reader close exception: ");
                    stringBuilder.append(e22);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e5) {
                    e22 = e5;
                    str = "HwGeneralService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (java.io.IOException e6) {
            android.util.Log.e("HwGeneralService", "initScreenState file access io exception.");
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e222) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initScreenState reader close exception: ");
                    stringBuilder.append(e222);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e7) {
                    e222 = e7;
                    str = "HwGeneralService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (Throwable th) {
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e8) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("initScreenState reader close exception: ");
                    stringBuilder3.append(e8);
                    android.util.Log.e("HwGeneralService", stringBuilder3.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e82) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initScreenState fis close exception: ");
                    stringBuilder.append(e82);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
        }
        java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
        stringBuilder4.append("initScreenState isCurveScreen = ");
        stringBuilder4.append(this.mIsCurveScreen);
        stringBuilder4.append(" params = ");
        stringBuilder4.append(line);
        android.util.Log.i("HwGeneralService", stringBuilder4.toString());
        stringBuilder.append("initScreenState fis close exception: ");
        stringBuilder.append(e222);
        android.util.Log.e(str, stringBuilder.toString());
        java.lang.StringBuilder stringBuilder42 = new java.lang.StringBuilder();
        stringBuilder42.append("initScreenState isCurveScreen = ");
        stringBuilder42.append(this.mIsCurveScreen);
        stringBuilder42.append(" params = ");
        stringBuilder42.append(line);
        android.util.Log.i("HwGeneralService", stringBuilder42.toString());
    }

    private void initForce() {
        java.lang.StringBuilder stringBuilder;
        java.lang.Exception e;
        java.lang.String str;
        java.io.BufferedReader reader = null;
        int line2int = 0;
        java.io.FileInputStream fis = null;
        try {
            fis = new java.io.FileInputStream(FILE_PATH);
            reader = new java.io.BufferedReader(new java.io.InputStreamReader(fis, "UTF-8"));
            java.lang.String readLine = reader.readLine();
            java.lang.String line = readLine;
            if (readLine != null) {
                line2int = java.lang.Integer.parseInt(line.trim());
                if ((line2int & 16) == 16) {
                    this.mIsSupportForce = true;
                }
            }
            try {
                reader.close();
            } catch (java.lang.Exception e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("initForce reader close exception: ");
                stringBuilder.append(e2);
                android.util.Log.e("HwGeneralService", stringBuilder.toString());
            }
            try {
                fis.close();
            } catch (java.lang.Exception e3) {
                e2 = e3;
                str = "HwGeneralService";
                stringBuilder = new java.lang.StringBuilder();
            }
        } catch (java.io.FileNotFoundException e4) {
            android.util.Log.e("HwGeneralService", "initForce file not found exception.");
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.lang.Exception e22) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initForce reader close exception: ");
                    stringBuilder.append(e22);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.lang.Exception e5) {
                    e22 = e5;
                    str = "HwGeneralService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (java.io.IOException e6) {
            android.util.Log.e("HwGeneralService", "initForce file access io exception.");
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.lang.Exception e222) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initForce reader close exception: ");
                    stringBuilder.append(e222);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.lang.Exception e7) {
                    e222 = e7;
                    str = "HwGeneralService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (Throwable th) {
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.lang.Exception e8) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("initForce reader close exception: ");
                    stringBuilder2.append(e8);
                    android.util.Log.e("HwGeneralService", stringBuilder2.toString());
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.lang.Exception e82) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("initForce fis close exception: ");
                    stringBuilder.append(e82);
                    android.util.Log.e("HwGeneralService", stringBuilder.toString());
                }
            }
        }
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("initForce   mIsSupportForce = ");
        stringBuilder3.append(this.mIsSupportForce);
        stringBuilder3.append(" line2int = ");
        stringBuilder3.append(line2int);
        android.util.Flog.i(1504, stringBuilder3.toString());
        stringBuilder.append("initForce fis close exception: ");
        stringBuilder.append(e222);
        android.util.Log.e(str, stringBuilder.toString());
        java.lang.StringBuilder stringBuilder32 = new java.lang.StringBuilder();
        stringBuilder32.append("initForce   mIsSupportForce = ");
        stringBuilder32.append(this.mIsSupportForce);
        stringBuilder32.append(" line2int = ");
        stringBuilder32.append(line2int);
        android.util.Flog.i(1504, stringBuilder32.toString());
    }

    private void initObserver(android.os.Handler handler) {
        this.mPressLimitObserver = new android.database.ContentObserver(handler) {
            public void onChange(boolean selfChange) {
                com.android.server.HwGeneralService.this.mLimit = android.provider.Settings.System.getFloatForUser(com.android.server.HwGeneralService.this.mContext.getContentResolver(), "pressure_habit_threshold", 0.2f, android.app.ActivityManager.getCurrentUser());
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("initObserver limit = ");
                stringBuilder.append(com.android.server.HwGeneralService.this.mLimit);
                android.util.Flog.i(1504, stringBuilder.toString());
            }
        };
        this.mResolver.registerContentObserver(android.provider.Settings.System.getUriFor("pressure_habit_threshold"), false, this.mPressLimitObserver, -1);
        this.mLimit = android.provider.Settings.System.getFloatForUser(this.mContext.getContentResolver(), "pressure_habit_threshold", 0.2f, android.app.ActivityManager.getCurrentUser());
    }

    public float getPressureLimit() {
        return this.mLimit;
    }

    public void playIvtEffect(java.lang.String effectName) {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") != 0) {
            android.util.Log.e("HwGeneralService", "playIvtEffect Method requires android.Manifest.permission.VIBRATE permission");
        } else {
            this.mIVibetonzImpl.playIvtEffect(effectName);
        }
    }

    public void stopPlayEffect() {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") != 0) {
            android.util.Log.e("HwGeneralService", "stopPlayEffect Method requires android.Manifest.permission.VIBRATE permission");
        } else {
            this.mIVibetonzImpl.stopPlayEffect();
        }
    }

    public void pausePlayEffect(java.lang.String effectName) {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") != 0) {
            android.util.Log.e("HwGeneralService", "pausePlayEffect Method requires android.Manifest.permission.VIBRATE permission");
        } else {
            this.mIVibetonzImpl.pausePlayEffect(effectName);
        }
    }

    public void resumePausedEffect(java.lang.String effectName) {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") != 0) {
            android.util.Log.e("HwGeneralService", "resumePausedEffect Method requires android.Manifest.permission.VIBRATE permission");
        } else {
            this.mIVibetonzImpl.resumePausedEffect(effectName);
        }
    }

    public boolean isPlaying(java.lang.String effectName) {
        return this.mIVibetonzImpl.isPlaying(effectName);
    }

    public boolean startHaptic(int callerID, int ringtoneType, android.net.Uri uri) {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") == 0) {
            return this.mIVibetonzImpl.startHaptic(this.mContext, callerID, ringtoneType, uri);
        }
        android.util.Log.e("HwGeneralService", "startHaptic Method requires android.Manifest.permission.VIBRATE permission");
        return false;
    }

    public boolean hasHaptic(android.net.Uri uri) {
        return this.mIVibetonzImpl.hasHaptic(this.mContext, uri);
    }

    public void stopHaptic() {
        if (this.mContext.checkCallingOrSelfPermission("android.permission.VIBRATE") != 0) {
            android.util.Log.e("HwGeneralService", "stopHaptic Method requires android.Manifest.permission.VIBRATE permission");
        } else {
            this.mIVibetonzImpl.stopHaptic();
        }
    }

    public void resetTouchWeight() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.CHECK_TOUCH_WEIGHT", null);
        com.android.server.HwTouchWeightService.getInstance(this.mContext, this.mHandler).resetTouchWeight();
    }

    public java.lang.String getTouchWeightValue() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.CHECK_TOUCH_WEIGHT", null);
        return com.android.server.HwTouchWeightService.getInstance(this.mContext, this.mHandler).getTouchWeightValue();
    }

    public boolean mkDataDir(java.lang.String path) {
        if (1000 != android.os.Binder.getCallingUid()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("HwGeneralService:mkDataDir, permission not allowed. uid = ");
            stringBuilder.append(android.os.Binder.getCallingUid());
            android.util.Slog.e("HwGeneralService", stringBuilder.toString());
            return false;
        }
        if (path != null) {
            if (!"".equals(path)) {
                if (path.startsWith("/data/")) {
                    java.io.File file = new java.io.File(path);
                    if (file.exists()) {
                        return true;
                    }
                    return file.mkdir();
                }
                android.util.Log.e("HwGeneralService", "path not startsWith data dir");
                return false;
            }
        }
        android.util.Log.e("HwGeneralService", "path is null");
        return false;
    }

    public android.os.Messenger getTestService() {
        if (!"true".equals(android.os.SystemProperties.get("ro.emui.test", "false"))) {
            return null;
        }
        try {
            dalvik.system.PathClassLoader loader = new dalvik.system.PathClassLoader("/system/framework/HwServiceTest.jar", getClass().getClassLoader());
            java.lang.Thread.currentThread().setContextClassLoader(loader);
            java.lang.Class clazz = loader.loadClass("com.huawei.test.systemserver.service.TestRunnerService");
            return (android.os.Messenger) clazz.getMethod("onBind", null).invoke(clazz.getConstructor(new java.lang.Class[]{android.content.Context.class}).newInstance(new java.lang.Object[]{this.mContext}), null);
        } catch (java.lang.Throwable e) {
            android.util.Log.e("HwGeneralService", "can  not get test service", e);
            return null;
        }
    }

    public int readProtectArea(java.lang.String optItem, int readBufLen, java.lang.String[] readBuf, int[] errorNum) {
        int pid = android.os.Binder.getCallingPid();
        int uid = android.os.Binder.getCallingUid();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("readProtectArea: callingPid is ");
        stringBuilder.append(pid);
        stringBuilder.append(",callingUid is ");
        stringBuilder.append(uid);
        android.util.Slog.i("HwGeneralService", stringBuilder.toString());
        return com.android.server.HwProtectAreaService.getInstance(this.mContext).readProtectArea(optItem, readBufLen, readBuf, errorNum);
    }

    public int writeProtectArea(java.lang.String optItem, int writeLen, java.lang.String writeBuf, int[] errorNum) {
        int pid = android.os.Binder.getCallingPid();
        int uid = android.os.Binder.getCallingUid();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("writeProtectArea: callingPid is ");
        stringBuilder.append(pid);
        stringBuilder.append(",callingUid is ");
        stringBuilder.append(uid);
        android.util.Slog.i("HwGeneralService", stringBuilder.toString());
        return com.android.server.HwProtectAreaService.getInstance(this.mContext).writeProtectArea(optItem, writeLen, writeBuf, errorNum);
    }

    public int setSdCardCryptdEnable(boolean enable, java.lang.String volId) {
        if (getCryptsdSupport()) {
            return com.android.server.HwSdCryptdService.getInstance(this.mContext).setSdCardCryptdEnable(enable, volId);
        }
        return -10;
    }

    public int unlockSdCardKey(int userId, int serialNumber, byte[] token, byte[] secret) {
        if (getCryptsdSupport()) {
            return com.android.server.HwSdCryptdService.getInstance(this.mContext).unlockSdCardKey(userId, serialNumber, token, secret);
        }
        return -10;
    }

    public int addSdCardUserKeyAuth(int userId, int serialNumber, byte[] token, byte[] secret) {
        if (getCryptsdSupport()) {
            return com.android.server.HwSdCryptdService.getInstance(this.mContext).addSdCardUserKeyAuth(userId, serialNumber, token, secret);
        }
        return -10;
    }

    private boolean getCryptsdSupport() {
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            boolean state = android.os.SystemProperties.getBoolean("ro.config.support_sdcard_crypt", true);
            return state;
        } finally {
            android.os.Binder.restoreCallingIdentity(ident);
        }
    }

    public int backupSecretkey() {
        if (getCryptsdSupport()) {
            return com.android.server.HwSdCryptdService.getInstance(this.mContext).backupSecretkey();
        }
        return -10;
    }

    public boolean supportHwPush() {
        java.io.File jarFile = huawei.cust.HwCfgFilePolicy.getCfgFile("jars/hwpush.jar", 0);
        if (jarFile != null && jarFile.exists()) {
            android.util.Slog.i("HwGeneralService", "push jarFile is exist in cust");
            return true;
        } else if (new java.io.File("/system/framework/hwpush.jar").exists()) {
            android.util.Slog.i("HwGeneralService", "push jarFile is exist in system");
            return true;
        } else {
            android.util.Slog.i("HwGeneralService", "push jarFile is not exist");
            return false;
        }
    }

    public long getPartitionInfo(java.lang.String partitionName, int infoType) {
        if (com.android.server.HwStorageManagerService.sSelf != null) {
            return com.android.server.HwStorageManagerService.sSelf.getPartitionInfo(partitionName, infoType);
        }
        android.util.Slog.i("HwGeneralService", "error getPartitionInfo HwGeneralService NULL PTR");
        return -1;
    }

    public java.lang.String mountCifs(java.lang.String source, java.lang.String option, android.os.IBinder binder) {
        return com.android.server.HwMountManagerService.getInstance(this.mContext).mountCifs(source, option, binder);
    }

    public void unmountCifs(java.lang.String mountPoint) {
        com.android.server.HwMountManagerService.getInstance(this.mContext).unmountCifs(mountPoint);
    }

    public int isSupportedCifs() {
        return com.android.server.HwMountManagerService.getInstance(this.mContext).isSupportedCifs();
    }

    public int getLocalDevStat(int dev) {
        return com.android.server.HwLocalDevManagerService.getInstance(this.mContext).getLocalDevStat(dev);
    }

    public java.lang.String getDeviceId(int dev) {
        return com.android.server.HwLocalDevManagerService.getInstance(this.mContext).getDeviceId(dev);
    }

    public int doSdcardCheckRW() {
        return com.android.server.HwLocalDevManagerService.getInstance(this.mContext).doSdcardCheckRW();
    }
}
