package com.android.server;

public class HwGnssDetectManager {
    private static long DETECT_INTERVAL = 60000;
    private static java.lang.String GPS_FAULT_CODE = "631001001";
    private static java.lang.String GPS_FAULT_DESCRIPTION_CODE = "831001001";
    private static java.lang.String GPS_FAULT_NAME = "GPS_Switch_Fault";
    private static java.lang.String GPS_FAULT_SUGGESTION_CODE = "531001001";
    private static java.lang.String GPS_HANDLE_TYPE = "3";
    private static java.lang.String KEY_EXTRA_INFO = "EXTRA_INFO";
    private static java.lang.String KEY_FAULT_CODE = "FAULT_CODE";
    private static java.lang.String KEY_FAULT_DESCRIPTION = "FAULT_DESCRIPTION";
    private static java.lang.String KEY_FAULT_NAME = "FAULT_NAME";
    private static java.lang.String KEY_FAULT_SUGGESTION = "FAULT_SUGGESTION";
    private static java.lang.String KEY_HANDLE_TYPE = "HANDLE_TYPE";
    private static java.lang.String KEY_REPAIR_ID = "REPAIR_ID";
    private static java.lang.String SMART_FAULT_ACTION = "huawei.intent.action.SMART_NOTIFY_FAULT";
    private static final java.lang.String SMART_FAULT_CLASS_NAME = "com.huawei.hwdetectrepair.smartnotify.eventlistener.InstantMessageReceiver";
    private static final java.lang.String SMART_FAULT_PACKAGE_NAME = "com.huawei.hwdetectrepair";
    private static final java.lang.String SMART_FAULT_PERMISSION = "huawei.permission.SMART_NOTIFY_FAULT";
    private static java.lang.String TAG = "HwGnssDetectManager";
    private static volatile com.android.server.HwGnssDetectManager mHwGnssDetectManager;
    private android.content.Context mContext;
    private java.util.HashMap<java.lang.String, java.lang.Long> mLastDetectTimeOfPkgs = new java.util.HashMap();

    private static class GPSREPAIRIDS {
        static java.lang.String REPAIR_SETTING_GPS_MODE_SWITCH_VALUE1 = "REPAIR_SETTING_GPS_MODE_SWITCH_VALUE1";
        static java.lang.String REPAIR_SETTING_GPS_MODE_SWITCH_VALUE2 = "REPAIR_SETTING_GPS_MODE_SWITCH_VALUE2";
        static java.lang.String REPAIR_SETTING_GPS_MODE_SWITCH_VALUE3 = "REPAIR_SETTING_GPS_MODE_SWITCH_VALUE3";
        static java.lang.String REPAIR_SETTING_GPS_SWITCH_OFF = "REPAIR_SETTING_GPS_SWITCH_OFF";
        static java.lang.String REPAIR_SETTING_GPS_SWITCH_ON = "REPAIR_SETTING_GPS_SWITCH_ON";
        static java.lang.String REPAIR_SETTING_WLAN_SCAN_SWITCH_OFF = "REPAIR_SETTING_WLAN_SCAN_SWITCH_OFF";
        static java.lang.String REPAIR_SETTING_WLAN_SCAN_SWITCH_ON = "REPAIR_SETTING_WLAN_SCAN_SWITCH_ON";

        private GPSREPAIRIDS() {
        }
    }

    public static com.android.server.HwGnssDetectManager getInstance(android.content.Context context) {
        if (mHwGnssDetectManager == null) {
            synchronized (com.android.server.HwGnssDetectManager.class) {
                if (mHwGnssDetectManager == null) {
                    mHwGnssDetectManager = new com.android.server.HwGnssDetectManager(context);
                }
            }
        }
        return mHwGnssDetectManager;
    }

    private HwGnssDetectManager(android.content.Context context) {
        this.mContext = context;
    }

    public void hwRequestLocationUpdatesLocked(android.location.LocationRequest request, com.android.server.LocationManagerService.Receiver receiver, int pid, int uid, java.lang.String packageName) {
        if (shouldDetect(request, receiver, pid, uid, packageName)) {
            broadcastDetect(packageName, getCommonDetect());
        }
    }

    public java.util.ArrayList<java.lang.String> gnssDetect(java.lang.String packageName) {
        return getCommonDetect();
    }

    private boolean shouldDetect(android.location.LocationRequest request, com.android.server.LocationManagerService.Receiver receiver, int pid, int uid, java.lang.String packageName) {
        java.lang.String str = packageName;
        if ("passive".equals(request.getProvider())) {
            return false;
        }
        if (!((android.os.PowerManager) this.mContext.getSystemService("power")).isScreenOn()) {
            android.util.Log.d(TAG, "now is not screen on, need not detect!");
            return false;
        } else if (isForeGroundProc(str)) {
            long now = android.os.SystemClock.elapsedRealtime();
            java.lang.Long lastDetectTime = (java.lang.Long) this.mLastDetectTimeOfPkgs.get(str);
            if (lastDetectTime != null && now - lastDetectTime.longValue() < DETECT_INTERVAL) {
                return false;
            }
            this.mLastDetectTimeOfPkgs.put(str, java.lang.Long.valueOf(now));
            return true;
        } else {
            java.lang.String str2 = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("package ");
            stringBuilder.append(str);
            stringBuilder.append(" is not foreground, need not detect!");
            android.util.Log.d(str2, stringBuilder.toString());
            return false;
        }
    }

    private java.util.ArrayList<java.lang.String> getCommonDetect() {
        boolean isLocationEnabled;
        boolean isHighAcc = false;
        java.util.ArrayList<java.lang.String> commonDetectedRepairIds = new java.util.ArrayList();
        boolean z = false;
        int locationMode = android.provider.Settings.Secure.getInt(this.mContext.getContentResolver(), "location_mode", 0);
        if (locationMode == 0) {
            isLocationEnabled = false;
        } else {
            isLocationEnabled = true;
        }
        if (locationMode == 3) {
            isHighAcc = true;
        }
        if (android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "wifi_scan_always_enabled", 0) == 1) {
            z = true;
        }
        boolean isWifiScanOpen = z;
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("GPS common detect ");
        sb.append(" isLocationEnabled ");
        sb.append(isLocationEnabled);
        sb.append(" locationMode ");
        sb.append(locationMode);
        sb.append(" isHighAcc ");
        sb.append(isHighAcc);
        sb.append(" isWifiScanOpen ");
        sb.append(isWifiScanOpen);
        android.util.Log.d(TAG, sb.toString());
        if (!isLocationEnabled) {
            commonDetectedRepairIds.add(com.android.server.HwGnssDetectManager.GPSREPAIRIDS.REPAIR_SETTING_GPS_SWITCH_ON);
        }
        if (isLocationEnabled && !isHighAcc) {
            commonDetectedRepairIds.add(com.android.server.HwGnssDetectManager.GPSREPAIRIDS.REPAIR_SETTING_GPS_MODE_SWITCH_VALUE1);
        }
        if (!isWifiScanOpen) {
            commonDetectedRepairIds.add(com.android.server.HwGnssDetectManager.GPSREPAIRIDS.REPAIR_SETTING_WLAN_SCAN_SWITCH_ON);
        }
        return commonDetectedRepairIds;
    }

    private void broadcastDetect(java.lang.String extraInfo, java.util.ArrayList<java.lang.String> repairIds) {
        if (repairIds != null && !repairIds.isEmpty()) {
            android.content.Intent intent = new android.content.Intent(SMART_FAULT_ACTION);
            intent.setClassName("com.huawei.hwdetectrepair", "com.huawei.hwdetectrepair.smartnotify.eventlistener.InstantMessageReceiver");
            intent.putExtra(KEY_EXTRA_INFO, extraInfo);
            intent.putExtra(KEY_HANDLE_TYPE, GPS_HANDLE_TYPE);
            intent.putExtra(KEY_FAULT_NAME, GPS_FAULT_NAME);
            intent.putExtra(KEY_FAULT_CODE, GPS_FAULT_CODE);
            intent.putExtra(KEY_FAULT_DESCRIPTION, GPS_FAULT_DESCRIPTION_CODE);
            intent.putExtra(KEY_FAULT_SUGGESTION, GPS_FAULT_SUGGESTION_CODE);
            intent.putStringArrayListExtra(KEY_REPAIR_ID, repairIds);
            this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.ALL, "huawei.permission.SMART_NOTIFY_FAULT");
        }
    }

    private boolean isForeGroundProc(java.lang.String packageName) {
        return ((android.app.ActivityManager) this.mContext.getSystemService("activity")).getPackageImportance(packageName) <= 125;
    }
}
