package com.android.server;

public class HwInputMethodManagerService extends com.android.server.InputMethodManagerService {
    public static final java.lang.String ACTION_SECURE_IME = "com.huawei.secime.SoftKeyboard";
    private static final java.util.Locale CHINA_LOCALE = new java.util.Locale("zh");
    private static final java.lang.String DESCRIPTOR = "android.view.inputmethod.InputMethodManager";
    private static final java.util.Locale ENGLISH_LOCALE = new java.util.Locale("en");
    public static final int FLAG_SHOW_INPUT = 65536;
    private static final java.lang.String INPUT_METHOD_ENABLED_FILE = "bflag";
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    public static final int SECURE_IME_NO_HIDE_FLAG = 4096;
    public static final java.lang.String SECURE_IME_PACKAGENAME = "com.huawei.secime";
    public static final java.lang.String SECURITY_INPUT_METHOD_ID = "com.huawei.secime/.SoftKeyboard";
    public static final java.lang.String SECURITY_INPUT_SERVICE_NAME = "input_method_secure";
    public static final java.lang.String SETTINGS_SECURE_KEYBOARD_CONTROL = "secure_keyboard";
    static final java.lang.String TAG = "HwInputMethodManagerService";
    private static final int TRANSACTION_isUseSecureIME = 1001;
    private static final int UNBIND_SECIME_IF_SHOULD = 10000;
    private static final boolean isSupportedSecIme = IS_CHINA_AREA;
    private boolean isSecMethodUsing = false;
    private boolean isSecureIMEEnabled = false;
    private boolean isSecureIMEExist = false;
    private com.android.server.HwInputMethodManagerService.SecureSettingsObserver mSecureSettingsObserver;
    private com.android.internal.view.IInputMethodManager mSecurityInputMethodService;

    private class SecureSettingsObserver extends android.database.ContentObserver {
        boolean mRegistered = false;
        int mUserId;

        public SecureSettingsObserver() {
            super(new android.os.Handler());
        }

        public void registerContentObserverInner(int userId) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SecureSettingsObserver mRegistered=");
            stringBuilder.append(this.mRegistered);
            stringBuilder.append(" new user=");
            stringBuilder.append(userId);
            stringBuilder.append(" current user=");
            stringBuilder.append(this.mUserId);
            android.util.Slog.d("HwInputMethodManagerService", stringBuilder.toString());
            if (!this.mRegistered || this.mUserId != userId) {
                android.content.ContentResolver resolver = com.android.server.HwInputMethodManagerService.this.mContext.getContentResolver();
                if (this.mRegistered) {
                    resolver.unregisterContentObserver(this);
                    this.mRegistered = false;
                }
                this.mUserId = userId;
                resolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("secure_keyboard"), false, this, userId);
                this.mRegistered = true;
            }
        }

        public void onChange(boolean selfChange, android.net.Uri uri) {
            if (uri != null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("SecureSettingsObserver onChange, uri = ");
                stringBuilder.append(uri.toString());
                android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
                if (android.provider.Settings.Secure.getUriFor("secure_keyboard").equals(uri)) {
                    com.android.server.HwInputMethodManagerService.this.isSecureIMEEnabled = com.android.server.HwInputMethodManagerService.this.isSecureIMEEnable();
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("isSecureIMEEnabled = ");
                    stringBuilder2.append(com.android.server.HwInputMethodManagerService.this.isSecureIMEEnabled);
                    android.util.Slog.i("HwInputMethodManagerService", stringBuilder2.toString());
                }
            }
        }
    }

    public HwInputMethodManagerService(android.content.Context context) {
        super(context);
    }

    protected void createFlagIfNecessary(int newUserId) {
        java.io.File flagFile = new java.io.File(android.os.Environment.getUserSystemDirectory(newUserId), "bflag");
        boolean existFlag = false;
        try {
            if (flagFile.exists()) {
                existFlag = true;
            } else {
                flagFile.createNewFile();
            }
            synchronized (this.mEnabledFileMap) {
                this.mEnabledFileMap.put(java.lang.String.valueOf(newUserId), java.lang.Boolean.valueOf(existFlag));
            }
        } catch (java.io.IOException e) {
            android.util.Slog.e("HwInputMethodManagerService", "Unable to create flag file!");
        }
    }

    protected boolean isFlagExists(int userId) {
        boolean value;
        synchronized (this.mEnabledFileMap) {
            value = ((java.lang.Boolean) this.mEnabledFileMap.get(java.lang.String.valueOf(userId))).booleanValue();
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isFlagExists  value = ");
        stringBuilder.append(value);
        stringBuilder.append(", userId = ");
        stringBuilder.append(userId);
        android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
        return value;
    }

    protected void ensureEnableSystemIME(java.lang.String id, android.view.inputmethod.InputMethodInfo p, android.content.Context context, int userId) {
        if (!isFlagExists(userId)) {
            if (isValidSystemDefaultIme(p, context) || isSystemImeThatHasEnglishSubtype(p) || isSystemImeThatHasChinaSubtype(p)) {
                android.util.Slog.i("HwInputMethodManagerService", "ensureEnableSystemIME will setInputMethodEnabledLocked");
                setInputMethodEnabledLocked(id, true);
            }
        }
    }

    private static boolean isSystemIme(android.view.inputmethod.InputMethodInfo inputMethod) {
        return (inputMethod.getServiceInfo().applicationInfo.flags & 1) != 0;
    }

    private boolean isValidSystemDefaultIme(android.view.inputmethod.InputMethodInfo imi, android.content.Context context) {
        if (!this.mSystemReady || !isSystemIme(imi)) {
            return false;
        }
        if (imi.getIsDefaultResourceId() != 0) {
            try {
                if (context.createPackageContext(imi.getPackageName(), 0).getResources().getBoolean(imi.getIsDefaultResourceId()) && containsSubtypeOf(imi, context.getResources().getConfiguration().locale.getLanguage())) {
                    return true;
                }
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
            } catch (android.content.res.Resources.NotFoundException e2) {
            }
        }
        if (imi.getSubtypeCount() == 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Found no subtypes in a system IME: ");
            stringBuilder.append(imi.getPackageName());
            android.util.Slog.w("HwInputMethodManagerService", stringBuilder.toString());
        }
        return false;
    }

    private static boolean isSystemImeThatHasEnglishSubtype(android.view.inputmethod.InputMethodInfo imi) {
        if (isSystemIme(imi)) {
            return containsSubtypeOf(imi, ENGLISH_LOCALE.getLanguage());
        }
        return false;
    }

    private static boolean isSystemImeThatHasChinaSubtype(android.view.inputmethod.InputMethodInfo imi) {
        if (isSystemIme(imi)) {
            return containsSubtypeOf(imi, CHINA_LOCALE.getLanguage());
        }
        return false;
    }

    private static boolean containsSubtypeOf(android.view.inputmethod.InputMethodInfo imi, java.lang.String language) {
        int N = imi.getSubtypeCount();
        for (int i = 0; i < N; i++) {
            if (imi.getSubtypeAt(i).getLocale().startsWith(language)) {
                return true;
            }
        }
        return false;
    }

    public void systemRunning(com.android.server.statusbar.StatusBarManagerService statusBar) {
        if (isSupportedSecIme) {
            this.mSecureSettingsObserver = new com.android.server.HwInputMethodManagerService.SecureSettingsObserver();
            this.mSecureSettingsObserver.registerContentObserverInner(this.mSettings.getCurrentUserId());
            this.isSecureIMEEnabled = isSecureIMEEnable();
            this.isSecureIMEExist = existSecureIME();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("systemRunning isSecureIMEEnabled = ");
            stringBuilder.append(this.isSecureIMEEnabled);
            stringBuilder.append(", isSecureIMEExist = ");
            stringBuilder.append(this.isSecureIMEExist);
            android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
        }
        super.systemRunning(statusBar);
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        if (code != 1001) {
            return super.onTransact(code, data, reply, flags);
        }
        data.enforceInterface("android.view.inputmethod.InputMethodManager");
        boolean result = isUseSecureIME();
        reply.writeNoException();
        reply.writeInt(result);
        return true;
    }

    private com.android.internal.view.IInputMethodManager getSecurityInputMethodService() {
        if (this.mSecurityInputMethodService == null) {
            this.mSecurityInputMethodService = com.android.internal.view.IInputMethodManager.Stub.asInterface(android.os.ServiceManager.getService("input_method_secure"));
        }
        return this.mSecurityInputMethodService;
    }

    private boolean isSecureIMEEnable() {
        return android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "secure_keyboard", 1, this.mSettings.getCurrentUserId()) == 1;
    }

    private boolean isUseSecureIME() {
        return this.isSecureIMEExist && this.isSecureIMEEnabled && isSupportedSecIme && getSecurityInputMethodService() != null;
    }

    public void addClient(com.android.internal.view.IInputMethodClient client, com.android.internal.view.IInputContext inputContext, int uid, int pid) {
        super.addClient(client, inputContext, uid, pid);
        if (getSecurityInputMethodService() != null) {
            try {
                this.mSecurityInputMethodService.addClient(client, inputContext, uid, pid);
            } catch (android.os.RemoteException e) {
            }
        }
    }

    public void removeClient(com.android.internal.view.IInputMethodClient client) {
        super.removeClient(client);
        if (getSecurityInputMethodService() != null) {
            try {
                this.mSecurityInputMethodService.removeClient(client);
            } catch (android.os.RemoteException e) {
            }
        }
    }

    public void setImeWindowStatus(android.os.IBinder token, android.os.IBinder startInputToken, int vis, int backDisposition) {
        if (!isUseSecureIME() || (token != null && this.mCurToken == token)) {
            super.setImeWindowStatus(token, startInputToken, vis, backDisposition);
            return;
        }
        try {
            this.mSecurityInputMethodService.setImeWindowStatus(token, startInputToken, vis, backDisposition);
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("HwInputMethodManagerService", "setImeWindowStatus, remote exception");
        }
    }

    public com.android.internal.view.InputBindResult startInputOrWindowGainedFocus(int startInputReason, com.android.internal.view.IInputMethodClient client, android.os.IBinder windowToken, int controlFlags, int softInputMode, int windowFlags, android.view.inputmethod.EditorInfo attribute, com.android.internal.view.IInputContext inputContext, int missingMethods, int unverifiedTargetSdkVersion) {
        int controlFlags2;
        com.android.internal.view.IInputMethodClient iInputMethodClient = client;
        android.view.inputmethod.EditorInfo editorInfo = attribute;
        boolean z;
        if (windowToken == null) {
            z = false;
            android.os.ResultReceiver resultReceiver = null;
            android.util.Slog.d("HwInputMethodManagerService", "------------startInput--------------");
            if (isUseSecureIME()) {
                if (isPasswordType(editorInfo)) {
                    android.util.Slog.d("HwInputMethodManagerService", "isPasswordType(attribute) == true, using SecurityIMMS");
                    if (this.mInputShown) {
                        z = super.hideSoftInput(iInputMethodClient, z, resultReceiver);
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("hideNormalSoftInput = ");
                        stringBuilder.append(z);
                        android.util.Slog.d("HwInputMethodManagerService", stringBuilder.toString());
                        if (z) {
                            controlFlags2 = controlFlags | 65536;
                            this.isSecMethodUsing = true;
                            return this.mSecurityInputMethodService.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags2, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                        }
                    }
                    controlFlags2 = controlFlags;
                    this.isSecMethodUsing = true;
                    try {
                        return this.mSecurityInputMethodService.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags2, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                    } catch (android.os.RemoteException e) {
                    }
                } else {
                    boolean isHide = z;
                    try {
                        isHide = this.mSecurityInputMethodService.hideSoftInput(iInputMethodClient, z, resultReceiver);
                    } catch (android.os.RemoteException e2) {
                    }
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("hideSecSoftInput = ");
                    stringBuilder2.append(isHide);
                    android.util.Slog.d("HwInputMethodManagerService", stringBuilder2.toString());
                    if (isHide) {
                        controlFlags2 = controlFlags | 65536;
                    } else {
                        controlFlags2 = controlFlags;
                    }
                    this.isSecMethodUsing = z;
                    return super.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags2, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                }
            }
        } else if (isUseSecureIME()) {
            android.os.ResultReceiver resultReceiver2;
            if (isPasswordType(editorInfo)) {
                android.util.Slog.d("HwInputMethodManagerService", "windowGainedFocus  isPasswordType(attribute) = true");
                this.isSecMethodUsing = true;
                resultReceiver2 = null;
                super.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags, 1, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                super.hideSoftInput(iInputMethodClient, 0, resultReceiver2);
                try {
                    return this.mSecurityInputMethodService.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                } catch (android.os.RemoteException e3) {
                }
            } else {
                z = false;
                resultReceiver2 = null;
                this.isSecMethodUsing = z;
                try {
                    this.mSecurityInputMethodService.hideSoftInput(iInputMethodClient, z, resultReceiver2);
                    com.android.internal.view.InputBindResult inputBindRes = super.startInputOrWindowGainedFocus(startInputReason, client, windowToken, controlFlags, softInputMode, windowFlags, attribute, inputContext, missingMethods, unverifiedTargetSdkVersion);
                    this.mSecurityInputMethodService.startInputOrWindowGainedFocus(10000, iInputMethodClient, windowToken, controlFlags, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
                    return inputBindRes;
                } catch (android.os.RemoteException e4) {
                }
            }
        }
        controlFlags2 = controlFlags;
        return super.startInputOrWindowGainedFocus(startInputReason, iInputMethodClient, windowToken, controlFlags2, softInputMode, windowFlags, editorInfo, inputContext, missingMethods, unverifiedTargetSdkVersion);
    }

    public void setInputMethod(android.os.IBinder token, java.lang.String id) {
        if (!"com.huawei.secime/.SoftKeyboard".equals(id)) {
            super.setInputMethod(token, id);
        }
    }

    public void setInputMethodAndSubtype(android.os.IBinder token, java.lang.String id, android.view.inputmethod.InputMethodSubtype subtype) {
        if (!isSupportedSecIme || !"com.huawei.secime/.SoftKeyboard".equals(id)) {
            super.setInputMethodAndSubtype(token, id, subtype);
        }
    }

    boolean setInputMethodEnabledLocked(java.lang.String id, boolean enabled) {
        if (isSupportedSecIme && "com.huawei.secime/.SoftKeyboard".equals(id)) {
            return false;
        }
        return super.setInputMethodEnabledLocked(id, enabled);
    }

    void setInputMethodLocked(java.lang.String id, int subtypeId) {
        if (!isSupportedSecIme || !"com.huawei.secime/.SoftKeyboard".equals(id)) {
            super.setInputMethodLocked(id, subtypeId);
        }
    }

    public void showInputMethodPickerFromClient(com.android.internal.view.IInputMethodClient client, int auxiliarySubtypeMode) {
        if (isUseSecureIME() && this.isSecMethodUsing) {
            android.util.Slog.w("HwInputMethodManagerService", "SecIME is using, don't show the input method chooser dialog!");
        } else {
            super.showInputMethodPickerFromClient(client, auxiliarySubtypeMode);
        }
    }

    public void hideMySoftInput(android.os.IBinder token, int flags) {
        if (!isUseSecureIME() || (token != null && this.mCurToken == token)) {
            super.hideMySoftInput(token, flags);
        } else {
            try {
                this.mSecurityInputMethodService.hideMySoftInput(token, flags);
            } catch (android.os.RemoteException e) {
            }
        }
    }

    public boolean showSoftInput(com.android.internal.view.IInputMethodClient client, int flags, android.os.ResultReceiver resultReceiver) {
        if (isUseSecureIME() && this.isSecMethodUsing) {
            try {
                hideSoftInput(client, 4096, resultReceiver);
                return this.mSecurityInputMethodService.showSoftInput(client, flags, resultReceiver);
            } catch (android.os.RemoteException e) {
            }
        }
        return super.showSoftInput(client, flags, resultReceiver);
    }

    public void showMySoftInput(android.os.IBinder token, int flags) {
        if (!isUseSecureIME() || (token != null && this.mCurToken == token)) {
            super.showMySoftInput(token, flags);
        } else {
            try {
                this.mSecurityInputMethodService.showMySoftInput(token, flags);
            } catch (android.os.RemoteException e) {
            }
        }
    }

    private boolean isPasswordType(android.view.inputmethod.EditorInfo attribute) {
        if (attribute != null) {
            return huawei.android.view.inputmethod.HwSecImmHelper.isPasswordInputType(attribute.inputType, true);
        }
        if (this.isSecMethodUsing) {
            return true;
        }
        return false;
    }

    protected boolean isSecureIME(java.lang.String packageName) {
        if ("com.huawei.secime".equals(packageName)) {
            return true;
        }
        return false;
    }

    protected boolean shouldBuildInputMethodList(java.lang.String packageName) {
        if (isSupportedSecIme && "com.huawei.secime".equals(packageName)) {
            return false;
        }
        return true;
    }

    protected void updateSecureIMEStatus() {
        this.isSecureIMEExist = existSecureIME();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isSecureIMEExist = ");
        stringBuilder.append(this.isSecureIMEExist);
        android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
    }

    private boolean existSecureIME() {
        java.util.List<android.content.pm.ResolveInfo> packages = this.mContext.getPackageManager().queryIntentServicesAsUser(new android.content.Intent("com.huawei.secime.SoftKeyboard"), 0, this.mSettings.getCurrentUserId());
        if (packages == null || packages.size() <= 0) {
            return false;
        }
        return true;
    }

    public boolean hideSoftInput(com.android.internal.view.IInputMethodClient client, int flags, android.os.ResultReceiver resultReceiver) {
        if (isUseSecureIME() && this.isSecMethodUsing) {
            if (4096 != flags) {
                try {
                    this.mSecurityInputMethodService.hideSoftInput(client, flags, resultReceiver);
                } catch (android.os.RemoteException e) {
                }
            } else {
                flags = 0;
            }
        }
        return super.hideSoftInput(client, flags, resultReceiver);
    }

    protected void switchUserExtra(int userId) {
        if (isSupportedSecIme) {
            if (this.mSecureSettingsObserver != null) {
                this.mSecureSettingsObserver.registerContentObserverInner(userId);
            }
            updateSecureIMEStatus();
            this.isSecureIMEEnabled = isSecureIMEEnable();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isSecureIMEEnabled = ");
            stringBuilder.append(this.isSecureIMEEnabled);
            android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
            if (isUseSecureIME()) {
                com.android.server.HwSecureInputMethodManagerInternal mLocalServices = (com.android.server.HwSecureInputMethodManagerInternal) com.android.server.LocalServices.getService(com.android.server.HwSecureInputMethodManagerInternal.class);
                if (mLocalServices != null) {
                    mLocalServices.setClientActiveFlag();
                } else {
                    android.util.Slog.w("HwInputMethodManagerService", "HwSecureInputMethodManagerInternal is not exist !");
                }
            }
        }
    }

    protected int getNaviBarEnabledDefValue() {
        int defValue;
        boolean FRONT_FINGERPRINT_NAVIGATION = android.os.SystemProperties.getBoolean("ro.config.hw_front_fp_navi", false);
        int FRONT_FINGERPRINT_NAVIGATION_TRIKEY = android.os.SystemProperties.getInt("ro.config.hw_front_fp_trikey", 0);
        if (FRONT_FINGERPRINT_NAVIGATION) {
            boolean isTrikeyExist = isTrikeyExist();
            if (FRONT_FINGERPRINT_NAVIGATION_TRIKEY == 1 && isTrikeyExist) {
                defValue = 0;
            } else if (android.os.SystemProperties.get("ro.config.hw_optb", "0").equals("156")) {
                defValue = 0;
            } else {
                defValue = 1;
            }
        } else {
            defValue = 1;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("NaviBar defValue = ");
        stringBuilder.append(defValue);
        android.util.Slog.i("HwInputMethodManagerService", stringBuilder.toString());
        return defValue;
    }

    /* JADX WARNING: Removed duplicated region for block: B:7:0x0041 A:{ExcHandler: java.lang.ClassNotFoundException (r1_3 'e' java.lang.Exception), Splitter: B:1:0x0001} */
    /* JADX WARNING: Removed duplicated region for block: B:7:0x0041 A:{ExcHandler: java.lang.ClassNotFoundException (r1_3 'e' java.lang.Exception), Splitter: B:1:0x0001} */
    /* JADX WARNING: Removed duplicated region for block: B:7:0x0041 A:{ExcHandler: java.lang.ClassNotFoundException (r1_3 'e' java.lang.Exception), Splitter: B:1:0x0001} */
    /* JADX WARNING: Removed duplicated region for block: B:7:0x0041 A:{ExcHandler: java.lang.ClassNotFoundException (r1_3 'e' java.lang.Exception), Splitter: B:1:0x0001} */
    /* JADX WARNING: Removed duplicated region for block: B:7:0x0041 A:{ExcHandler: java.lang.ClassNotFoundException (r1_3 'e' java.lang.Exception), Splitter: B:1:0x0001} */
    /* JADX WARNING: Missing block: B:7:0x0041, code:
            r1 = move-exception;
     */
    /* JADX WARNING: Missing block: B:8:0x0042, code:
            r3 = new java.lang.StringBuilder();
            r3.append("isTrikeyExist, reflect method handle, and has exception: ");
            r3.append(r1);
            android.util.Slog.e("HwInputMethodManagerService", r3.toString());
     */
    private boolean isTrikeyExist() {
        /*
        r6 = this;
        r0 = 0;
        r1 = "huawei.android.os.HwGeneralManager";
        r1 = java.lang.Class.forName(r1);	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r2 = "getInstance";
        r3 = 0;
        r2 = r1.getDeclaredMethod(r2, r3);	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r4 = "isSupportTrikey";
        r4 = r1.getDeclaredMethod(r4, r3);	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r5 = r3;
        r5 = (java.lang.Object[]) r5;	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r5 = r2.invoke(r1, r5);	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r3 = (java.lang.Object[]) r3;	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r3 = r4.invoke(r5, r3);	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r3 = (java.lang.Boolean) r3;	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r3 = r3.booleanValue();	 Catch:{ ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, ClassNotFoundException -> 0x0041, Exception -> 0x0029 }
        r0 = r3;
    L_0x0028:
        goto L_0x0059;
    L_0x0029:
        r1 = move-exception;
        r2 = "HwInputMethodManagerService";
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r4 = "isTrikeyExist, other exception: ";
        r3.append(r4);
        r3.append(r1);
        r3 = r3.toString();
        android.util.Slog.e(r2, r3);
        goto L_0x0059;
    L_0x0041:
        r1 = move-exception;
        r2 = "HwInputMethodManagerService";
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r4 = "isTrikeyExist, reflect method handle, and has exception: ";
        r3.append(r4);
        r3.append(r1);
        r3 = r3.toString();
        android.util.Slog.e(r2, r3);
        goto L_0x0028;
    L_0x0059:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.HwInputMethodManagerService.isTrikeyExist():boolean");
    }

    public void reportFullscreenMode(android.os.IBinder token, boolean fullscreen) {
        if (!isUseSecureIME() || (token != null && this.mCurToken == token)) {
            super.reportFullscreenMode(token, fullscreen);
            return;
        }
        try {
            this.mSecurityInputMethodService.reportFullscreenMode(token, fullscreen);
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("HwInputMethodManagerService", "reportFullscreenMode, remote exception");
        }
    }
}
