package com.android.server;

public class HwLocationManagerService extends com.android.server.LocationManagerService {
    private static final java.lang.String ACCURACY = "accuracy";
    private static final java.lang.String AIDL_MESSAGE_SERVICE_CLASS = ".HwLBSService";
    private static final java.lang.String AIDL_MESSAGE_SERVICE_PACKAGE = "com.huawei.lbs";
    static final int CODE_ADD_LOCATION_MODE = 1004;
    static final int CODE_GET_POWR_TYPE = 1001;
    static final int CODE_GNSS_DETECT = 1007;
    static final int CODE_LOG_EVENT = 1002;
    static final int CODE_REMOVE_LOCATION_MODE = 1005;
    public static final boolean D = android.util.Log.isLoggable("HwLocationManagerService", 3);
    protected static final int DEFAULT_MODE = 0;
    private static final java.lang.String DESCRIPTOR = "android.location.ILocationManager";
    private static final java.lang.String GNSS_LOCATION_FIX_STATUS = "GNSS_LOCATION_FIX_STATUS";
    private static final int INVALID_MODE_CODE = -1;
    private static final java.lang.String LATITUDE = "latitude";
    private static final java.lang.String LOCATION_MODE_BATTERY_SAVING = java.lang.Integer.toString(2);
    private static final java.lang.String LOCATION_MODE_HIGH_ACCURACY = java.lang.Integer.toString(3);
    private static final java.lang.String LOCATION_MODE_OFF = java.lang.Integer.toString(0);
    private static final java.lang.String LOCATION_MODE_SENSORS_ONLY = java.lang.Integer.toString(1);
    private static final java.lang.String LONGITUDE = "longitude";
    private static final java.lang.String MASTER_PASSWORD = com.android.server.location.HwLocalLocationManager.MASTER_PASSWORD;
    protected static final int MODE_BATCHING = 2;
    protected static final int MODE_FREEZE = 5;
    protected static final int MODE_GPS = 1;
    protected static final int MODE_NETWORK = 3;
    protected static final int MODE_PASSIVE = 4;
    private static final int MSG_DELAY_START_LBS_SERVICE = 26;
    private static final int MSG_LOCATION_FIX_TIMEOUT = 25;
    private static final int MSG_LOCATION_FIX_TIMEOUT_DELAY = 10000;
    private static final int MSG_LOCTION_HUAWEI_BEGIN = 20;
    private static final int MSG_SAVE_LOCATION_IN_DATABASE = 27;
    private static final int MSG_SAVE_LOCATION_TIMEOUT_DELAY = 600000;
    private static final int MSG_SAVE_LOCATION_VALID_PERIOD = 3600000;
    private static final int MSG_SCREEN_OFF = 23;
    private static final int MSG_SCREEN_ON = 24;
    private static final int MSG_WIFI_ALWAYS_SCAN_REOPEN = 22;
    private static final int MSG_WIFI_ALWAYS_SCAN_RESET = 21;
    private static final int NETWORK_LOCATION_MIN_INTERVAL_BY_5G = 40000;
    private static final int OPERATION_SUCCESS = 0;
    private static final int OTHER_EXCEPTION = -2;
    private static final java.lang.String SAVED_LOCATION = "save_location_database";
    private static final int SERVICE_RESTART_COUNT = 3;
    private static final long SERVICE_RESTART_TIME_INTERVAL = 60000;
    private static final long SERVICE_RUN_TIME_INTERVAL = 600000;
    static final int SETTINGS_LOCATION_MODE = 1006;
    private static final java.lang.String SOURCE = "source";
    private static final java.lang.String TAG = "HwLocationManagerService";
    private static final java.lang.String TIMESTAMP = "timestamp";
    private static final int WIFI_ALWAYS_SCAN_REOPEN_DELAY = 30000;
    private static final int WIFI_ALWAYS_SCAN_SCEENONOFF_DELAY = 5000;
    private static final java.lang.String WIFI_SCAN_ALWAYS_AVAILABLE_RESET_FLAG = "wifi_scan_always_available_reset_flag";
    private static final java.lang.String WIFI_SCAN_ALWAYS_AVAILABLE_USER_OPR = "wifi_scan_always_available_user_selection";
    private static java.util.Map<java.lang.Integer, java.lang.Integer> mSettingsByUserId = new java.util.HashMap();
    private static java.util.ArrayList<java.lang.String> mSupervisoryControlWhiteList = new java.util.ArrayList(java.util.Arrays.asList(new java.lang.String[]{"com.sankuai.meituan"}));
    private long LOCK_HELD_BAD_TIME = 60000;
    private boolean WIFISCAN_CONTROL_ON = android.os.SystemProperties.getBoolean("ro.config.hw_wifiscan_control_on", false);
    private boolean isAlwaysScanReset = false;
    private boolean isAlwaysScanScreenOff = false;
    private android.os.IBinder mBinderLBSService;
    private final android.content.BroadcastReceiver mBroadcastReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("receive broadcast intent, action: ");
            stringBuilder.append(action);
            android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
            if ("android.location.GPS_ENABLED_CHANGE".equals(action)) {
                if (intent.hasExtra("enabled")) {
                    boolean navigating = intent.getBooleanExtra("enabled", false);
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("EXTRA_GPS_ENABLED navigating=");
                    stringBuilder2.append(navigating);
                    android.util.Log.d("HwLocationManagerService", stringBuilder2.toString());
                    com.android.server.HwLocationManagerService.this.refreshSystemUIStatus(navigating);
                    if (!navigating) {
                        com.android.server.HwLocationManagerService.this.sendHwLocationMessage(25, 0);
                    }
                }
            } else if ("android.net.wifi.WIFI_STATE_CHANGED".equals(action)) {
                com.android.server.HwLocationManagerService.this.handleWifiStateChanged(intent.getIntExtra("wifi_state", 4));
            } else if ("android.intent.action.SCREEN_ON".equals(action)) {
                com.android.server.HwLocationManagerService.this.sendHwLocationMessage(24, 5000);
            } else if ("android.intent.action.SCREEN_OFF".equals(action)) {
                com.android.server.HwLocationManagerService.this.sendHwLocationMessage(23, 5000);
            }
        }
    };
    private com.android.server.location.HwGeoFencerBase mGeoFencer;
    private final android.content.Context mHwContext;
    private com.android.server.location.HwGpsPowerTracker mHwGpsPowerTracker;
    private boolean mIs5GHzBandSupported = false;
    private boolean mLBSServiceStart = false;
    private com.android.server.HwLocationManagerService.LBSServiceDeathHandler mLBSServicedeathHandler;
    private android.location.Location mLastLocation = null;
    private android.os.Handler mLbsServiceHandler;
    private com.android.server.location.HwLocalLocationProvider mLocalLocationProvider;
    private com.android.server.LocationManagerServiceUtil mLocationManagerServiceUtil;
    private android.content.BroadcastReceiver mPackegeClearReceiver = new android.content.BroadcastReceiver() {
        private java.lang.String getPackageName(android.content.Intent intent) {
            android.net.Uri uri = intent.getData();
            return uri != null ? uri.getSchemeSpecificPart() : null;
        }

        private boolean explicitlyStopped(java.lang.String pkg) {
            android.content.pm.PackageManager pm = com.android.server.HwLocationManagerService.this.mContext.getPackageManager();
            if (pm == null) {
                return false;
            }
            try {
                android.content.pm.ApplicationInfo ai = pm.getApplicationInfo(pkg, 0);
                if (ai == null || (ai.flags & 2097152) == 0) {
                    return false;
                }
                return true;
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("package info not found:");
                stringBuilder.append(pkg);
                android.util.Log.w("HwLocationManagerService", stringBuilder.toString());
                return false;
            }
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                java.lang.String action = intent.getAction();
                if ("android.intent.action.PACKAGE_DATA_CLEARED".equals(action) || "android.intent.action.PACKAGE_RESTARTED".equals(action)) {
                    java.lang.String pkg = getPackageName(intent);
                    if (explicitlyStopped(pkg)) {
                        com.android.server.HwLocationManagerService.this.removeStoppedRecords(pkg);
                    }
                }
            }
        }
    };
    java.util.HashMap<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> mPreservedRecordsByPkg = new java.util.HashMap();
    private long mServiceRestartCount;
    private long mStartServiceTime;
    java.util.HashMap<java.lang.String, java.lang.String> mSupervisoryPkgList = new java.util.HashMap();

    private class LBSServiceDeathHandler implements android.content.ServiceConnection, android.os.IBinder.DeathRecipient {
        private LBSServiceDeathHandler() {
        }

        /* synthetic */ LBSServiceDeathHandler(com.android.server.HwLocationManagerService x0, com.android.server.HwLocationManagerService.AnonymousClass1 x1) {
            this();
        }

        public void onServiceConnected(android.content.ComponentName arg0, android.os.IBinder service) {
            android.util.Log.d("HwLocationManagerService", "bindLbsService Connect lbs service successful");
            com.android.server.HwLocationManagerService.this.mBinderLBSService = service;
            com.android.server.HwLocationManagerService.this.mLBSServiceStart = true;
            com.android.server.HwLocationManagerService.this.notifyServiceDied();
        }

        public void onServiceDisconnected(android.content.ComponentName name) {
            android.util.Log.d("HwLocationManagerService", "bindLbsService disconnect lbs service");
            com.android.server.HwLocationManagerService.this.mBinderLBSService = null;
            com.android.server.HwLocationManagerService.this.mLBSServiceStart = false;
        }

        public void binderDied() {
            android.util.Log.d("HwLocationManagerService", "bindLbsService lbs service has died!");
            if (com.android.server.HwLocationManagerService.this.mBinderLBSService != null) {
                com.android.server.HwLocationManagerService.this.mBinderLBSService.unlinkToDeath(com.android.server.HwLocationManagerService.this.mLBSServicedeathHandler, 0);
                com.android.server.HwLocationManagerService.this.mBinderLBSService = null;
            }
            if (java.lang.System.currentTimeMillis() - com.android.server.HwLocationManagerService.this.mStartServiceTime > 600000) {
                com.android.server.HwLocationManagerService.this.mServiceRestartCount = 0;
            }
            com.android.server.HwLocationManagerService.this.sendLbsServiceRestartMessage();
        }
    }

    static {
        mSupervisoryControlWhiteList.add("com.sankuai.meituan.dispatch.homebrew");
        mSupervisoryControlWhiteList.add("com.huawei.hidisk");
        mSupervisoryControlWhiteList.add("com.nianticlabs.pokemongo");
    }

    public HwLocationManagerService(android.content.Context context) {
        super(context);
        this.mLocationManagerServiceUtil = com.android.server.LocationManagerServiceUtil.getDefault(this, context);
        this.mHwContext = context;
        this.mGeoFencerEnabled = false;
        this.mIs5GHzBandSupported = isDualBandSupported();
        registerPkgClearReceiver();
    }

    private void refreshSystemUIStatus(boolean isRefreshMonitor) {
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            for (com.android.server.LocationManagerService.Receiver receiver : this.mLocationManagerServiceUtil.getReceivers().values()) {
                receiver.updateMonitoring(isRefreshMonitor);
            }
        }
    }

    private void checkWifiScanAlwaysResetFlag() {
        if (android.provider.Settings.Global.getInt(this.mHwContext.getContentResolver(), "wifi_scan_always_available_reset_flag", 0) == 1) {
            android.util.Log.d("HwLocationManagerService", " the phone is boot before the wlan alwas scan reset to open.");
            sendHwLocationMessage(22, 0);
        }
    }

    private void sendHwLocationMessage(int what, int delay) {
        android.os.Handler locationHandler = this.mLocationManagerServiceUtil.getLocationHandler();
        locationHandler.removeMessages(what);
        android.os.Message m = android.os.Message.obtain(locationHandler, what);
        if (delay > 0) {
            locationHandler.sendMessageDelayed(m, (long) delay);
        } else {
            locationHandler.sendMessage(m);
        }
    }

    private void handleWifiStateChanged(int state) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("wifistate :");
        stringBuilder.append(state);
        android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        if (state == 1) {
            int always_wifi_scan = android.provider.Settings.Global.getInt(this.mHwContext.getContentResolver(), "wifi_scan_always_enabled", 0);
            int userAction = android.provider.Settings.Global.getInt(this.mHwContext.getContentResolver(), "wifi_scan_always_available_user_selection", 0);
            if ((android.provider.Settings.Secure.getInt(this.mHwContext.getContentResolver(), "device_provisioned", 0) != 0) && this.isAlwaysScanReset && always_wifi_scan == 1 && userAction != 1) {
                sendHwLocationMessage(21, 0);
            }
            this.isAlwaysScanReset = false;
        } else if (state == 3) {
            this.isAlwaysScanReset = true;
        }
    }

    /* JADX WARNING: Missing block: B:24:0x010d, code:
            return true;
     */
    protected boolean hwLocationHandleMessage(android.os.Message r8) {
        /*
        r7 = this;
        r0 = "HwLocationManagerService";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "hwLocationHandleMessage :";
        r1.append(r2);
        r2 = r8.what;
        r1.append(r2);
        r2 = ", sceenoff:";
        r1.append(r2);
        r2 = r7.isAlwaysScanScreenOff;
        r1.append(r2);
        r1 = r1.toString();
        android.util.Log.d(r0, r1);
        r0 = r8.what;
        r1 = 7;
        r2 = 0;
        if (r0 == r1) goto L_0x010e;
    L_0x0028:
        r1 = 1;
        switch(r0) {
            case 21: goto L_0x00ed;
            case 22: goto L_0x00d4;
            case 23: goto L_0x0088;
            case 24: goto L_0x0068;
            case 25: goto L_0x0042;
            case 26: goto L_0x0033;
            case 27: goto L_0x002e;
            default: goto L_0x002c;
        };
    L_0x002c:
        goto L_0x0111;
    L_0x002e:
        r7.saveLocationToDataBase();
        goto L_0x010d;
    L_0x0033:
        r0 = "HwLocationManagerService";
        r2 = "bindLbsService start service message has come.";
        android.util.Log.d(r0, r2);
        r7.startLBSService();
        r7.bindLBSService();
        goto L_0x010d;
    L_0x0042:
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "GNSS_LOCATION_FIX_STATUS";
        r0 = android.provider.Settings.Global.getInt(r0, r3, r2);
        if (r0 != r1) goto L_0x0063;
    L_0x0050:
        r3 = "HwLocationManagerService";
        r4 = "set gnss_location_fix_status to 0";
        android.util.Log.d(r3, r4);
        r3 = r7.mHwContext;
        r3 = r3.getContentResolver();
        r4 = "GNSS_LOCATION_FIX_STATUS";
        android.provider.Settings.Global.putInt(r3, r4, r2);
    L_0x0063:
        r7.readySaveLocationToDataBase();
        goto L_0x010d;
    L_0x0068:
        r0 = r7.isAlwaysScanScreenOff;
        if (r0 == 0) goto L_0x010d;
    L_0x006c:
        r7.isAlwaysScanScreenOff = r2;
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_enabled";
        android.provider.Settings.Global.putInt(r0, r3, r1);
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_available_reset_flag";
        android.provider.Settings.Global.putInt(r0, r3, r2);
        goto L_0x010d;
    L_0x0088:
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_enabled";
        r0 = android.provider.Settings.Global.getInt(r0, r3, r2);
        r3 = r7.mHwContext;
        r3 = r3.getContentResolver();
        r4 = "wifi_scan_always_available_user_selection";
        r3 = android.provider.Settings.Global.getInt(r3, r4, r2);
        r4 = r7.mHwContext;
        r4 = r4.getContentResolver();
        r5 = "device_provisioned";
        r4 = android.provider.Settings.Secure.getInt(r4, r5, r2);
        if (r4 == 0) goto L_0x00b2;
    L_0x00b0:
        r4 = r1;
        goto L_0x00b3;
    L_0x00b2:
        r4 = r2;
    L_0x00b3:
        if (r4 == 0) goto L_0x010d;
    L_0x00b5:
        if (r0 != r1) goto L_0x010d;
    L_0x00b7:
        if (r3 == r1) goto L_0x010d;
    L_0x00b9:
        r7.isAlwaysScanScreenOff = r1;
        r5 = r7.mHwContext;
        r5 = r5.getContentResolver();
        r6 = "wifi_scan_always_enabled";
        android.provider.Settings.Global.putInt(r5, r6, r2);
        r2 = r7.mHwContext;
        r2 = r2.getContentResolver();
        r5 = "wifi_scan_always_available_reset_flag";
        android.provider.Settings.Global.putInt(r2, r5, r1);
        goto L_0x010d;
    L_0x00d4:
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_enabled";
        android.provider.Settings.Global.putInt(r0, r3, r1);
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_available_reset_flag";
        android.provider.Settings.Global.putInt(r0, r3, r2);
        goto L_0x010d;
    L_0x00ed:
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r3 = "wifi_scan_always_enabled";
        android.provider.Settings.Global.putInt(r0, r3, r2);
        r0 = r7.mHwContext;
        r0 = r0.getContentResolver();
        r2 = "wifi_scan_always_available_reset_flag";
        android.provider.Settings.Global.putInt(r0, r2, r1);
        r0 = 22;
        r2 = 30000; // 0x7530 float:4.2039E-41 double:1.4822E-319;
        r7.sendHwLocationMessage(r0, r2);
    L_0x010d:
        return r1;
    L_0x010e:
        r7.hwLocationCheck();
    L_0x0111:
        return r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.HwLocationManagerService.hwLocationHandleMessage(android.os.Message):boolean");
    }

    protected void enableLocalLocationProviders(com.android.server.location.GnssLocationProvider gnssProvider) {
        if (gnssProvider == null || !gnssProvider.isLocalDBEnabled()) {
            android.util.Log.e("HwLocationManagerService", "localDB is disabled");
            return;
        }
        android.util.Log.e("HwLocationManagerService", "init and enable localLocationProvider ");
        this.mLocalLocationProvider = com.android.server.location.HwLocalLocationProvider.getInstance(this.mLocationManagerServiceUtil.getContext(), this);
        this.mLocalLocationProvider.enable();
        this.mLocationManagerServiceUtil.addProviderLocked(this.mLocalLocationProvider);
        this.mLocationManagerServiceUtil.getRealProviders().put("local_database", this.mLocalLocationProvider);
        this.mLocationManagerServiceUtil.getEnabledProviders().add(this.mLocalLocationProvider.getName());
    }

    protected void updateLocalLocationDB(android.location.Location location, java.lang.String provider) {
        if (location != null) {
            if (!provider.equals("passive")) {
                try {
                    java.lang.String encryptedLong = MASTER_PASSWORD;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(location.getLongitude());
                    stringBuilder.append("");
                    encryptedLong = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(encryptedLong, stringBuilder.toString());
                    java.lang.String encryptedLat = MASTER_PASSWORD;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(location.getLatitude());
                    stringBuilder2.append("");
                    encryptedLat = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(encryptedLat, stringBuilder2.toString());
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("result loc: ");
                    stringBuilder3.append(encryptedLong);
                    stringBuilder3.append(", ");
                    stringBuilder3.append(encryptedLat);
                    android.util.Log.d("HwLocationManagerService", stringBuilder3.toString());
                } catch (java.lang.Exception e) {
                    android.util.Log.e("HwLocationManagerService", "print loc Exception");
                }
            }
            if (this.mLocalLocationProvider == null || this.mLocalLocationProvider.isValidLocation(location)) {
                if (!(provider.equals("passive") || provider.equals("local_database") || this.mLocalLocationProvider == null || !this.mLocalLocationProvider.isEnabled())) {
                    this.mLocalLocationProvider.updataLocationDB(location);
                }
                updateLastLocationDataBase(location, provider);
                return;
            }
            android.util.Log.d("HwLocationManagerService", "incoming location is invdlid,and not report app");
        }
    }

    public void initHwLocationPowerTracker(android.content.Context context) {
        this.mHwGpsPowerTracker = new com.android.server.location.HwGpsPowerTracker(context);
        android.content.IntentFilter intentFilter = new android.content.IntentFilter();
        intentFilter.addAction("android.location.GPS_ENABLED_CHANGE");
        if (this.WIFISCAN_CONTROL_ON) {
            intentFilter.addAction("android.net.wifi.WIFI_STATE_CHANGED");
            intentFilter.addCategory("android.net.wifi.WIFI_STATE_CHANGED@hwBrExpand@WifiStatus=WIFIENABLED|WifiStatus=WIFIDISABLED");
            intentFilter.addAction("android.intent.action.SCREEN_ON");
            intentFilter.addAction("android.intent.action.SCREEN_OFF");
        }
        this.mHwContext.registerReceiverAsUser(this.mBroadcastReceiver, android.os.UserHandle.ALL, intentFilter, null, this.mLocationManagerServiceUtil.getLocationHandler());
        this.mLBSServicedeathHandler = new com.android.server.HwLocationManagerService.LBSServiceDeathHandler(this, null);
        this.mLbsServiceHandler = this.mLocationManagerServiceUtil.getLocationHandler();
        checkWifiScanAlwaysResetFlag();
    }

    public void hwLocationPowerTrackerRecordRequest(java.lang.String pkgName, int quality, boolean isIntent) {
        this.mHwGpsPowerTracker.recordRequest(pkgName, quality, isIntent);
    }

    public void hwLocationPowerTrackerRemoveRequest(java.lang.String pkgName) {
        this.mHwGpsPowerTracker.removeRequest(pkgName);
    }

    public void hwLocationPowerTrackerDump(java.io.PrintWriter pw) {
        this.mHwGpsPowerTracker.dump(pw);
    }

    public void hwQuickGpsSwitch() {
        if ("hi110x".equalsIgnoreCase(android.os.SystemProperties.get("ro.connectivity.chiptype", ""))) {
            this.mLocationManagerServiceUtil.getContext().getContentResolver().registerContentObserver(android.provider.Settings.Global.getUriFor("quick_gps_switch"), true, new android.database.ContentObserver(this.mLocationManagerServiceUtil.getLocationHandler()) {
                public void onChange(boolean selfChange) {
                    int quickGpsSettings = android.provider.Settings.Global.getInt(com.android.server.HwLocationManagerService.this.mLocationManagerServiceUtil.getContext().getContentResolver(), "quick_gps_switch", 1);
                    android.os.SystemProperties.set("persist.sys.pgps.config", java.lang.Integer.toString(quickGpsSettings));
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Settings.Global.QUICK_GPS_SWITCH  set ");
                    stringBuilder.append(quickGpsSettings);
                    android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
                }
            }, -1);
        }
    }

    public void hwSendLocationChangedAction(android.content.Context context, java.lang.String packageName) {
        android.content.Intent intent = new android.content.Intent("android.location.LOCATION_REQUEST_CHANGE_ACTION");
        intent.putExtra("package", packageName);
        context.sendBroadcastAsUser(intent, android.os.UserHandle.ALL);
    }

    public void checkGeoFencerEnabled(android.content.pm.PackageManager packageManager) {
        this.mGeoFencerPackageName = android.content.res.Resources.getSystem().getString(33685939);
        if (this.mGeoFencerPackageName == null || packageManager.resolveService(new android.content.Intent(this.mGeoFencerPackageName), 0) == null) {
            this.mGeoFencer = null;
            this.mGeoFencerEnabled = false;
        } else {
            this.mGeoFencer = com.android.server.location.HwGeoFencerProxy.getGeoFencerProxy(this.mLocationManagerServiceUtil.getContext(), this.mGeoFencerPackageName);
            this.mGeoFencerEnabled = true;
        }
        this.mComboNlpPackageName = android.content.res.Resources.getSystem().getString(33685940);
        if (this.mComboNlpPackageName != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(this.mComboNlpPackageName);
            stringBuilder.append(".nlp:ready");
            this.mComboNlpReadyMarker = stringBuilder.toString();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(this.mComboNlpPackageName);
            stringBuilder.append(".nlp:screen");
            this.mComboNlpScreenMarker = stringBuilder.toString();
        }
    }

    public boolean addQcmGeoFencer(android.location.Geofence geofence, android.location.LocationRequest sanitizedRequest, int uid, android.app.PendingIntent intent, java.lang.String packageName) {
        if (this.mGeoFencer == null || !this.mGeoFencerEnabled) {
            return false;
        }
        long j;
        if (sanitizedRequest.getExpireAt() == Long.MAX_VALUE) {
            j = -1;
        } else {
            j = sanitizedRequest.getExpireAt() - android.os.SystemClock.elapsedRealtime();
        }
        this.mGeoFencer.add(new android.location.GeoFenceParams(uid, geofence.getLatitude(), geofence.getLongitude(), geofence.getRadius(), j, intent, packageName));
        return true;
    }

    public boolean removeQcmGeoFencer(android.app.PendingIntent intent) {
        if (this.mGeoFencer == null || !this.mGeoFencerEnabled) {
            return false;
        }
        this.mGeoFencer.remove(intent);
        return true;
    }

    private void setGnssLocationFixStatus(android.location.Location location, java.lang.String provider) {
        int location_fix_status = android.provider.Settings.Global.getInt(this.mHwContext.getContentResolver(), "GNSS_LOCATION_FIX_STATUS", 0);
        android.os.Bundle extras = location.getExtras();
        if ((extras == null || !extras.getBoolean("QUICKGPS")) && "gps".equals(provider)) {
            if (location_fix_status == 0) {
                android.util.Log.d("HwLocationManagerService", "set gnss_location_fix_status to 1");
                android.provider.Settings.Global.putInt(this.mHwContext.getContentResolver(), "GNSS_LOCATION_FIX_STATUS", 1);
            }
            sendHwLocationMessage(25, 10000);
        }
    }

    protected android.location.Location screenLocationLocked(android.location.Location location, java.lang.String provider) {
        setGnssLocationFixStatus(location, provider);
        if (this.mLocationManagerServiceUtil.isMockProvider("network")) {
            return location;
        }
        com.android.server.location.LocationProviderProxy providerProxy = (com.android.server.location.LocationProviderProxy) this.mLocationManagerServiceUtil.getProvidersByName().get("network");
        if (!(this.mComboNlpPackageName == null || providerProxy == null || !provider.equals("network"))) {
            if (!this.mLocationManagerServiceUtil.isMockProvider("network")) {
                java.lang.String connectedNlpPackage = providerProxy.getConnectedPackageName();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("connectedNlpPackage ");
                stringBuilder.append(connectedNlpPackage);
                android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
                if (connectedNlpPackage == null) {
                    return location;
                }
                java.lang.String[] pNames = connectedNlpPackage.split(";");
                if (pNames.length == 2) {
                    if (!(pNames[0].equals(this.mComboNlpPackageName) || pNames[1].equals(this.mComboNlpPackageName))) {
                        return location;
                    }
                } else if (!connectedNlpPackage.equals(this.mComboNlpPackageName)) {
                    return location;
                }
                android.os.Bundle extras = location.getExtras();
                boolean isBeingScreened = false;
                if (extras == null) {
                    extras = new android.os.Bundle();
                }
                if (extras.containsKey(this.mComboNlpReadyMarker)) {
                    if (D) {
                        android.util.Log.d("HwLocationManagerService", "This location is marked as ready for broadcast");
                    }
                    extras.remove(this.mComboNlpReadyMarker);
                } else {
                    java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> records = (java.util.ArrayList) this.mLocationManagerServiceUtil.getRecordsByProvider().get("passive");
                    if (records != null) {
                        java.util.Iterator it = records.iterator();
                        while (it.hasNext()) {
                            com.android.server.LocationManagerService.UpdateRecord r = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                            if (r.mReceiver.mIdentity.mPackageName.equals(this.mComboNlpPackageName)) {
                                if (!isBeingScreened) {
                                    isBeingScreened = true;
                                    extras.putBoolean(this.mComboNlpScreenMarker, true);
                                }
                                if (!r.mReceiver.callLocationChangedLocked(location)) {
                                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                    stringBuilder2.append("RemoteException calling onLocationChanged on ");
                                    stringBuilder2.append(r.mReceiver);
                                    android.util.Slog.w("HwLocationManagerService", stringBuilder2.toString());
                                } else if (D) {
                                    android.util.Log.d("HwLocationManagerService", "Sending location for screening");
                                }
                            }
                        }
                    }
                    if (isBeingScreened) {
                        return null;
                    }
                    if (D) {
                        android.util.Log.d("HwLocationManagerService", "Not screening locations");
                    }
                }
                return location;
            }
        }
        return location;
    }

    protected void setGeoFencerEnabled(boolean enabled) {
        if (this.mGeoFencer != null) {
            this.mGeoFencerEnabled = enabled;
        }
    }

    protected void dumpGeoFencer(java.io.PrintWriter pw) {
        if (this.mGeoFencer != null && this.mGeoFencerEnabled) {
            this.mGeoFencer.dump(pw, "");
        }
    }

    public boolean proxyGps(java.lang.String pkg, int uid, boolean proxy) {
        if (proxy) {
            com.android.server.location.GpsFreezeProc.getInstance().addFreezeProcess(pkg, uid);
        } else {
            com.android.server.location.GpsFreezeProc.getInstance().removeFreezeProcess(pkg, uid);
        }
        return true;
    }

    protected boolean isFreeze(java.lang.String pkg) {
        return com.android.server.location.GpsFreezeProc.getInstance().isFreeze(pkg);
    }

    protected void dumpGpsFreezeProxy(java.io.PrintWriter pw) {
        com.android.server.location.GpsFreezeProc.getInstance().dump(pw);
    }

    public void refreshPackageWhitelist(int type, java.util.List<java.lang.String> pkgList) {
        com.android.server.location.GpsFreezeProc.getInstance().refreshPackageWhitelist(type, pkgList);
    }

    protected android.util.ArraySet<java.lang.String> getPackageWhiteList(int type) {
        return com.android.server.location.GpsFreezeProc.getInstance().getPackageWhiteList(type);
    }

    private int addSupervisoryControlProc(java.lang.String packagename, int uid, int expectedmode) {
        java.lang.Object obj = packagename;
        int i = uid;
        java.lang.String mExpectedMode = getMode(expectedmode);
        if (mExpectedMode == null) {
            return -1;
        }
        java.lang.StringBuilder stringBuilder;
        java.lang.StringBuilder stringBuilder2;
        if (i <= 1000) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("addSupervisoryControlProc, uid less than 1000, invalid! uid is ");
            stringBuilder.append(i);
            android.util.Slog.i("HwLocationManagerService", stringBuilder.toString());
            return -2;
        } else if (com.android.server.location.GpsFreezeProc.getInstance().isInPackageWhiteListByType(5, obj)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("addSupervisoryControlProc, packagename:");
            stringBuilder.append(obj);
            stringBuilder.append(" is in PackageWhiteList break");
            android.util.Slog.i("HwLocationManagerService", stringBuilder.toString());
            return -2;
        } else if (mSupervisoryControlWhiteList.contains(obj)) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("addSupervisoryControlProc, packagename:");
            stringBuilder2.append(obj);
            stringBuilder2.append(" is in local whiteList, return");
            android.util.Slog.i("HwLocationManagerService", stringBuilder2.toString());
            return 0;
        } else {
            synchronized (this.mLocationManagerServiceUtil.getmLock()) {
                this.mSupervisoryPkgList.put(obj, mExpectedMode);
            }
            if (isNetworkAvailable(i) || !mExpectedMode.equals("network")) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("addSupervisoryControlProc, mExpectedMode is ");
                stringBuilder2.append(mExpectedMode);
                stringBuilder2.append(",packagename=");
                stringBuilder2.append(obj);
                stringBuilder2.append(", mSupervisoryPkgList is ");
                stringBuilder2.append(this.mSupervisoryPkgList.toString());
                android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
                synchronized (this.mLocationManagerServiceUtil.getmLock()) {
                    java.util.HashMap<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> mSwitchRecords = new java.util.HashMap();
                    java.util.HashMap<java.lang.Object, com.android.server.LocationManagerService.Receiver> mReceivers = this.mLocationManagerServiceUtil.getReceivers();
                    if (mReceivers != null) {
                        for (com.android.server.LocationManagerService.Receiver receiver : mReceivers.values()) {
                            java.lang.String str;
                            java.lang.String currentMode = "";
                            if (receiver.mIdentity.mPackageName.equals(obj)) {
                                for (com.android.server.LocationManagerService.UpdateRecord record : receiver.mUpdateRecords.values()) {
                                    currentMode = record.mProvider;
                                    java.lang.String mode = getSwitchMode(i, record.mRealRequest.getProvider(), currentMode, mExpectedMode);
                                    if (!mode.equals(currentMode)) {
                                        mSwitchRecords.put(record, mode);
                                        stringBuilder = new java.lang.StringBuilder();
                                        stringBuilder.append("addSupervisoryControlProc, originalMode: ");
                                        stringBuilder.append(record.mRealRequest.getProvider());
                                        stringBuilder.append(", currentMode: ");
                                        stringBuilder.append(currentMode);
                                        stringBuilder.append(", mExpectedMode: ");
                                        stringBuilder.append(mExpectedMode);
                                        stringBuilder.append(", receiver: ");
                                        stringBuilder.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(receiver)));
                                        android.util.Slog.d("HwLocationManagerService", stringBuilder.toString());
                                    }
                                    str = packagename;
                                }
                            }
                            str = packagename;
                        }
                    }
                    java.util.ArrayList<java.lang.String> updateProviders = updateLocationMode(mSwitchRecords);
                    if (!(updateProviders == null || updateProviders.isEmpty())) {
                        android.os.Handler mHandler = this.mLocationManagerServiceUtil.getLocationHandler();
                        mHandler.sendMessage(android.os.Message.obtain(mHandler, 6, updateProviders));
                    }
                }
                return 0;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("addSupervisoryControlProc, packagename=");
            stringBuilder.append(obj);
            stringBuilder.append("expectedmode is network, but Network is not Available");
            android.util.Slog.i("HwLocationManagerService", stringBuilder.toString());
            return -2;
        }
    }

    private void removeSupervisoryControlProc(java.lang.String packagename, int uid) {
        java.lang.StringBuilder stringBuilder;
        if (uid <= 1000 && uid != 0) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("removeSupervisoryControlProc, uid less than 1000, invalid! uid is ");
            stringBuilder.append(uid);
            android.util.Slog.i("HwLocationManagerService", stringBuilder.toString());
        } else if (mSupervisoryControlWhiteList.contains(packagename)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("removeSupervisoryControlProc packagename:");
            stringBuilder.append(packagename);
            stringBuilder.append(" is in local whiteList, return");
            android.util.Slog.i("HwLocationManagerService", stringBuilder.toString());
        } else {
            java.util.HashMap<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> mSwitchRecords = new java.util.HashMap();
            synchronized (this.mLocationManagerServiceUtil.getmLock()) {
                java.lang.StringBuilder stringBuilder2;
                if (packagename == null && uid == 0) {
                    try {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("remove All SupervisoryControlProc ");
                        stringBuilder2.append(this.mSupervisoryPkgList.toString());
                        android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
                        for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : this.mSupervisoryPkgList.entrySet()) {
                            mSwitchRecords.putAll(getRemoveSwitchRecords((java.lang.String) entry.getKey()));
                        }
                        this.mSupervisoryPkgList.clear();
                    } catch (java.lang.Throwable th) {
                        throw th;
                    }
                } else if (packagename != null) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("remove SupervisoryControlProc packagename=");
                    stringBuilder2.append(packagename);
                    android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
                    mSwitchRecords.putAll(getRemoveSwitchRecords(packagename));
                    this.mSupervisoryPkgList.remove(packagename);
                }
                java.util.ArrayList<java.lang.String> updateProviders = updateLocationMode(mSwitchRecords);
                if (updateProviders == null) {
                    updateProviders = new java.util.ArrayList();
                }
                java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> preservedRecords = (java.util.ArrayList) this.mPreservedRecordsByPkg.get(packagename);
                if (preservedRecords != null) {
                    java.util.Iterator<com.android.server.LocationManagerService.UpdateRecord> it = preservedRecords.iterator();
                    while (it.hasNext()) {
                        com.android.server.LocationManagerService.UpdateRecord record = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                        if (!record.mReceiver.mUpdateRecords.containsValue(record)) {
                            java.lang.String provider = record.mRealRequest.getProvider();
                            record.mReceiver.mUpdateRecords.put(provider, record);
                            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                            stringBuilder3.append("removeSupervisoryControlProc add origin record ");
                            stringBuilder3.append(provider);
                            android.util.Log.i("HwLocationManagerService", stringBuilder3.toString());
                            if (!updateProviders.contains(provider)) {
                                updateProviders.add(provider);
                            }
                        }
                    }
                }
                this.mPreservedRecordsByPkg.remove(packagename);
                if (!(updateProviders == null || updateProviders.isEmpty())) {
                    android.os.Handler mHandler = this.mLocationManagerServiceUtil.getLocationHandler();
                    mHandler.sendMessage(android.os.Message.obtain(mHandler, 6, updateProviders));
                }
            }
        }
    }

    private java.util.HashMap<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> getRemoveSwitchRecords(java.lang.String packagename) {
        java.util.HashMap<java.lang.Object, com.android.server.LocationManagerService.Receiver> mReceivers = this.mLocationManagerServiceUtil.getReceivers();
        java.util.HashMap<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> mSwitchRecords = new java.util.HashMap();
        if (mReceivers != null) {
            for (com.android.server.LocationManagerService.Receiver receiver : mReceivers.values()) {
                if (receiver.mIdentity.mPackageName.equals(packagename)) {
                    for (com.android.server.LocationManagerService.UpdateRecord record : receiver.mUpdateRecords.values()) {
                        if (!record.mProvider.equals(record.mRealRequest.getProvider())) {
                            mSwitchRecords.put(record, record.mRealRequest.getProvider());
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("getRemoveSwitchRecords, packagename:");
                            stringBuilder.append(packagename);
                            stringBuilder.append(" originalMode: ");
                            stringBuilder.append(record.mRealRequest.getProvider());
                            stringBuilder.append(", currentMode: ");
                            stringBuilder.append(record.mProvider);
                            stringBuilder.append(", receiver: ");
                            stringBuilder.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(receiver)));
                            android.util.Slog.d("HwLocationManagerService", stringBuilder.toString());
                        }
                    }
                }
            }
        }
        java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> preservedRecords = (java.util.ArrayList) this.mPreservedRecordsByPkg.get(packagename);
        if (preservedRecords != null) {
            java.util.Iterator<com.android.server.LocationManagerService.UpdateRecord> it = preservedRecords.iterator();
            while (it.hasNext()) {
                com.android.server.LocationManagerService.UpdateRecord record2 = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                if (!record2.mProvider.equals(record2.mRealRequest.getProvider())) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("getRemoveSwitchRecords record ");
                    stringBuilder2.append(record2);
                    android.util.Log.i("HwLocationManagerService", stringBuilder2.toString());
                    mSwitchRecords.put(record2, record2.mRealRequest.getProvider());
                    it.remove();
                }
            }
        }
        return mSwitchRecords;
    }

    private java.util.ArrayList<java.lang.String> updateLocationMode(java.util.HashMap<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> mSwitchRecords) {
        if (mSwitchRecords.size() == 0) {
            android.util.Slog.d("HwLocationManagerService", " package has no request send yet");
            return null;
        }
        java.util.HashMap<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> recordsByProvider = this.mLocationManagerServiceUtil.getRecordsByProvider();
        java.util.ArrayList<java.lang.String> updateproviders = new java.util.ArrayList();
        for (java.util.Map.Entry<com.android.server.LocationManagerService.UpdateRecord, java.lang.String> entry : mSwitchRecords.entrySet()) {
            java.lang.String target = (java.lang.String) entry.getValue();
            java.lang.String current = ((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mProvider;
            ((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mProvider = target;
            ((java.util.ArrayList) recordsByProvider.get(current)).remove(entry.getKey());
            if (((java.util.ArrayList) recordsByProvider.get(target)) == null) {
                recordsByProvider.put(target, new java.util.ArrayList());
            }
            if (!((java.util.ArrayList) recordsByProvider.get(target)).contains(entry.getKey())) {
                ((java.util.ArrayList) recordsByProvider.get(target)).add((com.android.server.LocationManagerService.UpdateRecord) entry.getKey());
            }
            ((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mReceiver.mUpdateRecords.remove(current, entry.getKey());
            com.android.server.LocationManagerService.Receiver receiver = ((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mReceiver;
            com.android.server.LocationManagerService.UpdateRecord oldRecord = (com.android.server.LocationManagerService.UpdateRecord) ((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mReceiver.mUpdateRecords.put(target, (com.android.server.LocationManagerService.UpdateRecord) entry.getKey());
            if (oldRecord != null) {
                java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> oldRecords = (java.util.ArrayList) this.mPreservedRecordsByPkg.get(oldRecord.mReceiver.mIdentity.mPackageName);
                if (oldRecords == null) {
                    oldRecords = new java.util.ArrayList();
                    this.mPreservedRecordsByPkg.put(oldRecord.mReceiver.mIdentity.mPackageName, oldRecords);
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateLocationMode oldRecord ");
                stringBuilder.append(oldRecord);
                android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
                if (!oldRecords.contains(oldRecord)) {
                    oldRecords.add(oldRecord);
                }
            }
            if (!updateproviders.contains(current)) {
                updateproviders.add(current);
            }
            if (!updateproviders.contains(target)) {
                updateproviders.add(target);
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("updateLocationMode receive : ");
            stringBuilder2.append(((com.android.server.LocationManagerService.UpdateRecord) entry.getKey()).mReceiver.toString());
            stringBuilder2.append(" ");
            stringBuilder2.append(current);
            stringBuilder2.append(" -> ");
            stringBuilder2.append(target);
            android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
        }
        return updateproviders;
    }

    private java.lang.String getSwitchMode(int uid, java.lang.String originalMode, java.lang.String currentMode, java.lang.String mExpectedMode) {
        java.lang.String targetmode = null;
        if (!(originalMode == null || mExpectedMode == null)) {
            if (currentMode != null) {
                if (!mExpectedMode.equals(currentMode)) {
                    if (!"passive".equals(originalMode)) {
                        if ("gps".equals(mExpectedMode)) {
                            targetmode = originalMode;
                        }
                        if ("network".equals(mExpectedMode) && "gps".equals(currentMode)) {
                            targetmode = "network";
                        }
                        if ("passive".equals(mExpectedMode)) {
                            targetmode = "passive";
                        }
                        if (targetmode == null || !isLocationModeAvailable(targetmode, uid)) {
                            return currentMode;
                        }
                        return targetmode;
                    }
                }
                return currentMode;
            }
        }
        return currentMode;
    }

    private java.lang.String getMode(int mode) {
        switch (mode) {
            case 0:
                break;
            case 1:
                return "gps";
            case 2:
                break;
            case 3:
                return "network";
            case 4:
                return "passive";
            case 5:
                break;
            default:
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("add unknow LocationMode, error! expectedmode is ");
                stringBuilder.append(mode);
                android.util.Slog.e("HwLocationManagerService", stringBuilder.toString());
                break;
        }
        return null;
    }

    private boolean isLocationModeAvailable(java.lang.String locationMode, int uid) {
        if (locationMode == null) {
            return false;
        }
        if ("network".equals(locationMode)) {
            if (this.mLocationManagerServiceUtil.isAllowedByCurrentUserSettingsLocked("network")) {
                return true;
            }
            android.util.Slog.i("HwLocationManagerService", "network setting is unavailable.");
            return false;
        } else if (!"gps".equals(locationMode)) {
            return false;
        } else {
            if (this.mLocationManagerServiceUtil.isAllowedByCurrentUserSettingsLocked("gps")) {
                return true;
            }
            android.util.Slog.i("HwLocationManagerService", "gps setting is unavailable.");
            return false;
        }
    }

    private void hwRemoveSwitchUpdates(com.android.server.LocationManagerService.Receiver receiver) {
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> preservedRecords = (java.util.ArrayList) this.mPreservedRecordsByPkg.get(receiver.mIdentity.mPackageName);
            if (preservedRecords != null) {
                java.util.Iterator<com.android.server.LocationManagerService.UpdateRecord> it = preservedRecords.iterator();
                while (it.hasNext()) {
                    com.android.server.LocationManagerService.UpdateRecord record = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                    if (record.mReceiver.equals(receiver)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("hwRemoveUpdatesLocked ");
                        stringBuilder.append(record);
                        android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
                        record.disposeLocked(false);
                        it.remove();
                    }
                }
            }
        }
    }

    private boolean isNetworkAvailable(int uid) {
        int i = uid;
        long identity;
        try {
            if (this.mHwContext == null) {
                android.util.Slog.e("HwLocationManagerService", "mHwContext is null error!");
                return false;
            }
            android.net.ConnectivityManager connectivity = (android.net.ConnectivityManager) this.mHwContext.getSystemService("connectivity");
            if (connectivity == null) {
                android.util.Slog.e("HwLocationManagerService", "connectivityManager is null error!");
                return false;
            }
            android.net.NetworkInfo infoWifi = connectivity.getNetworkInfo(1);
            android.net.NetworkInfo infoMoblie = connectivity.getNetworkInfo(0);
            if (infoWifi != null) {
                if (infoMoblie != null) {
                    boolean isWifiConn = infoWifi.isConnected();
                    boolean isMobileConn = infoMoblie.isConnected();
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("uid is ");
                    stringBuilder.append(i);
                    stringBuilder.append(" , isWifiConn is ");
                    stringBuilder.append(isWifiConn);
                    stringBuilder.append(" , isMobileConn is ");
                    stringBuilder.append(isMobileConn);
                    android.util.Slog.d("HwLocationManagerService", stringBuilder.toString());
                    android.net.HwNetworkPolicyManager manager = android.net.HwNetworkPolicyManager.from(this.mHwContext);
                    if (manager == null) {
                        android.util.Slog.e("HwLocationManagerService", "HwNetworkPolicyManager is null error!");
                        return false;
                    }
                    identity = android.os.Binder.clearCallingIdentity();
                    int policy = 0;
                    policy = manager.getHwUidPolicy(i);
                    android.os.Binder.restoreCallingIdentity(identity);
                    boolean wifiAccess = (policy & 2) == 0;
                    boolean mobileAccess = (policy & 1) == 0;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("policy is ");
                    stringBuilder2.append(policy);
                    stringBuilder2.append(" , wifiAccess is ");
                    stringBuilder2.append(wifiAccess);
                    stringBuilder2.append(", mobileAccess is ");
                    stringBuilder2.append(mobileAccess);
                    android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
                    boolean wifiAvaiable = wifiAccess && isWifiConn;
                    boolean mobileAvailable = mobileAccess && isMobileConn;
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("wifiAvaiable is ");
                    stringBuilder3.append(wifiAvaiable);
                    stringBuilder3.append(" , mobileAvailable is ");
                    stringBuilder3.append(mobileAvailable);
                    android.util.Slog.d("HwLocationManagerService", stringBuilder3.toString());
                    if (!wifiAvaiable) {
                        if (!mobileAvailable) {
                            return false;
                        }
                    }
                    return true;
                }
            }
            android.util.Slog.e("HwLocationManagerService", "infoWifi or infoMoblie is null error!");
            return false;
        } catch (java.lang.RuntimeException e) {
            java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
            stringBuilder4.append("RuntimeException error!");
            stringBuilder4.append(e.toString());
            android.util.Slog.e("HwLocationManagerService", stringBuilder4.toString());
            return false;
        } catch (java.lang.Exception e2) {
            android.util.Slog.e("HwLocationManagerService", "Exception error!");
            return false;
        } catch (java.lang.Throwable th) {
            android.os.Binder.restoreCallingIdentity(identity);
            java.lang.Throwable th2 = th;
        }
    }

    private boolean enforceAccessPermission(int pid, int uid) {
        if (this.mHwContext.checkPermission("android.permission.ACCESS_FINE_LOCATION", pid, uid) != 0) {
            if (this.mHwContext.checkPermission("android.permission.ACCESS_COARSE_LOCATION", pid, uid) != 0) {
                return false;
            }
        }
        return true;
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        int _result;
        int _result2;
        java.lang.String packagename;
        switch (code) {
            case 1001:
                data.enforceInterface("android.location.ILocationManager");
                _result = getPowerTypeByPackageName(data.readString());
                reply.writeNoException();
                reply.writeInt(_result);
                return true;
            case 1002:
                data.enforceInterface("android.location.ILocationManager");
                _result2 = logEvent(data.readInt(), data.readInt(), data.readString());
                reply.writeNoException();
                reply.writeInt(_result2);
                return true;
            case 1004:
                data.enforceInterface("android.location.ILocationManager");
                packagename = data.readString();
                _result = data.readInt();
                int expectedmode = data.readInt();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("on transact ADD_LOCATION_MODE  uid is ");
                stringBuilder.append(_result);
                stringBuilder.append(" , expectedmode is ");
                stringBuilder.append(expectedmode);
                stringBuilder.append(" , packagename is ");
                stringBuilder.append(packagename);
                android.util.Slog.d("HwLocationManagerService", stringBuilder.toString());
                _result2 = addSupervisoryControlProc(packagename, _result, expectedmode);
                reply.writeNoException();
                reply.writeInt(_result2);
                return true;
            case 1005:
                data.enforceInterface("android.location.ILocationManager");
                packagename = data.readString();
                _result = data.readInt();
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("on transact REMOVE_LOCATION_MODE uid is ");
                stringBuilder2.append(_result);
                stringBuilder2.append(" , packagename is ");
                stringBuilder2.append(packagename);
                android.util.Slog.d("HwLocationManagerService", stringBuilder2.toString());
                removeSupervisoryControlProc(packagename, _result);
                reply.writeNoException();
                return true;
            case 1006:
                data.enforceInterface("android.location.ILocationManager");
                _result2 = checkLocationSettings(data.readInt(), data.readString(), data.readString());
                reply.writeNoException();
                reply.writeInt(_result2);
                return true;
            case 1007:
                data.enforceInterface("android.location.ILocationManager");
                android.util.Slog.d("HwLocationManagerService", "on transact CODE_GNSS_DETECT");
                java.util.ArrayList<java.lang.String> _result3 = gnssDetect(data.readString());
                reply.writeNoException();
                reply.writeStringList(_result3);
                return true;
            default:
                return super.onTransact(code, data, reply, flags);
        }
    }

    private int checkLocationSettings(int userId, java.lang.String name, java.lang.String value) {
        int resultValue = -1;
        int mUserId = userId;
        if (!isChineseVersion()) {
            return -1;
        }
        if ("location_mode".equals(name)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("LOCATION_MODE, name: ");
            stringBuilder.append(name);
            stringBuilder.append(", value: ");
            stringBuilder.append(value);
            android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
            if (!LOCATION_MODE_SENSORS_ONLY.equals(value)) {
                if (!LOCATION_MODE_BATTERY_SAVING.equals(value)) {
                    if (LOCATION_MODE_OFF.equals(value) || LOCATION_MODE_HIGH_ACCURACY.equals(value)) {
                        mSettingsByUserId.put(java.lang.Integer.valueOf(mUserId), java.lang.Integer.valueOf(2));
                    }
                }
            }
            resultValue = 3;
            mSettingsByUserId.put(java.lang.Integer.valueOf(mUserId), java.lang.Integer.valueOf(2));
        } else if ("location_providers_allowed".equals(name)) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("LOCATION_PROVIDERS_ALLOWED, name: ");
            stringBuilder2.append(name);
            stringBuilder2.append(", value: ");
            stringBuilder2.append(value);
            android.util.Log.d("HwLocationManagerService", stringBuilder2.toString());
            if (mSettingsByUserId.containsKey(java.lang.Integer.valueOf(mUserId))) {
                int cnt = ((java.lang.Integer) mSettingsByUserId.get(java.lang.Integer.valueOf(mUserId))).intValue();
                if (cnt > 0) {
                    cnt--;
                    if (cnt == 0) {
                        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("clear mSettingsByUserId, cnt: ");
                        stringBuilder3.append(cnt);
                        android.util.Log.d("HwLocationManagerService", stringBuilder3.toString());
                        mSettingsByUserId.clear();
                    } else {
                        mSettingsByUserId.put(java.lang.Integer.valueOf(mUserId), java.lang.Integer.valueOf(cnt));
                    }
                }
            } else {
                if (!"+gps".equals(value)) {
                    if (!"+network".equals(value)) {
                        if ("-gps".equals(value) || "-network".equals(value)) {
                            resultValue = 0;
                            mSettingsByUserId.put(java.lang.Integer.valueOf(mUserId), java.lang.Integer.valueOf(2));
                        }
                    }
                }
                resultValue = 3;
                mSettingsByUserId.put(java.lang.Integer.valueOf(mUserId), java.lang.Integer.valueOf(2));
            }
        }
        return resultValue;
    }

    private boolean isChineseVersion() {
        return "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    }

    public static int qualityToType(int quality) {
        if (quality != 100) {
            if (!(quality == 102 || quality == 104)) {
                if (quality != 203) {
                    switch (quality) {
                        case 200:
                            return 0;
                        case 201:
                            break;
                        default:
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("quality( ");
                            stringBuilder.append(quality);
                            stringBuilder.append(" ) is error !");
                            android.util.Slog.d("HwLocationManagerService", stringBuilder.toString());
                            return -1;
                    }
                }
            }
            return 1;
        }
        return 2;
    }

    public int getPowerTypeByPackageName(java.lang.String packageName) {
        if (!enforceAccessPermission(android.os.Binder.getCallingPid(), android.os.Binder.getCallingUid())) {
            return -1;
        }
        int power_type_ret = -1;
        if (android.text.TextUtils.isEmpty(packageName)) {
            return -1;
        }
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            for (com.android.server.LocationManagerService.Receiver receiver : this.mLocationManagerServiceUtil.getReceivers().values()) {
                if (packageName.equals(receiver.mIdentity.mPackageName)) {
                    java.util.HashMap<java.lang.String, com.android.server.LocationManagerService.UpdateRecord> updateRecords = receiver.mUpdateRecords;
                    if (updateRecords != null) {
                        for (com.android.server.LocationManagerService.UpdateRecord updateRecord : updateRecords.values()) {
                            int power_type = qualityToType(updateRecord.mRequest.getQuality());
                            if (power_type > power_type_ret) {
                                power_type_ret = power_type;
                                if (power_type_ret == 2) {
                                    return power_type_ret;
                                }
                            }
                        }
                        continue;
                    } else {
                        continue;
                    }
                }
            }
            return power_type_ret;
        }
    }

    public int logEvent(int type, int event, java.lang.String parameter) {
        if (enforceAccessPermission(android.os.Binder.getCallingPid(), android.os.Binder.getCallingUid()) && !android.text.TextUtils.isEmpty(parameter)) {
            return com.android.server.location.HwGpsLogServices.getInstance(this.mHwContext).logEvent(type, event, parameter);
        }
        return -1;
    }

    protected boolean isGPSDisabled() {
        java.lang.String allowedProviders = android.provider.Settings.Secure.getStringForUser(this.mContext.getContentResolver(), "location_providers_allowed", android.app.ActivityManager.getCurrentUser());
        if (!android.hdm.HwDeviceManager.disallowOp(13)) {
            return false;
        }
        if (allowedProviders.contains("gps")) {
            android.util.Slog.i("HwLocationManagerService", "gps provider cannot be enabled, set it to false .");
            android.provider.Settings.Secure.setLocationProviderEnabledForUser(this.mContext.getContentResolver(), "gps", false, android.app.ActivityManager.getCurrentUser());
        }
        return true;
    }

    protected java.lang.String getLocationProvider(int uid, android.location.LocationRequest request, java.lang.String packageName, java.lang.String provider) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String targetprovider = provider;
        if ("gps".equals(provider) && com.android.server.location.GpsFreezeProc.getInstance().isInPackageWhiteListByType(5, packageName)) {
            targetprovider = "network";
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("packageName:");
            stringBuilder.append(packageName);
            stringBuilder.append(" is change gps provider to ");
            stringBuilder.append(targetprovider);
            android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        } else if (this.mSupervisoryPkgList.containsKey(packageName)) {
            if (isNetworkAvailable(uid) || !((java.lang.String) this.mSupervisoryPkgList.get(packageName)).equals("network")) {
                targetprovider = getSwitchMode(uid, provider, provider, (java.lang.String) this.mSupervisoryPkgList.get(packageName));
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("network is not available, packageName:");
                stringBuilder.append(packageName);
                stringBuilder.append(" need not change provider to network");
                android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
                targetprovider = provider;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("packageName:");
            stringBuilder.append(packageName);
            stringBuilder.append(" is change ");
            stringBuilder.append(provider);
            stringBuilder.append(" provider to ");
            stringBuilder.append(targetprovider);
            android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        }
        if ("network".equals(provider) && this.mIs5GHzBandSupported && request.getInterval() < 40000) {
            android.util.Log.d("HwLocationManagerService", "5G network min interval need to 40s");
            request.setInterval(40000);
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("lbsService mLBSServiceStart:");
        stringBuilder.append(this.mLBSServiceStart);
        android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        if ("gps".equals(provider) && !this.mLBSServiceStart) {
            android.util.Log.d("HwLocationManagerService", " LocationManager. bindLbsService start.");
            startLBSService();
            bindLBSService();
            if (this.mLbsServiceHandler.hasMessages(26)) {
                android.util.Log.d("HwLocationManagerService", " mLbsServiceHandler has delay message. bindLbsService start.");
                this.mLbsServiceHandler.removeMessages(26);
                this.mServiceRestartCount = 0;
            }
        }
        return targetprovider;
    }

    private void startLBSService() {
        this.mStartServiceTime = java.lang.System.currentTimeMillis();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(this.mContext.getPackageName());
        stringBuilder.append(" start lbs service. bindLbsService start time:");
        stringBuilder.append(this.mStartServiceTime);
        android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        try {
            android.content.Intent bindIntent = new android.content.Intent();
            bindIntent.setClassName("com.huawei.lbs", "com.huawei.lbs.HwLBSService");
            bindIntent.addFlags(268435456);
            this.mContext.startService(bindIntent);
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("startLBSService Exception: ");
            stringBuilder2.append(e.getMessage());
            android.util.Log.e("HwLocationManagerService", stringBuilder2.toString());
        }
    }

    private void bindLBSService() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(this.mContext.getPackageName());
        stringBuilder.append(" bind lbs service. bindLbsService");
        android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
        try {
            android.content.Intent bindIntent = new android.content.Intent();
            bindIntent.setClassName("com.huawei.lbs", "com.huawei.lbs.HwLBSService");
            this.mContext.bindService(bindIntent, this.mLBSServicedeathHandler, 1);
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("bindLBSService Exception: ");
            stringBuilder2.append(e.getMessage());
            android.util.Log.e("HwLocationManagerService", stringBuilder2.toString());
        }
    }

    private void notifyServiceDied() {
        try {
            if (this.mBinderLBSService != null) {
                this.mBinderLBSService.linkToDeath(this.mLBSServicedeathHandler, 0);
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwLocationManagerService", "IBinder register linkToDeath function fail.");
        }
    }

    private void sendLbsServiceRestartMessage() {
        long delayTime = 0;
        if (!this.mLbsServiceHandler.hasMessages(26)) {
            android.os.Message mTimeOut = android.os.Message.obtain(this.mLbsServiceHandler, 26);
            delayTime = (long) (60000.0d * java.lang.Math.pow(2.0d, (double) this.mServiceRestartCount));
            if (delayTime > 0) {
                this.mLbsServiceHandler.sendMessageDelayed(mTimeOut, delayTime);
            } else {
                this.mLbsServiceHandler.sendMessage(mTimeOut);
            }
        }
        if (this.mServiceRestartCount < 3) {
            this.mServiceRestartCount++;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("bindLbsService sendLbsServiceRestartMessage mServiceRestartCount: ");
        stringBuilder.append(this.mServiceRestartCount);
        stringBuilder.append(",delayTime:");
        stringBuilder.append(delayTime);
        android.util.Log.d("HwLocationManagerService", stringBuilder.toString());
    }

    protected void updateLastLocationDataBase(android.location.Location location, java.lang.String provider) {
        if (this.mLocalLocationProvider == null || this.mLocalLocationProvider.isValidLocation(location)) {
            try {
                if (this.mLastLocation == null) {
                    this.mLastLocation = readLastLocationDataBase();
                    if (this.mLastLocation == null) {
                        this.mLastLocation = new android.location.Location(location);
                        saveLocationToDataBase();
                        return;
                    }
                }
                if (location.getProvider().equals("network") && this.mLastLocation.getProvider().equals("gps") && location.getTime() - this.mLastLocation.getTime() > 3600000) {
                    android.util.Log.e("HwLocationManagerService", "New GPS Provider result not be refreshed by Network Provider result");
                    return;
                }
                this.mLastLocation.setLongitude(location.getLongitude());
                this.mLastLocation.setLatitude(location.getLatitude());
                this.mLastLocation.setTime(location.getTime());
                this.mLastLocation.setProvider(location.getProvider());
                this.mLastLocation.setAccuracy(location.getAccuracy());
                return;
            } catch (java.lang.Exception e) {
                android.util.Log.e("HwLocationManagerService", "updateLastLocationDataBase failed", e);
                return;
            }
        }
        android.util.Log.e("HwLocationManagerService", "incoming location is invdlid,and not report app");
    }

    protected void readySaveLocationToDataBase() {
        if (this.mLastLocation == null) {
            android.util.Log.e("HwLocationManagerService", "mLastLocation is NULL, nothing to saved");
            return;
        }
        long nowTime = java.lang.System.currentTimeMillis();
        if (0 != this.mLastLocation.getTime()) {
            if (nowTime - this.mLastLocation.getTime() <= 3600000) {
                sendHwLocationMessage(27, 600000);
            }
        }
        sendHwLocationMessage(27, 0);
    }

    protected void saveLocationToDataBase() {
        org.json.JSONObject jsonObj = new org.json.JSONObject();
        java.lang.StringBuilder stringBuilder;
        try {
            java.lang.String encryptedLong = MASTER_PASSWORD;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(this.mLastLocation.getLongitude());
            stringBuilder2.append("");
            encryptedLong = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(encryptedLong, stringBuilder2.toString());
            java.lang.String encryptedLat = MASTER_PASSWORD;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(this.mLastLocation.getLatitude());
            stringBuilder.append("");
            encryptedLat = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(encryptedLat, stringBuilder.toString());
            jsonObj.put("longitude", encryptedLong);
            jsonObj.put("latitude", encryptedLat);
            jsonObj.put("accuracy", (double) this.mLastLocation.getAccuracy());
            jsonObj.put("timestamp", this.mLastLocation.getTime());
            jsonObj.put("source", this.mLastLocation.getProvider());
        } catch (org.json.JSONException e) {
            android.util.Log.e("HwLocationManagerService", "updateLastLocationDataBase json error!");
            return;
        } catch (java.lang.Exception e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("saveLocationToDataBase Exception :");
            stringBuilder.append(e2.getMessage());
            android.util.Log.e("HwLocationManagerService", stringBuilder.toString());
        }
        android.provider.Settings.Global.putString(this.mHwContext.getContentResolver(), "save_location_database", jsonObj.toString());
    }

    protected android.location.Location readLastLocationDataBase() {
        try {
            java.lang.String locationStr = android.provider.Settings.Global.getString(this.mHwContext.getContentResolver(), "save_location_database");
            if (locationStr == null) {
                android.util.Log.e("HwLocationManagerService", "readLastLocationDataBase locationStr null");
                return null;
            }
            org.json.JSONObject jsonObj = new org.json.JSONObject(locationStr);
            java.lang.String encryptedLong = jsonObj.getString("longitude");
            java.lang.String decryptedLat = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.decrypt(MASTER_PASSWORD, jsonObj.getString("latitude"));
            double longitudeSaved = java.lang.Double.parseDouble(com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.decrypt(MASTER_PASSWORD, encryptedLong));
            double latitudeSaved = java.lang.Double.parseDouble(decryptedLat);
            java.lang.String providerSeaved = jsonObj.getString("source");
            long timestampSaved = jsonObj.getLong("timestamp");
            float accuricy = (float) jsonObj.getLong("timestamp");
            float f;
            if (0.0d == longitudeSaved) {
                f = accuricy;
            } else if (0.0d == latitudeSaved) {
                java.lang.String str = locationStr;
                f = accuricy;
            } else {
                android.location.Location location = new android.location.Location("gps");
                location.setLongitude(longitudeSaved);
                location.setLatitude(latitudeSaved);
                location.setTime(timestampSaved);
                location.setProvider(providerSeaved);
                location.setAccuracy(accuricy);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("readLastLocationDataBase");
                stringBuilder.append(location);
                android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
                return location;
            }
            android.util.Log.e("HwLocationManagerService", "No record in Database");
            return null;
        } catch (java.lang.Exception e) {
            android.util.Log.e("HwLocationManagerService", "readLastLocationDataBase failed", e);
            return null;
        }
    }

    protected boolean isExceptionAppForUserSettingsLocked(java.lang.String packageName) {
        if (packageName == null) {
            return false;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isExceptionAppForUserSettingsLocked packageName:");
        stringBuilder.append(packageName);
        android.util.Log.e("HwLocationManagerService", stringBuilder.toString());
        if ("com.hisi.mapcon".equals(packageName)) {
            return true;
        }
        return false;
    }

    private boolean isDualBandSupported() {
        return this.mContext.getResources().getBoolean(17957074);
    }

    protected void hwSendBehavior(huawei.android.security.IHwBehaviorCollectManager.BehaviorId bid) {
        huawei.android.security.IHwBehaviorCollectManager manager = android.common.HwFrameworkFactory.getHwBehaviorCollectManager();
        if (manager != null) {
            manager.sendBehavior(android.os.Binder.getCallingUid(), android.os.Binder.getCallingPid(), bid);
        }
    }

    public void hwRequestLocationUpdatesLocked(android.location.LocationRequest request, com.android.server.LocationManagerService.Receiver receiver, int pid, int uid, java.lang.String packageName) {
        com.android.server.HwGnssDetectManager.getInstance(this.mHwContext).hwRequestLocationUpdatesLocked(request, receiver, pid, uid, packageName);
        android.os.Handler locationHandler = this.mLocationManagerServiceUtil.getLocationHandler();
        if (!locationHandler.hasMessages(7)) {
            locationHandler.sendEmptyMessageDelayed(7, 300000);
        }
    }

    public java.util.ArrayList<java.lang.String> gnssDetect(java.lang.String packageName) {
        java.util.ArrayList gnssDetect;
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            gnssDetect = com.android.server.HwGnssDetectManager.getInstance(this.mHwContext).gnssDetect(packageName);
        }
        return gnssDetect;
    }

    public void hwRemoveUpdatesLocked(com.android.server.LocationManagerService.Receiver receiver) {
        hwRemoveSwitchUpdates(receiver);
    }

    private void registerPkgClearReceiver() {
        android.content.IntentFilter packageFilter = new android.content.IntentFilter();
        packageFilter.addAction("android.intent.action.PACKAGE_DATA_CLEARED");
        packageFilter.addAction("android.intent.action.PACKAGE_RESTARTED");
        packageFilter.addDataScheme("package");
        this.mContext.registerReceiverAsUser(this.mPackegeClearReceiver, android.os.UserHandle.OWNER, packageFilter, null, null);
    }

    private void hwLocationCheck() {
        removeNotRunAndNotExistRecords();
        hwLockCheck();
    }

    /* JADX WARNING: Missing block: B:39:0x011e, code:
            return;
     */
    private void removeNotRunAndNotExistRecords() {
        /*
        r15 = this;
        r0 = r15.mContext;
        r1 = "activity";
        r0 = r0.getSystemService(r1);
        r0 = (android.app.ActivityManager) r0;
        r1 = r0.getRunningAppProcesses();
        r2 = r15.mLocationManagerServiceUtil;
        r2 = r2.getmLock();
        monitor-enter(r2);
        r3 = r15.mLocationManagerServiceUtil;	 Catch:{ all -> 0x011f }
        r3 = r3.getRecordsByProvider();	 Catch:{ all -> 0x011f }
        if (r3 == 0) goto L_0x011d;
    L_0x001d:
        r4 = r3.isEmpty();	 Catch:{ all -> 0x011f }
        if (r4 == 0) goto L_0x0025;
    L_0x0023:
        goto L_0x011d;
    L_0x0025:
        if (r1 != 0) goto L_0x0030;
    L_0x0027:
        r4 = "HwLocationManagerService";
        r5 = "no Process find";
        android.util.Log.w(r4, r5);	 Catch:{ all -> 0x011f }
        monitor-exit(r2);	 Catch:{ all -> 0x011f }
        return;
    L_0x0030:
        r4 = r15.mLocationManagerServiceUtil;	 Catch:{ all -> 0x011f }
        r4 = r4.getReceivers();	 Catch:{ all -> 0x011f }
        r4 = r4.clone();	 Catch:{ all -> 0x011f }
        r4 = (java.util.HashMap) r4;	 Catch:{ all -> 0x011f }
        r5 = r3.entrySet();	 Catch:{ all -> 0x011f }
        r5 = r5.iterator();	 Catch:{ all -> 0x011f }
    L_0x0044:
        r6 = r5.hasNext();	 Catch:{ all -> 0x011f }
        if (r6 == 0) goto L_0x011b;
    L_0x004a:
        r6 = r5.next();	 Catch:{ all -> 0x011f }
        r6 = (java.util.Map.Entry) r6;	 Catch:{ all -> 0x011f }
        r7 = r6.getValue();	 Catch:{ all -> 0x011f }
        r7 = (java.util.ArrayList) r7;	 Catch:{ all -> 0x011f }
        if (r7 == 0) goto L_0x0044;
    L_0x0058:
        r8 = r7.clone();	 Catch:{ all -> 0x011f }
        r8 = (java.util.ArrayList) r8;	 Catch:{ all -> 0x011f }
        r7 = r8;
        r8 = r7.iterator();	 Catch:{ all -> 0x011f }
    L_0x0063:
        r9 = r8.hasNext();	 Catch:{ all -> 0x011f }
        if (r9 == 0) goto L_0x0119;
    L_0x0069:
        r9 = r8.next();	 Catch:{ all -> 0x011f }
        r9 = (com.android.server.LocationManagerService.UpdateRecord) r9;	 Catch:{ all -> 0x011f }
        r10 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r10 = r4.containsValue(r10);	 Catch:{ all -> 0x011f }
        if (r10 != 0) goto L_0x00ae;
    L_0x0077:
        r10 = 0;
        r9.disposeLocked(r10);	 Catch:{ all -> 0x011f }
        r10 = "HwLocationManagerService";
        r11 = new java.lang.StringBuilder;	 Catch:{ all -> 0x011f }
        r11.<init>();	 Catch:{ all -> 0x011f }
        r12 = "receiver not exists, but updateRecord not remove!  pid = ";
        r11.append(r12);	 Catch:{ all -> 0x011f }
        r12 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r12 = r12.mIdentity;	 Catch:{ all -> 0x011f }
        r12 = r12.mPid;	 Catch:{ all -> 0x011f }
        r11.append(r12);	 Catch:{ all -> 0x011f }
        r12 = " uid = ";
        r11.append(r12);	 Catch:{ all -> 0x011f }
        r12 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r12 = r12.mIdentity;	 Catch:{ all -> 0x011f }
        r12 = r12.mUid;	 Catch:{ all -> 0x011f }
        r11.append(r12);	 Catch:{ all -> 0x011f }
        r12 = " UpdateRecord = ";
        r11.append(r12);	 Catch:{ all -> 0x011f }
        r11.append(r9);	 Catch:{ all -> 0x011f }
        r11 = r11.toString();	 Catch:{ all -> 0x011f }
        android.util.Log.w(r10, r11);	 Catch:{ all -> 0x011f }
        goto L_0x0063;
    L_0x00ae:
        r10 = 0;
        r11 = r1.iterator();	 Catch:{ all -> 0x011f }
    L_0x00b3:
        r12 = r11.hasNext();	 Catch:{ all -> 0x011f }
        if (r12 == 0) goto L_0x00d6;
    L_0x00b9:
        r12 = r11.next();	 Catch:{ all -> 0x011f }
        r12 = (android.app.ActivityManager.RunningAppProcessInfo) r12;	 Catch:{ all -> 0x011f }
        r13 = r12.pid;	 Catch:{ all -> 0x011f }
        r14 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r14 = r14.mIdentity;	 Catch:{ all -> 0x011f }
        r14 = r14.mPid;	 Catch:{ all -> 0x011f }
        if (r13 != r14) goto L_0x00d5;
    L_0x00c9:
        r13 = r12.uid;	 Catch:{ all -> 0x011f }
        r14 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r14 = r14.mIdentity;	 Catch:{ all -> 0x011f }
        r14 = r14.mUid;	 Catch:{ all -> 0x011f }
        if (r13 != r14) goto L_0x00d5;
    L_0x00d3:
        r10 = 1;
        goto L_0x00d6;
    L_0x00d5:
        goto L_0x00b3;
    L_0x00d6:
        if (r10 != 0) goto L_0x0117;
    L_0x00d8:
        r11 = r15.mLocationManagerServiceUtil;	 Catch:{ all -> 0x011f }
        r12 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r11.removeUpdatesLocked(r12);	 Catch:{ all -> 0x011f }
        r11 = "HwLocationManagerService";
        r12 = new java.lang.StringBuilder;	 Catch:{ all -> 0x011f }
        r12.<init>();	 Catch:{ all -> 0x011f }
        r13 = "process may be died, but request not remove!  pid = ";
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r13 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r13 = r13.mIdentity;	 Catch:{ all -> 0x011f }
        r13 = r13.mPid;	 Catch:{ all -> 0x011f }
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r13 = " uid = ";
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r13 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r13 = r13.mIdentity;	 Catch:{ all -> 0x011f }
        r13 = r13.mUid;	 Catch:{ all -> 0x011f }
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r13 = " receiver = ";
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r13 = r9.mReceiver;	 Catch:{ all -> 0x011f }
        r13 = r13.toString();	 Catch:{ all -> 0x011f }
        r12.append(r13);	 Catch:{ all -> 0x011f }
        r12 = r12.toString();	 Catch:{ all -> 0x011f }
        android.util.Log.w(r11, r12);	 Catch:{ all -> 0x011f }
    L_0x0117:
        goto L_0x0063;
    L_0x0119:
        goto L_0x0044;
    L_0x011b:
        monitor-exit(r2);	 Catch:{ all -> 0x011f }
        return;
    L_0x011d:
        monitor-exit(r2);	 Catch:{ all -> 0x011f }
        return;
    L_0x011f:
        r3 = move-exception;
        monitor-exit(r2);	 Catch:{ all -> 0x011f }
        throw r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.HwLocationManagerService.removeNotRunAndNotExistRecords():void");
    }

    private void hwLockCheck() {
        java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> longLockRecords = checkLongLock();
        clearLongLock(longLockRecords);
        callClientHandle(longLockRecords);
        finalCheck();
    }

    private java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> checkLongLock() {
        java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> longLockRecords = new java.util.ArrayList();
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            java.util.HashMap<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> recordsByProvider = this.mLocationManagerServiceUtil.getRecordsByProvider();
            long currentTime = android.os.SystemClock.elapsedRealtime();
            for (java.util.Map.Entry<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> entry : recordsByProvider.entrySet()) {
                java.util.Iterator it = ((java.util.ArrayList) entry.getValue()).iterator();
                while (it.hasNext()) {
                    long currentTime2;
                    com.android.server.LocationManagerService.UpdateRecord record = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                    long acquireLockTime = record.mReceiver.mAcquireLockTime;
                    if (acquireLockTime > record.mReceiver.mReleaseLockTime) {
                        currentTime2 = currentTime;
                        if (currentTime - acquireLockTime >= this.LOCK_HELD_BAD_TIME) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("hold lock for too long time ");
                            stringBuilder.append(record);
                            stringBuilder.append(" receiver ");
                            stringBuilder.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(record.mReceiver)));
                            android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
                            longLockRecords.add(record);
                        }
                    } else {
                        currentTime2 = currentTime;
                    }
                    currentTime = currentTime2;
                }
            }
        }
        return longLockRecords;
    }

    private void clearLongLock(java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> longLockRecords) {
        if (longLockRecords != null) {
            if (!longLockRecords.isEmpty()) {
                int listSize = longLockRecords.size();
                for (int i = 0; i < listSize; i++) {
                    com.android.server.LocationManagerService.UpdateRecord record = (com.android.server.LocationManagerService.UpdateRecord) longLockRecords.get(i);
                    synchronized (record.mReceiver) {
                        record.mReceiver.clearPendingBroadcastsLocked();
                    }
                }
            }
        }
    }

    private void callClientHandle(java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> badRecords) {
        if (badRecords != null) {
            if (!badRecords.isEmpty()) {
                synchronized (this.mLocationManagerServiceUtil.getmLock()) {
                    java.util.Iterator it = badRecords.iterator();
                    while (it.hasNext()) {
                        com.android.server.LocationManagerService.UpdateRecord record = (com.android.server.LocationManagerService.UpdateRecord) it.next();
                        if (record.mReceiver.mListener != null) {
                            record.mReceiver.callLocationChangedLocked(new android.location.Location("DEAD"));
                        }
                    }
                }
            }
        }
    }

    private void finalCheck() {
        boolean needCheckAgain;
        int totalPendingBroadcasts = 0;
        synchronized (this.mLocationManagerServiceUtil.getmLock()) {
            java.util.HashMap<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> recordsByProvider = this.mLocationManagerServiceUtil.getRecordsByProvider();
            for (java.util.Map.Entry<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> entry : recordsByProvider.entrySet()) {
                java.util.Iterator it = ((java.util.ArrayList) entry.getValue()).iterator();
                while (it.hasNext()) {
                    totalPendingBroadcasts += ((com.android.server.LocationManagerService.UpdateRecord) it.next()).mReceiver.mPendingBroadcasts;
                }
            }
            java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> gpsRecords = (java.util.ArrayList) recordsByProvider.get("gps");
            boolean z = (totalPendingBroadcasts <= 0 || gpsRecords == null || gpsRecords.isEmpty()) ? false : true;
            needCheckAgain = z;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwCheckLock finalCheck ");
        stringBuilder.append(totalPendingBroadcasts);
        stringBuilder.append(" needCheckAgain ");
        stringBuilder.append(needCheckAgain);
        android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
        if (needCheckAgain) {
            android.os.Handler locationHandler = this.mLocationManagerServiceUtil.getLocationHandler();
            if (!locationHandler.hasMessages(7)) {
                locationHandler.sendEmptyMessageDelayed(7, 300000);
            }
        }
    }

    private void removeStoppedRecords(java.lang.String pkgName) {
        if (pkgName != null) {
            boolean isPkgHasRecord = false;
            synchronized (this.mLocationManagerServiceUtil.getmLock()) {
                for (java.util.Map.Entry<java.lang.String, java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord>> entry : this.mLocationManagerServiceUtil.getRecordsByProvider().entrySet()) {
                    java.util.ArrayList<com.android.server.LocationManagerService.UpdateRecord> records = (java.util.ArrayList) entry.getValue();
                    if (records != null) {
                        java.util.Iterator it = ((java.util.ArrayList) records.clone()).iterator();
                        while (it.hasNext()) {
                            if (pkgName.equals(((com.android.server.LocationManagerService.UpdateRecord) it.next()).mReceiver.mIdentity.mPackageName)) {
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("package stopped, remove updateRecords and receivers: ");
                                stringBuilder.append(pkgName);
                                android.util.Log.i("HwLocationManagerService", stringBuilder.toString());
                                isPkgHasRecord = true;
                                break;
                            }
                        }
                        if (isPkgHasRecord) {
                            break;
                        }
                    }
                }
            }
            if (isPkgHasRecord) {
                removeNotRunAndNotExistRecords();
            }
        }
    }
}
