package com.android.server;

public final class HwMountManagerService {
    private static final java.lang.String TAG = "HwMountManagerService";
    private static volatile com.android.server.HwMountManagerService mInstance = null;
    private android.content.Context mContext;
    private android.os.Handler mHandler;
    private final java.lang.Object mLock = new java.lang.Object();
    private final java.util.HashMap<java.lang.String, com.android.server.HwMountManagerService.MountingBinderInfo> mMBIMaps = new java.util.HashMap();
    private android.os.HandlerThread mThread;

    protected final class MountingBinderInfo implements android.os.IBinder.DeathRecipient {
        public final android.os.IBinder mBinder;
        public java.lang.String mMountPoint;

        public MountingBinderInfo(android.os.IBinder binder, java.lang.String mountPoint) {
            this.mBinder = binder;
            this.mMountPoint = mountPoint;
        }

        public void binderDied() {
            com.android.server.HwMountManagerService.this.handleMountingBinderDeath(this);
        }
    }

    public static synchronized com.android.server.HwMountManagerService getInstance(android.content.Context context) {
        com.android.server.HwMountManagerService hwMountManagerService;
        synchronized (com.android.server.HwMountManagerService.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.HwMountManagerService(context);
            }
            hwMountManagerService = mInstance;
        }
        return hwMountManagerService;
    }

    public HwMountManagerService(android.content.Context context) {
        this.mContext = context;
        this.mThread = new android.os.HandlerThread("HwMountManagerService");
        this.mThread.start();
        this.mHandler = new android.os.Handler(this.mThread.getLooper());
    }

    public void handleMountingBinderDeath(final com.android.server.HwMountManagerService.MountingBinderInfo mbi) {
        this.mHandler.post(new java.lang.Runnable() {
            public void run() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Binder Death: mountPoint=");
                stringBuilder.append(mbi.mMountPoint);
                android.util.Log.d("HwMountManagerService", stringBuilder.toString());
                try {
                    synchronized (com.android.server.HwMountManagerService.this.mLock) {
                        com.android.server.HwMountManagerService.this.mMBIMaps.remove(mbi.mMountPoint);
                    }
                    com.android.server.StorageManagerService.sSelf.mVold.unmountCifs(mbi.mMountPoint);
                } catch (java.lang.Exception e) {
                    android.util.Log.e("HwMountManagerService", "handleMountingBinderDeath unmountCifs error!");
                }
            }
        });
    }

    public java.lang.String mountCifs(java.lang.String source, java.lang.String option, android.os.IBinder binder) {
        this.mContext.enforceCallingPermission("android.permission.MOUNT_UNMOUNT_FILESYSTEMS", "mountCifs called no permission");
        java.lang.String mountPoint = null;
        try {
            mountPoint = com.android.server.StorageManagerService.sSelf.mVold.mountCifs(source, option);
            if (!(mountPoint == null || binder == null)) {
                synchronized (this.mLock) {
                    com.android.server.HwMountManagerService.MountingBinderInfo mbi = new com.android.server.HwMountManagerService.MountingBinderInfo(binder, mountPoint);
                    binder.linkToDeath(mbi, 0);
                    this.mMBIMaps.put(mountPoint, mbi);
                }
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwMountManagerService", "HwMountManagerService mountCifs error!");
        }
        return mountPoint;
    }

    public void unmountCifs(java.lang.String mountPoint) {
        this.mContext.enforceCallingPermission("android.permission.MOUNT_UNMOUNT_FILESYSTEMS", "unmountCifs called no permission");
        try {
            com.android.server.StorageManagerService.sSelf.mVold.unmountCifs(mountPoint);
            synchronized (this.mLock) {
                com.android.server.HwMountManagerService.MountingBinderInfo mbi = (com.android.server.HwMountManagerService.MountingBinderInfo) this.mMBIMaps.get(mountPoint);
                if (mbi == null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("unmountCifs: mountPoint=");
                    stringBuilder.append(mountPoint);
                    stringBuilder.append(" [not found]");
                    android.util.Log.d("HwMountManagerService", stringBuilder.toString());
                } else {
                    mbi.mBinder.unlinkToDeath(mbi, 0);
                    this.mMBIMaps.remove(mountPoint);
                }
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwMountManagerService", "HwMountManagerService unmountCifs error!");
        }
    }

    public int isSupportedCifs() {
        this.mContext.enforceCallingPermission("android.permission.MOUNT_UNMOUNT_FILESYSTEMS", "isSupportedCifs called no permission");
        try {
            return com.android.server.StorageManagerService.sSelf.mVold.supportCifs();
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwMountManagerService", "HwMountManagerService isSupportedCifs error!");
            return -1;
        }
    }
}
