package com.android.server;

public final class HwSdCryptdService {
    private static final java.lang.String BROADCAST_HWSDCRYPTD_STATE = "com.huawei.android.HWSDCRYPTD_STATE";
    private static final java.lang.String BROADCAST_PERSSION = "com.huawei.hwSdCryptd.permission.RECV_HWSDCRYPTD_RESULT";
    private static final java.lang.String CRYPTD_TAG = "SdCryptdConnector";
    private static final boolean DEBUG = true;
    private static final java.lang.String EXTRA_ENABLE = "enable";
    private static final java.lang.String EXTRA_EVENT_CODE = "code";
    private static final java.lang.String EXTRA_EVENT_MSG = "message";
    private static final int MAX_CONTAINERS = 250;
    private static final int MSG_DO_BROADCAST = 1;
    private static final int MSG_DO_MOUNT = 0;
    private static final int RESPONSE_CODE_ERROR = -1;
    private static final int RESPONSE_CODE_OK = 0;
    private static final int RESPONSE_SDCRYPTD_FAILED = 906;
    private static final int RESPONSE_SDCRYPTD_MOUNT = 905;
    private static final int RESPONSE_SDCRYPTD_SUCCESS = 907;
    private static final java.lang.String TAG = "HwSdCryptdService";
    private static volatile com.android.server.HwSdCryptdService mInstance = null;
    private android.content.Context mContext;
    private android.os.Handler mHandler;
    private android.os.HandlerThread mThread = new android.os.HandlerThread("HwSdCryptdHandler");
    private volatile android.os.IVold mVold;

    private final class HwSdCryptdHandler extends android.os.Handler {
        public HwSdCryptdHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 0:
                    android.util.Log.i("HwSdCryptdService", "handleMessage MSG_DO_MOUNT");
                    java.lang.String volId = msg.obj;
                    android.os.storage.IStorageManager mountService = com.android.server.HwSdCryptdService.getMountService();
                    if (mountService == null) {
                        android.util.Log.e("HwSdCryptdService", "unMount cannot get IMountService service.");
                        return;
                    }
                    try {
                        mountService.mount(volId);
                        return;
                    } catch (java.lang.Exception e) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("HwSdCryptdHandler mountService has exception : ");
                        stringBuilder.append(e);
                        android.util.Log.e("HwSdCryptdService", stringBuilder.toString());
                        return;
                    }
                case 1:
                    android.util.Log.i("HwSdCryptdService", "handleMessage MSG_DO_BROADCAST");
                    com.android.server.HwSdCryptdService.this.sendBroadcast(msg.obj);
                    return;
                default:
                    return;
            }
        }
    }

    public static synchronized com.android.server.HwSdCryptdService getInstance(android.content.Context context) {
        com.android.server.HwSdCryptdService hwSdCryptdService;
        synchronized (com.android.server.HwSdCryptdService.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.HwSdCryptdService(context);
            }
            hwSdCryptdService = mInstance;
        }
        return hwSdCryptdService;
    }

    public HwSdCryptdService(android.content.Context context) {
        this.mContext = context;
        this.mThread.start();
        this.mHandler = new com.android.server.HwSdCryptdService.HwSdCryptdHandler(this.mThread.getLooper());
        connect();
    }

    private void connect() {
        android.os.IBinder binder = android.os.ServiceManager.getService("vold");
        if (binder != null) {
            try {
                binder.linkToDeath(new android.os.IBinder.DeathRecipient() {
                    public void binderDied() {
                        android.util.Slog.w("HwSdCryptdService", "vold died; reconnecting");
                        com.android.server.HwSdCryptdService.this.mVold = null;
                        com.android.server.HwSdCryptdService.this.connect();
                    }
                }, 0);
            } catch (android.os.RemoteException e) {
                binder = null;
            }
        }
        if (binder != null) {
            this.mVold = android.os.IVold.Stub.asInterface(binder);
        } else {
            android.util.Slog.w("HwSdCryptdService", "vold not found; trying again");
        }
        if (this.mVold == null) {
            com.android.internal.os.BackgroundThread.getHandler().postDelayed(new com.android.server.-$$Lambda$HwSdCryptdService$dI4z0u8m27l3cJ8TMrOeHHSTzZg(this), 1000);
        }
    }

    public int setSdCardCryptdEnable(boolean enable, java.lang.String volId) {
        if (!checkPermission("setSdCardCryptdEnable")) {
            return -1;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setCryptdEnable: ");
        stringBuilder.append(enable);
        stringBuilder.append(",volId: ");
        stringBuilder.append(volId);
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        int code = -1;
        try {
            if (this.mVold != null) {
                if (enable) {
                    this.mVold.cryptsdEnable(volId);
                } else {
                    this.mVold.cryptsdDisable(volId);
                }
                code = 0;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("setSdCardCryptdEnable has exception : ");
            stringBuilder2.append(e);
            android.util.Log.e("HwSdCryptdService", stringBuilder2.toString());
        }
        return code;
    }

    public int addSdCardUserKeyAuth(int userId, int serialNumber, byte[] token, byte[] secret) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("addSdCardUserKeyAuth,userId: ");
        stringBuilder.append(userId);
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        if (!checkPermission("addSdCardUserKeyAuth")) {
            return -1;
        }
        int code = -1;
        try {
            if (this.mVold != null) {
                this.mVold.cryptsdAddKeyAuth(userId, serialNumber, encodeBytes(token), encodeBytes(secret));
                code = 0;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("addSdCardUserKeyAuth has exception : ");
            stringBuilder2.append(e);
            android.util.Log.e("HwSdCryptdService", stringBuilder2.toString());
        }
        return code;
    }

    public int unlockSdCardKey(int userId, int serialNumber, byte[] token, byte[] secret) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("unlockSdCardKey,userId: ");
        stringBuilder.append(userId);
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        if (!checkPermission("unlockSdCardKey")) {
            return -1;
        }
        int code = -1;
        try {
            if (this.mVold != null) {
                this.mVold.cryptsdUnlockKey(userId, serialNumber, encodeBytes(token), encodeBytes(secret));
                code = 0;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("unlockSdCardKey has exception : ");
            stringBuilder2.append(e);
            android.util.Log.e("HwSdCryptdService", stringBuilder2.toString());
        }
        return code;
    }

    public int backupSecretkey() {
        android.util.Log.i("HwSdCryptdService", "backupSecretkey");
        if (!checkPermission("backupSecretkey")) {
            return -1;
        }
        int code = -1;
        try {
            if (this.mVold != null) {
                this.mVold.cryptsdBackupInfo();
                code = 0;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("backupSecretkey has exception : ");
            stringBuilder.append(e);
            android.util.Log.e("HwSdCryptdService", stringBuilder.toString());
        }
        return code;
    }

    private java.lang.String encodeBytes(byte[] bytes) {
        if (com.android.internal.util.ArrayUtils.isEmpty(bytes)) {
            return "!";
        }
        return com.android.internal.util.HexDump.toHexString(bytes);
    }

    private void sendBroadcast(android.content.Intent intent) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("sendBroadcast:");
        stringBuilder.append(intent.getAction());
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.ALL, "com.huawei.hwSdCryptd.permission.RECV_HWSDCRYPTD_RESULT");
    }

    private boolean checkPermission(java.lang.String method) {
        if (android.os.UserHandle.getAppId(android.os.Binder.getCallingUid()) == 1000) {
            return true;
        }
        int pid = android.os.Binder.getCallingPid();
        int uid = android.os.Binder.getCallingUid();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(method);
        stringBuilder.append("called no permission, callingPid is ");
        stringBuilder.append(pid);
        stringBuilder.append(",callingUid is ");
        stringBuilder.append(uid);
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        return false;
    }

    public void onCryptsdMessage(java.lang.String message) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("receive event: ");
        stringBuilder.append(message);
        android.util.Log.i("HwSdCryptdService", stringBuilder.toString());
        if (message != null) {
            java.lang.String[] cooked = com.android.server.NativeDaemonEvent.unescapeArgs(message);
            if (!com.android.internal.util.ArrayUtils.isEmpty(cooked)) {
                int code = -1;
                try {
                    code = java.lang.Integer.parseInt(cooked[0]);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("parseInt has exception : ");
                    stringBuilder2.append(e);
                    android.util.Log.e("HwSdCryptdService", stringBuilder2.toString());
                }
                if (905 == code) {
                    if (cooked.length == 2) {
                        this.mHandler.obtainMessage(0, cooked[1]).sendToTarget();
                    }
                } else if ((907 == code || 906 == code) && cooked.length == 3) {
                    android.content.Intent intent = new android.content.Intent("com.huawei.android.HWSDCRYPTD_STATE");
                    intent.putExtra("code", code);
                    intent.putExtra("enable", cooked[1]);
                    intent.putExtra("message", cooked[2]);
                    this.mHandler.obtainMessage(1, intent).sendToTarget();
                }
            }
        }
    }

    public static android.os.storage.IStorageManager getMountService() {
        android.os.IBinder service = android.os.ServiceManager.getService("mount");
        if (service != null) {
            return android.os.storage.IStorageManager.Stub.asInterface(service);
        }
        android.util.Log.e("HwSdCryptdService", "getMountService ERROR");
        return null;
    }
}
