package com.android.server;

public class HwTouchWeightService {
    private static final java.lang.String FILE_PATH = "/sys/touchscreen/touch_weight";
    private static final int GET_WEIGHT_TIMEOUT = 1800;
    private static final int GET_WEIGHT_TIMEOUT_MESSAGE = 100;
    private static final int HAERT_BEAT_MESSAGE = 101;
    private static final int HAERT_BEAT_TIME = 1000;
    private static final java.lang.String HAERT_BEAT_VALUE = "2";
    private static final java.lang.String RUN_TOUCH_WEIGHT_VALUE = "1";
    private static final java.lang.String STOP_TOUCH_WEIGHT_VALUE = "0";
    private static final java.lang.String TAG = "HwTouchWeightService";
    private static volatile com.android.server.HwTouchWeightService mInstance = null;
    private boolean isFeatureEnabled = false;
    private boolean isFeatureSupport = false;
    private android.os.Handler mHandler;

    private final class TouchWeightHandler extends android.os.Handler {
        public TouchWeightHandler(android.os.Looper looper) {
            super(looper, null, true);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 100:
                    com.android.server.HwTouchWeightService.this.resetTouchWeight();
                    break;
                case 101:
                    com.android.server.HwTouchWeightService.this.startHeartBeat();
                    break;
                default:
                    return;
            }
        }
    }

    public HwTouchWeightService(android.content.Context context, android.os.Handler handler) {
        this.mHandler = new com.android.server.HwTouchWeightService.TouchWeightHandler(handler.getLooper());
        this.isFeatureSupport = isFeatureSupport();
    }

    private boolean isFeatureSupport() {
        if (new java.io.File("/sys/touchscreen/touch_weight").exists()) {
            return true;
        }
        return false;
    }

    public synchronized java.lang.String getTouchWeightValue() {
        java.lang.String val;
        if (!this.isFeatureSupport) {
            return null;
        }
        if (!this.isFeatureEnabled) {
            enableTouchWeight();
        }
        java.io.FileInputStream in = null;
        try {
            in = new java.io.FileInputStream(new java.io.File("/sys/touchscreen/touch_weight"));
            byte[] b = new byte[64];
            val = new java.lang.String(b, 0, in.read(b), "utf-8");
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("HwTouchWeightService getTouchWeightValue ");
            stringBuilder.append(val);
            android.util.Log.i("touch weight", stringBuilder.toString());
            try {
                in.close();
            } catch (java.io.IOException e) {
            }
        } catch (java.io.FileNotFoundException e2) {
            if (in != null) {
                in.close();
            }
            resetTimeOut();
            android.util.Log.i("touch weight", "HwTouchWeightService getTouchWeightValue null");
            return null;
        } catch (java.io.IOException e3) {
            if (in != null) {
                try {
                    in.close();
                } catch (java.io.IOException e4) {
                }
            }
            resetTimeOut();
            android.util.Log.i("touch weight", "HwTouchWeightService getTouchWeightValue null");
            return null;
        } catch (Throwable th) {
            if (in != null) {
                try {
                    in.close();
                } catch (java.io.IOException e5) {
                }
            }
        }
        return val;
    }

    public synchronized void resetTouchWeight() {
        if (this.isFeatureSupport) {
            if (this.mHandler.hasMessages(101)) {
                this.mHandler.removeMessages(101);
            }
            this.isFeatureEnabled = false;
            setTouchWeightValue("0");
        }
    }

    private void enableTouchWeight() {
        setTouchWeightValue("1");
        this.isFeatureEnabled = true;
        startHeartBeat();
    }

    private void setTouchWeightValue(java.lang.String val) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HwTouchWeightService setTouchWeightValue ");
        stringBuilder.append(val);
        android.util.Log.i("touch weight", stringBuilder.toString());
        java.io.FileOutputStream fileOutWriteMode = null;
        try {
            fileOutWriteMode = new java.io.FileOutputStream(new java.io.File("/sys/touchscreen/touch_weight"));
            fileOutWriteMode.write(val.getBytes("utf-8"));
            try {
                fileOutWriteMode.close();
            } catch (java.io.IOException e) {
            }
        } catch (java.io.FileNotFoundException e2) {
            if (fileOutWriteMode != null) {
                fileOutWriteMode.close();
            }
        } catch (java.io.IOException e3) {
            if (fileOutWriteMode != null) {
                fileOutWriteMode.close();
            }
        } catch (Throwable th) {
            if (fileOutWriteMode != null) {
                try {
                    fileOutWriteMode.close();
                } catch (java.io.IOException e4) {
                }
            }
        }
    }

    public static synchronized com.android.server.HwTouchWeightService getInstance(android.content.Context context, android.os.Handler handler) {
        com.android.server.HwTouchWeightService hwTouchWeightService;
        synchronized (com.android.server.HwTouchWeightService.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.HwTouchWeightService(context, handler);
            }
            hwTouchWeightService = mInstance;
        }
        return hwTouchWeightService;
    }

    private void startHeartBeat() {
        setTouchWeightValue("2");
        if (this.mHandler == null) {
            android.util.Log.e("HwTouchWeightService", "startHeartBeat mHandler is null");
            return;
        }
        this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(101), 1000);
    }

    private void resetTimeOut() {
        if (this.mHandler.hasMessages(100)) {
            this.mHandler.removeMessages(100);
        }
        this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(100), 1800);
    }
}
