package com.android.server;

public class PPPOEStateMachine extends com.android.internal.util.StateMachine {
    private static final boolean DEBUG = true;
    public static final int MAX_LOG_SIZE = 25;
    private static final java.lang.String NETWORKTYPE = "WIFI_PPPOE";
    public static final java.lang.String PHASE_AUTHENTICATE = "5";
    public static final java.lang.String PHASE_CALLBACK = "6";
    public static final java.lang.String PHASE_DEAD = "0";
    public static final java.lang.String PHASE_DISCONNECT = "10";
    public static final java.lang.String PHASE_DORMANT = "3";
    public static final java.lang.String PHASE_ESTABLISH = "4";
    public static final java.lang.String PHASE_HOLDOFF = "11";
    public static final java.lang.String PHASE_INITIALIZE = "1";
    public static final java.lang.String PHASE_MASTER = "12";
    public static final java.lang.String PHASE_NETWORK = "7";
    public static final java.lang.String PHASE_RUNNING = "8";
    public static final java.lang.String PHASE_SERIALCONN = "2";
    public static final java.lang.String PHASE_TERMINATE = "9";
    public static final int PPPOE_EVENT_CODE = 652;
    private static final java.lang.String PPPOE_TAG = "PPPOEConnector";
    public static final int RESPONSE_QUEUE_SIZE = 10;
    private static final java.lang.String TAG = "PPPOEStateMachine";
    static final java.util.Set<java.lang.String> stateCode = new java.util.HashSet();
    private android.net.ConnectivityManager mCm;
    private com.android.server.PPPOEStateMachine.ConnectedState mConnectedState = new com.android.server.PPPOEStateMachine.ConnectedState();
    private final java.util.concurrent.atomic.AtomicLong mConnectedTimeAtomicLong = new java.util.concurrent.atomic.AtomicLong(0);
    private com.android.server.PPPOEStateMachine.ConnectingState mConnectingState = new com.android.server.PPPOEStateMachine.ConnectingState();
    private android.content.Context mContext;
    private java.util.concurrent.CountDownLatch mCountDownLatch = new java.util.concurrent.CountDownLatch(1);
    private android.net.RouteInfo mDefRoute = null;
    private com.android.server.PPPOEStateMachine.DefaultState mDefaultState = new com.android.server.PPPOEStateMachine.DefaultState();
    private com.android.server.PPPOEStateMachine.DisconnectedState mDisconnectedState = new com.android.server.PPPOEStateMachine.DisconnectedState();
    private com.android.server.PPPOEStateMachine.DisconnectingState mDisconnectingState = new com.android.server.PPPOEStateMachine.DisconnectingState();
    private com.android.server.PPPOEStateMachine.InitialState mInitialState = new com.android.server.PPPOEStateMachine.InitialState();
    private com.android.server.NativeDaemonConnector mNativeConnetor;
    private final java.util.concurrent.atomic.AtomicInteger mPPPOEState = new java.util.concurrent.atomic.AtomicInteger(android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal());
    private com.android.server.PPPOEStateMachine.StartFailedState mStartFailedState = new com.android.server.PPPOEStateMachine.StartFailedState();
    private com.android.server.PPPOEStateMachine.StopFailedState mStopFailedState = new com.android.server.PPPOEStateMachine.StopFailedState();
    private android.os.PowerManager.WakeLock mWakeLock;

    private class ConnectedState extends com.android.internal.util.State {
        private ConnectedState() {
        }

        public void enter() {
            android.util.Log.d("PPPOEStateMachine", "success to connect pppoe.");
            com.android.server.PPPOEStateMachine.this.mPPPOEState.set(android.net.wifi.PPPOEInfo.Status.ONLINE.ordinal());
            com.android.server.PPPOEStateMachine.this.mConnectedTimeAtomicLong.set(java.lang.System.currentTimeMillis());
            android.content.Intent completeIntent = new android.content.Intent("android.net.wifi.PPPOE_COMPLETED_ACTION");
            completeIntent.addFlags(67108864);
            completeIntent.putExtra("pppoe_result_status", "SUCCESS");
            com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(completeIntent);
            android.content.Intent connectIntent = new android.content.Intent("android.net.wifi.PPPOE_STATE_CHANGED");
            connectIntent.addFlags(67108864);
            connectIntent.putExtra("pppoe_state", "PPPOE_STATE_CONNECTED");
            com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(connectIntent);
        }

        public boolean processMessage(android.os.Message msg) {
            int i = msg.what;
            if (i != 151555) {
                if (i != 589826) {
                    return false;
                }
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mDisconnectingState);
            } else if ("10".equals(com.android.server.NativeDaemonEvent.unescapeArgs(msg.obj)[1])) {
                android.util.Log.w("PPPOEStateMachine", "lost pppoe service.");
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mDisconnectingState);
            }
            return true;
        }
    }

    private class ConnectingState extends com.android.internal.util.State {
        private ConnectingState() {
        }

        public void enter() {
            final android.os.Message message = new android.os.Message();
            message.copyFrom(com.android.server.PPPOEStateMachine.this.getCurrentMessage());
            new java.lang.Thread(new java.lang.Runnable() {
                public void run() {
                    com.android.server.PPPOEStateMachine.this.mWakeLock.acquire();
                    com.android.server.PPPOEStateMachine.this.mPPPOEState.set(android.net.wifi.PPPOEInfo.Status.CONNECTING.ordinal());
                    android.content.Intent intent = new android.content.Intent("android.net.wifi.PPPOE_STATE_CHANGED");
                    intent.addFlags(67108864);
                    intent.putExtra("pppoe_state", "PPPOE_STATE_CONNECTING");
                    com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(intent);
                    android.net.wifi.PPPOEConfig serverInfoConfig = message.obj;
                    android.util.Log.d("PPPOEStateMachine", "start PPPOE");
                    if (!com.android.server.PPPOEStateMachine.this.startPPPOE(serverInfoConfig)) {
                        com.android.server.PPPOEStateMachine.this.mStartFailedState.setErrorCode("FAILURE_INTERNAL_ERROR");
                        com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStartFailedState);
                    }
                    com.android.server.PPPOEStateMachine.this.mWakeLock.release();
                }
            }).start();
        }

        public boolean processMessage(android.os.Message msg) {
            if (msg.what != 151555) {
                return false;
            }
            java.lang.String[] cooked = com.android.server.NativeDaemonEvent.unescapeArgs(msg.obj);
            if ("8".equals(cooked[1])) {
                if (updateConfig()) {
                    com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mConnectedState);
                    return true;
                }
                com.android.server.PPPOEStateMachine.this.mStartFailedState.setErrorCode("FAILURE_INTERNAL_ERROR");
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStartFailedState);
                return true;
            } else if ("10".equals(cooked[1])) {
                com.android.server.PPPOEStateMachine.this.mStartFailedState.setErrorCode("FAILURE_INTERNAL_ERROR");
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStartFailedState);
                return true;
            } else if (com.android.server.PPPOEStateMachine.stateCode.contains(cooked[1])) {
                return true;
            } else {
                com.android.server.PPPOEStateMachine.this.mStartFailedState.setErrorCode(cooked[1]);
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStartFailedState);
                return true;
            }
        }

        private boolean updateConfig() {
            android.os.INetworkManagementService netService = android.os.INetworkManagementService.Stub.asInterface(android.os.ServiceManager.getService("network_management"));
            android.net.ConnectivityManager connectivityManager = (android.net.ConnectivityManager) com.android.server.PPPOEStateMachine.this.mContext.getSystemService("connectivity");
            android.net.LinkProperties prop = connectivityManager.getActiveLinkProperties();
            android.net.Network wifiNetwork = connectivityManager.getNetworkForType(1);
            if (wifiNetwork == null) {
                android.util.Log.e("PPPOEStateMachine", "ConnectingState, updateConfig, No Network for type WIFI!");
                return false;
            }
            if (prop != null) {
                for (android.net.RouteInfo routeInfo : prop.getRoutes()) {
                    if (routeInfo.isDefaultRoute()) {
                        com.android.server.PPPOEStateMachine.this.mDefRoute = routeInfo;
                        break;
                    }
                }
                if (com.android.server.PPPOEStateMachine.this.mDefRoute != null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Remove default route ");
                    stringBuilder.append(com.android.server.PPPOEStateMachine.this.mDefRoute.toString());
                    android.util.Log.d("PPPOEStateMachine", stringBuilder.toString());
                    try {
                        netService.removeRoute(wifiNetwork.netId, com.android.server.PPPOEStateMachine.this.mDefRoute);
                    } catch (java.lang.Exception e) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Failed to remove route ");
                        stringBuilder.append(com.android.server.PPPOEStateMachine.this.mDefRoute);
                        android.util.Log.e("PPPOEStateMachine", stringBuilder.toString(), e);
                        return false;
                    }
                }
            }
            java.lang.String interfaceName = android.os.SystemProperties.get("ppp.interface", "ppp0");
            java.net.InetAddress destAddr = android.net.NetworkUtils.numericToInetAddress(android.os.SystemProperties.get("ppp.InetAddress", "0.0.0.0"));
            android.net.RouteInfo route = new android.net.RouteInfo(new android.net.LinkAddress(destAddr, 0), android.net.NetworkUtils.numericToInetAddress(android.os.SystemProperties.get("ppp.gateway", "0.0.0.0")), interfaceName);
            java.util.List<android.net.RouteInfo> routes = new java.util.ArrayList();
            routes.add(route);
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("add route ");
            stringBuilder2.append(route.toString());
            android.util.Log.d("PPPOEStateMachine", stringBuilder2.toString());
            android.net.ConnectivityManager connectivityManager2;
            android.net.LinkProperties prop2;
            android.net.Network wifiNetwork2;
            try {
                netService.addInterfaceToLocalNetwork(interfaceName, routes);
                if (prop != null) {
                    java.lang.String[] args;
                    java.util.Collection<java.net.InetAddress> dnses = prop.getDnsServers();
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("net.");
                    stringBuilder2.append(interfaceName);
                    stringBuilder2.append(".dns2");
                    java.lang.String dns2 = android.os.SystemProperties.get(stringBuilder2.toString());
                    if (dns2 != null && dns2.trim().length() > 0) {
                        prop.addDnsServer(android.net.NetworkUtils.numericToInetAddress(dns2));
                        android.os.SystemProperties.set("net.dns2", dns2);
                    }
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("net.");
                    stringBuilder3.append(interfaceName);
                    stringBuilder3.append(".dns1");
                    java.lang.String dns1 = android.os.SystemProperties.get(stringBuilder3.toString());
                    if (dns1 == null || dns1.trim().length() <= 0) {
                    } else {
                        prop.addDnsServer(android.net.NetworkUtils.numericToInetAddress(dns1));
                        android.os.SystemProperties.set("net.dns1", dns1);
                    }
                    netService = android.net.NetworkUtils.makeStrings(dnses);
                    int length = netService.length;
                    int dnses2 = 0;
                    while (dnses2 < length) {
                        connectivityManager2 = connectivityManager;
                        java.lang.String arg = netService[dnses2];
                        args = netService;
                        prop2 = prop;
                        java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                        wifiNetwork2 = wifiNetwork;
                        stringBuilder4.append("after set dns servers: ");
                        stringBuilder4.append(arg);
                        android.util.Log.e("PPPOEStateMachine", stringBuilder4.toString());
                        dnses2++;
                        connectivityManager = connectivityManager2;
                        netService = args;
                        prop = prop2;
                        wifiNetwork = wifiNetwork2;
                    }
                    args = netService;
                    connectivityManager2 = connectivityManager;
                    prop2 = prop;
                    wifiNetwork2 = wifiNetwork;
                    netService = new java.lang.StringBuilder();
                    netService.append("set net.dns1 :");
                    netService.append(dns1);
                    netService.append(" net.dns2: ");
                    netService.append(dns2);
                    android.util.Log.d("PPPOEStateMachine", netService.toString());
                    return true;
                }
                connectivityManager2 = connectivityManager;
                prop2 = prop;
                wifiNetwork2 = wifiNetwork;
                return false;
            } catch (java.lang.Exception e2) {
                android.os.INetworkManagementService iNetworkManagementService = netService;
                connectivityManager2 = connectivityManager;
                prop2 = prop;
                wifiNetwork2 = wifiNetwork;
                java.lang.Exception exception = e2;
                java.lang.StringBuilder stringBuilder5 = new java.lang.StringBuilder();
                stringBuilder5.append("Failed to add route ");
                stringBuilder5.append(route);
                android.util.Log.e("PPPOEStateMachine", stringBuilder5.toString(), e2);
                return false;
            }
        }
    }

    private class DefaultState extends com.android.internal.util.State {
        private DefaultState() {
        }

        public boolean processMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder;
            switch (msg.what) {
                case 69632:
                    if (msg.arg1 == 0) {
                        android.util.Log.d("PPPOEStateMachine", "New client listening to asynchronous messages");
                        return true;
                    }
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Client connection failure, error=");
                    stringBuilder.append(msg.arg1);
                    android.util.Log.e("PPPOEStateMachine", stringBuilder.toString());
                    return true;
                case 69633:
                    return true;
                case 69636:
                    if (msg.arg1 == 2) {
                        android.util.Log.e("PPPOEStateMachine", "Send failed, client connection lost");
                        return true;
                    }
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Client connection lost with reason: ");
                    stringBuilder.append(msg.arg1);
                    android.util.Log.d("PPPOEStateMachine", stringBuilder.toString());
                    return true;
                case 151555:
                    return true;
                case 589825:
                    android.util.Log.d("PPPOEStateMachine", "start PPPOE");
                    if (com.android.server.PPPOEStateMachine.this.mPPPOEState.get() == android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal()) {
                        com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mConnectingState);
                        return true;
                    }
                    android.util.Log.w("PPPOEStateMachine", "the pppoe is already online.");
                    android.content.Intent completeIntent = new android.content.Intent("android.net.wifi.PPPOE_COMPLETED_ACTION");
                    completeIntent.addFlags(67108864);
                    completeIntent.putExtra("pppoe_result_status", "ALREADY_ONLINE");
                    com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(completeIntent);
                    return true;
                case 589826:
                    android.util.Log.d("PPPOEStateMachine", "stop PPPOE");
                    if (com.android.server.PPPOEStateMachine.this.mPPPOEState.get() != android.net.wifi.PPPOEInfo.Status.ONLINE.ordinal()) {
                        return true;
                    }
                    com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mDisconnectingState);
                    return true;
                default:
                    return false;
            }
        }
    }

    private class DisconnectedState extends com.android.internal.util.State {
        private DisconnectedState() {
        }

        public void enter() {
            updateConfig();
            com.android.server.PPPOEStateMachine.this.mConnectedTimeAtomicLong.set(0);
            com.android.server.PPPOEStateMachine.this.mPPPOEState.set(android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal());
            android.content.Intent connectIntent = new android.content.Intent("android.net.wifi.PPPOE_STATE_CHANGED");
            connectIntent.addFlags(67108864);
            connectIntent.putExtra("pppoe_state", "PPPOE_STATE_DISCONNECTED");
            com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(connectIntent);
        }

        private boolean updateConfig() {
            android.os.INetworkManagementService netService = android.os.INetworkManagementService.Stub.asInterface(android.os.ServiceManager.getService("network_management"));
            android.net.ConnectivityManager connectivityManager = (android.net.ConnectivityManager) com.android.server.PPPOEStateMachine.this.mContext.getSystemService("connectivity");
            android.net.LinkProperties prop = connectivityManager.getActiveLinkProperties();
            android.net.Network wifiNetwork = connectivityManager.getNetworkForType(1);
            if (wifiNetwork == null) {
                android.util.Log.e("PPPOEStateMachine", "DisconnectedState, updateConfig, No Network for type WiFi!");
                return false;
            }
            if (prop != null) {
                java.util.Collection<java.net.InetAddress> dnses = prop.getDnsServers();
            }
            java.lang.String interfaceName = android.os.SystemProperties.get("wifi.interface", "wlan0");
            if (com.android.server.PPPOEStateMachine.this.mDefRoute == null) {
                return false;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Reset default route via %s");
            stringBuilder.append(interfaceName);
            android.util.Log.d("PPPOEStateMachine", stringBuilder.toString());
            try {
                netService.addRoute(wifiNetwork.netId, com.android.server.PPPOEStateMachine.this.mDefRoute);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("dhcp.");
                stringBuilder2.append(interfaceName);
                stringBuilder2.append(".dns1");
                java.lang.String dns1 = android.os.SystemProperties.get(stringBuilder2.toString());
                if (dns1 != null && dns1.trim().length() > 0) {
                    java.net.InetAddress dns = android.net.NetworkUtils.numericToInetAddress(dns1);
                    if (prop != null) {
                        prop.addDnsServer(dns);
                    }
                    android.os.SystemProperties.set("net.dns1", dns1);
                }
                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("dhcp.");
                stringBuilder3.append(interfaceName);
                stringBuilder3.append(".dns2");
                java.lang.String dns2 = android.os.SystemProperties.get(stringBuilder3.toString());
                if (dns2 != null && dns2.trim().length() > 0) {
                    java.net.InetAddress dns3 = android.net.NetworkUtils.numericToInetAddress(dns2);
                    if (prop != null) {
                        prop.addDnsServer(dns3);
                    }
                    android.os.SystemProperties.set("net.dns2", dns2);
                }
                java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                stringBuilder4.append("set net.dns1 :");
                stringBuilder4.append(dns1);
                stringBuilder4.append(" net.dns2: ");
                stringBuilder4.append(dns2);
                android.util.Log.d("PPPOEStateMachine", stringBuilder4.toString());
                return true;
            } catch (java.lang.Exception e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Failed to add route ");
                stringBuilder.append(com.android.server.PPPOEStateMachine.this.mDefRoute);
                android.util.Log.e("PPPOEStateMachine", stringBuilder.toString(), e);
                return false;
            }
        }
    }

    private class DisconnectingState extends com.android.internal.util.State {
        private DisconnectingState() {
        }

        public void enter() {
            new android.os.Message().copyFrom(com.android.server.PPPOEStateMachine.this.getCurrentMessage());
            new java.lang.Thread(new java.lang.Runnable() {
                public void run() {
                    com.android.server.PPPOEStateMachine.this.mWakeLock.acquire();
                    android.content.Intent intent = new android.content.Intent("android.net.wifi.PPPOE_STATE_CHANGED");
                    intent.addFlags(67108864);
                    intent.putExtra("pppoe_state", "PPPOE_STATE_DISCONNECTING");
                    com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(intent);
                    android.util.Log.d("PPPOEStateMachine", "stop PPPOE");
                    if (!com.android.server.PPPOEStateMachine.this.stopPPPOE()) {
                        com.android.server.PPPOEStateMachine.this.mStopFailedState.setErrorCode("FAILURE_INTERNAL_ERROR");
                        com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStopFailedState);
                    }
                    com.android.server.PPPOEStateMachine.this.mWakeLock.release();
                }
            }).start();
        }

        public boolean processMessage(android.os.Message msg) {
            if (msg.what != 151555) {
                return false;
            }
            java.lang.String[] cooked = com.android.server.NativeDaemonEvent.unescapeArgs(msg.obj);
            if ("0".equals(cooked[1])) {
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mDisconnectedState);
                return true;
            } else if (com.android.server.PPPOEStateMachine.stateCode.contains(cooked[1])) {
                return true;
            } else {
                com.android.server.PPPOEStateMachine.this.mStopFailedState.setErrorCode(cooked[1]);
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mStopFailedState);
                return true;
            }
        }
    }

    private class InitialState extends com.android.internal.util.State {
        private InitialState() {
        }

        public boolean processMessage(android.os.Message msg) {
            if (msg.what != 589825) {
                return false;
            }
            if (com.android.server.PPPOEStateMachine.this.mPPPOEState.get() == android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal()) {
                com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mConnectingState);
                return true;
            }
            android.content.Intent completeIntent = new android.content.Intent("android.net.wifi.PPPOE_COMPLETED_ACTION");
            completeIntent.addFlags(67108864);
            completeIntent.putExtra("pppoe_result_status", "ALREADY_ONLINE");
            com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(completeIntent);
            return true;
        }
    }

    public class NativeDaemonConnectorCallbacks implements com.android.server.INativeDaemonConnectorCallbacks {
        public void onDaemonConnected() {
            android.util.Log.d("PPPOEStateMachine", "Start native daemon connector success.");
            com.android.server.PPPOEStateMachine.this.mCountDownLatch.countDown();
        }

        public boolean onCheckHoldWakeLock(int code) {
            return false;
        }

        public boolean onEvent(int code, java.lang.String raw, java.lang.String[] cooked) {
            if (code == 652) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onEvent receive native daemon connector event, code=");
                stringBuilder.append(code);
                stringBuilder.append(",raw=");
                stringBuilder.append(raw);
                android.util.Log.d("PPPOEStateMachine", stringBuilder.toString());
                com.android.server.PPPOEStateMachine.this.sendMessage(151555, raw);
            }
            return true;
        }
    }

    private class StartFailedState extends com.android.internal.util.State {
        private java.lang.String errorCode;

        private StartFailedState() {
        }

        public void enter() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Failed to start PPPOE, error code is ");
            stringBuilder.append(this.errorCode);
            android.util.Log.e("PPPOEStateMachine", stringBuilder.toString());
            com.android.server.PPPOEStateMachine.this.stopPPPOE();
            com.android.server.PPPOEStateMachine.this.mPPPOEState.set(android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal());
            android.content.Intent intent = new android.content.Intent("android.net.wifi.PPPOE_COMPLETED_ACTION");
            intent.addFlags(67108864);
            intent.putExtra("pppoe_result_status", "FAILURE");
            intent.putExtra("pppoe_result_error_code", this.errorCode);
            com.android.server.PPPOEStateMachine.this.mContext.sendStickyBroadcast(intent);
            com.android.server.PPPOEStateMachine.this.transitionTo(com.android.server.PPPOEStateMachine.this.mInitialState);
        }

        public void setErrorCode(java.lang.String errorCode) {
            this.errorCode = errorCode;
        }
    }

    private class StopFailedState extends com.android.internal.util.State {
        private java.lang.String errorCode;

        private StopFailedState() {
        }

        public void enter() {
            com.android.server.PPPOEStateMachine.this.mConnectedTimeAtomicLong.set(0);
            com.android.server.PPPOEStateMachine.this.mPPPOEState.set(android.net.wifi.PPPOEInfo.Status.OFFLINE.ordinal());
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Failed to stop PPPOE , error code is ");
            stringBuilder.append(this.errorCode);
            android.util.Log.e("PPPOEStateMachine", stringBuilder.toString());
        }

        public void setErrorCode(java.lang.String errorCode) {
            this.errorCode = errorCode;
        }
    }

    static {
        stateCode.add("0");
        stateCode.add("1");
        stateCode.add("2");
        stateCode.add("3");
        stateCode.add("4");
        stateCode.add("5");
        stateCode.add("6");
        stateCode.add("7");
        stateCode.add("8");
        stateCode.add("9");
        stateCode.add("10");
        stateCode.add("11");
        stateCode.add("12");
    }

    public PPPOEStateMachine(android.content.Context context, java.lang.String name) {
        super(name);
        android.util.Log.d("PPPOEStateMachine", " create PPPOE state Machine");
        this.mContext = context;
        this.mWakeLock = ((android.os.PowerManager) this.mContext.getSystemService("power")).newWakeLock(1, "PPPOEStateMachine");
        addState(this.mDefaultState);
        addState(this.mInitialState, this.mDefaultState);
        addState(this.mConnectingState, this.mDefaultState);
        addState(this.mConnectedState, this.mDefaultState);
        addState(this.mStartFailedState, this.mDefaultState);
        addState(this.mDisconnectingState, this.mDefaultState);
        addState(this.mDisconnectedState, this.mDefaultState);
        addState(this.mStopFailedState, this.mDefaultState);
        setInitialState(this.mInitialState);
        this.mNativeConnetor = new com.android.server.NativeDaemonConnector(new com.android.server.PPPOEStateMachine.NativeDaemonConnectorCallbacks(), "netd", 10, "PPPOEConnector", 25, null);
    }

    public void start() {
        new java.lang.Thread(this.mNativeConnetor, "PPPOEConnector").start();
        try {
            this.mCountDownLatch.await();
        } catch (java.lang.InterruptedException e) {
            e.printStackTrace();
        }
        super.start();
    }

    private void checkAndSetConnectivityInstance() {
        if (this.mCm == null) {
            this.mCm = (android.net.ConnectivityManager) this.mContext.getSystemService("connectivity");
        }
    }

    private boolean stopPPPOE() {
        android.util.Log.d("PPPOEStateMachine", "execute stop PPPOE");
        try {
            this.mNativeConnetor.execute("pppoed", new java.lang.Object[]{"stop"});
            return true;
        } catch (java.lang.Exception e) {
            android.util.Log.e("PPPOEStateMachine", "Failed to stop PPPOE.", e);
            return false;
        }
    }

    private boolean startPPPOE(android.net.wifi.PPPOEConfig serverConfig) {
        android.util.Log.d("PPPOEStateMachine", "startPPPOE");
        try {
            this.mNativeConnetor.execute("pppoed", buildStartArgs(serverConfig));
            return true;
        } catch (java.lang.Exception e) {
            android.util.Log.e("PPPOEStateMachine", "Failed to start PPPOE", e);
            return false;
        }
    }

    public android.net.wifi.PPPOEInfo getPPPOEInfo() {
        android.util.Log.d("PPPOEStateMachine", "getPPPOEInfo");
        android.net.wifi.PPPOEInfo.Status status = android.net.wifi.PPPOEInfo.Status.fromInt(this.mPPPOEState.get());
        long onLineTime = 0;
        if (status.equals(android.net.wifi.PPPOEInfo.Status.ONLINE)) {
            onLineTime = (java.lang.System.currentTimeMillis() - this.mConnectedTimeAtomicLong.get()) / 1000;
        }
        return new android.net.wifi.PPPOEInfo(status, onLineTime);
    }

    private java.lang.Object[] buildStartArgs(android.net.wifi.PPPOEConfig serverConfig) {
        java.lang.Object[] cfgArgs = serverConfig.getArgs();
        int i = 1;
        int argc = cfgArgs.length + 1;
        java.lang.Object[] argv = new java.lang.Object[argc];
        argv[0] = "start";
        while (i < argc) {
            argv[i] = cfgArgs[i - 1];
            i++;
        }
        return argv;
    }
}
