package com.android.server;

public class PrivacyModeChangeReceiver extends android.content.BroadcastReceiver {
    private static final boolean DEBUG = false;
    private static final java.lang.String DESCRIPTOR = "huawei.com.android.server.IPackageManager";
    private static int MAX_NUM = 20;
    private static int MAX_PKG = 100;
    private static final java.lang.String TAG = "PrivacyModeChangeReceiver";
    public static final int transaction_setEnabledVisitorSetting = 1001;
    private android.app.ActivityManager am;
    private android.content.Context mContext;
    private android.content.pm.IPackageManager mPackageManagerService;
    private android.content.pm.PackageManager pm;

    public void onReceive(android.content.Context context, android.content.Intent intent) {
        this.mContext = context;
        this.pm = this.mContext.getPackageManager();
        this.am = (android.app.ActivityManager) this.mContext.getSystemService("activity");
        if (intent.getIntExtra("privacy_mode_value", 1) == 1) {
            new java.lang.Thread("privacymodechange") {
                public void run() {
                    try {
                        com.android.server.PrivacyModeChangeReceiver.this.removeAllRecentTask();
                        com.android.server.PrivacyModeChangeReceiver.this.transactToPackageManagerService(1001, "setEnabledVisitorSetting", 2, 0);
                    } catch (java.lang.Exception e) {
                        android.util.Slog.e("PrivacyModeChangeReceiver", "change to visitor  mode failure  ", e);
                    }
                }
            }.start();
        } else if (intent.getIntExtra("privacy_mode_value", 0) == 0) {
            new java.lang.Thread("privacymodechange") {
                public void run() {
                    try {
                        com.android.server.PrivacyModeChangeReceiver.this.transactToPackageManagerService(1001, "setEnabledVisitorSetting", 1, 0);
                    } catch (java.lang.Exception e) {
                        android.util.Slog.e("PrivacyModeChangeReceiver", "change to host mode failure ", e);
                    }
                }
            }.start();
        }
    }

    private void updateAppfromSetting(int state) {
        java.lang.String pkgNameList = android.provider.Settings.Secure.getString(this.mContext.getContentResolver(), "privacy_app_list");
        if (pkgNameList == null) {
            android.util.Slog.e("PrivacyModeChangeReceiver", " pkgNameList = null ");
        } else if (pkgNameList.contains(";")) {
            java.lang.String[] pkgNameArray = pkgNameList.split(";");
            int i = 0;
            while (i < MAX_PKG && i < pkgNameArray.length) {
                setApplicationEnabledSetting(pkgNameArray[i], state);
                i++;
            }
        } else {
            setApplicationEnabledSetting(pkgNameList, state);
        }
    }

    private void removeAllRecentTask() {
        java.util.List<android.app.ActivityManager.RecentTaskInfo> recentTasks = this.am.getRecentTasks(MAX_NUM, 2);
        if (recentTasks != null) {
            int size = recentTasks.size();
            int i = 0;
            while (i < size && i < MAX_NUM) {
                android.app.ActivityManager.RecentTaskInfo recentInfo = (android.app.ActivityManager.RecentTaskInfo) recentTasks.get(i);
                android.content.Intent intent = new android.content.Intent(recentInfo.baseIntent);
                if (recentInfo.origActivity != null) {
                    intent.setComponent(recentInfo.origActivity);
                }
                if (isCurrentHomeActivity(intent.getComponent(), null)) {
                    android.util.Slog.e("PrivacyModeChangeReceiver", " isCurrentHomeActivity");
                } else if (!intent.getComponent().getPackageName().equals(this.mContext.getPackageName())) {
                    try {
                        android.app.ActivityManager.getService().removeTask(recentInfo.persistentId);
                    } catch (android.os.RemoteException e) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("removeTask has error. [e.toString()]: ");
                        stringBuilder.append(e.toString());
                        android.util.Slog.e("PrivacyModeChangeReceiver", stringBuilder.toString());
                    }
                    recentTasks.clear();
                }
                i++;
            }
        }
    }

    private boolean isCurrentHomeActivity(android.content.ComponentName component, android.content.pm.ActivityInfo homeInfo) {
        if (homeInfo == null) {
            homeInfo = new android.content.Intent("android.intent.action.MAIN").addCategory("android.intent.category.HOME").resolveActivityInfo(this.mContext.getPackageManager(), 0);
        }
        if (homeInfo != null && homeInfo.packageName.equals(component.getPackageName()) && homeInfo.name.equals(component.getClassName())) {
            return true;
        }
        return false;
    }

    private void setApplicationEnabledSetting(java.lang.String pkgName, int enabledStatus) {
        java.lang.StringBuilder stringBuilder;
        try {
            if (isAppExits(pkgName)) {
                this.pm.setApplicationEnabledSetting(pkgName, enabledStatus, 0);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("the pkg ");
                stringBuilder2.append(pkgName);
                stringBuilder2.append(" enablestatus: ");
                stringBuilder2.append(enabledStatus);
                android.util.Slog.e("PrivacyModeChangeReceiver", stringBuilder2.toString());
            }
        } catch (java.lang.SecurityException e) {
            e.printStackTrace();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Unable to change enabled state of package xxx SecurityException: ");
            stringBuilder.append(pkgName);
            stringBuilder.append(e.toString());
            android.util.Slog.e("PrivacyModeChangeReceiver", stringBuilder.toString());
        } catch (java.lang.Exception e2) {
            e2.printStackTrace();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Unable to change enabled state of package 1: ");
            stringBuilder.append(pkgName);
            stringBuilder.append(e2.toString());
            android.util.Slog.e("PrivacyModeChangeReceiver", stringBuilder.toString());
        }
    }

    private boolean isAppExits(java.lang.String pkgName) {
        boolean z = false;
        if (!(this.pm == null || pkgName == null)) {
            if (!"".equals(pkgName)) {
                try {
                    if (this.pm.getPackageInfo(pkgName, 0) != null) {
                        z = true;
                    }
                    return z;
                } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("The packageName ");
                    stringBuilder.append(pkgName);
                    stringBuilder.append(" is not exit: \n");
                    stringBuilder.append(e.toString());
                    android.util.Slog.e("PrivacyModeChangeReceiver", stringBuilder.toString());
                    return false;
                }
            }
        }
        return false;
    }

    private android.content.pm.IPackageManager getPackageManager() {
        if (this.mPackageManagerService == null) {
            this.mPackageManagerService = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
        }
        return this.mPackageManagerService;
    }

    private synchronized boolean transactToPackageManagerService(int code, java.lang.String transactName, int enabledStatus, int flag) {
        boolean success;
        android.os.Parcel _data = android.os.Parcel.obtain();
        android.os.Parcel _reply = android.os.Parcel.obtain();
        boolean success2 = false;
        success = false;
        try {
            android.os.IBinder packageManagerServiceBinder = getPackageManager().asBinder();
            if (packageManagerServiceBinder != null) {
                _data.writeInterfaceToken("huawei.com.android.server.IPackageManager");
                _data.writeInt(enabledStatus);
                _data.writeInt(flag);
                _data.writeInt(this.mContext.getUserId());
                packageManagerServiceBinder.transact(code, _data, _reply, 0);
                _reply.readException();
                if (_reply.readInt() == 0) {
                    success2 = true;
                }
                success = success2;
            }
            _reply.recycle();
        } catch (android.os.RemoteException localRemoteException) {
            try {
                localRemoteException.printStackTrace();
                _reply.recycle();
            } catch (Throwable th) {
                _reply.recycle();
                _data.recycle();
            }
        }
        _data.recycle();
        return success;
    }
}
