package com.android.server;

public final class SMCSAMSHelper {
    private static final boolean DBG = android.os.SystemProperties.getBoolean("ro.enable.st_debug", false);
    private static final boolean DBG_PERFORMANCE = DBG;
    static final int SMCS_AMS_MOVE_SELF_AUTO_TRIMED_PROCS = 5;
    static final java.lang.String SMCS_TRIM_TYPE_SELF_AUTO = "trimer_self_auto";
    static final java.lang.String SMCS_TRIM_TYPE_USER_ONE_SHOOT = "trimer_user_one_shoot";
    private static final int STP_EVENT_MAX_NUM = android.os.SystemProperties.getInt("ro.smart_trim.stpe_num", 200);
    private static final java.lang.String TAG = "SMCSAMSHelper";
    private static com.android.server.SMCSAMSHelper mSelf = null;
    com.android.server.am.HwActivityManagerService mAms = com.android.server.am.HwActivityManagerService.self();
    private long mSelfAutoTrimId = 0;
    private java.util.HashSet<java.lang.String> mSelfAutoTrimedProcs = null;

    private SMCSAMSHelper() {
    }

    public static com.android.server.SMCSAMSHelper getInstance() {
        if (mSelf == null) {
            mSelf = new com.android.server.SMCSAMSHelper();
        }
        return mSelf;
    }

    void setAlarmService(com.android.server.AlarmManagerService alarmService) {
    }

    public boolean handleTransact(android.os.Parcel data, android.os.Parcel reply, int flag) {
        boolean res = true;
        if (data == null) {
            return false;
        }
        int iEvent = data.readInt();
        if (DBG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SMCSAMSHelper.handleTransact: ");
            stringBuilder.append(iEvent);
            android.util.Log.v("SMCSAMSHelper", stringBuilder.toString());
        }
        if (iEvent != 5) {
            res = false;
        } else {
            handleMoveSelfAutoTrimedProcs(data, reply);
        }
        return res;
    }

    public void trimProcessPostProcess(java.lang.String trimProc, int uid, java.lang.String trimType, java.util.HashSet<java.lang.String> pkgList) {
        java.lang.StringBuilder stringBuilder;
        long timeStart = -1;
        if (DBG) {
            timeStart = java.lang.System.currentTimeMillis();
        }
        if (trimType.equals("trimer_self_auto")) {
            handleSelfAutoTrimPostProcess(trimProc, uid, trimType, pkgList);
        } else if (DBG) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SMCSAMSHelper.trimProcessPostProcess: unkonw trim type ");
            stringBuilder.append(trimType);
            android.util.Log.e("SMCSAMSHelper", stringBuilder.toString());
        }
        if (DBG) {
            long timeCost = java.lang.System.currentTimeMillis() - timeStart;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SMCSAMSHelper.trimProcessPostProcess: total cost ");
            stringBuilder.append(timeCost);
            stringBuilder.append(" ms.");
            android.util.Log.v("SMCSAMSHelper", stringBuilder.toString());
        }
    }

    private void handleSelfAutoTrimPostProcess(java.lang.String trimProc, int uid, java.lang.String trimType, java.util.HashSet<java.lang.String> pkgList) {
        if (trimProc != null && trimProc.length() > 0) {
            if (this.mSelfAutoTrimedProcs == null) {
                this.mSelfAutoTrimedProcs = new java.util.HashSet();
            }
            this.mSelfAutoTrimedProcs.add(trimProc);
        }
        informTrimAlarm(pkgList);
    }

    private void informTrimAlarm(java.util.HashSet<java.lang.String> hashSet) {
    }

    private void handleMoveSelfAutoTrimedProcs(android.os.Parcel data, android.os.Parcel reply) {
        long trimedId = data.readLong();
        if (trimedId != this.mSelfAutoTrimId) {
            if (DBG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("SMCSAMSHelper.handleMoveSelfAutoTrimedProcs: trimed id is different ");
                stringBuilder.append(trimedId);
                stringBuilder.append(" ");
                stringBuilder.append(this.mSelfAutoTrimId);
                android.util.Log.v("SMCSAMSHelper", stringBuilder.toString());
            }
            return;
        }
        if (this.mSelfAutoTrimedProcs != null) {
            reply.writeInt(this.mSelfAutoTrimedProcs.size());
            java.util.Iterator<java.lang.String> it = this.mSelfAutoTrimedProcs.iterator();
            while (it.hasNext()) {
                reply.writeString((java.lang.String) it.next());
            }
            this.mSelfAutoTrimedProcs.clear();
        }
        this.mSelfAutoTrimId = -1;
    }

    private java.util.HashSet<java.lang.String> stringChangeA2H(java.util.ArrayList<java.lang.String> src) {
        if (src != null) {
            if (src.size() != 0) {
                java.util.HashSet<java.lang.String> dst = new java.util.HashSet();
                java.util.Iterator<java.lang.String> it = src.iterator();
                while (it.hasNext()) {
                    java.lang.String sPkg = (java.lang.String) it.next();
                    if (sPkg != null && sPkg.length() > 0) {
                        dst.add(sPkg);
                    }
                }
                return dst;
            }
        }
        return null;
    }

    private java.util.ArrayList<java.lang.String> stringChangeH2A(java.util.HashSet<java.lang.String> src) {
        if (src != null) {
            if (src.size() != 0) {
                java.util.ArrayList<java.lang.String> dst = new java.util.ArrayList();
                java.util.Iterator<java.lang.String> it = src.iterator();
                while (it.hasNext()) {
                    dst.add((java.lang.String) it.next());
                }
                return dst;
            }
        }
        return null;
    }

    private void dumpStrings(java.util.ArrayList<java.lang.String> strs, java.lang.String sLog) {
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(sLog);
        stringBuilder.append(":\n");
        sb.append(stringBuilder.toString());
        if (strs != null) {
            java.util.Iterator<java.lang.String> it = strs.iterator();
            while (it.hasNext()) {
                java.lang.String s = (java.lang.String) it.next();
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("    ");
                stringBuilder.append(s);
                stringBuilder.append("\n");
                sb.append(stringBuilder.toString());
            }
            android.util.Log.v("SMCSAMSHelper", sb.toString());
        }
    }

    private void dumpSmartTrimProcessEvent(java.util.ArrayList<com.huawei.android.smcs.SmartTrimProcessEvent> events, java.lang.String sLog) {
        java.lang.StringBuilder stringBuilder;
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        if (events != null) {
            if (events.size() != 0) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append(sLog);
                stringBuilder2.append("\n");
                sb.append(stringBuilder2.toString());
                int size = events.size();
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(sLog);
                stringBuilder.append(": total ");
                stringBuilder.append(size);
                stringBuilder.append(" events.");
                sb.append(stringBuilder.toString());
                for (int i = 0; i < size; i++) {
                    sb.append(((com.huawei.android.smcs.SmartTrimProcessEvent) events.get(i)).toString());
                    sb.append("\n");
                }
                android.util.Log.v("SMCSAMSHelper", sb.toString());
                return;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(sLog);
        stringBuilder.append(": empty events");
        android.util.Log.v("SMCSAMSHelper", stringBuilder.toString());
    }

    private void dumpSTProcessRecords(java.util.ArrayList<com.huawei.android.smcs.STProcessRecord> stProcessRecords, java.lang.String sLog) {
        if (stProcessRecords != null) {
            if (stProcessRecords.size() != 0) {
                java.lang.StringBuffer sb = new java.lang.StringBuffer();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(sLog);
                stringBuilder.append("\n");
                sb.append(stringBuilder.toString());
                java.util.Iterator<com.huawei.android.smcs.STProcessRecord> it = stProcessRecords.iterator();
                while (it.hasNext()) {
                    com.huawei.android.smcs.STProcessRecord stpr = (com.huawei.android.smcs.STProcessRecord) it.next();
                    if (stpr != null) {
                        sb.append(stpr.toString());
                        sb.append("\n");
                    }
                }
                android.util.Log.v("SMCSAMSHelper", sb.toString());
                return;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append(sLog);
        stringBuilder2.append(" empty process records.");
        android.util.Log.v("SMCSAMSHelper", stringBuilder2.toString());
    }
}
