package com.android.server;

public class SmartcardSystemService extends org.simalliance.openmobileapi.service.ISmartcardSystemService.Stub {
    private static final int AID_APP = 10000;
    private static final int CONNECTED = 2;
    private static final int CONNECTING = 1;
    private static final int DISCONNECTED = 0;
    public static final java.lang.String SMARTCARD_SERVICE_TAG = "SmartcardSystemService";
    private final org.simalliance.openmobileapi.service.ISmartcardServiceCallback callback = new org.simalliance.openmobileapi.service.ISmartcardServiceCallback.Stub() {
        public void notifyEvent(int eventType, java.lang.String name) throws android.os.RemoteException {
        }
    };
    public volatile java.lang.Exception lastException;
    private int mBindStatus = 0;
    private android.content.ServiceConnection mConnection;
    private android.content.Context mContext;
    private boolean mIccCardReady;
    private com.android.server.SmartcardSystemService.SmartcardSystemHandler mSmartcardSystemHandler;
    private volatile org.simalliance.openmobileapi.service.ISmartcardService smartcardService;

    private static class SmartcardSystemHandler extends android.os.Handler {
        public SmartcardSystemHandler(android.os.Looper looper) {
            super(looper, null, true);
        }
    }

    private static java.lang.String bytesToString(byte[] bytes) {
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        int length = bytes.length;
        for (int i = 0; i < length; i++) {
            sb.append(java.lang.String.format("%02X", new java.lang.Object[]{java.lang.Integer.valueOf(bytes[i] & 255)}));
        }
        return sb.toString();
    }

    private byte[] stringToByteArray(java.lang.String s) {
        byte[] b = new byte[(s.length() / 2)];
        for (int i = 0; i < b.length; i++) {
            b[i] = (byte) java.lang.Integer.parseInt(s.substring(2 * i, (2 * i) + 2), 16);
        }
        return b;
    }

    public static byte[] hexStringToByteArray(java.lang.String s) {
        int len = s.length();
        byte[] data = new byte[(len / 2)];
        for (int i = 0; i < len; i += 2) {
            data[i / 2] = (byte) ((java.lang.Character.digit(s.charAt(i), 16) << 4) + java.lang.Character.digit(s.charAt(i + 1), 16));
        }
        return data;
    }

    public SmartcardSystemService(android.content.Context context) {
        if (context != null) {
            this.mContext = context;
            this.mSmartcardSystemHandler = new com.android.server.SmartcardSystemService.SmartcardSystemHandler(com.android.internal.os.BackgroundThread.get().getLooper());
            this.mConnection = new android.content.ServiceConnection() {
                public synchronized void onServiceConnected(android.content.ComponentName className, android.os.IBinder service) {
                    com.android.server.SmartcardSystemService.this.smartcardService = org.simalliance.openmobileapi.service.ISmartcardService.Stub.asInterface(service);
                    android.util.Log.i("SmartcardSystemService", "Smartcard system service onServiceConnected");
                    com.android.server.SmartcardSystemService.this.mBindStatus = 2;
                }

                public void onServiceDisconnected(android.content.ComponentName className) {
                    com.android.server.SmartcardSystemService.this.smartcardService = null;
                    android.util.Log.i("SmartcardSystemService", "Smartcard system service onServiceDisconnected");
                    com.android.server.SmartcardSystemService.this.mBindStatus = 0;
                }
            };
            android.content.BroadcastReceiver apduServiceLaunchedReceiver = new android.content.BroadcastReceiver() {
                public void onReceive(android.content.Context context, android.content.Intent intent) {
                    if ("android.intent.action.SIM_STATE_CHANGED".equals(intent.getAction()) && "READY".equals(intent.getStringExtra("ss"))) {
                        android.util.Log.i("SmartcardSystemService", "INTENT_VALUE_ICC_READY");
                        com.android.server.SmartcardSystemService.this.mIccCardReady = true;
                    }
                }
            };
            android.content.IntentFilter intentFilter = new android.content.IntentFilter();
            intentFilter.addAction("android.intent.action.SIM_STATE_CHANGED");
            context.registerReceiver(apduServiceLaunchedReceiver, intentFilter);
            return;
        }
        throw new java.lang.NullPointerException("context must not be null");
    }

    public void closeChannel(long hChannel) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("called: closeChannel(");
            stringBuilder.append(hChannel);
            stringBuilder.append(")");
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            this.smartcardService.closeChannel(hChannel, error);
            this.lastException = error.createException();
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("SmartcardError: ");
            stringBuilder2.append(error.toString());
            android.util.Log.i("SmartcardSystemService", stringBuilder2.toString());
            return;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public java.lang.String getReaders() throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            android.util.Log.i("SmartcardSystemService", "called: getReaders()");
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            java.lang.String[] result = this.smartcardService.getReaders(error);
            int i = 0;
            for (int i2 = 0; i2 < result.length; i2++) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getReaders(");
                stringBuilder.append(i2);
                stringBuilder.append(") returned: ");
                stringBuilder.append(result[i2]);
                android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            }
            this.lastException = error.createException();
            java.lang.StringBuffer readerlist = new java.lang.StringBuffer();
            while (i < result.length) {
                readerlist.append(result[i]);
                readerlist.append(";");
                i++;
            }
            return readerlist.toString();
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public boolean isCardPresent(java.lang.String reader) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            boolean result = this.smartcardService.isCardPresent(reader, error);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isCardPresent(");
            stringBuilder.append(reader);
            stringBuilder.append(") returned: ");
            stringBuilder.append(result);
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            this.lastException = error.createException();
            return result;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public long openBasicChannel(java.lang.String reader) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("called: openBasicChannel(");
            stringBuilder.append(reader);
            stringBuilder.append(")");
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            long channelValue = this.smartcardService.openBasicChannel(reader, this.callback, error);
            this.lastException = error.createException();
            return channelValue;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public long openBasicChannelAid(java.lang.String reader, java.lang.String aid) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("called: openBasicChannelAid (");
            stringBuilder.append(reader);
            stringBuilder.append(")");
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            long channelValue = this.smartcardService.openBasicChannelAid(reader, stringToByteArray(aid), this.callback, error);
            this.lastException = error.createException();
            return channelValue;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public long openLogicalChannel(java.lang.String reader, java.lang.String aid) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("called: openLogicalChannel(");
            stringBuilder.append(reader);
            stringBuilder.append(", ");
            stringBuilder.append(aid);
            stringBuilder.append(")");
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            long channelValue = this.smartcardService.openLogicalChannel(reader, stringToByteArray(aid), this.callback, error);
            this.lastException = error.createException();
            return channelValue;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public java.lang.String transmit(long hChannel, java.lang.String command) throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("called: transmit(");
            stringBuilder.append(hChannel);
            stringBuilder.append(", ");
            stringBuilder.append(command);
            stringBuilder.append(")");
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            org.simalliance.openmobileapi.service.SmartcardError error = new org.simalliance.openmobileapi.service.SmartcardError();
            byte[] cmd = hexStringToByteArray(command);
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("transmitting: ");
            stringBuilder2.append(bytesToString(cmd));
            android.util.Log.i("SmartcardSystemService", stringBuilder2.toString());
            java.lang.String strResponse = "";
            java.lang.StringBuilder stringBuilder3;
            try {
                byte[] rsp = this.smartcardService.transmit(hChannel, cmd, error);
                if (rsp != null) {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("transmit returned: ");
                    stringBuilder3.append(bytesToString(rsp));
                    android.util.Log.i("SmartcardSystemService", stringBuilder3.toString());
                    strResponse = bytesToString(rsp);
                }
            } catch (java.lang.Exception e) {
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("transmit exception: ");
                stringBuilder3.append(e.toString());
                android.util.Log.w("SmartcardSystemService", stringBuilder3.toString());
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("transmit Error object: ");
                stringBuilder3.append(error.toString());
                android.util.Log.w("SmartcardSystemService", stringBuilder3.toString());
            }
            java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
            stringBuilder4.append("transmit returned: ");
            stringBuilder4.append(strResponse);
            android.util.Log.i("SmartcardSystemService", stringBuilder4.toString());
            this.lastException = error.createException();
            return strResponse;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    public java.lang.String getLastError() {
        if (checkAccessSmartcardAPI()) {
            android.util.Log.i("SmartcardSystemService", "called: getLastError");
            java.lang.String strErrorMessage = "";
            if (this.lastException != null) {
                strErrorMessage = this.lastException.getMessage();
                if (strErrorMessage == null) {
                    strErrorMessage = this.lastException.toString();
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getLastError - message ");
                stringBuilder.append(strErrorMessage);
                android.util.Log.w("SmartcardSystemService", stringBuilder.toString());
            }
            return strErrorMessage;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    private void bindSmartCardService() {
        android.util.Log.i("SmartcardSystemService", "called bindSmartCardService");
        this.mSmartcardSystemHandler.post(new java.lang.Runnable() {
            public void run() {
                if (com.android.server.SmartcardSystemService.this.mBindStatus == 0) {
                    android.util.Log.i("SmartcardSystemService", "begin bind SmartCardService");
                    android.content.Intent startIntent = new android.content.Intent(org.simalliance.openmobileapi.service.ISmartcardService.class.getName());
                    android.content.ComponentName comp = startIntent.resolveSystemService(com.android.server.SmartcardSystemService.this.mContext.getPackageManager(), 0);
                    startIntent.setComponent(comp);
                    if (comp != null) {
                        boolean result = com.android.server.SmartcardSystemService.this.mContext.bindService(startIntent, com.android.server.SmartcardSystemService.this.mConnection, 1);
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("bindService result: ");
                        stringBuilder.append(result);
                        android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
                        if (result) {
                            com.android.server.SmartcardSystemService.this.mBindStatus = 1;
                        }
                    } else {
                        android.util.Log.i("SmartcardSystemService", "SmartcardService not exist");
                        com.android.server.SmartcardSystemService.this.mBindStatus = 0;
                    }
                }
            }
        });
    }

    public boolean connectSmartCardService() throws android.os.RemoteException {
        if (checkAccessSmartcardAPI()) {
            android.util.Log.i("SmartcardSystemService", "connectSmartCardService");
            if (this.mIccCardReady) {
                android.util.Log.i("SmartcardSystemService", "Icc Card Ready");
                if (this.mBindStatus == 0) {
                    bindSmartCardService();
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("bind result:");
            stringBuilder.append(this.mBindStatus);
            android.util.Log.i("SmartcardSystemService", stringBuilder.toString());
            if (this.mBindStatus == 2) {
                return true;
            }
            return false;
        }
        throw new java.lang.SecurityException("Permission denied for accessing Smartcard API");
    }

    private boolean checkAccessSmartcardAPI() {
        if (android.os.Binder.getCallingUid() < 10000) {
            return true;
        }
        return false;
    }
}
