package com.android.server;

public class SystemBlockMonitor extends java.lang.Thread implements com.android.server.HwServiceFactory.ISystemBlockMonitor {
    static final long CHECK_INTERVAL = 6000;
    static final int COMPLETED = 0;
    private static final boolean DEBUG = android.os.SystemProperties.getBoolean("ro.debuggable", false);
    static final long DEFAULT_TIMEOUT = 6000;
    static final long DUMP_INTERVAL = 60000;
    public static final java.util.List<java.lang.String> HAL_INTERFACES_OF_INTEREST = java.util.Arrays.asList(new java.lang.String[]{"android.hardware.audio@2.0::IDevicesFactory", "android.hardware.bluetooth@1.0::IBluetoothHci", "android.hardware.camera.provider@2.4::ICameraProvider", "android.hardware.vr@1.0::IVr", "android.hardware.media.omx@1.0::IOmx"});
    static final int JLOG_DEFAULT_TIMEOUT = 6;
    public static final java.lang.String[] NATIVE_STACKS_OF_INTEREST = new java.lang.String[]{"/system/bin/netd", "/system/bin/audioserver", "/system/bin/cameraserver", "/system/bin/drmserver", "/system/bin/mediadrmserver", "/system/bin/mediaserver", "/system/bin/installd", "/system/bin/sdcard", "/system/bin/surfaceflinger", "media.log", "/system/bin/keystore", "media.codec", "media.extractor", "com.android.bluetooth"};
    static final int OVERDUE = 2;
    static final java.lang.String TAG = "SystemBlockMonitor";
    static final int WAITING = 1;
    static com.android.server.SystemBlockMonitor sSystemBlockMonitor;
    private long dumpStarTtime = 0;
    final java.util.ArrayList<com.android.server.SystemBlockMonitor.HandlerChecker> mHandlerCheckers = new java.util.ArrayList();
    com.android.server.SystemBlockMonitor.HandlerChecker mMonitorChecker = null;
    android.os.HandlerThread mMonitorThread = null;

    private static final class BinderThreadMonitor implements com.android.server.Watchdog.Monitor {
        private BinderThreadMonitor() {
        }

        public void monitor() {
            android.os.Binder.blockUntilThreadAvailable();
        }
    }

    public final class HandlerChecker implements java.lang.Runnable {
        private boolean mCompleted;
        private com.android.server.Watchdog.Monitor mCurrentMonitor;
        private final android.os.Handler mHandler;
        private final java.util.ArrayList<com.android.server.Watchdog.Monitor> mMonitors = new java.util.ArrayList();
        private final java.lang.String mName;
        private long mStartTime;
        private final long mWaitMax;

        HandlerChecker(android.os.Handler handler, java.lang.String name, long waitMaxMillis) {
            this.mHandler = handler;
            this.mName = name;
            this.mWaitMax = waitMaxMillis;
            this.mCompleted = true;
        }

        public void addMonitor(com.android.server.Watchdog.Monitor monitor) {
            this.mMonitors.add(monitor);
        }

        public void scheduleCheckLocked() {
            if (this.mMonitors.size() == 0 && this.mHandler.getLooper().getQueue().isPolling()) {
                this.mCompleted = true;
            } else if (this.mCompleted) {
                this.mCompleted = false;
                this.mCurrentMonitor = null;
                this.mStartTime = android.os.SystemClock.uptimeMillis();
                this.mHandler.postAtFrontOfQueue(this);
            }
        }

        public int getCompletionStateLocked() {
            if (this.mCompleted) {
                return 0;
            }
            if (android.os.SystemClock.uptimeMillis() - this.mStartTime < this.mWaitMax) {
                return 1;
            }
            return 2;
        }

        public java.lang.Thread getThread() {
            return this.mHandler.getLooper().getThread();
        }

        public java.lang.String getName() {
            return this.mName;
        }

        public void run() {
            int size = this.mMonitors.size();
            for (int i = 0; i < size; i++) {
                synchronized (com.android.server.SystemBlockMonitor.this) {
                    this.mCurrentMonitor = (com.android.server.Watchdog.Monitor) this.mMonitors.get(i);
                }
                this.mCurrentMonitor.monitor();
            }
            synchronized (com.android.server.SystemBlockMonitor.this) {
                this.mCompleted = true;
                this.mCurrentMonitor = null;
            }
        }
    }

    public static synchronized com.android.server.SystemBlockMonitor getInstance() {
        synchronized (com.android.server.SystemBlockMonitor.class) {
            if (DEBUG) {
                if (sSystemBlockMonitor == null) {
                    sSystemBlockMonitor = new com.android.server.SystemBlockMonitor();
                }
                android.util.Slog.i("SystemBlockMonitor", "getInstance SystemBlockMonitor");
                com.android.server.SystemBlockMonitor systemBlockMonitor = sSystemBlockMonitor;
                return systemBlockMonitor;
            }
            return null;
        }
    }

    protected SystemBlockMonitor() {
        super("SystemBlockMonitor");
        android.util.Slog.i("SystemBlockMonitor", "Create SystemBlockMonitor");
        this.mMonitorThread = new android.os.HandlerThread("monitor thread");
        this.mMonitorThread.start();
        this.mMonitorChecker = new com.android.server.SystemBlockMonitor.HandlerChecker(this.mMonitorThread.getThreadHandler(), "monitor thread", 6000);
        this.mHandlerCheckers.add(this.mMonitorChecker);
        this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(com.android.server.FgThread.getHandler(), "foreground thread", 6000));
        this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(new android.os.Handler(android.os.Looper.getMainLooper()), "main thread", 6000));
        this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(com.android.server.UiThread.getHandler(), "ui thread", 6000));
        this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(com.android.server.IoThread.getHandler(), "i/o thread", 6000));
        this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(com.android.server.DisplayThread.getHandler(), "display thread", 6000));
        addMonitor(new com.android.server.SystemBlockMonitor.BinderThreadMonitor());
    }

    public void init(android.content.Context context, com.android.server.am.ActivityManagerService activity) {
        android.util.Slog.i("SystemBlockMonitor", "SystemBlockMonitor Init");
    }

    public void addMonitor(com.android.server.Watchdog.Monitor monitor) {
        synchronized (this) {
            if (isAlive()) {
                throw new java.lang.RuntimeException("Monitors can't be added once the SystemBlockMonitor is running");
            }
            if (monitor != null) {
                this.mMonitorChecker.addMonitor(monitor);
            }
        }
    }

    public void addThread(android.os.Handler thread) {
        if (thread != null) {
            addThread(thread, 6000);
        }
    }

    public void addThread(android.os.Handler thread, long timeoutMillis) {
        synchronized (this) {
            if (isAlive()) {
                throw new java.lang.RuntimeException("Threads can't be added once the SystemBlockMonitor is running");
            }
            this.mHandlerCheckers.add(new com.android.server.SystemBlockMonitor.HandlerChecker(thread, thread.getLooper().getThread().getName(), timeoutMillis));
        }
    }

    private int evaluateCheckerCompletionLocked() {
        int state = 0;
        int checkerSize = this.mHandlerCheckers.size();
        for (int i = 0; i < checkerSize; i++) {
            com.android.server.SystemBlockMonitor.HandlerChecker hc = (com.android.server.SystemBlockMonitor.HandlerChecker) this.mHandlerCheckers.get(i);
            state = state > hc.getCompletionStateLocked() ? state : hc.getCompletionStateLocked();
        }
        return state;
    }

    private void printLockedThread() {
        int checkerSize = this.mHandlerCheckers.size();
        for (int i = 0; i < checkerSize; i++) {
            com.android.server.SystemBlockMonitor.HandlerChecker hc = (com.android.server.SystemBlockMonitor.HandlerChecker) this.mHandlerCheckers.get(i);
            if (hc.getCompletionStateLocked() == 2) {
                java.lang.String lockedThread = hc.getName();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(lockedThread);
                stringBuilder.append(" is blocked for over 6 seconds");
                android.util.Slog.i("SystemBlockMonitor", stringBuilder.toString());
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append(lockedThread);
                stringBuilder2.append(" is blocked for over 6 seconds");
                android.util.Jlog.d(353, lockedThread, 6, stringBuilder2.toString());
            }
        }
    }

    public void startRun() {
        if (sSystemBlockMonitor != null) {
            sSystemBlockMonitor.start();
        }
    }

    public int checkRecentLockedState() {
        if (this.dumpStarTtime == 0 || android.os.SystemClock.uptimeMillis() - this.dumpStarTtime >= 60000) {
            return 0;
        }
        return android.os.Process.myPid();
    }

    public void run() {
        while (true) {
            synchronized (this) {
                int i;
                int checkerSize = this.mHandlerCheckers.size();
                for (i = 0; i < checkerSize; i++) {
                    ((com.android.server.SystemBlockMonitor.HandlerChecker) this.mHandlerCheckers.get(i)).scheduleCheckLocked();
                }
                try {
                    wait(6000);
                } catch (java.lang.InterruptedException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("error msg :");
                    stringBuilder.append(e.getMessage());
                    android.util.Slog.w("SystemBlockMonitor", stringBuilder.toString());
                }
                i = evaluateCheckerCompletionLocked();
                if (i == 0) {
                } else if (i == 1) {
                } else if (i == 2) {
                    android.util.Slog.i("SystemBlockMonitor", "OVERDUE");
                    printLockedThread();
                    if (this.dumpStarTtime == 0 || android.os.SystemClock.uptimeMillis() - this.dumpStarTtime >= 60000) {
                        this.dumpStarTtime = android.os.SystemClock.uptimeMillis();
                    }
                }
            }
        }
    }
}
