package com.android.server.am;

public final class HwActivityStackSupervisor extends com.android.server.am.ActivityStackSupervisor {
    private static final java.lang.String ACTION_CONFIRM_APPLOCK_CREDENTIAL = "huawei.intent.action.APPLOCK_FRAMEWORK_MANAGER";
    private static final java.lang.String ACTION_CONFIRM_APPLOCK_PACKAGENAME = "com.huawei.systemmanager";
    private static final int CRASH_INTERVAL_THRESHOLD = 60000;
    private static final int CRASH_TIMES_THRESHOLD = 3;
    private static final java.lang.String SPLIT_SCREEN_APP_NAME = "splitscreen.SplitScreenAppActivity";
    private static final java.lang.String STACK_DIVIDER_APP_NAME = "stackdivider.ForcedResizableInfoActivity";
    private int mCrashTimes;
    private long mFirstLaunchTime;
    private java.lang.String mLastHomePkg;
    private int mNextPcFreeStackId = 1000000008;
    private int mNextVrFreeStackId = 1100000000;
    private android.widget.Toast mToast = null;
    private final java.util.ArrayList<com.android.server.am.ActivityRecord> mWindowStateChangedActivities = new java.util.ArrayList();

    public HwActivityStackSupervisor(com.android.server.am.ActivityManagerService service, android.os.Looper looper) {
        super(service, looper);
    }

    private boolean isUninstallableApk(java.lang.String pkgName) {
        if (pkgName == null || "android".equals(pkgName)) {
            return false;
        }
        try {
            android.content.pm.PackageInfo pInfo = this.mService.mContext.getPackageManager().getPackageInfo(pkgName, 0);
            if (pInfo == null || (pInfo.applicationInfo.flags & 1) == 0) {
                return true;
            }
            return false;
        } catch (android.content.pm.PackageManager.NameNotFoundException e) {
            return false;
        }
    }

    public void recognitionMaliciousApp(android.app.IApplicationThread caller, android.content.Intent intent) {
        if (caller == null) {
            android.content.Intent homeIntent = this.mService.getHomeIntent();
            java.lang.String action = intent.getAction();
            java.util.Set<java.lang.String> category = intent.getCategories();
            if (action != null && action.equals(homeIntent.getAction()) && category != null && category.containsAll(homeIntent.getCategories())) {
                android.content.ComponentName cmp = intent.getComponent();
                java.lang.String strPkg = null;
                if (cmp != null) {
                    strPkg = cmp.getPackageName();
                }
                java.lang.String strPkg2 = strPkg;
                if (strPkg2 != null) {
                    if (android.hdm.HwDeviceManager.disallowOp(26, strPkg2)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(strPkg2);
                        stringBuilder.append(" is a ignored frequent relaunch app set by MDM!");
                        android.util.Slog.i("ActivityManager", stringBuilder.toString());
                    } else if (isUninstallableApk(strPkg2)) {
                        if (strPkg2.equals(this.mLastHomePkg)) {
                            this.mCrashTimes++;
                            long now = android.os.SystemClock.uptimeMillis();
                            if (this.mCrashTimes >= 3) {
                                if (now - this.mFirstLaunchTime < 60000) {
                                    try {
                                        android.app.ActivityThread.getPackageManager().clearPackagePreferredActivities(strPkg2);
                                    } catch (android.os.RemoteException e) {
                                    }
                                    this.mService.showUninstallLauncherDialog(strPkg2);
                                    this.mLastHomePkg = null;
                                    this.mCrashTimes = 0;
                                } else {
                                    this.mCrashTimes = 1;
                                    this.mFirstLaunchTime = now;
                                }
                            }
                        } else {
                            this.mLastHomePkg = strPkg2;
                            this.mCrashTimes = 0;
                            this.mFirstLaunchTime = android.os.SystemClock.uptimeMillis();
                        }
                    }
                }
            }
        }
    }

    android.content.pm.ResolveInfo resolveIntent(android.content.Intent intent, java.lang.String resolvedType, int userId, int flags, int filterCallingUid) {
        int callingUserId = android.os.UserHandle.getUserId(android.os.Binder.getCallingUid());
        if (userId == callingUserId && userId == 0) {
            return super.resolveIntent(intent, resolvedType, userId, flags, filterCallingUid);
        }
        if (!this.mService.mUserController.mInjector.getUserManagerInternal().isSameGroupForClone(callingUserId, userId)) {
            return super.resolveIntent(intent, resolvedType, userId, flags, filterCallingUid);
        }
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            android.content.pm.ResolveInfo resolveIntent = super.resolveIntent(intent, resolvedType, userId, flags, filterCallingUid);
            return resolveIntent;
        } finally {
            android.os.Binder.restoreCallingIdentity(ident);
        }
    }

    private final void noteActivityDisplayedEnd(java.lang.String activityName, int uid, int pid, long time) {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RES_APP)) && this.mService.mSystemReady) {
            android.rms.iaware.DataContract.Apps.Builder builder = android.rms.iaware.DataContract.Apps.builder();
            builder.addEvent(85013);
            builder.addActivityDisplayedInfoWithUid(activityName, uid, pid, time);
            android.rms.iaware.CollectData appsData = builder.build();
            long id = android.os.Binder.clearCallingIdentity();
            resManager.reportData(appsData);
            android.os.Binder.restoreCallingIdentity(id);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("EVENT_APP_ACTIVITY_DISPLAYED_FINISH reportData: ");
            stringBuilder.append(activityName);
            stringBuilder.append(" ");
            stringBuilder.append(pid);
            stringBuilder.append(" ");
            stringBuilder.append(time);
            android.util.Slog.d("ActivityManager", stringBuilder.toString());
        }
    }

    void reportActivityLaunchedLocked(boolean timeout, com.android.server.am.ActivityRecord r, long thisTime, long totalTime) {
        if (!(timeout || r == null || r.app == null || r.shortComponentName == null || r.app.pid <= 0)) {
            noteActivityDisplayedEnd(r.shortComponentName, r.app.uid, r.app.pid, thisTime);
        }
        super.reportActivityLaunchedLocked(timeout, r, thisTime, totalTime);
    }

    public java.util.ArrayList<com.android.server.am.ActivityRecord> getWindowStateChangedActivities() {
        return this.mWindowStateChangedActivities;
    }

    public void scheduleReportPCWindowStateChangedLocked(com.android.server.am.TaskRecord task) {
        for (int i = task.mActivities.size() - 1; i >= 0; i--) {
            com.android.server.am.ActivityRecord r = (com.android.server.am.ActivityRecord) task.mActivities.get(i);
            if (!(r.app == null || r.app.thread == null)) {
                getWindowStateChangedActivities().add(r);
            }
        }
        if (!this.mHandler.hasMessages(10001)) {
            this.mHandler.sendEmptyMessage(10001);
        }
    }

    public void handlePCWindowStateChanged() {
        synchronized (this.mService) {
            java.util.List<com.android.server.am.ActivityRecord> list = getWindowStateChangedActivities();
            for (int i = list.size() - 1; i >= 0; i--) {
                com.android.server.am.ActivityRecord r = (com.android.server.am.ActivityRecord) list.remove(i);
                if (r instanceof com.android.server.am.HwActivityRecord) {
                    ((com.android.server.am.HwActivityRecord) r).schedulePCWindowStateChanged();
                }
            }
        }
    }

    protected int getNextVrStackId() {
        while (true) {
            if (this.mNextVrFreeStackId >= 1100000000 && getStack(this.mNextVrFreeStackId) == null) {
                return this.mNextVrFreeStackId;
            }
            this.mNextVrFreeStackId++;
        }
    }

    protected int getNextPcStackId() {
        while (true) {
            if (this.mNextPcFreeStackId >= 1100000000) {
                this.mNextPcFreeStackId = 1000000008;
            }
            if (this.mNextPcFreeStackId >= 1000000008 && getStack(this.mNextPcFreeStackId) == null) {
                return this.mNextPcFreeStackId;
            }
            this.mNextPcFreeStackId++;
        }
    }

    protected com.android.server.am.ActivityStack getValidLaunchStackOnDisplay(int displayId, com.android.server.am.ActivityRecord r) {
        com.android.server.am.ActivityDisplay activityDisplay = (com.android.server.am.ActivityDisplay) this.mActivityDisplays.get(displayId);
        java.lang.StringBuilder stringBuilder;
        if (activityDisplay == null) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Display with displayId=");
            stringBuilder.append(displayId);
            stringBuilder.append(" not found.");
            throw new java.lang.IllegalArgumentException(stringBuilder.toString());
        } else if (android.util.HwVRUtils.isValidVRDisplayId(displayId)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("vr getValidLaunchStackOnDisplay displayid is: ");
            stringBuilder.append(displayId);
            android.util.Slog.i("ActivityManager", stringBuilder.toString());
            return com.android.server.HwServiceFactory.createActivityStack(activityDisplay, getNextVrStackId(), this, r.getWindowingMode(), r.getActivityType(), true);
        } else if (android.util.HwPCUtils.isPcCastModeInServer() && android.util.HwPCUtils.isValidExtDisplayId(displayId)) {
            return com.android.server.HwServiceFactory.createActivityStack(activityDisplay, getNextPcStackId(), this, 10, 1, true);
        } else {
            if (android.util.HwPCUtils.isPcCastModeInServer() && displayId == 0) {
                android.util.HwPCUtils.log("ActivityManager", " create full screen stack because the stack is null when r is from pc");
                activityDisplay.getOrCreateStack(1, 0, true);
            }
            return super.getValidLaunchStackOnDisplay(displayId, r);
        }
    }

    protected boolean restoreRecentTaskLocked(com.android.server.am.TaskRecord task, android.app.ActivityOptions aOptions, boolean onTop) {
        if ((android.util.HwPCUtils.isPcCastModeInServer() || android.util.HwVRUtils.isVRMode()) && task == null) {
            return false;
        }
        return super.restoreRecentTaskLocked(task, aOptions, onTop);
    }

    protected void handleDisplayRemoved(int displayId) {
        int i = 0;
        com.android.server.am.ActivityDisplay activityDisplay;
        int size;
        java.util.ArrayList<com.android.server.am.ActivityStack> stacks;
        if (android.util.HwPCUtils.isPcCastModeInServer() && android.util.HwPCUtils.isValidExtDisplayId(displayId)) {
            synchronized (this.mService) {
                activityDisplay = (com.android.server.am.ActivityDisplay) this.mActivityDisplays.get(displayId);
                if (activityDisplay != null) {
                    size = activityDisplay.getChildCount();
                    stacks = new java.util.ArrayList();
                    while (i < size) {
                        stacks.add(activityDisplay.getChildAt(i));
                        i++;
                    }
                    onDisplayRemoved(stacks);
                    activityDisplay.remove();
                    this.mActivityDisplays.remove(displayId);
                }
            }
        } else if (android.util.HwVRUtils.isValidVRDisplayId(displayId)) {
            synchronized (this.mService) {
                activityDisplay = (com.android.server.am.ActivityDisplay) this.mActivityDisplays.get(displayId);
                if (activityDisplay != null) {
                    size = activityDisplay.getChildCount();
                    stacks = new java.util.ArrayList();
                    while (i < size) {
                        stacks.add(activityDisplay.getChildAt(i));
                        i++;
                    }
                    onVRdisplayRemoved(activityDisplay, stacks, displayId);
                }
            }
        } else {
            super.handleDisplayRemoved(displayId);
        }
    }

    protected boolean keepStackResumed(com.android.server.am.ActivityStack stack) {
        if (android.util.HwPCUtils.isPcCastModeInServer() && stack != null) {
            if (android.util.HwPCUtils.isPcDynamicStack(stack.mStackId) && stack.shouldBeVisible(null)) {
                return true;
            }
            if (android.util.HwPCUtils.isPcDynamicStack(this.mFocusedStack.mStackId) && !android.util.HwPCUtils.isPcDynamicStack(stack.mStackId)) {
                return true;
            }
        }
        return super.keepStackResumed(stack);
    }

    protected boolean isStackInVisible(com.android.server.am.ActivityStack stack) {
        if (stack != null && android.util.HwPCUtils.isExtDynamicStack(stack.mStackId) && stack.shouldBeVisible(null)) {
            return true;
        }
        return super.isStackInVisible(stack);
    }

    protected void showToast(final int displayId) {
        if (android.util.HwPCUtils.isPcCastModeInServer()) {
            android.content.Context context;
            if (android.util.HwPCUtils.isValidExtDisplayId(displayId)) {
                context = android.util.HwPCUtils.getDisplayContext(this.mService.mContext, displayId);
            } else {
                context = this.mService.mContext;
            }
            if (context != null) {
                com.android.server.UiThread.getHandler().post(new java.lang.Runnable() {
                    public void run() {
                        if (com.android.server.am.HwActivityStackSupervisor.this.mToast != null) {
                            com.android.server.am.HwActivityStackSupervisor.this.mToast.cancel();
                        }
                        if (android.util.HwPCUtils.isValidExtDisplayId(displayId)) {
                            com.android.server.am.HwActivityStackSupervisor.this.mToast = android.widget.Toast.makeText(context, context.getResources().getString(33685970), 0);
                        } else {
                            com.android.server.am.HwActivityStackSupervisor.this.mToast = android.widget.Toast.makeText(context, context.getString(33685971), 0);
                        }
                        if (com.android.server.am.HwActivityStackSupervisor.this.mToast != null) {
                            com.android.server.am.HwActivityStackSupervisor.this.mToast.show();
                        }
                    }
                });
            }
        }
    }

    protected boolean startProcessOnExtDisplay(com.android.server.am.ActivityRecord r) {
        com.android.server.am.ActivityRecord activityRecord = r;
        if (r.getStack() == null || !android.util.HwPCUtils.isExtDynamicStack(r.getStack().mStackId) || r.getTask() == null || r.getTask().getLaunchBounds() == null) {
            return super.startProcessOnExtDisplay(r);
        }
        java.lang.String[] args = null;
        if (r.getTask().getLaunchBounds() != null) {
            args = new java.lang.String[]{java.lang.String.valueOf(r.getDisplayId()), java.lang.String.valueOf(r.getTask().getLaunchBounds().width()), java.lang.String.valueOf(r.getTask().getLaunchBounds().height())};
        }
        this.mService.startProcessLocked(activityRecord.processName, activityRecord.info.applicationInfo, true, 0, "activity", activityRecord.intent.getComponent(), false, false, 0, true, null, null, args, null);
        return true;
    }

    public boolean shouldNotKillProcWhenRemoveTask(java.lang.String pkg) {
        if (!"com.tencent.mm".equals(pkg)) {
            return false;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" cleanUpRemovedTaskLocked, do not kill process : ");
        stringBuilder.append(pkg);
        android.util.Slog.d("ActivityManager", stringBuilder.toString());
        return true;
    }

    public void onDisplayRemoved(java.util.ArrayList<com.android.server.am.ActivityStack> stacks) {
        java.util.ArrayList<android.content.Intent> mIntentList = new java.util.ArrayList();
        for (int i = stacks.size() - 1; i >= 0; i--) {
            ((com.android.server.am.ActivityStack) stacks.get(i)).mForceHidden = true;
        }
        java.util.ArrayList<com.android.server.am.ProcessRecord> procs = getPCProcessRecordList();
        while (!stacks.isEmpty()) {
            com.android.server.am.ActivityStack stack = (com.android.server.am.ActivityStack) stacks.get(0);
            com.android.server.am.TaskRecord tr = stack.topTask();
            if (tr != null) {
                if (!(tr.intent == null || stack.inPinnedWindowingMode())) {
                    mIntentList.add(tr.intent);
                }
                if (tr instanceof com.android.server.am.HwTaskRecord) {
                    removeProcessesActivityNotFinished(((com.android.server.am.HwTaskRecord) tr).getActivities(), procs);
                }
                stack.moveTaskToBackLocked(stack.getStackId());
                stack.finishAllActivitiesLocked(true);
            } else {
                stack.finishAllActivitiesLocked(true);
            }
            stacks.remove(stack);
        }
        killPCProcessesLocked(procs);
        android.pc.IHwPCManager pcManager = android.util.HwPCUtils.getHwPCManager();
        if (pcManager != null) {
            try {
                pcManager.saveAppIntent(mIntentList);
            } catch (android.os.RemoteException e) {
                android.util.HwPCUtils.log("ActivityManager", "fail to saveAppIntent on display removed");
            }
        }
        if (this.mService instanceof com.android.server.am.HwActivityManagerService) {
            ((com.android.server.am.HwActivityManagerService) this.mService).mPkgDisplayMaps.clear();
        }
    }

    public void onVRdisplayRemoved(com.android.server.am.ActivityDisplay display, java.util.ArrayList<com.android.server.am.ActivityStack> stacks, int displayId) {
        android.util.Slog.i("ActivityManager", "onVRdisplayRemoved");
        if (stacks == null) {
            android.util.Slog.w("ActivityManager", "vr activitystack is null");
            return;
        }
        while (!stacks.isEmpty()) {
            com.android.server.am.ActivityStack stack = (com.android.server.am.ActivityStack) stacks.get(0);
            moveTasksToFullscreenStackLocked(stack, false);
            stacks.remove(stack);
        }
        display.remove();
        this.mActivityDisplays.remove(displayId);
        resumeFocusedStackTopActivityLocked();
    }

    protected boolean resumeAppLockActivityIfNeeded(com.android.server.am.ActivityStack stack, android.app.ActivityOptions targetOptions) {
        if (this.mCurrentUser != 0) {
            return false;
        }
        com.android.server.am.ActivityRecord r = stack.topRunningActivityLocked();
        if (r == null || r.isState(com.android.server.am.ActivityStack.ActivityState.RESUMED) || !isKeyguardDismiss() || !isAppInLockList(r.packageName)) {
            return false;
        }
        android.content.Intent newIntent = new android.content.Intent("huawei.intent.action.APPLOCK_FRAMEWORK_MANAGER");
        newIntent.setFlags(109051904);
        newIntent.setPackage("com.huawei.systemmanager");
        newIntent.putExtra("android.intent.extra.TASK_ID", r.task.taskId);
        newIntent.putExtra("android.intent.extra.PACKAGE_NAME", r.packageName);
        android.app.ActivityOptions options = android.app.ActivityOptions.makeBasic();
        options.setLaunchTaskId(r.task.taskId);
        this.mService.mContext.startActivity(newIntent, options.toBundle());
        return true;
    }

    protected boolean isAppInLockList(java.lang.String pgkName) {
        if (pgkName != null && android.provider.Settings.Secure.getInt(this.mService.mContext.getContentResolver(), "app_lock_func_status", 0) == 1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(android.provider.Settings.Secure.getString(this.mService.mContext.getContentResolver(), "app_lock_list"));
            stringBuilder.append(";");
            java.lang.String stringBuilder2 = stringBuilder.toString();
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append(pgkName);
            stringBuilder3.append(";");
            if (stringBuilder2.contains(stringBuilder3.toString())) {
                return true;
            }
        }
        return false;
    }

    private boolean isKeyguardDismiss() {
        return getKeyguardController().isKeyguardLocked() ^ 1;
    }

    public boolean isInVisibleStack(java.lang.String pkg) {
        if (pkg != null) {
            if (!pkg.isEmpty()) {
                int size = this.mActivityDisplays.size();
                com.android.server.am.HwActivityStack hwStack = null;
                com.android.server.am.ActivityDisplay activityDisplay = null;
                for (int displayNdx = 0; displayNdx < size; displayNdx++) {
                    activityDisplay = (com.android.server.am.ActivityDisplay) this.mActivityDisplays.valueAt(displayNdx);
                    for (int stackNdx = activityDisplay.getChildCount() - 1; stackNdx >= 0; stackNdx--) {
                        com.android.server.am.ActivityStack stack = activityDisplay.getChildAt(stackNdx);
                        if ((stack instanceof com.android.server.am.HwActivityStack) && ((com.android.server.am.HwActivityStack) stack).isVisibleLocked(pkg, true)) {
                            return true;
                        }
                    }
                }
                return false;
            }
        }
        return false;
    }

    protected boolean notKillProcessWhenRemoveTask(com.android.server.am.ProcessRecord processRecord) {
        boolean z = true;
        if (this.mService.mContext == null) {
            return true;
        }
        if (android.provider.Settings.System.getInt(this.mService.mContext.getContentResolver(), "not_kill_process_when_remove_task", 1) != 1) {
            z = false;
        }
        return z;
    }

    boolean hasActivityInStackLocked(android.content.pm.ActivityInfo aInfo) {
        com.android.server.am.HwActivityStackSupervisor hwActivityStackSupervisor = this;
        android.content.pm.ActivityInfo activityInfo = aInfo;
        boolean z = false;
        if (activityInfo == null) {
            return false;
        }
        java.lang.String affinity = activityInfo.taskAffinity;
        java.lang.String pkgName = activityInfo.packageName;
        java.lang.String processName = activityInfo.processName;
        if (!(affinity == null || pkgName == null || processName == null)) {
            if (activityInfo.applicationInfo != null) {
                int userId = android.os.UserHandle.getUserId(activityInfo.applicationInfo.uid);
                int i = 1;
                int displayNdx = hwActivityStackSupervisor.mActivityDisplays.size() - 1;
                while (displayNdx >= 0) {
                    int i2;
                    java.util.ArrayList<com.android.server.am.ActivityStack> stacks = ((com.android.server.am.ActivityDisplay) hwActivityStackSupervisor.mActivityDisplays.valueAt(displayNdx)).mStacks;
                    int stackNdx = stacks.size() - i;
                    while (stackNdx >= 0) {
                        java.util.ArrayList<com.android.server.am.TaskRecord> allTasks = ((com.android.server.am.ActivityStack) stacks.get(stackNdx)).getAllTasks();
                        int taskNdx = allTasks.size() - i;
                        while (taskNdx >= 0) {
                            com.android.server.am.TaskRecord task = (com.android.server.am.TaskRecord) allTasks.get(taskNdx);
                            if (task != null) {
                                if (task.userId == userId) {
                                    if (task.affinity != null && task.affinity.equals(affinity)) {
                                        java.util.ArrayList<com.android.server.am.ActivityRecord> activities = task.mActivities;
                                        int numActivities = activities.size();
                                        if (numActivities <= 0) {
                                            return z;
                                        }
                                        int activityNdx = numActivities - 1;
                                        while (true) {
                                            int activityNdx2 = activityNdx;
                                            if (activityNdx2 < 0) {
                                                return false;
                                            }
                                            com.android.server.am.ActivityRecord r = (com.android.server.am.ActivityRecord) activities.get(activityNdx2);
                                            if (!(r.finishing || r.isState(com.android.server.am.ActivityStack.ActivityState.DESTROYED) || r.app == null)) {
                                                if (pkgName.equals(r.packageName)) {
                                                    if (processName.equals(r.app.processName)) {
                                                        return true;
                                                    }
                                                }
                                            }
                                            activityNdx = activityNdx2 - 1;
                                            i = 1;
                                        }
                                    }
                                }
                            }
                            taskNdx--;
                            i = i;
                            z = false;
                        }
                        i2 = i;
                        stackNdx--;
                        z = false;
                    }
                    i2 = i;
                    displayNdx--;
                    hwActivityStackSupervisor = this;
                    z = false;
                }
                return false;
            }
        }
        return false;
    }

    private int getSpecialTaskId(boolean isDefaultDisplay, com.android.server.am.ActivityStack stack, java.lang.String pkgName, boolean invisibleAlso) {
        java.util.ArrayList<com.android.server.am.TaskRecord> tasks;
        int taskNdx;
        com.android.server.am.TaskRecord tr;
        if (pkgName != null) {
            if (!"".equals(pkgName)) {
                tasks = stack.getAllTasks();
                for (taskNdx = tasks.size() - 1; taskNdx >= 0; taskNdx--) {
                    tr = (com.android.server.am.TaskRecord) tasks.get(taskNdx);
                    if (tr != null) {
                        if (invisibleAlso || tr.isVisible()) {
                            candicatedArs = new com.android.server.am.ActivityRecord[2];
                            int arIdx = 0;
                            candicatedArs[0] = tr.topRunningActivityLocked();
                            candicatedArs[1] = tr.getRootActivity();
                            while (true) {
                                int arIdx2 = arIdx;
                                if (arIdx2 >= candicatedArs.length) {
                                    continue;
                                    break;
                                }
                                com.android.server.am.ActivityRecord ar = candicatedArs[arIdx2];
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("getSpecialTaskId ar = ");
                                stringBuilder.append(ar);
                                stringBuilder.append(", tr.isVisible() = ");
                                stringBuilder.append(tr.isVisible());
                                android.util.HwPCUtils.log("ActivityManager", stringBuilder.toString());
                                if (ar != null && ar.packageName != null && ar.packageName.equals(pkgName)) {
                                    return tr.taskId;
                                }
                                arIdx = arIdx2 + 1;
                            }
                        }
                    }
                }
                return -1;
            }
        }
        if (isDefaultDisplay) {
            tasks = stack.getAllTasks();
            taskNdx = tasks.size() - 1;
            while (true) {
                int taskNdx2 = taskNdx;
                if (taskNdx2 < 0) {
                    break;
                }
                tr = (com.android.server.am.TaskRecord) tasks.get(taskNdx2);
                if (tr == null || !(invisibleAlso || tr.isVisible())) {
                    taskNdx = taskNdx2 - 1;
                }
            }
            return tr.taskId;
        }
        tr = stack.topTask();
        if (tr != null && (invisibleAlso || tr.isVisible())) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("getSpecialTaskId tr.taskId = ");
            stringBuilder2.append(tr.taskId);
            android.util.HwPCUtils.log("ActivityManager", stringBuilder2.toString());
            return tr.taskId;
        }
        return -1;
    }

    public int getTopTaskIdInDisplay(int displayId, java.lang.String pkgName, boolean invisibleAlso) {
        int N = this.mActivityDisplays.size();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getTopTaskIdInDisplay displayId = ");
        stringBuilder.append(displayId);
        stringBuilder.append(", N = ");
        stringBuilder.append(N);
        stringBuilder.append(", pkgName = ");
        stringBuilder.append(pkgName);
        android.util.HwPCUtils.log("ActivityManager", stringBuilder.toString());
        if (displayId < 0) {
            return -1;
        }
        com.android.server.am.ActivityDisplay activityDisplay = getActivityDisplay(displayId);
        if (activityDisplay == null) {
            android.util.HwPCUtils.log("ActivityManager", "getTopTaskIdInDisplay activityDisplay not exist");
            return -1;
        }
        for (int stackNdx = activityDisplay.getChildCount() - 1; stackNdx >= 0; stackNdx--) {
            int taskId = getSpecialTaskId(displayId == 0 ? 1 : 0, activityDisplay.getChildAt(stackNdx), pkgName, invisibleAlso);
            if (taskId != -1) {
                return taskId;
            }
        }
        return -1;
    }

    public android.graphics.Rect getPCTopTaskBounds(int displayId) {
        int N = this.mActivityDisplays.size();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getPCTopTaskBounds displayId = ");
        stringBuilder.append(displayId);
        stringBuilder.append(", N = ");
        stringBuilder.append(N);
        android.util.HwPCUtils.log("ActivityManager", stringBuilder.toString());
        if (displayId < 0) {
            return null;
        }
        com.android.server.am.ActivityDisplay activityDisplay = getActivityDisplay(displayId);
        if (activityDisplay == null) {
            android.util.HwPCUtils.log("ActivityManager", "getPCTopTaskBounds activityDisplay not exist");
            return null;
        }
        android.graphics.Rect rect = new android.graphics.Rect();
        int stackNdx = activityDisplay.getChildCount() - 1;
        while (stackNdx >= 0) {
            com.android.server.am.TaskRecord tr = activityDisplay.getChildAt(stackNdx).topTask();
            if (tr == null || !tr.isVisible()) {
                stackNdx--;
            } else {
                tr.getWindowContainerBounds(rect);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("getTaskIdInPCDisplayLocked tr.taskId = ");
                stringBuilder2.append(tr.taskId);
                stringBuilder2.append(", rect = ");
                stringBuilder2.append(rect);
                android.util.HwPCUtils.log("ActivityManager", stringBuilder2.toString());
                return rect;
            }
        }
        return null;
    }

    protected void uploadUnSupportSplitScreenAppPackageName(java.lang.String pkgName) {
        if (this.mService.mContext != null) {
            android.content.Context context = this.mService.mContext;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("{ Launcher fail, pkgName:");
            stringBuilder.append(pkgName);
            stringBuilder.append(" }");
            com.huawei.android.statistical.StatisticalUtils.reporte(context, 174, stringBuilder.toString());
        }
    }

    protected com.android.server.am.ActivityStack getTargetSplitTopStack(com.android.server.am.ActivityStack current) {
        com.android.server.am.ActivityStack targetSplitTopStack = null;
        com.android.server.am.ActivityStack topSecondaryStack;
        if (current.getWindowingMode() == 3) {
            topSecondaryStack = current.getDisplay().getTopStackInWindowingMode(4);
            com.android.server.am.ActivityRecord topSecondaryActivityRecord = null;
            if (topSecondaryStack != null) {
                topSecondaryActivityRecord = topSecondaryStack.topRunningActivityLocked();
            }
            if (topSecondaryActivityRecord == null || topSecondaryActivityRecord.toString().contains("splitscreen.SplitScreenAppActivity")) {
                com.android.server.am.ActivityStack homeStack = current.getDisplay().getStack(4, 2);
                if (homeStack != null) {
                    targetSplitTopStack = homeStack;
                }
            } else {
                targetSplitTopStack = topSecondaryStack;
            }
            return targetSplitTopStack;
        } else if (current.getWindowingMode() != 4 || current.getActivityType() != 1) {
            return null;
        } else {
            topSecondaryStack = getNextStackInSplitSecondary(current);
            com.android.server.am.ActivityRecord nextTargetRecord = null;
            if (topSecondaryStack != null) {
                nextTargetRecord = topSecondaryStack.topRunningActivityLocked();
            }
            if (nextTargetRecord == null || !nextTargetRecord.info.name.contains("splitscreen.SplitScreenAppActivity")) {
                return null;
            }
            com.android.server.am.ActivityStack topPrimaryStack = current.getDisplay().getTopStackInWindowingMode(3);
            if (topPrimaryStack != null) {
                return topPrimaryStack;
            }
            return null;
        }
    }

    protected com.android.server.am.ActivityStack getNextStackInSplitSecondary(com.android.server.am.ActivityStack current) {
        java.util.ArrayList<com.android.server.am.ActivityStack> mStacks = current.getDisplay().mStacks;
        boolean returnNext = false;
        for (int i = mStacks.size() - 1; i >= 0; i--) {
            com.android.server.am.ActivityStack targetStack = (com.android.server.am.ActivityStack) mStacks.get(i);
            if (returnNext) {
                if (!targetStack.topRunningActivityLocked().info.name.contains("stackdivider.ForcedResizableInfoActivity")) {
                    if (targetStack.getWindowingMode() == 4) {
                        return targetStack;
                    }
                }
            } else if (targetStack.getStackId() == current.getStackId()) {
                returnNext = true;
            }
        }
        return null;
    }

    private java.util.ArrayList<com.android.server.am.ProcessRecord> getPCProcessRecordList() {
        java.util.ArrayList<com.android.server.am.ProcessRecord> procs = new java.util.ArrayList();
        int NP = this.mService.mProcessNames.getMap().size();
        for (int ip = 0; ip < NP; ip++) {
            android.util.SparseArray<com.android.server.am.ProcessRecord> apps = (android.util.SparseArray) this.mService.mProcessNames.getMap().valueAt(ip);
            int NA = apps.size();
            for (int ia = 0; ia < NA; ia++) {
                com.android.server.am.ProcessRecord proc = (com.android.server.am.ProcessRecord) apps.valueAt(ia);
                if (proc != this.mService.mHomeProcess) {
                    if (proc.mDisplayId != 0) {
                        procs.add(proc);
                    }
                }
            }
        }
        return procs;
    }

    private void killPCProcessesLocked(java.util.ArrayList<com.android.server.am.ProcessRecord> procs) {
        int NU = procs.size();
        for (int iu = 0; iu < NU; iu++) {
            com.android.server.am.ProcessRecord pr = (com.android.server.am.ProcessRecord) procs.get(iu);
            pr.kill("HwPCUtils#DisplayRemoved", true);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("killPCProcessesLocked: pr = ");
            stringBuilder.append(pr);
            android.util.HwPCUtils.log("ActivityManager", stringBuilder.toString());
        }
    }

    private void removeProcessesActivityNotFinished(java.util.ArrayList<com.android.server.am.ActivityRecord> activities, java.util.ArrayList<com.android.server.am.ProcessRecord> procs) {
        for (int activityNdx = activities.size() - 1; activityNdx >= 0; activityNdx--) {
            com.android.server.am.ActivityRecord r = (com.android.server.am.ActivityRecord) activities.get(activityNdx);
            int NP = procs.size();
            for (int i = 0; i < NP; i++) {
                if (((com.android.server.am.ProcessRecord) procs.get(i)).processName.equals(r.processName)) {
                    procs.remove(i);
                    break;
                }
            }
        }
    }
}
