package com.android.server.am;

public final class HwGameAssistantController {
    public static final boolean DEBUG = false;
    public static final int EVENT_MARK_AS_GAME = 4;
    public static final int EVENT_MOVE_BACKGROUND = 2;
    public static final int EVENT_MOVE_FRONT = 1;
    public static final int EVENT_REPLACE_FRONT = 3;
    public static final java.lang.String GAME_GESTURE_MODE = "game_gesture_disabled_mode";
    public static final int GAME_GESTURE_MODE_CLOSE = 2;
    public static final int GAME_GESTURE_MODE_DEFAULT = 2;
    public static final int GAME_GESTURE_MODE_OPEN = 1;
    public static final java.lang.String GAME_KEY_CONTROL_MODE = "game_key_control_mode";
    public static final int GAME_KEY_CONTROL_MODE_CLOSE = 2;
    public static final int GAME_KEY_CONTROL_MODE_DEFAULT = 2;
    public static final int GAME_KEY_CONTROL_MODE_OPEN = 1;
    private static final int MSG_BROADCAST_USER_PRESENT = 106;
    private static final int MSG_FOREGROUND_ACTIVITY_CHANGED = 100;
    private static final int MSG_GAME_LIST_CHANGED = 102;
    private static final int MSG_GAME_STATUS_CHANGED = 101;
    private static final int MSG_MARK_AS_GAME = 103;
    private static final int MSG_PACKAGE_REMOVED_OR_DATA_CLEARED = 104;
    private static final int MSG_USER_SWITCHING = 105;
    public static final java.lang.String PERMISSION_READ_GAME_LIST = "com.huawei.gameassistant.permission.READ_GAME_LIST";
    public static final java.lang.String PERMISSION_WRITE_GAME_LIST = "com.huawei.gameassistant.permission.WIRTE_GAME_LIST";
    static final java.lang.String TAG = "HwGameAssistantController";
    private boolean isSwitchingUser = false;
    private android.contentsensor.IActivityObserver mActivityObserver = new android.contentsensor.IActivityObserver.Stub() {
        public void activityResumed(int pid, int uid, android.content.ComponentName componentName) throws android.os.RemoteException {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("pid=");
            stringBuilder.append(pid);
            stringBuilder.append(", uid=");
            stringBuilder.append(uid);
            stringBuilder.append(", component=");
            stringBuilder.append(componentName);
            android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
            android.os.Bundle bundle = new android.os.Bundle();
            bundle.putInt("pid", pid);
            bundle.putInt("uid", uid);
            bundle.putString("packageName", componentName != null ? componentName.getPackageName() : "");
            com.android.server.am.HwGameAssistantController.this.mHandler.sendMessage(com.android.server.am.HwGameAssistantController.this.mHandler.obtainMessage(100, bundle));
        }

        public void activityPaused(int pid, int uid, android.content.ComponentName componentName) throws android.os.RemoteException {
        }
    };
    private final android.content.Context mContext;
    private int mCurFgPid;
    private java.lang.String mCurFgPkg;
    private boolean mCurIsGame;
    final android.os.RemoteCallbackList<com.huawei.android.app.IGameObserver> mGameObservers = new android.os.RemoteCallbackList();
    private java.util.ArrayList<java.lang.String> mGameSpacePackageList = new java.util.ArrayList();
    private android.os.Handler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private java.lang.String mLastForegroundPkg = "";
    private boolean mLastIsGame = false;
    private final com.android.server.am.HwActivityManagerService mService;
    private android.app.SynchronousUserSwitchObserver mUserSwitchObserver = new android.app.SynchronousUserSwitchObserver() {
        public void onUserSwitching(int newUserId) throws android.os.RemoteException {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onUserSwitching newUserId = ");
            stringBuilder.append(newUserId);
            android.util.Slog.w("HwGameAssistantController", stringBuilder.toString());
            com.android.server.am.HwGameAssistantController.this.isSwitchingUser = true;
            com.android.server.am.HwGameAssistantController.this.mHandler.sendEmptyMessage(105);
        }
    };

    public HwGameAssistantController(com.android.server.am.HwActivityManagerService service) {
        this.mService = service;
        this.mContext = service.mContext;
        initHandlerThread();
        this.mService.registerActivityObserver(this.mActivityObserver);
        this.mService.registerUserSwitchObserver(this.mUserSwitchObserver, "HwGameAssistantController");
    }

    private void initHandlerThread() {
        this.mHandlerThread = new android.os.HandlerThread("HwGameAssistantController");
        this.mHandlerThread.start();
        this.mHandler = new android.os.Handler(this.mHandlerThread.getLooper()) {
            public void handleMessage(android.os.Message msg) {
                android.os.Bundle bundle;
                switch (msg.what) {
                    case 100:
                        bundle = (android.os.Bundle) msg.obj;
                        com.android.server.am.HwGameAssistantController.this.updateForegroundActivityState(bundle.getInt("pid"), bundle.getInt("uid"), bundle.getString("packageName"));
                        if (!com.android.server.am.HwGameAssistantController.this.isSwitchingUser) {
                            com.android.server.am.HwGameAssistantController.this.handleForegroundActivityChanged();
                            break;
                        } else {
                            android.util.Slog.d("HwGameAssistantController", "user is not present");
                            return;
                        }
                    case 101:
                        bundle = (android.os.Bundle) msg.obj;
                        com.android.server.am.HwGameAssistantController.this.handleGameStatusChanged(bundle.getString("packageName"), bundle.getInt("event"));
                        break;
                    case 102:
                        com.android.server.am.HwGameAssistantController.this.handleGameListChanged();
                        break;
                    case 104:
                        bundle = msg.obj;
                        com.android.server.am.HwGameAssistantController.this.handlePackageRemovedOrDataCleared(bundle.getInt("userId"), bundle.getString("packageName"));
                        break;
                    case 105:
                        com.android.server.am.HwGameAssistantController.this.updateForegroundActivityState(0, 0, "");
                        com.android.server.am.HwGameAssistantController.this.handleForegroundActivityChanged();
                        break;
                    case 106:
                        com.android.server.am.HwGameAssistantController.this.isSwitchingUser = false;
                        com.android.server.am.HwGameAssistantController.this.handleForegroundActivityChanged();
                        break;
                    default:
                        break;
                }
            }
        };
    }

    private boolean isPrimaryUser(int userId) {
        android.content.pm.UserInfo userInfo = null;
        long identity = android.os.Binder.clearCallingIdentity();
        try {
            userInfo = android.os.UserManager.get(this.mContext).getUserInfo(userId);
            if (userInfo != null) {
                if (userInfo.isPrimary()) {
                    return true;
                }
            }
            return false;
        } finally {
            android.os.Binder.restoreCallingIdentity(identity);
        }
    }

    private android.content.pm.UserInfo getCurrentUserInfo() {
        android.content.pm.UserInfo userInfo = null;
        long identity = android.os.Binder.clearCallingIdentity();
        try {
            userInfo = this.mService.getCurrentUser();
            return userInfo;
        } finally {
            android.os.Binder.restoreCallingIdentity(identity);
        }
    }

    private int getCurrentUserId() {
        android.content.pm.UserInfo userInfo = getCurrentUserInfo();
        return userInfo != null ? userInfo.id : 0;
    }

    private boolean isGameModeDisabled() {
        android.content.pm.UserInfo userInfo = getCurrentUserInfo();
        if (userInfo != null) {
            if (userInfo.isPrimary()) {
                return false;
            }
        }
        android.util.Slog.e("HwGameAssistantController", "Game Mode is disabled for non-primary user!");
        return true;
    }

    private void updateForegroundActivityState(int pid, int uid, java.lang.String packageName) {
        this.mCurFgPkg = "";
        this.mCurFgPid = 0;
        if (isPrimaryUser(android.os.UserHandle.getUserId(uid))) {
            this.mCurFgPkg = packageName;
            this.mCurFgPid = pid;
        }
        this.mCurIsGame = isGame(this.mCurFgPkg);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("UPDATE: mCurFgPkg=");
        stringBuilder.append(this.mCurFgPkg);
        stringBuilder.append(", mCurFgPid=");
        stringBuilder.append(this.mCurFgPid);
        stringBuilder.append(", mCurIsGame=");
        stringBuilder.append(this.mCurIsGame);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
    }

    private java.lang.String getForegroundPackage() {
        return this.mLastForegroundPkg;
    }

    private boolean isGameForeground() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isGameForeground? ");
        stringBuilder.append(this.mLastIsGame);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        return this.mLastIsGame;
    }

    private boolean hasPermission(java.lang.String permission, java.lang.String func) {
        if (this.mService.checkCallingPermission(permission) == 0) {
            return true;
        }
        java.lang.String msg = new java.lang.StringBuilder();
        msg.append("Permission Denial: ");
        msg.append(func);
        msg.append(" from pid=");
        msg.append(android.os.Binder.getCallingPid());
        msg.append(", uid=");
        msg.append(android.os.Binder.getCallingUid());
        msg.append(" requires ");
        msg.append(permission);
        android.util.Slog.w("HwGameAssistantController", msg.toString());
        return false;
    }

    public boolean addGameSpacePackageList(java.util.List<java.lang.String> packageList) {
        if (hasPermission("com.huawei.gameassistant.permission.WIRTE_GAME_LIST", "addGameSpacePackageList")) {
            if (!isGameModeDisabled()) {
                if (packageList != null) {
                    if (!packageList.isEmpty()) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("addGameSpacePackageList, pid=");
                        stringBuilder.append(android.os.Binder.getCallingPid());
                        stringBuilder.append(", list=");
                        stringBuilder.append(packageList.toString());
                        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
                        boolean changed = false;
                        synchronized (this.mGameSpacePackageList) {
                            java.lang.String foregroundPkg = getForegroundPackage();
                            int j = packageList.size();
                            for (int i = 0; i < j; i++) {
                                java.lang.String pkgName = (java.lang.String) packageList.get(i);
                                if (!(android.text.TextUtils.isEmpty(pkgName) || this.mGameSpacePackageList.contains(pkgName))) {
                                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                    stringBuilder2.append("add to Game Space:");
                                    stringBuilder2.append(pkgName);
                                    android.util.Slog.d("HwGameAssistantController", stringBuilder2.toString());
                                    this.mGameSpacePackageList.add(pkgName);
                                    changed = true;
                                    if (foregroundPkg != null && foregroundPkg.equals(pkgName)) {
                                        this.mLastIsGame = true;
                                        android.os.Bundle bundle = new android.os.Bundle();
                                        bundle.putString("packageName", pkgName);
                                        bundle.putInt("event", 4);
                                        this.mHandler.sendMessage(this.mHandler.obtainMessage(101, bundle));
                                    }
                                }
                            }
                        }
                        if (changed) {
                            this.mHandler.sendEmptyMessage(102);
                        }
                        return changed;
                    }
                }
                android.util.Slog.e("HwGameAssistantController", "addGameSpacePackageList error: empty list");
                return false;
            }
        }
        return false;
    }

    public boolean delGameSpacePackageList(java.util.List<java.lang.String> packageList) {
        if (hasPermission("com.huawei.gameassistant.permission.WIRTE_GAME_LIST", "delGameSpacePackageList")) {
            if (!isGameModeDisabled()) {
                if (packageList != null) {
                    if (!packageList.isEmpty()) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("delGameSpacePackageList, pid=");
                        stringBuilder.append(android.os.Binder.getCallingPid());
                        stringBuilder.append(", list=");
                        stringBuilder.append(packageList.toString());
                        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
                        boolean changed = false;
                        synchronized (this.mGameSpacePackageList) {
                            int j = packageList.size();
                            for (int i = 0; i < j; i++) {
                                java.lang.String pkgName = (java.lang.String) packageList.get(i);
                                if (this.mGameSpacePackageList.contains(pkgName)) {
                                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                    stringBuilder2.append("del from Game Space:");
                                    stringBuilder2.append(pkgName);
                                    android.util.Slog.d("HwGameAssistantController", stringBuilder2.toString());
                                    this.mGameSpacePackageList.remove(pkgName);
                                    changed = true;
                                }
                            }
                        }
                        if (changed) {
                            this.mHandler.sendEmptyMessage(102);
                        }
                        return changed;
                    }
                }
                android.util.Slog.e("HwGameAssistantController", "delGameSpacePackageList error: empty list");
                return false;
            }
        }
        return false;
    }

    private boolean isGame(java.lang.String packageName) {
        boolean contains;
        synchronized (this.mGameSpacePackageList) {
            contains = this.mGameSpacePackageList.contains(packageName);
        }
        return contains;
    }

    public boolean isInGameSpace(java.lang.String packageName) {
        if (isGameModeDisabled()) {
            return false;
        }
        return isGame(packageName);
    }

    public java.util.List<java.lang.String> getGameList() {
        if (hasPermission("com.huawei.gameassistant.permission.READ_GAME_LIST", "getGameList")) {
            if (!isGameModeDisabled()) {
                java.util.List<java.lang.String> list = new java.util.ArrayList();
                synchronized (this.mGameSpacePackageList) {
                    list.addAll(this.mGameSpacePackageList);
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getGameList: ");
                stringBuilder.append(list.toString());
                android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
                return list;
            }
        }
        return null;
    }

    public void registerGameObserver(com.huawei.android.app.IGameObserver observer) {
        if (observer != null) {
            boolean result = this.mGameObservers.register(observer);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("registerGameObserver:");
            stringBuilder.append(observer);
            stringBuilder.append(", result=");
            stringBuilder.append(result);
            android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        }
    }

    public void unregisterGameObserver(com.huawei.android.app.IGameObserver observer) {
        if (observer != null) {
            boolean result = this.mGameObservers.unregister(observer);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("unregisterGameObserver:");
            stringBuilder.append(observer);
            stringBuilder.append(", result=");
            stringBuilder.append(result);
            android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        }
    }

    public boolean isGameDndOn() {
        return isGameForeground();
    }

    public boolean isGameKeyControlOn() {
        int userId = getCurrentUserId();
        int mode = android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "game_key_control_mode", 2, userId);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Keycontrol mode is ");
        stringBuilder.append(mode);
        stringBuilder.append(" for user ");
        stringBuilder.append(userId);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        return mode == 1 && isGameForeground();
    }

    public boolean isGameGestureDisabled() {
        int userId = getCurrentUserId();
        int mode = android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "game_gesture_disabled_mode", 2, userId);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Gesture disable mode is ");
        stringBuilder.append(mode);
        stringBuilder.append(" for user ");
        stringBuilder.append(userId);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        return mode == 1 && isGameForeground();
    }

    private void handleGameStatusChanged(java.lang.String packageName, int event) {
        dispatchGameStatusChanged(packageName, event);
    }

    private void handleForegroundActivityChanged() {
        int event = 0;
        if (!(this.mCurFgPkg == null || this.mCurFgPkg.equals(this.mLastForegroundPkg))) {
            if (this.mLastIsGame) {
                event = this.mCurIsGame ? 3 : 2;
            } else if (this.mCurIsGame) {
                event = 1;
            }
        }
        this.mLastForegroundPkg = this.mCurFgPkg;
        this.mLastIsGame = this.mCurIsGame;
        if (event != 0) {
            dispatchGameStatusChanged(this.mCurFgPkg, event);
        }
    }

    private void dispatchGameStatusChanged(java.lang.String packageName, int event) {
        int i = this.mGameObservers.beginBroadcast();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("dispatchGameStatusChanged, packageName=");
        stringBuilder.append(packageName);
        stringBuilder.append(", event=");
        stringBuilder.append(event);
        stringBuilder.append(", i=");
        stringBuilder.append(i);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        while (i > 0) {
            i--;
            com.huawei.android.app.IGameObserver observer = (com.huawei.android.app.IGameObserver) this.mGameObservers.getBroadcastItem(i);
            if (observer != null) {
                try {
                    observer.onGameStatusChanged(packageName, event);
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("HwGameAssistantController", "dispatchGameStatusChanged error because RemoteException!");
                }
            }
        }
        this.mGameObservers.finishBroadcast();
    }

    private void handleGameListChanged() {
        dispatchGameListChanged();
    }

    private void dispatchGameListChanged() {
        int i = this.mGameObservers.beginBroadcast();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("dispatchGameListChanged, i=");
        stringBuilder.append(i);
        android.util.Slog.d("HwGameAssistantController", stringBuilder.toString());
        while (i > 0) {
            i--;
            com.huawei.android.app.IGameObserver observer = (com.huawei.android.app.IGameObserver) this.mGameObservers.getBroadcastItem(i);
            if (observer != null) {
                try {
                    observer.onGameListChanged();
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("HwGameAssistantController", "dispatchGameListChanged error because RemoteException!");
                }
            }
        }
        this.mGameObservers.finishBroadcast();
    }

    /* JADX WARNING: Missing block: B:14:0x0029, code:
            r3.mHandler.sendEmptyMessage(102);
     */
    /* JADX WARNING: Missing block: B:19:0x0034, code:
            return;
     */
    private void handlePackageRemovedOrDataCleared(int r4, java.lang.String r5) {
        /*
        r3 = this;
        r0 = "com.huawei.gameassistant";
        r0 = r0.equals(r5);
        if (r0 == 0) goto L_0x0034;
    L_0x0008:
        r0 = r3.isPrimaryUser(r4);
        if (r0 != 0) goto L_0x000f;
    L_0x000e:
        return;
    L_0x000f:
        r0 = r3.mGameSpacePackageList;
        monitor-enter(r0);
        r1 = r3.mGameSpacePackageList;	 Catch:{ all -> 0x0031 }
        r1 = r1.isEmpty();	 Catch:{ all -> 0x0031 }
        if (r1 == 0) goto L_0x001c;
    L_0x001a:
        monitor-exit(r0);	 Catch:{ all -> 0x0031 }
        return;
    L_0x001c:
        r1 = "HwGameAssistantController";
        r2 = "Clear gamespace because GameAssistant is removed or data cleared!";
        android.util.Slog.d(r1, r2);	 Catch:{ all -> 0x0031 }
        r1 = r3.mGameSpacePackageList;	 Catch:{ all -> 0x0031 }
        r1.clear();	 Catch:{ all -> 0x0031 }
        monitor-exit(r0);	 Catch:{ all -> 0x0031 }
        r0 = r3.mHandler;
        r1 = 102; // 0x66 float:1.43E-43 double:5.04E-322;
        r0.sendEmptyMessage(r1);
        goto L_0x0034;
    L_0x0031:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0031 }
        throw r1;
    L_0x0034:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.am.HwGameAssistantController.handlePackageRemovedOrDataCleared(int, java.lang.String):void");
    }

    void onPackageRemovedOrDataCleared(android.content.Intent intent) {
        if (intent != null) {
            if (intent.getData() != null) {
                int userId = intent.getIntExtra("android.intent.extra.user_handle", -1);
                java.lang.String packageName = intent.getData().getSchemeSpecificPart();
                android.os.Bundle bundle = new android.os.Bundle();
                bundle.putInt("userId", userId);
                bundle.putString("packageName", packageName);
                this.mHandler.sendMessage(this.mHandler.obtainMessage(104, bundle));
            }
        }
    }

    void handleInterestedBroadcast(android.content.Intent intent) {
        if (intent != null) {
            if (intent.getAction() != null) {
                java.lang.String action = intent.getAction();
                boolean z = true;
                int hashCode = action.hashCode();
                if (hashCode != 267468725) {
                    if (hashCode != 525384130) {
                        if (hashCode == 823795052) {
                            if (action.equals("android.intent.action.USER_PRESENT")) {
                                z = true;
                            }
                        }
                    } else if (action.equals("android.intent.action.PACKAGE_REMOVED")) {
                        z = false;
                    }
                } else if (action.equals("android.intent.action.PACKAGE_DATA_CLEARED")) {
                    z = true;
                }
                switch (z) {
                    case false:
                        if (intent.getBooleanExtra("android.intent.extra.REPLACING", false)) {
                            android.util.Slog.d("HwGameAssistantController", "ACTION_PACKAGE_REMOVED received, but has EXTRA_REPLACING true");
                            break;
                        }
                    case true:
                        onPackageRemovedOrDataCleared(intent);
                        break;
                    case true:
                        this.mHandler.sendEmptyMessage(106);
                        break;
                    default:
                        break;
                }
            }
        }
    }
}
