package com.android.server.am;

public class HwMtmBroadcastResourceManager implements com.android.server.am.AbsHwMtmBroadcastResourceManager {
    public static final int CACHED_APP_MIN_ADJ = 900;
    public static final int FOREGROUND_APP_ADJ = 0;
    private static final int INVALID_CONFIG_POLICY = -1;
    private static final java.lang.String TAG = "HwMtmBroadcastResourceManager";
    public static final int TOP_APP = 2;
    private com.android.server.mtm.iaware.srms.AwareBroadcastRegister mAwareBRRegister = null;
    private com.android.server.mtm.iaware.srms.AwareBroadcastSend mAwareBRSend = null;
    private com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService mAwareJobSchedulerService = null;
    private java.util.HashMap<com.android.server.am.ReceiverList, java.lang.String> mBRIdMap = new java.util.HashMap();
    private com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar mBrDumpRadar = null;
    private com.android.server.mtm.iaware.srms.AwareBroadcastPolicy mIawareBrPolicy = null;
    private final com.android.server.am.BroadcastQueue mQueue;
    private int mSysServicePid = android.os.Process.myPid();

    public HwMtmBroadcastResourceManager(com.android.server.am.BroadcastQueue queue) {
        this.mQueue = queue;
        com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.initBrCache(this.mQueue.mQueueName, this.mQueue.mService);
    }

    public boolean iawareProcessBroadcast(int type, boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        if (type == 0) {
            boolean enqueue = enqueueIawareProxyBroacast(isParallel, r, target);
            trackBrFlow(enqueue, isParallel, r, target);
            return enqueue;
        } else if (type == 1) {
            return processBroadcastScheduler(isParallel, r, target);
        } else {
            return false;
        }
    }

    public void iawareCheckCombinedConditon(android.content.IntentFilter filter) {
        if (filter == null) {
            android.rms.iaware.AwareLog.e("HwMtmBroadcastResourceManager", "iawareCheckCombinedConditon param error!");
            return;
        }
        if (this.mAwareBRRegister == null) {
            this.mAwareBRRegister = com.android.server.mtm.iaware.srms.AwareBroadcastRegister.getInstance();
        }
        java.lang.String acId = this.mAwareBRRegister.findMatchedAssembleConditionId(filter.getIdentifier());
        if (acId != null) {
            java.util.Iterator<java.lang.String> actions = filter.actionsIterator();
            if (actions != null) {
                while (actions.hasNext()) {
                    java.lang.String condition = this.mAwareBRRegister.getBRAssembleCondition(acId, (java.lang.String) actions.next());
                    if (condition != null) {
                        filter.addCategory(condition);
                        if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("brreg: add condition: ");
                            stringBuilder.append(condition);
                            stringBuilder.append(" for ");
                            stringBuilder.append(filter.getIdentifier());
                            android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
                        }
                    }
                }
            }
        }
    }

    public void iawareCountDuplicatedReceiver(boolean isRegister, com.android.server.am.ReceiverList rl, android.content.IntentFilter filter) {
        if (rl != null) {
            if (!isRegister || filter != null) {
                if (this.mAwareBRRegister == null) {
                    this.mAwareBRRegister = com.android.server.mtm.iaware.srms.AwareBroadcastRegister.getInstance();
                }
                java.lang.String brId = "";
                if (isRegister) {
                    brId = filter.getIdentifier();
                    this.mBRIdMap.put(rl, brId);
                } else {
                    brId = (java.lang.String) this.mBRIdMap.remove(rl);
                }
                int brCount = this.mAwareBRRegister.countReceiverRegister(isRegister, brId);
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    java.lang.String str = "HwMtmBroadcastResourceManager";
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("brreg: regCounter, ");
                    stringBuilder.append(isRegister ? "register" : "unregister");
                    stringBuilder.append(" brId: ");
                    stringBuilder.append(brId);
                    stringBuilder.append(" count:");
                    stringBuilder.append(brCount);
                    android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
                }
                return;
            }
        }
        android.rms.iaware.AwareLog.e("HwMtmBroadcastResourceManager", "iawareCountDuplicatedReceiver param error!");
    }

    public boolean iawareNeedSkipBroadcastSend(java.lang.String action, java.lang.Object[] data) {
        if (action != null) {
            if (data != null) {
                if (com.android.server.rms.iaware.srms.BroadcastExFeature.isFeatureEnabled(2)) {
                    if (this.mAwareBRSend == null) {
                        this.mAwareBRSend = com.android.server.mtm.iaware.srms.AwareBroadcastSend.getInstance();
                    }
                    if (this.mAwareBRSend.setData(action, data)) {
                        return this.mAwareBRSend.needSkipBroadcastSend(action);
                    }
                    return false;
                }
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", "BrSend feature not enabled!");
                }
                return false;
            }
        }
        android.rms.iaware.AwareLog.e("HwMtmBroadcastResourceManager", "iawareNeedSkipBroadcastSend param error!");
        return false;
    }

    private boolean processBroadcastScheduler(boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        com.android.server.am.BroadcastRecord broadcastRecord = r;
        android.content.pm.ResolveInfo resolveInfo = target;
        if (!(isParallel || broadcastRecord == null || resolveInfo == null)) {
            if (resolveInfo instanceof android.content.pm.ResolveInfo) {
                android.content.pm.ResolveInfo info = resolveInfo;
                java.lang.String packageName = null;
                android.content.pm.ComponentInfo ci = info.getComponentInfo();
                if (!(ci == null || ci.applicationInfo == null)) {
                    packageName = ci.applicationInfo.packageName;
                }
                java.lang.String packageName2 = packageName;
                java.lang.String action = broadcastRecord.intent.getAction();
                android.content.IntentFilter filter = info.filter;
                boolean z;
                android.content.IntentFilter filter2;
                if (filter == null || filter.countActionFilters() <= 0) {
                    z = true;
                    filter2 = filter;
                    java.lang.String str = "HwMtmBroadcastResourceManager";
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brjob not process: ");
                    stringBuilder.append(info);
                    stringBuilder.append(", filter: ");
                    android.content.IntentFilter filter3 = filter2;
                    stringBuilder.append(filter3 == null ? "null" : filter3);
                    stringBuilder.append(", count: ");
                    stringBuilder.append(filter3 == null ? "null" : java.lang.Integer.valueOf(filter3.countActionFilters()));
                    android.rms.iaware.AwareLog.w(str, stringBuilder.toString());
                    com.android.server.mtm.iaware.brjob.StartupByBroadcastRecorder.getInstance().recordStartupTimeByBroadcast(packageName2, action, java.lang.System.currentTimeMillis());
                    trackImplicitBr(false, z, packageName2, action);
                } else {
                    if (broadcastRecord.iawareCtrlType == 2) {
                        z = true;
                        filter2 = filter;
                        com.android.server.mtm.iaware.brjob.StartupByBroadcastRecorder.getInstance().recordStartupTimeByBroadcast(packageName2, action, java.lang.System.currentTimeMillis());
                        trackImplicitBr(z, z, packageName2, action);
                    } else if (broadcastRecord.queue == null || !enqueueBroadcastScheduler(isParallel, r, target)) {
                        filter2 = filter;
                        trackImplicitBr(false, true, packageName2, action);
                    } else {
                        trackImplicitBr(true, false, packageName2, action);
                        com.android.server.mtm.iaware.appmng.appstart.AwareAppStartupPolicy policy = com.android.server.mtm.iaware.appmng.appstart.AwareAppStartupPolicy.self();
                        if (policy != null) {
                            policy.updateBroadJobCtrlBigData(packageName2);
                        }
                        broadcastRecord.queue.finishReceiverLocked(broadcastRecord, broadcastRecord.resultCode, broadcastRecord.resultData, broadcastRecord.resultExtras, broadcastRecord.resultAbort, null);
                        broadcastRecord.queue.scheduleBroadcastsLocked();
                        broadcastRecord.state = 0;
                        return true;
                    }
                }
                return false;
            }
        }
        android.rms.iaware.AwareLog.e("HwMtmBroadcastResourceManager", "iaware_brjob processBroadcastScheduler param error!");
        return false;
    }

    private boolean enqueueBroadcastScheduler(boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        com.android.server.am.BroadcastRecord broadcastRecord = r;
        java.lang.Object obj = target;
        if (getAwareJobSchedulerService() == null) {
            return false;
        }
        if (isSystemApplication(obj)) {
            android.content.IIntentReceiver resultTo = broadcastRecord.resultTo;
            if (broadcastRecord.resultTo != null) {
                android.rms.iaware.AwareLog.d("HwMtmBroadcastResourceManager", "reset resultTo null");
                resultTo = null;
            }
            java.util.List<java.lang.Object> receiver = new java.util.ArrayList();
            receiver.add(obj);
            java.util.List<java.lang.Object> receiver2 = receiver;
            return this.mAwareJobSchedulerService.schedule(new com.android.server.am.HwBroadcastRecord(new com.android.server.am.BroadcastRecord(broadcastRecord.queue, broadcastRecord.intent, broadcastRecord.callerApp, broadcastRecord.callerPackage, broadcastRecord.callingPid, broadcastRecord.callingUid, broadcastRecord.callerInstantApp, broadcastRecord.resolvedType, broadcastRecord.requiredPermissions, broadcastRecord.appOp, broadcastRecord.options, receiver2, resultTo, broadcastRecord.resultCode, broadcastRecord.resultData, broadcastRecord.resultExtras, broadcastRecord.ordered, broadcastRecord.sticky, broadcastRecord.initialSticky, broadcastRecord.userId)));
        }
        android.rms.iaware.AwareLog.w("HwMtmBroadcastResourceManager", "iaware_brjob not system app");
        return false;
    }

    private boolean enqueueIawareProxyBroacast(boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        com.android.server.am.BroadcastRecord broadcastRecord = r;
        java.lang.Object obj = target;
        if (isAbnormalParameters(isParallel, r, target) || getIawareBrPolicy() == null || broadcastRecord.iawareCtrlType == 1 || !this.mIawareBrPolicy.isProxyedAllowedCondition() || broadcastRecord.callingPid != this.mSysServicePid || isThirdOrKeyBroadcast()) {
            return false;
        }
        java.lang.String pkg = getPkg(obj);
        int pid = getPid(obj);
        int uid = getUid(obj);
        if (isAbnormalValue(pkg, pid, uid) || pid == this.mSysServicePid) {
            return false;
        }
        java.lang.String action = null;
        if (broadcastRecord.intent != null) {
            action = broadcastRecord.intent.getAction();
        }
        java.lang.String action2 = action;
        java.lang.String str;
        int i;
        java.lang.String str2;
        boolean pid2;
        if (this.mIawareBrPolicy.isNotProxySysPkg(pkg, action2)) {
            str = pkg;
            i = pid;
            str2 = action2;
            pid2 = isParallel;
        } else if (isInstrumentationApp(obj)) {
            str = pkg;
            i = pid;
            pkg = uid;
            str2 = action2;
            pid2 = isParallel;
        } else {
            boolean isSystemApp = isSystemApplication(obj);
            int curProcState = getcurProcState(obj);
            int curAdj = getProcessCurrentAdj(obj);
            int i2;
            int i3;
            boolean z;
            if (-1 == curProcState) {
                i2 = curAdj;
                i3 = curProcState;
                i = pid;
                pkg = uid;
                str2 = action2;
                z = isSystemApp;
                pid2 = isParallel;
            } else if (-10000 == curAdj) {
                str = pkg;
                i2 = curAdj;
                i3 = curProcState;
                i = pid;
                pkg = uid;
                str2 = action2;
                z = isSystemApp;
                pid2 = isParallel;
            } else {
                int curAdj2 = curAdj;
                int curProcState2 = curProcState;
                if (!this.mIawareBrPolicy.shouldIawareProxyBroadcast(action2, broadcastRecord.callingPid, uid, pid, pkg)) {
                    return false;
                }
                java.util.List<java.lang.Object> receiver = new java.util.ArrayList();
                receiver.add(obj);
                boolean isSystemApp2 = isSystemApp;
                java.lang.String pkg2 = pkg;
                int pid3 = pid;
                int uid2 = uid;
                com.android.server.am.BroadcastRecord proxyBR = new com.android.server.am.BroadcastRecord(broadcastRecord.queue, broadcastRecord.intent, broadcastRecord.callerApp, broadcastRecord.callerPackage, broadcastRecord.callingPid, broadcastRecord.callingUid, broadcastRecord.callerInstantApp, broadcastRecord.resolvedType, broadcastRecord.requiredPermissions, broadcastRecord.appOp, broadcastRecord.options, receiver, broadcastRecord.resultTo, broadcastRecord.resultCode, broadcastRecord.resultData, broadcastRecord.resultExtras, broadcastRecord.ordered, broadcastRecord.sticky, broadcastRecord.initialSticky, broadcastRecord.userId);
                proxyBR.dispatchClockTime = broadcastRecord.dispatchClockTime;
                proxyBR.dispatchTime = broadcastRecord.dispatchTime;
                proxyBR.iawareCtrlType = 1;
                com.android.server.am.HwBroadcastRecord hwBr = new com.android.server.am.HwBroadcastRecord(proxyBR);
                hwBr.setReceiverUid(uid2);
                hwBr.setReceiverPid(pid3);
                hwBr.setReceiverCurAdj(curAdj2);
                hwBr.setReceiverPkg(pkg2);
                hwBr.setSysApp(isSystemApp2);
                hwBr.setReceiverCurProcState(curProcState2);
                return this.mIawareBrPolicy.enqueueIawareProxyBroacast(isParallel, hwBr);
            }
            return false;
        }
        return false;
    }

    public void iawareStartCountBroadcastSpeed(boolean isParallel, com.android.server.am.BroadcastRecord r) {
        if (r != null && getIawareBrPolicy() != null && isParallel && r.iawareCtrlType != 1) {
            java.lang.String action = null;
            if (r.intent != null) {
                action = r.intent.getAction();
            }
            if (action != null) {
                this.mIawareBrPolicy.iawareStartCountBroadcastSpeed(isParallel, r.dispatchClockTime, r.receivers.size());
            }
        }
    }

    public void iawareEndCountBroadcastSpeed(com.android.server.am.BroadcastRecord r) {
        if (r != null && getIawareBrPolicy() != null && r.iawareCtrlType != 1) {
            scheduleTrackBrFlowData();
            this.mIawareBrPolicy.endCheckCount();
        }
    }

    private boolean isAbnormalParameters(boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        if (isParallel && r != null) {
            if (target != null) {
                return false;
            }
        }
        return true;
    }

    private com.android.server.mtm.iaware.srms.AwareBroadcastPolicy getIawareBrPolicy() {
        if (this.mIawareBrPolicy == null && com.android.server.mtm.MultiTaskManagerService.self() != null) {
            this.mIawareBrPolicy = com.android.server.mtm.MultiTaskManagerService.self().getIawareBrPolicy();
        }
        return this.mIawareBrPolicy;
    }

    private com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService getAwareJobSchedulerService() {
        if (this.mAwareJobSchedulerService == null && com.android.server.mtm.MultiTaskManagerService.self() != null) {
            this.mAwareJobSchedulerService = com.android.server.mtm.MultiTaskManagerService.self().getAwareJobSchedulerService();
        }
        return this.mAwareJobSchedulerService;
    }

    public static void insertIawareBroadcast(java.util.ArrayList<com.android.server.am.HwBroadcastRecord> parallelList, java.lang.String name) {
        if (parallelList != null) {
            if (parallelList.size() != 0) {
                int i = 0;
                com.android.server.am.BroadcastQueue queue = ((com.android.server.am.HwBroadcastRecord) parallelList.get(0)).getBroacastQueue();
                synchronized (queue.mService) {
                    int listSize = parallelList.size();
                    while (i < listSize) {
                        queue.mParallelBroadcasts.add(i, ((com.android.server.am.HwBroadcastRecord) parallelList.get(i)).getBroadcastRecord());
                        i++;
                    }
                    queue.scheduleBroadcastsLocked();
                }
            }
        }
    }

    private java.lang.String getPkg(java.lang.Object target) {
        if (target instanceof com.android.server.am.BroadcastFilter) {
            return ((com.android.server.am.BroadcastFilter) target).packageName;
        }
        return null;
    }

    private int getPid(java.lang.Object target) {
        if (!(target instanceof com.android.server.am.BroadcastFilter)) {
            return -1;
        }
        com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
        if (filter.receiverList == null) {
            return -1;
        }
        int pid = filter.receiverList.pid;
        if (pid > 0 || filter.receiverList.app == null) {
            return pid;
        }
        return filter.receiverList.app.pid;
    }

    private int getUid(java.lang.Object target) {
        if (!(target instanceof com.android.server.am.BroadcastFilter)) {
            return -1;
        }
        com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
        if (filter.receiverList == null) {
            return -1;
        }
        int uid = filter.receiverList.uid;
        if (uid > 0 || filter.receiverList.app == null) {
            return uid;
        }
        return filter.receiverList.app.uid;
    }

    private boolean isSystemApplication(java.lang.Object target) {
        boolean systemApp = false;
        boolean z = false;
        if (target instanceof com.android.server.am.BroadcastFilter) {
            com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
            if (filter.receiverList != null && filter.receiverList.app != null) {
                int flags = filter.receiverList.app.info.flags;
                int privateFlags = filter.receiverList.app.info.privateFlags;
                if ((flags & 1) == 0 && (flags & 128) == 0) {
                    if ((privateFlags & 8) == 0) {
                        systemApp = z;
                    }
                }
                z = true;
                systemApp = z;
            } else if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                android.rms.iaware.AwareLog.d("HwMtmBroadcastResourceManager", "isSystemApplication BroadcastFilter: filter something is null");
            }
            return systemApp;
        } else if (!(target instanceof android.content.pm.ResolveInfo)) {
            return false;
        } else {
            android.content.pm.ResolveInfo info = (android.content.pm.ResolveInfo) target;
            if (info.activityInfo != null && info.activityInfo.applicationInfo != null) {
                if (!(info.activityInfo.applicationInfo.isSystemApp() || info.activityInfo.applicationInfo.isPrivilegedApp())) {
                    if (!info.activityInfo.applicationInfo.isUpdatedSystemApp()) {
                        return z;
                    }
                }
                z = true;
                return z;
            } else if (!com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                return false;
            } else {
                android.rms.iaware.AwareLog.w("HwMtmBroadcastResourceManager", "isSystemApplication ResolveInfo: info, info.activityInfo, info.activityInfo.applicationInfo is null ");
                return false;
            }
        }
    }

    private boolean isInstrumentationApp(java.lang.Object target) {
        boolean instrumentationApp = false;
        if (target instanceof com.android.server.am.BroadcastFilter) {
            com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
            if (!(filter.receiverList == null || filter.receiverList.app == null || filter.receiverList.app.instr == null)) {
                instrumentationApp = true;
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    android.rms.iaware.AwareLog.d("HwMtmBroadcastResourceManager", "instrumentation app do not proxy!");
                }
            }
        }
        return instrumentationApp;
    }

    private boolean isThirdOrKeyBroadcast() {
        return ("background".equals(this.mQueue.mQueueName) || "foreground".equals(this.mQueue.mQueueName)) ? false : true;
    }

    private com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar getBrDumpRadar() {
        if (this.mBrDumpRadar == null && com.android.server.mtm.MultiTaskManagerService.self() != null) {
            this.mBrDumpRadar = com.android.server.mtm.MultiTaskManagerService.self().getIawareBrRadar();
        }
        return this.mBrDumpRadar;
    }

    private void trackBrFlow(boolean enqueue, boolean isParallel, com.android.server.am.BroadcastRecord r, java.lang.Object target) {
        if (!(getBrDumpRadar() == null || r == null || !isParallel || target == null)) {
            if (target instanceof com.android.server.am.BroadcastFilter) {
                boolean isProxyed = r.iawareCtrlType == 1;
                com.android.server.mtm.iaware.srms.AwareBroadcastPolicy policy = getIawareBrPolicy();
                if (policy != null) {
                    this.mBrDumpRadar.trackBrFlowSpeed(enqueue, isProxyed, policy.isSpeedNoCtrol() ^ 1, 1 ^ policy.isScreenOff());
                }
            }
        }
    }

    private void scheduleTrackBrFlowData() {
        if (getBrDumpRadar() != null) {
            this.mBrDumpRadar.scheduleTrackBrFlowData();
        }
    }

    private void trackImplicitBr(boolean inControl, boolean startup, java.lang.String packageName, java.lang.String action) {
        if (!(getBrDumpRadar() == null || packageName == null)) {
            if (action != null) {
                this.mBrDumpRadar.trackImplicitBrDetail(inControl, startup, packageName, action);
                this.mBrDumpRadar.scheduleTrackBrFlowData();
            }
        }
    }

    public static void insertIawareOrderedBroadcast(com.android.server.am.HwBroadcastRecord hwBr) {
        if (hwBr != null) {
            com.android.server.am.BroadcastRecord r = hwBr.getBroadcastRecord();
            if (r != null) {
                if (r.queue != null) {
                    synchronized (r.queue.mService) {
                        r.iawareCtrlType = 2;
                        r.queue.enqueueOrderedBroadcastLocked(r);
                        r.queue.scheduleBroadcastsLocked();
                    }
                }
            }
        }
    }

    private int getProcessCurrentAdj(java.lang.Object target) {
        if (!(target instanceof com.android.server.am.BroadcastFilter)) {
            return -10000;
        }
        com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
        if (filter.receiverList != null && filter.receiverList.app != null) {
            return filter.receiverList.app.curAdj;
        }
        if (!com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
            return -10000;
        }
        android.rms.iaware.AwareLog.d("HwMtmBroadcastResourceManager", "getProcessCurrentAdj BroadcastFilter: filter something is null");
        return -10000;
    }

    private int getcurProcState(java.lang.Object target) {
        if (!(target instanceof com.android.server.am.BroadcastFilter)) {
            return -1;
        }
        com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) target;
        if (filter.receiverList != null && filter.receiverList.app != null) {
            return filter.receiverList.app.curProcState;
        }
        if (!com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
            return -1;
        }
        android.rms.iaware.AwareLog.d("HwMtmBroadcastResourceManager", "getProcessCurrentAdj BroadcastFilter: filter something is null");
        return -1;
    }

    private boolean isAbnormalValue(java.lang.String pkg, int pid, int uid) {
        if (!(pkg == null || pid == -1)) {
            if (uid != -1) {
                return false;
            }
        }
        return true;
    }

    private int filterRegisteredReceiver(android.content.Intent intent, com.android.server.am.BroadcastFilter filter, com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo) {
        if (filter.countActionFilters() > 0 && ((pInfo.mProcInfo.mType == 2 || pInfo.mPid == this.mSysServicePid) && this.mIawareBrPolicy.assemFilterBr(intent, filter))) {
            return com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.DISCARDBR.ordinal();
        }
        if (pInfo.mPid != this.mSysServicePid) {
            if (pInfo.mProcInfo.mCurAdj >= 0) {
                int configListPolicy = getPolicyFromConfigList(intent, filter.packageName, pInfo);
                if (configListPolicy != -1) {
                    return configListPolicy;
                }
                int policy = this.mIawareBrPolicy.filterBr(intent, pInfo);
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brFilter : reg policy:");
                    stringBuilder.append(policy);
                    stringBuilder.append(", pkgname:");
                    stringBuilder.append(filter.packageName);
                    stringBuilder.append(", action:");
                    stringBuilder.append(intent.getAction());
                    stringBuilder.append(", proc state:");
                    stringBuilder.append(pInfo.getState());
                    stringBuilder.append(", proc type:");
                    stringBuilder.append(pInfo.mProcInfo.mType);
                    android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
                }
                return policy;
            }
        }
        return com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.NONE.ordinal();
    }

    private int filterResolveInfo(android.content.Intent intent, android.content.pm.ResolveInfo resolveInfo, com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo) {
        int configListPolicy = getPolicyFromConfigList(intent, resolveInfo.activityInfo.applicationInfo.packageName, pInfo);
        if (configListPolicy != -1) {
            if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brFilter resolve config policy: ");
                stringBuilder.append(configListPolicy);
                stringBuilder.append(", pkgname:");
                stringBuilder.append(resolveInfo.activityInfo.applicationInfo.packageName);
                stringBuilder.append(", action:");
                stringBuilder.append(intent.getAction());
                android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
            }
            return configListPolicy;
        }
        int policy = this.mIawareBrPolicy.filterBr(intent, pInfo);
        if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("iaware_brFilter : resolve policy:");
            stringBuilder2.append(policy);
            stringBuilder2.append(", pkgname:");
            stringBuilder2.append(resolveInfo.activityInfo.applicationInfo.packageName);
            stringBuilder2.append(", action:");
            stringBuilder2.append(intent.getAction());
            stringBuilder2.append(", proc state:");
            stringBuilder2.append(pInfo.getState());
            stringBuilder2.append(", proc type:");
            stringBuilder2.append(pInfo.mProcInfo.mType);
            android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder2.toString());
        }
        return policy;
    }

    public void iawareFilterBroadcast(android.content.Intent intent, com.android.server.am.ProcessRecord callerApp, java.lang.String callerPackage, int callingPid, int callingUid, boolean callerInstantApp, java.lang.String resolvedType, java.lang.String[] requiredPermissions, int appOp, android.app.BroadcastOptions options, java.util.List receivers, java.util.List<com.android.server.am.BroadcastFilter> registeredReceivers, android.content.IIntentReceiver resultTo, int resultCode, java.lang.String resultData, android.os.Bundle resultExtras, boolean ordered, boolean sticky, boolean initialSticky, int userId) {
        if (isCondtionSatisfy(intent)) {
            android.content.Intent intent2 = intent;
            this.mIawareBrPolicy.getStateFromSendBr(intent2);
            android.content.IIntentReceiver proxyResultTo = resultTo;
            if (ordered && resultTo != null) {
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                    android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", "reset resultTo null");
                }
                proxyResultTo = null;
            }
            android.content.IIntentReceiver proxyResultTo2 = proxyResultTo;
            android.content.Intent intent3 = intent2;
            com.android.server.am.ProcessRecord processRecord = callerApp;
            java.lang.String str = callerPackage;
            int i = callingPid;
            int i2 = callingUid;
            boolean z = callerInstantApp;
            java.lang.String str2 = resolvedType;
            java.lang.String[] strArr = requiredPermissions;
            int i3 = appOp;
            android.app.BroadcastOptions broadcastOptions = options;
            java.util.List list = receivers;
            java.util.List<com.android.server.am.BroadcastFilter> list2 = registeredReceivers;
            android.content.IIntentReceiver iIntentReceiver = proxyResultTo2;
            int i4 = resultCode;
            java.lang.String str3 = resultData;
            android.os.Bundle bundle = resultExtras;
            boolean z2 = ordered;
            boolean z3 = sticky;
            boolean z4 = initialSticky;
            int i5 = userId;
            processRegisteredReceiver(intent3, processRecord, str, i, i2, z, str2, strArr, i3, broadcastOptions, list, list2, iIntentReceiver, i4, str3, bundle, z2, z3, z4, i5);
            processResolveReceiver(intent, processRecord, str, i, i2, z, str2, strArr, i3, broadcastOptions, list, list2, iIntentReceiver, i4, str3, bundle, z2, z3, z4, i5);
        }
    }

    private void processRegisteredReceiver(android.content.Intent intent, com.android.server.am.ProcessRecord callerApp, java.lang.String callerPackage, int callingPid, int callingUid, boolean callerInstantApp, java.lang.String resolvedType, java.lang.String[] requiredPermissions, int appOp, android.app.BroadcastOptions options, java.util.List receivers, java.util.List<com.android.server.am.BroadcastFilter> registeredReceivers, android.content.IIntentReceiver resultTo, int resultCode, java.lang.String resultData, android.os.Bundle resultExtras, boolean ordered, boolean sticky, boolean initialSticky, int userId) {
        if (registeredReceivers != null) {
            java.lang.String action = intent.getAction();
            com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrBeforeCount(registeredReceivers.size());
            java.util.Iterator<com.android.server.am.BroadcastFilter> regIterator = registeredReceivers.iterator();
            while (true) {
                java.util.Iterator<com.android.server.am.BroadcastFilter> regIterator2 = regIterator;
                if (regIterator2.hasNext()) {
                    com.android.server.am.BroadcastFilter filter = (com.android.server.am.BroadcastFilter) regIterator2.next();
                    com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo = getProcessInfo(filter);
                    if (pInfo == null) {
                        com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrNoProcessCount(1);
                    } else {
                        android.content.Intent intent2 = intent;
                        int policy = filterRegisteredReceiver(intent2, filter, pInfo);
                        if (policy == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.DISCARDBR.ordinal()) {
                            regIterator2.remove();
                            com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrAfterCount(1);
                            trackBrFilter(action, pInfo, policy, true, filter);
                        } else if (policy == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.CACHEBR.ordinal()) {
                            java.util.List<java.lang.Object> cacheReceiver = new java.util.ArrayList();
                            cacheReceiver.add(filter);
                            int policy2 = policy;
                            com.android.server.am.HwBroadcastRecord hwBr = new com.android.server.am.HwBroadcastRecord(new com.android.server.am.BroadcastRecord(this.mQueue, intent2, callerApp, callerPackage, callingPid, callingUid, callerInstantApp, resolvedType, requiredPermissions, appOp, options, cacheReceiver, resultTo, resultCode, resultData, resultExtras, ordered, sticky, initialSticky, userId));
                            hwBr.setCurrentReceiverPid(pInfo.mPid);
                            hwBr.setReceiverPkg(filter.packageName);
                            boolean trim = this.mIawareBrPolicy.awareTrimAndEnqueueBr(ordered ^ 1, hwBr, false, pInfo.mPid, filter.packageName);
                            regIterator2.remove();
                            policy = hwBr;
                            trackBrFilter(action, pInfo, policy2, trim, filter);
                        } else {
                            int policy3 = policy;
                            if (policy3 == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.NONE.ordinal()) {
                                trackBrFilter(action, pInfo, policy3, false, filter);
                            }
                        }
                    }
                    regIterator = regIterator2;
                } else {
                    return;
                }
            }
        }
    }

    private void processResolveReceiver(android.content.Intent intent, com.android.server.am.ProcessRecord callerApp, java.lang.String callerPackage, int callingPid, int callingUid, boolean callerInstantApp, java.lang.String resolvedType, java.lang.String[] requiredPermissions, int appOp, android.app.BroadcastOptions options, java.util.List receivers, java.util.List<com.android.server.am.BroadcastFilter> list, android.content.IIntentReceiver resultTo, int resultCode, java.lang.String resultData, android.os.Bundle resultExtras, boolean ordered, boolean sticky, boolean initialSticky, int userId) {
        if (receivers != null) {
            java.lang.String action = intent.getAction();
            com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrBeforeCount(receivers.size());
            java.util.Iterator<android.content.pm.ResolveInfo> iterator = receivers.iterator();
            while (true) {
                java.util.Iterator<android.content.pm.ResolveInfo> iterator2 = iterator;
                if (iterator2.hasNext()) {
                    android.content.pm.ResolveInfo resolveInfo = (android.content.pm.ResolveInfo) iterator2.next();
                    com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo = getProcessInfo(resolveInfo);
                    if (pInfo == null) {
                        com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrNoProcessCount(1);
                    } else {
                        android.content.Intent intent2 = intent;
                        int policy = filterResolveInfo(intent2, resolveInfo, pInfo);
                        if (policy == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.DISCARDBR.ordinal()) {
                            iterator2.remove();
                            com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatBrAfterCount(1);
                            trackBrFilter(action, pInfo, policy, true, resolveInfo);
                        } else if (policy == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.CACHEBR.ordinal()) {
                            java.util.List<java.lang.Object> cacheReceiver = new java.util.ArrayList();
                            cacheReceiver.add(resolveInfo);
                            int policy2 = policy;
                            com.android.server.am.HwBroadcastRecord hwBr = new com.android.server.am.HwBroadcastRecord(new com.android.server.am.BroadcastRecord(this.mQueue, intent2, callerApp, callerPackage, callingPid, callingUid, callerInstantApp, resolvedType, requiredPermissions, appOp, options, cacheReceiver, resultTo, resultCode, resultData, resultExtras, ordered, sticky, initialSticky, userId));
                            hwBr.setCurrentReceiverPid(pInfo.mPid);
                            hwBr.setReceiverPkg(resolveInfo.activityInfo.applicationInfo.packageName);
                            boolean trim = this.mIawareBrPolicy.awareTrimAndEnqueueBr(0, hwBr, false, pInfo.mPid, resolveInfo.activityInfo.applicationInfo.packageName);
                            iterator2.remove();
                            policy = hwBr;
                            trackBrFilter(action, pInfo, policy2, trim, resolveInfo);
                        } else {
                            int policy3 = policy;
                            if (policy3 == com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.NONE.ordinal()) {
                                trackBrFilter(action, pInfo, policy3, false, resolveInfo);
                            }
                        }
                    }
                    iterator = iterator2;
                } else {
                    return;
                }
            }
        }
    }

    private com.android.server.mtm.iaware.appmng.AwareProcessInfo getProcessInfo(java.lang.Object target) {
        com.android.server.mtm.iaware.appmng.AwareProcessInfo awareProcessInfo = null;
        if (target instanceof com.android.server.am.BroadcastFilter) {
            int pid = getPid(target);
            if (pid == this.mSysServicePid) {
                return new com.android.server.mtm.iaware.appmng.AwareProcessInfo(pid, new com.android.server.mtm.taskstatus.ProcessInfo(pid, 1000));
            }
            if (isInstrumentationApp(target)) {
                return null;
            }
            awareProcessInfo = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance().getAwareProcessInfo(pid);
            if (awareProcessInfo != null) {
                awareProcessInfo.mProcInfo.mCurAdj = getProcessCurrentAdj(target);
            }
        } else if (target instanceof android.content.pm.ResolveInfo) {
            android.content.pm.ResolveInfo info = (android.content.pm.ResolveInfo) target;
            com.android.server.am.ProcessRecord app = this.mQueue.mService.getProcessRecordLocked(info.activityInfo.processName, info.activityInfo.applicationInfo.uid, false);
            if (app != null) {
                if (app.instr != null) {
                    return null;
                }
                awareProcessInfo = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance().getAwareProcessInfo(app.pid);
                if (awareProcessInfo != null) {
                    awareProcessInfo.mProcInfo.mCurAdj = app.curAdj;
                }
            }
        }
        return awareProcessInfo;
    }

    private int getPolicyFromConfigList(android.content.Intent intent, java.lang.String pkgName, com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo) {
        if (!com.android.server.rms.iaware.srms.BroadcastExFeature.isBrFilterWhiteList(pkgName)) {
            if (!com.android.server.rms.iaware.srms.BroadcastExFeature.isBrFilterWhiteApp(intent.getAction(), pkgName)) {
                if (pInfo.getState() == 1 && com.android.server.rms.iaware.srms.BroadcastExFeature.isBrFilterBlackApp(intent.getAction(), pkgName)) {
                    return com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.CACHEBR.ordinal();
                }
                return -1;
            }
        }
        return com.android.server.mtm.iaware.srms.AwareBroadcastPolicy.BrCtrlType.NONE.ordinal();
    }

    private boolean isCondtionSatisfy(android.content.Intent intent) {
        if (intent != null) {
            if (intent.getAction() != null) {
                if (!com.android.server.rms.iaware.srms.BroadcastExFeature.isFeatureEnabled(1) || getIawareBrPolicy() == null) {
                    return false;
                }
                if (intent.getPackage() == null) {
                    if (intent.getComponent() == null) {
                        return true;
                    }
                }
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("it is explicitly : ");
                    stringBuilder.append(intent.getAction());
                    android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
                }
                return false;
            }
        }
        return false;
    }

    public static void unProxyCachedBr(java.util.ArrayList<com.android.server.am.HwBroadcastRecord> awareParallelBrs, java.util.ArrayList<com.android.server.am.HwBroadcastRecord> awareOrderedBrs) {
        java.lang.StringBuilder stringBuilder;
        int count;
        com.android.server.am.BroadcastQueue queue = null;
        if (awareParallelBrs != null && awareParallelBrs.size() > 0) {
            queue = ((com.android.server.am.HwBroadcastRecord) awareParallelBrs.get(0)).getBroacastQueue();
            if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("unproxy ");
                stringBuilder.append(queue.mQueueName);
                stringBuilder.append(" Broadcast pkg Parallel Broadcasts (");
                stringBuilder.append(awareParallelBrs);
                stringBuilder.append(")");
                android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
            }
            count = awareParallelBrs.size();
            for (int i = 0; i < count; i++) {
                queue.mParallelBroadcasts.add(i, ((com.android.server.am.HwBroadcastRecord) awareParallelBrs.get(i)).getBroadcastRecord());
            }
        }
        if (awareOrderedBrs != null && awareOrderedBrs.size() > 0) {
            if (queue == null) {
                queue = ((com.android.server.am.HwBroadcastRecord) awareOrderedBrs.get(0)).getBroacastQueue();
            }
            boolean pending = queue.mPendingBroadcastTimeoutMessage;
            if (pending) {
                movePendingBroadcastToProxyList(queue.mOrderedBroadcasts, awareOrderedBrs, ((com.android.server.am.HwBroadcastRecord) awareOrderedBrs.get(0)).getCurrentReceiverPid());
            }
            if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("unproxy ");
                stringBuilder.append(queue.mQueueName);
                stringBuilder.append(" pending:");
                stringBuilder.append(pending);
                stringBuilder.append(" Broadcast pkg Orded Broadcasts (");
                stringBuilder.append(awareOrderedBrs);
                stringBuilder.append(")");
                android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
            }
            count = awareOrderedBrs.size();
            for (int i2 = 0; i2 < count; i2++) {
                if (pending) {
                    queue.mOrderedBroadcasts.add(i2 + 1, ((com.android.server.am.HwBroadcastRecord) awareOrderedBrs.get(i2)).getBroadcastRecord());
                } else {
                    queue.mOrderedBroadcasts.add(i2, ((com.android.server.am.HwBroadcastRecord) awareOrderedBrs.get(i2)).getBroadcastRecord());
                }
            }
        }
        if (queue != null) {
            queue.scheduleBroadcastsLocked();
        }
    }

    public static boolean isSameReceiver(java.lang.Object o1, java.lang.Object o2) {
        if (o1 != null) {
            if (o2 != null) {
                if (o1 != o2) {
                    if ((o1 instanceof com.android.server.am.BroadcastFilter) && (o2 instanceof com.android.server.am.BroadcastFilter)) {
                        if (((com.android.server.am.BroadcastFilter) o1).receiverList != ((com.android.server.am.BroadcastFilter) o2).receiverList) {
                            return false;
                        }
                    } else if (!(o1 instanceof android.content.pm.ResolveInfo) || !(o2 instanceof android.content.pm.ResolveInfo)) {
                        return false;
                    } else {
                        android.content.pm.ResolveInfo info1 = (android.content.pm.ResolveInfo) o1;
                        android.content.pm.ResolveInfo info2 = (android.content.pm.ResolveInfo) o2;
                        if (info1.activityInfo == info2.activityInfo && info1.providerInfo == info2.providerInfo) {
                            if (info1.serviceInfo != info2.serviceInfo) {
                            }
                        }
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }

    private static void movePendingBroadcastToProxyList(java.util.ArrayList<com.android.server.am.BroadcastRecord> orderedBroadcasts, java.util.ArrayList<com.android.server.am.HwBroadcastRecord> orderedProxyBroadcasts, int pid) {
        java.util.ArrayList<com.android.server.am.HwBroadcastRecord> needMoveReceivers;
        int i = pid;
        if (orderedProxyBroadcasts.size() != 0) {
            if (orderedBroadcasts.size() != 0) {
                com.android.server.am.BroadcastRecord r = (com.android.server.am.BroadcastRecord) orderedBroadcasts.get(0);
                java.util.List<java.lang.Object> needMoveReceivers2 = new java.util.ArrayList();
                java.util.List<java.lang.Object> receivers = r.receivers;
                java.util.List<java.lang.Object> list;
                java.util.List<java.lang.Object> list2;
                if (receivers == null) {
                    list = receivers;
                    needMoveReceivers = orderedProxyBroadcasts;
                } else if (i <= 0) {
                    list2 = needMoveReceivers2;
                    list = receivers;
                    needMoveReceivers = orderedProxyBroadcasts;
                } else {
                    java.util.List<java.lang.Object> needMoveReceivers3;
                    java.util.List<java.lang.Object> receivers2;
                    int recIdx;
                    int numReceivers;
                    int recIdx2 = r.nextReceiver;
                    int numReceivers2 = receivers.size();
                    int i2 = recIdx2;
                    while (i2 < numReceivers2) {
                        int i3;
                        java.lang.Object target = receivers.get(i2);
                        int resolvePid = getResolvePid(r.queue, target);
                        if (resolvePid <= 0 || resolvePid != i) {
                            needMoveReceivers3 = needMoveReceivers2;
                            receivers2 = receivers;
                            recIdx = recIdx2;
                            numReceivers = numReceivers2;
                            i3 = i2;
                            needMoveReceivers = orderedProxyBroadcasts;
                        } else {
                            needMoveReceivers2.add(target);
                            java.util.List<java.lang.Object> receiver = new java.util.ArrayList();
                            receiver.add(target);
                            recIdx = recIdx2;
                            numReceivers = numReceivers2;
                            receivers2 = receivers;
                            needMoveReceivers3 = needMoveReceivers2;
                            i3 = i2;
                            needMoveReceivers = orderedProxyBroadcasts;
                            needMoveReceivers.add(new com.android.server.am.HwBroadcastRecord(new com.android.server.am.BroadcastRecord(r.queue, r.intent, r.callerApp, r.callerPackage, r.callingPid, r.callingUid, r.callerInstantApp, r.resolvedType, r.requiredPermissions, r.appOp, r.options, receiver, null, r.resultCode, r.resultData, r.resultExtras, r.ordered, r.sticky, r.initialSticky, r.userId)));
                        }
                        i2 = i3 + 1;
                        recIdx2 = recIdx;
                        numReceivers2 = numReceivers;
                        receivers = receivers2;
                        needMoveReceivers2 = needMoveReceivers3;
                        i = pid;
                        java.util.ArrayList<com.android.server.am.BroadcastRecord> arrayList = orderedBroadcasts;
                    }
                    needMoveReceivers3 = needMoveReceivers2;
                    receivers2 = receivers;
                    recIdx = recIdx2;
                    numReceivers = numReceivers2;
                    needMoveReceivers = orderedProxyBroadcasts;
                    list2 = needMoveReceivers3;
                    if (list2.size() > 0) {
                        receivers2.removeAll(list2);
                        if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getFilterDebug()) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("unproxy, moving receivers in Ordered Broadcasts (");
                            stringBuilder.append(r);
                            stringBuilder.append(") to proxyList, Move receivers : ");
                            stringBuilder.append(list2);
                            android.rms.iaware.AwareLog.i("HwMtmBroadcastResourceManager", stringBuilder.toString());
                        }
                    }
                    return;
                }
                return;
            }
        }
        needMoveReceivers = orderedProxyBroadcasts;
    }

    private static int getResolvePid(com.android.server.am.BroadcastQueue queue, java.lang.Object target) {
        if (target instanceof android.content.pm.ResolveInfo) {
            android.content.pm.ResolveInfo info = (android.content.pm.ResolveInfo) target;
            com.android.server.am.ProcessRecord app = queue.mService.getProcessRecordLocked(info.activityInfo.processName, info.activityInfo.applicationInfo.uid, false);
            if (app != null) {
                return app.pid;
            }
        }
        return -1;
    }

    private void trackBrFilter(java.lang.String action, com.android.server.mtm.iaware.appmng.AwareProcessInfo pInfo, int policy, boolean droped, java.lang.Object receiver) {
        if (com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.isBetaUser() && getBrDumpRadar() != null) {
            if (!droped) {
                if (pInfo.mPid == this.mSysServicePid) {
                    com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatSsNoDropCount(1);
                } else if (pInfo.mProcInfo.mCurAdj < 0) {
                    com.android.server.mtm.iaware.srms.AwareBroadcastDumpRadar.increatPerAppNoDropCount(1);
                }
            }
            if (pInfo.mPid == this.mSysServicePid) {
                pInfo.mProcInfo.mProcessName = "system_server";
            }
            java.lang.String id = "unknow";
            if (receiver instanceof com.android.server.am.BroadcastFilter) {
                id = com.android.server.mtm.iaware.srms.AwareBroadcastRegister.removeBRIdUncommonData(((com.android.server.am.BroadcastFilter) receiver).getIdentifier());
            }
            java.lang.String processType = "unknow";
            if (droped) {
                processType = "drop";
            } else {
                processType = "nodrop";
            }
            java.lang.String key = new java.lang.StringBuilder();
            key.append(action);
            key.append(",");
            key.append(pInfo.mProcInfo.mProcessName);
            key.append(",");
            key.append(id);
            key.append(",");
            key.append(pInfo.getState());
            key.append(",");
            key.append(policy);
            key.append(",");
            key.append(processType);
            this.mBrDumpRadar.addBrFilterDetail(key.toString());
        }
    }
}
