package com.android.server.am;

public class HwPCMultiWindowManager {
    private static final int DP_WINDOW_OVERLAP_OFFSET = 30;
    private static final int DP_WINDOW_OVERLAP_OFFSET_MIN = 15;
    static final int FIX_ORIENTATION_LANDSCAPE = 2;
    static final int FIX_ORIENTATION_NONE = 0;
    static final int FIX_ORIENTATION_PORTRAIT = 1;
    private static final int MAX_TIMES_TO_ADJUST_BOUNDS = 30;
    private static final int MSG_REQUEST_ORIENTATION = 1;
    private static final int MSG_REQUEST_ORIENTATION_DELAY = 200;
    static final int SPECIAL_PACKAGE_TYPE_FULLSCREEN_NO_NAVIGATIONBAR = 7;
    static final int SPECIAL_PACKAGE_TYPE_MAXIMIZED_ONLY = 3;
    static final int SPECIAL_PACKAGE_TYPE_NEED_DELAY = 2;
    static final int SPECIAL_PACKAGE_TYPE_PAD_FULLSCREEN = 6;
    static final int SPECIAL_PACKAGE_TYPE_PORTRAIT = 4;
    static final int SPECIAL_PACKAGE_TYPE_PORTRAIT_MAXIMIZED = 5;
    static final int SPECIAL_PACKAGE_TYPE_VIDEO_NEED_FULLSCREEN = 1;
    static final java.lang.String TAG = "HwPCMultiWindowManager";
    private static final java.lang.Object mLock = new java.lang.Object();
    private static volatile com.android.server.am.HwPCMultiWindowManager mSingleInstance = null;
    private int mCurDisplayId = -1;
    private int mDecorHeight = 0;
    final java.util.HashMap<java.lang.String, java.util.HashMap<java.lang.String, com.android.server.am.HwPCMultiWindowManager.Entry>> mEntries;
    boolean mFixOrientationChanged = false;
    final java.util.List<java.lang.String> mFullscreenNoNavigationBar = new java.util.ArrayList();
    final android.os.Handler mHandler;
    int mLastRequestedOrientation = 0;
    final java.util.List<java.lang.String> mMaximizedOnlyList = new java.util.ArrayList();
    final java.util.List<java.lang.String> mNeedDelayList = new java.util.ArrayList();
    private android.graphics.Point mNonDecorScreenSize = new android.graphics.Point();
    final java.util.List<java.lang.String> mPadFullscreenList = new java.util.ArrayList();
    final java.util.List<java.lang.String> mPortraitMaximizedPkgList = new java.util.ArrayList();
    final java.util.List<java.lang.String> mPortraitPkgList = new java.util.ArrayList();
    final com.android.server.am.ActivityManagerService mService;
    final com.android.server.am.HwPCMultiWindowSettingsWriter mSettingsWriter;
    final java.util.List<java.lang.String> mSpecialVideosList = new java.util.ArrayList();
    private java.util.Set<java.lang.Integer> mUpdateTaskSet = java.util.Collections.synchronizedSet(new java.util.HashSet());

    public static class Entry {
        public int originalWindowState = this.windowState;
        public final java.lang.String pkgName;
        public android.graphics.Rect windowBounds = new android.graphics.Rect();
        public int windowState = 1;

        public Entry(java.lang.String _name) {
            this.pkgName = _name;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("pkgName=");
            stringBuilder.append(this.pkgName);
            stringBuilder.append("; windowState=");
            stringBuilder.append(java.lang.Integer.toHexString(this.windowState));
            stringBuilder.append("; originalWindowState=");
            stringBuilder.append(java.lang.Integer.toHexString(this.originalWindowState));
            stringBuilder.append("; bounds=");
            stringBuilder.append(this.windowBounds == null ? "null" : this.windowBounds.toShortString());
            return stringBuilder.toString();
        }
    }

    private final class WorkerHandler extends android.os.Handler {
        public WorkerHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                synchronized (com.android.server.am.HwPCMultiWindowManager.this.mService) {
                    com.android.server.am.TaskRecord tr = com.android.server.am.HwPCMultiWindowManager.this.mService.mStackSupervisor.anyTaskForIdLocked(msg.arg2);
                    if (tr != null) {
                        com.android.server.am.HwPCMultiWindowManager.this.updateTaskByRequestedOrientationInternal(tr, msg.arg1);
                    }
                }
            }
        }
    }

    public static com.android.server.am.HwPCMultiWindowManager getInstance(com.android.server.am.ActivityManagerService service) {
        if (mSingleInstance == null) {
            synchronized (mLock) {
                if (mSingleInstance == null) {
                    mSingleInstance = new com.android.server.am.HwPCMultiWindowManager(service);
                }
            }
        }
        return mSingleInstance;
    }

    private HwPCMultiWindowManager(com.android.server.am.ActivityManagerService service) {
        this.mService = service;
        this.mEntries = new java.util.HashMap();
        com.android.server.am.HwPCMultiWindowPolicy.initialize(getRightContext(this.mService.mContext), this);
        this.mSettingsWriter = new com.android.server.am.HwPCMultiWindowSettingsWriter(this);
        this.mHandler = new com.android.server.am.HwPCMultiWindowManager.WorkerHandler(this.mService.mHandler.getLooper());
        this.mUpdateTaskSet.clear();
    }

    public void putEntry(java.lang.String deviceKey, java.lang.String entryKey, com.android.server.am.HwPCMultiWindowManager.Entry entry) {
        if (!android.text.TextUtils.isEmpty(deviceKey)) {
            if (!android.text.TextUtils.isEmpty(entryKey)) {
                if (!this.mEntries.containsKey(deviceKey)) {
                    this.mEntries.put(deviceKey, new java.util.HashMap());
                }
                ((java.util.HashMap) this.mEntries.get(deviceKey)).put(entryKey, entry);
            }
        }
    }

    public void putEntryForCurDevice(java.lang.String entryKey, com.android.server.am.HwPCMultiWindowManager.Entry entry) {
        putEntry(getCurDeviceKey(), entryKey, entry);
    }

    public com.android.server.am.HwPCMultiWindowManager.Entry getEntry(java.lang.String entryKey) {
        java.lang.String deviceKey = getCurDeviceKey();
        if (this.mEntries.containsKey(deviceKey)) {
            return (com.android.server.am.HwPCMultiWindowManager.Entry) ((java.util.HashMap) this.mEntries.get(deviceKey)).get(entryKey);
        }
        return null;
    }

    private void removeEntry(java.lang.String entryKey) {
        java.lang.String deviceKey = getCurDeviceKey();
        if (this.mEntries.containsKey(deviceKey) && ((java.util.HashMap) this.mEntries.get(deviceKey)).containsKey(entryKey)) {
            ((java.util.HashMap) this.mEntries.get(deviceKey)).remove(entryKey);
        }
    }

    private java.lang.String getCurDeviceKey() {
        android.graphics.Point deviceSize = new android.graphics.Point();
        android.view.Display display = getExtDisplay(null);
        if (display != null) {
            display.getRealSize(deviceSize);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(deviceSize.x);
        stringBuilder.append("_");
        stringBuilder.append(deviceSize.y);
        return stringBuilder.toString();
    }

    public void storeTaskSettings(com.android.server.am.TaskRecord record) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                java.lang.String name = record.mRootActivityInfo.packageName;
                com.android.server.am.HwPCMultiWindowManager.Entry entry = getEntry(name);
                if (entry == null) {
                    entry = new com.android.server.am.HwPCMultiWindowManager.Entry(name);
                }
                calStoredEntry(record, entry);
                putEntryForCurDevice(name, entry);
                this.mSettingsWriter.scheduleWrite();
            }
        }
    }

    private void calStoredEntry(com.android.server.am.TaskRecord record, com.android.server.am.HwPCMultiWindowManager.Entry entry) {
        if (!(record == null || record.mRootActivityInfo == null)) {
            if (entry != null) {
                entry.originalWindowState = record.mOriginalWindowState;
                boolean hasBounds = android.content.res.HwPCMultiWindowCompatibility.isLayoutHadBounds(record.mWindowState);
                if ((record instanceof com.android.server.am.HwTaskRecord) && ((com.android.server.am.HwTaskRecord) record).mSaveBounds) {
                    entry.windowState = ((com.android.server.am.HwTaskRecord) record).mWindowState;
                    if (hasBounds && isInScreen(record.getOverrideBounds())) {
                        entry.windowBounds.set(record.getOverrideBounds());
                    }
                } else if (hasBounds && isInScreen(record.getOverrideBounds())) {
                    entry.windowBounds.offsetTo(record.getOverrideBounds().left, record.getOverrideBounds().top);
                }
            }
        }
    }

    public void restoreTaskWindowState(com.android.server.am.TaskRecord record) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                record.mOriginalWindowState = getWindowStateByDefault(record, record.mRootActivityInfo.screenOrientation);
                record.mNextWindowState = getWindowState(record);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("restoreTaskWindowState: (N:");
                stringBuilder.append(java.lang.Integer.toHexString(record.mNextWindowState));
                stringBuilder.append(", O:");
                stringBuilder.append(java.lang.Integer.toHexString(record.mOriginalWindowState));
                stringBuilder.append(", C:");
                stringBuilder.append(java.lang.Integer.toHexString(record.mWindowState));
                stringBuilder.append(")");
                android.util.HwPCUtils.log("HwPCMultiWindowManager", stringBuilder.toString());
            }
        }
    }

    private int getWindowState(com.android.server.am.TaskRecord record) {
        int windowState = getWindowStateBySaved(record);
        if (windowState < 0) {
            return record.mOriginalWindowState;
        }
        return windowState;
    }

    private int getWindowStateBySaved(com.android.server.am.TaskRecord record) {
        java.lang.String pkgName = record.mRootActivityInfo.packageName;
        com.android.server.am.HwPCMultiWindowManager.Entry entry = getEntry(pkgName);
        if (entry == null) {
            return -1;
        }
        if (record.mOriginalWindowState == entry.originalWindowState) {
            return entry.windowState;
        }
        removeEntry(pkgName);
        return -1;
    }

    private boolean isPadFullscreen(com.android.server.am.TaskRecord record) {
        if (!android.util.HwPCUtils.enabledInPad() || record == null || record.mRootActivityInfo == null || (!this.mPadFullscreenList.contains(record.mRootActivityInfo.packageName) && !this.mPadFullscreenList.contains(record.mRootActivityInfo.name.toLowerCase()))) {
            return false;
        }
        return true;
    }

    private boolean isMaximizedOnly(com.android.server.am.TaskRecord record) {
        if (record == null || record.mRootActivityInfo == null || !this.mMaximizedOnlyList.contains(record.mRootActivityInfo.packageName)) {
            return false;
        }
        return true;
    }

    private boolean isFullscreenNoNavigationBar(com.android.server.am.TaskRecord record) {
        if (record == null || record.mRootActivityInfo == null || !this.mFullscreenNoNavigationBar.contains(record.mRootActivityInfo.packageName.toLowerCase())) {
            return false;
        }
        return true;
    }

    private boolean isMaximizedButPortrait(com.android.server.am.TaskRecord record) {
        if (record == null || record.mRootActivityInfo == null || !this.mPortraitMaximizedPkgList.contains(record.mRootActivityInfo.packageName)) {
            return false;
        }
        return true;
    }

    /* JADX WARNING: Missing block: B:35:0x0083, code:
            return false;
     */
    private boolean isFullscreenOnly(com.android.server.am.TaskRecord r10) {
        /*
        r9 = this;
        r0 = 0;
        if (r10 == 0) goto L_0x0083;
    L_0x0003:
        r1 = r10.mRootActivityInfo;
        if (r1 == 0) goto L_0x0083;
    L_0x0007:
        r1 = r10.mRootActivityInfo;
        r1 = r1.packageName;
        r2 = "com.android.browser";
        r1 = r1.equals(r2);
        if (r1 == 0) goto L_0x0014;
    L_0x0013:
        return r0;
    L_0x0014:
        r1 = android.util.HwPCUtils.enabledInPad();
        if (r1 == 0) goto L_0x0027;
    L_0x001a:
        r1 = r10.mRootActivityInfo;
        r1 = r1.packageName;
        r2 = "com.example.android.notepad";
        r1 = r1.equals(r2);
        if (r1 == 0) goto L_0x0027;
    L_0x0026:
        return r0;
    L_0x0027:
        r1 = r10.mRootActivityInfo;
        r1 = r1.getThemeResource();
        if (r1 != 0) goto L_0x0041;
    L_0x002f:
        r2 = r10.mRootActivityInfo;
        r2 = r2.applicationInfo;
        r2 = r2.targetSdkVersion;
        r3 = 11;
        if (r2 >= r3) goto L_0x003d;
    L_0x0039:
        r2 = 16973829; // 0x1030005 float:2.4060914E-38 double:8.386186E-317;
        goto L_0x0040;
    L_0x003d:
        r2 = 16973931; // 0x103006b float:2.40612E-38 double:8.386236E-317;
    L_0x0040:
        r1 = r2;
    L_0x0041:
        r2 = r10.mRootActivityInfo;
        r2 = r2.applicationInfo;
        r2 = r2.uid;
        r2 = android.os.UserHandle.getUserId(r2);
        r3 = com.android.server.AttributeCache.instance();
        r4 = r10.mRootActivityInfo;
        r4 = r4.packageName;
        r5 = com.android.internal.R.styleable.Window;
        r3 = r3.get(r4, r1, r5, r2);
        r4 = 1;
        if (r3 == 0) goto L_0x0067;
    L_0x005c:
        r5 = r3.array;
        r6 = 4;
        r5 = r5.getBoolean(r6, r0);
        if (r5 == 0) goto L_0x0067;
    L_0x0065:
        r5 = r4;
        goto L_0x0068;
    L_0x0067:
        r5 = r0;
    L_0x0068:
        if (r5 == 0) goto L_0x006b;
    L_0x006a:
        return r4;
    L_0x006b:
        r6 = com.huawei.pgmng.plug.PGSdk.getInstance();	 Catch:{ Exception -> 0x0081 }
        r7 = r9.mService;	 Catch:{ Exception -> 0x0081 }
        r7 = r7.mContext;	 Catch:{ Exception -> 0x0081 }
        r8 = r10.mRootActivityInfo;	 Catch:{ Exception -> 0x0081 }
        r8 = r8.packageName;	 Catch:{ Exception -> 0x0081 }
        r6 = r6.getPkgType(r7, r8);	 Catch:{ Exception -> 0x0081 }
        r7 = 5;
        if (r6 != r7) goto L_0x0080;
    L_0x007e:
        r0 = r4;
    L_0x0080:
        return r0;
    L_0x0081:
        r4 = move-exception;
        return r0;
    L_0x0083:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.am.HwPCMultiWindowManager.isFullscreenOnly(com.android.server.am.TaskRecord):boolean");
    }

    public boolean isPortraitApp(com.android.server.am.TaskRecord record) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                return isPortraitOnly(record, record.mRootActivityInfo.screenOrientation);
            }
        }
        return false;
    }

    private boolean isPortraitOnly(com.android.server.am.TaskRecord record, int requestOrientation) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                if (!(requestOrientation == 1 || requestOrientation == 7 || requestOrientation == 9 || requestOrientation == 12)) {
                    if (requestOrientation != 14 || android.util.HwPCUtils.enabledInPad()) {
                        if (this.mPortraitPkgList.contains(record.mRootActivityInfo.packageName)) {
                            return true;
                        }
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }

    private boolean isResizeable(com.android.server.am.TaskRecord record) {
        boolean z = false;
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                if ((record.mRootActivityInfo.applicationInfo.flags & 1) == 0) {
                    return android.content.pm.ActivityInfo.isResizeableMode(record.mResizeMode);
                }
                if (2 == record.mResizeMode) {
                    z = true;
                }
                return z;
            }
        }
        return false;
    }

    private int getWindowStateByDefault(com.android.server.am.TaskRecord record, int requestOrientation) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                if (isFullscreenNoNavigationBar(record)) {
                    return 132612;
                }
                if (isPadFullscreen(record)) {
                    return 4;
                }
                if (isMaximizedOnly(record)) {
                    return 3;
                }
                if (isFullscreenOnly(record)) {
                    return 4;
                }
                if (isMaximizedButPortrait(record)) {
                    return 513;
                }
                if (isPortraitOnly(record, requestOrientation)) {
                    if (isResizeablePortraitType(record, record.mRootActivityInfo.packageName)) {
                        return 1538;
                    }
                    return 1;
                } else if (isResizeable(record)) {
                    return android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction();
                } else {
                    return android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithPartAction();
                }
            }
        }
        return android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithPartAction();
    }

    private boolean isResizeablePortraitType(com.android.server.am.TaskRecord record, java.lang.String pkgName) {
        return isResizeable(record) && !this.mPortraitPkgList.contains(pkgName);
    }

    static boolean isFixedOrientationPortrait(int screenOrientation) {
        if (screenOrientation == 1 || screenOrientation == 7 || screenOrientation == 9) {
            return true;
        }
        return screenOrientation == 12;
    }

    static boolean isFixedOrientationLandscape(int screenOrientation) {
        if (!(screenOrientation == 0 || screenOrientation == 6 || screenOrientation == 8)) {
            if (screenOrientation != 11) {
                return false;
            }
        }
        return true;
    }

    public android.graphics.Rect getWindowBounds(com.android.server.am.TaskRecord record) {
        android.graphics.Rect bounds = getWindowBoundsBySaved(record);
        if (bounds == null || bounds.isEmpty()) {
            return getWindowBoundsByDefault(getWindowStateByDefault(record, record.mRootActivityInfo.screenOrientation));
        }
        return bounds;
    }

    private android.graphics.Rect getWindowBoundsBySaved(com.android.server.am.TaskRecord record) {
        com.android.server.am.HwPCMultiWindowManager.Entry entry = getEntry(record.mRootActivityInfo.packageName);
        if (entry == null) {
            return null;
        }
        return entry.windowBounds;
    }

    private boolean isInScreen(android.graphics.Rect bounds) {
        boolean z = false;
        if (bounds != null) {
            if (!bounds.isEmpty()) {
                android.graphics.Point size = getExtDisplaySize();
                if (bounds.left >= 0 && bounds.right <= size.x && bounds.top >= 0 && bounds.bottom <= size.y) {
                    z = true;
                }
                return z;
            }
        }
        return false;
    }

    private android.graphics.Rect getWindowBoundsByDefault(int windowState) {
        com.android.server.am.HwPCMultiWindowPolicy.updateDefaultSize(getRightContext(this.mService.mContext), this);
        int layoutState = android.content.res.HwPCMultiWindowCompatibility.getWindowStateLayout(windowState);
        android.graphics.Rect bounds = new android.graphics.Rect();
        switch (layoutState) {
            case 1:
                getBounds(true, bounds);
                return bounds;
            case 2:
                getBounds(false, bounds);
                return bounds;
            case 3:
                android.graphics.Point size = getExtDisplaySize();
                bounds.set(0, 0, size.x, size.y);
                return bounds;
            default:
                return null;
        }
    }

    public android.graphics.Rect getLaunchBounds(com.android.server.am.TaskRecord record) {
        android.graphics.Rect outRect = new android.graphics.Rect();
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                java.lang.String str;
                if (!android.content.res.HwPCMultiWindowCompatibility.isLayoutHadBounds(record.mNextWindowState)) {
                    switch (android.content.res.HwPCMultiWindowCompatibility.getWindowStateLayout(record.mNextWindowState)) {
                        case 3:
                            outRect.set(getMaximizedBounds());
                            break;
                        case 4:
                            outRect = null;
                            break;
                        default:
                            break;
                    }
                }
                outRect = getWindowBounds(record);
                if (!(outRect == null || record.mRootActivityInfo.windowLayout == null)) {
                    int width = getFinalWidth(record.mRootActivityInfo.windowLayout);
                    if (width > 0) {
                        outRect.right = outRect.left + width;
                    }
                    int height = getFinalHeight(record.mRootActivityInfo.windowLayout);
                    if (height > 0) {
                        outRect.bottom = outRect.top + height;
                    }
                }
                outRect = adjustBounds(outRect, record.taskId);
                java.lang.String str2 = "HwPCMultiWindowManager";
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getLaunchBounds: ");
                if (outRect == null) {
                    str = "null";
                } else {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(outRect.toShortString());
                    stringBuilder2.append(" (");
                    stringBuilder2.append(outRect.width());
                    stringBuilder2.append(", ");
                    stringBuilder2.append(outRect.height());
                    stringBuilder2.append(")");
                    str = stringBuilder2.toString();
                }
                stringBuilder.append(str);
                android.util.HwPCUtils.log(str2, stringBuilder.toString());
                return outRect;
            }
        }
        return outRect;
    }

    private boolean isRectHasWindowSize(android.graphics.Rect rect) {
        android.graphics.Point size = getExtDisplaySize();
        android.graphics.Rect screenRect = new android.graphics.Rect(0, 0, size.x, size.y);
        if (!(rect == null || rect.isEmpty())) {
            if (!rect.equals(screenRect)) {
                return true;
            }
        }
        return false;
    }

    private android.graphics.Rect adjustBounds(android.graphics.Rect rect, int taskId) {
        com.android.server.am.HwPCMultiWindowManager hwPCMultiWindowManager = this;
        android.graphics.Rect rect2 = rect;
        if (!isRectHasWindowSize(rect)) {
            return rect2;
        }
        int displayNdx;
        int childCount;
        int i;
        int i2;
        android.graphics.Point size = getExtDisplaySize();
        android.graphics.Rect screenRect = new android.graphics.Rect(0, 0, size.x, size.y);
        java.util.ArrayList<android.graphics.Rect> bounds = new java.util.ArrayList();
        android.util.SparseArray<com.android.server.am.ActivityDisplay> activityDisplays = hwPCMultiWindowManager.mService.mStackSupervisor.mActivityDisplays;
        java.util.ArrayList<com.android.server.am.ActivityStack> stacks = new java.util.ArrayList();
        boolean tryForwardY = true;
        for (displayNdx = activityDisplays.size() - 1; displayNdx >= 0; displayNdx--) {
            com.android.server.am.ActivityDisplay activityDisplay = (com.android.server.am.ActivityDisplay) activityDisplays.valueAt(displayNdx);
            childCount = activityDisplay.getChildCount();
            for (i = 0; i < childCount; i++) {
                stacks.add(activityDisplay.getChildAt(i));
            }
        }
        displayNdx = stacks.size();
        for (int i3 = 0; i3 < displayNdx; i3++) {
            com.android.server.am.ActivityStack stack = (com.android.server.am.ActivityStack) stacks.get(i3);
            if (!(stack.mDisplayId == 0 || stack.mDisplayId == -1)) {
                com.android.server.am.TaskRecord task = stack.topTask();
                if (task != null) {
                    if (!(taskId == task.taskId || task.getOverrideBounds() == null || task.getOverrideBounds().equals(screenRect))) {
                        bounds.add(task.getOverrideBounds());
                    }
                }
            }
            i2 = taskId;
        }
        i2 = taskId;
        android.graphics.Rect newRect = new android.graphics.Rect(rect2);
        childCount = com.android.server.am.HwPCMultiWindowPolicy.dpToPx(hwPCMultiWindowManager.getRightContext(hwPCMultiWindowManager.mService.mContext), 15);
        int i4 = 30;
        i = com.android.server.am.HwPCMultiWindowPolicy.dpToPx(hwPCMultiWindowManager.getRightContext(hwPCMultiWindowManager.mService.mContext), 30);
        int i5 = 0;
        boolean tryForwardX = true;
        while (hwPCMultiWindowManager.isWindowOverlapped(newRect, bounds)) {
            int i6 = i5 + 1;
            if (i5 >= i4) {
                break;
            }
            int offsetY;
            i5 = 0;
            int offsetY2 = 0;
            boolean noX = false;
            boolean noY = false;
            if (tryForwardX && newRect.right + childCount < size.x) {
                i5 = newRect.right + i > size.x ? size.x - newRect.right : i;
            } else if (newRect.left - childCount > 0) {
                i5 = newRect.left - i > 0 ? 0 - i : 0 - newRect.left;
                tryForwardX = false;
            } else {
                noX = true;
            }
            if (!tryForwardY || newRect.bottom + childCount >= size.y) {
                if (newRect.top - childCount > 0) {
                    offsetY2 = newRect.top - i > 0 ? 0 - i : 0 - newRect.top;
                    tryForwardY = false;
                } else {
                    noY = true;
                }
                offsetY = offsetY2;
            } else {
                offsetY = newRect.bottom + i > size.y ? size.y - newRect.bottom : i;
            }
            if (noX && noY) {
                break;
            }
            newRect.offset(i5, offsetY);
            i5 = i6;
            hwPCMultiWindowManager = this;
            i4 = 30;
        }
        return newRect;
    }

    private boolean isWindowOverlapped(android.graphics.Rect rect, java.util.ArrayList<android.graphics.Rect> taskBounds) {
        int taskBoundsSize = taskBounds.size();
        for (int i = 0; i < taskBoundsSize; i++) {
            if (rect.equals((android.graphics.Rect) taskBounds.get(i))) {
                android.util.HwPCUtils.log("HwPCMultiWindowManager", "isWindowOverlapped return true.");
                return true;
            }
        }
        return false;
    }

    private void getBounds(boolean isPortrait, android.graphics.Rect out) {
        int width;
        int height;
        android.graphics.Point size = getExtDisplaySize();
        if (isPortrait) {
            width = com.android.server.am.HwPCMultiWindowPolicy.mDefPortraitWidth;
            height = (int) (((float) com.android.server.am.HwPCMultiWindowPolicy.mDefPortraitWidth) / com.android.server.am.HwPCMultiWindowPolicy.mPortraitRatio);
        } else {
            height = com.android.server.am.HwPCMultiWindowPolicy.mDefLandscapeHeight;
            width = (int) (((float) com.android.server.am.HwPCMultiWindowPolicy.mDefLandscapeHeight) * com.android.server.am.HwPCMultiWindowPolicy.mLandscapeRatio);
        }
        height += this.mDecorHeight;
        if (width > size.x) {
            width = size.x;
            height = (int) (((float) size.x) / (isPortrait ? com.android.server.am.HwPCMultiWindowPolicy.mPortraitRatio : com.android.server.am.HwPCMultiWindowPolicy.mLandscapeRatio));
        }
        if (height > size.y) {
            height = size.y;
            width = (int) (((float) size.y) * (isPortrait ? com.android.server.am.HwPCMultiWindowPolicy.mPortraitRatio : com.android.server.am.HwPCMultiWindowPolicy.mLandscapeRatio));
        }
        out.set(com.android.server.am.HwPCMultiWindowPolicy.mWindowMarginLeft, com.android.server.am.HwPCMultiWindowPolicy.mWindowMarginTop, com.android.server.am.HwPCMultiWindowPolicy.mWindowMarginLeft + width, com.android.server.am.HwPCMultiWindowPolicy.mWindowMarginTop + height);
    }

    private boolean isNeedDelay(com.android.server.am.TaskRecord record) {
        if (record != null) {
            if (record.mRootActivityInfo != null) {
                java.lang.String pkgName = record.mRootActivityInfo.packageName;
                if (android.text.TextUtils.isEmpty(pkgName) || !this.mNeedDelayList.contains(pkgName)) {
                    return false;
                }
                android.util.HwPCUtils.log("HwPCMultiWindowManager", "isNeedDelay return true.");
                return true;
            }
        }
        return false;
    }

    public void updateTaskByRequestedOrientation(com.android.server.am.TaskRecord record, int requestedOrientation) {
        if (isNeedDelay(record)) {
            if (requestedOrientation != 0) {
                if (!(this.mLastRequestedOrientation == 0 || this.mLastRequestedOrientation == requestedOrientation)) {
                    this.mFixOrientationChanged = true;
                }
                this.mLastRequestedOrientation = requestedOrientation;
            }
            android.os.Message msg = android.os.Message.obtain();
            this.mHandler.removeMessages(1);
            msg.what = 1;
            msg.arg1 = requestedOrientation;
            msg.arg2 = record.taskId;
            this.mHandler.sendMessageDelayed(msg, 200);
            return;
        }
        this.mFixOrientationChanged = false;
        this.mLastRequestedOrientation = 0;
        updateTaskByRequestedOrientationInternal(record, requestedOrientation);
    }

    public void updateTaskByRequestedOrientationInternal(com.android.server.am.TaskRecord record, int customRequestedOrientation) {
        if (customRequestedOrientation != 0) {
            int currentOrientation = 1;
            if (!(android.content.res.HwPCMultiWindowCompatibility.getWindowStateLayout(record.mWindowState) == 1)) {
                currentOrientation = 2;
            }
            if (currentOrientation != customRequestedOrientation || ((this.mFixOrientationChanged && customRequestedOrientation == 2) || this.mUpdateTaskSet.contains(java.lang.Integer.valueOf(record.taskId)))) {
                this.mFixOrientationChanged = false;
                this.mLastRequestedOrientation = 0;
                record.mNextWindowState = getWindowStateByDefault(record, customRequestedOrientation);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateTaskByRequestedOrientation-pre by default: ");
                stringBuilder.append(java.lang.Integer.toHexString(record.mWindowState));
                stringBuilder.append(" to ");
                stringBuilder.append(java.lang.Integer.toHexString(record.mNextWindowState));
                android.util.HwPCUtils.log("HwPCMultiWindowManager", stringBuilder.toString());
                if (record.mWindowState != record.mNextWindowState || this.mUpdateTaskSet.contains(java.lang.Integer.valueOf(record.taskId))) {
                    java.lang.String str;
                    android.graphics.Rect rect = getWindowBoundsByDefault(record.mNextWindowState);
                    if (!(record.getOverrideBounds() == null || record.getOverrideBounds().isEmpty() || !isRectHasWindowSize(rect))) {
                        rect.offsetTo(record.getOverrideBounds().left, record.getOverrideBounds().top);
                    }
                    rect = adjustBounds(rect, record.taskId);
                    if (record instanceof com.android.server.am.HwTaskRecord) {
                        ((com.android.server.am.HwTaskRecord) record).mSaveBounds = false;
                    }
                    java.lang.String str2 = "HwPCMultiWindowManager";
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("updateTaskByRequestedOrientation: ");
                    stringBuilder.append(java.lang.Integer.toHexString(record.mNextWindowState));
                    stringBuilder.append(" - ");
                    if (rect == null) {
                        str = "null";
                    } else {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append(rect.toShortString());
                        stringBuilder2.append(" (");
                        stringBuilder2.append(rect.width());
                        stringBuilder2.append(", ");
                        stringBuilder2.append(rect.height());
                        stringBuilder2.append(")");
                        str = stringBuilder2.toString();
                    }
                    stringBuilder.append(str);
                    android.util.HwPCUtils.log(str2, stringBuilder.toString());
                }
                this.mUpdateTaskSet.remove(java.lang.Integer.valueOf(record.taskId));
            }
        }
    }

    void resizeTaskFromPC(com.android.server.am.TaskRecord record, android.graphics.Rect rect) {
        record.resize(rect, 3, true, false);
    }

    private android.view.Display getExtDisplay(boolean isInternal) {
        android.hardware.display.DisplayManager displayManager = null;
        if (this.mService.mWindowManager instanceof com.android.server.wm.HwWindowManagerService) {
            displayManager = ((com.android.server.wm.HwWindowManagerService) this.mService.mWindowManager).getDisplayManager();
        }
        if (displayManager == null) {
            return null;
        }
        int i = 0;
        if (isInternal) {
            return displayManager.getDisplay(0);
        }
        android.view.Display[] displays = displayManager.getDisplays();
        int length = displays.length;
        while (i < length) {
            android.view.Display d = displays[i];
            if (android.util.HwPCUtils.isValidExtDisplayId(d.getDisplayId())) {
                return d;
            }
            i++;
        }
        return null;
    }

    private android.graphics.Point getExtDisplaySize() {
        android.view.Display display = getExtDisplay(false);
        if (!(display == null || display.getDisplayId() == this.mCurDisplayId)) {
            this.mNonDecorScreenSize.x = 0;
            this.mNonDecorScreenSize.y = 0;
            this.mCurDisplayId = display.getDisplayId();
        }
        if ((this.mNonDecorScreenSize.x == 0 || this.mNonDecorScreenSize.y == 0) && display != null && (this.mService.mWindowManager instanceof com.android.server.wm.HwWindowManagerService)) {
            com.android.server.policy.WindowManagerPolicy policy = ((com.android.server.wm.HwWindowManagerService) this.mService.mWindowManager).getPolicy();
            android.graphics.Point fullScreenSize = new android.graphics.Point();
            display.getRealSize(fullScreenSize);
            if (policy != null) {
                this.mNonDecorScreenSize.x = policy.getNonDecorDisplayWidth(fullScreenSize.x, fullScreenSize.y, 0, 0, display.getDisplayId(), null);
                this.mNonDecorScreenSize.y = policy.getNonDecorDisplayHeight(fullScreenSize.x, fullScreenSize.y, 0, 0, display.getDisplayId(), null);
                this.mDecorHeight = fullScreenSize.y - this.mNonDecorScreenSize.y;
            }
        }
        return this.mNonDecorScreenSize;
    }

    private android.content.Context getRightContext(android.content.Context ctx) {
        android.view.Display display = getExtDisplay(null);
        if (display != null) {
            return ctx.createDisplayContext(display);
        }
        return ctx;
    }

    public android.graphics.Rect getMaximizedBounds() {
        android.graphics.Point size = getExtDisplaySize();
        return new android.graphics.Rect(0, 0, size.x, size.y);
    }

    public boolean isSupportResize(com.android.server.am.TaskRecord record, boolean isFullscreen, boolean isMaximized) {
        if (record == null) {
            return false;
        }
        if (isFullscreen) {
            return android.content.res.HwPCMultiWindowCompatibility.isFullscreenable(record.mWindowState);
        }
        if (isMaximized) {
            return android.content.res.HwPCMultiWindowCompatibility.isMaximizeable(record.mWindowState);
        }
        return android.content.pm.ActivityInfo.isResizeableMode(record.mResizeMode);
    }

    private int getFinalWidth(android.content.pm.ActivityInfo.WindowLayout windowLayout) {
        int width = 0;
        if (windowLayout.width > 0) {
            width = computeExtWidth(windowLayout.width);
        }
        if (windowLayout.widthFraction > 0.0f) {
            return (int) (((float) getExtDisplaySize().x) * windowLayout.widthFraction);
        }
        return width;
    }

    private int getFinalHeight(android.content.pm.ActivityInfo.WindowLayout windowLayout) {
        int height = 0;
        if (windowLayout.height > 0) {
            height = computeExtWidth(windowLayout.height);
        }
        if (windowLayout.heightFraction > 0.0f) {
            return (int) (((float) getExtDisplaySize().y) * windowLayout.heightFraction);
        }
        return height;
    }

    private int computeExtWidth(int val) {
        int internalDPI = 1;
        int externalDPI = 1;
        android.view.DisplayInfo info = new android.view.DisplayInfo();
        android.view.Display dis = getExtDisplay(true);
        if (dis != null) {
            dis.getDisplayInfo(info);
            internalDPI = info.logicalDensityDpi;
        }
        dis = getExtDisplay(false);
        if (dis != null) {
            dis.getDisplayInfo(info);
            externalDPI = info.logicalDensityDpi;
        }
        return (val * externalDPI) / internalDPI;
    }

    public boolean isSpecialVideo(java.lang.String pkgName) {
        return this.mSpecialVideosList.contains(pkgName);
    }

    public boolean isOlnyFullscreen(java.lang.String pkgName) {
        if (!this.mPadFullscreenList.contains(pkgName)) {
            if (!this.mFullscreenNoNavigationBar.contains(pkgName)) {
                return false;
            }
        }
        return true;
    }

    public void setForceUpdateTask(int taskId) {
        this.mUpdateTaskSet.add(java.lang.Integer.valueOf(taskId));
    }
}
