package com.android.server.am;

public class HwPCMultiWindowPolicy {
    static final float PAD_LANDSCAPE_RATIO = 1.7777778f;
    static final float PAD_LANDSCAPE_WIDTH = 0.65f;
    static final float PAD_MARGIN_LEFT_RATIO = 0.1f;
    static final float PAD_MARGIN_TOP_RATIO = 0.04f;
    static final float PAD_PORTRAIT_HEIGHT = 0.9f;
    static final float PAD_PORTRAIT_RATIO = 0.5625f;
    static int mDefLandscapeHeight = 550;
    static int mDefPortraitWidth = 360;
    static int mLandscapeMaxWidth = 1200;
    static float mLandscapeRatio = 1.7777778f;
    static int mPortraitMaxHeightDp = 900;
    static float mPortraitRatio = 0.5625f;
    static int mWindowMarginLeft = 0;
    static int mWindowMarginTop = 0;

    static void initialize(android.content.Context context, com.android.server.am.HwPCMultiWindowManager multiWindowMgr) {
        try {
            updateDefaultSize(context, multiWindowMgr);
        } catch (java.lang.Exception e) {
            android.util.Log.e("HwPCMultiWindowPolicy", "initialize error", e);
        }
    }

    public static int dpToPx(android.content.Context context, int dps) {
        return java.lang.Math.round(context.getResources().getDisplayMetrics().density * ((float) dps));
    }

    public static int pxToDp(android.content.Context context, int px) {
        return java.lang.Math.round(((float) px) / context.getResources().getDisplayMetrics().density);
    }

    public static android.graphics.Rect pxRectToDpRect(android.content.Context context, android.graphics.Rect rect) {
        return new android.graphics.Rect(pxToDp(context, rect.left), pxToDp(context, rect.top), pxToDp(context, rect.right), pxToDp(context, rect.bottom));
    }

    public static android.graphics.Rect dpRectToPxRect(android.content.Context context, android.graphics.Rect rect) {
        return new android.graphics.Rect(dpToPx(context, rect.left), dpToPx(context, rect.top), dpToPx(context, rect.right), dpToPx(context, rect.bottom));
    }

    public static void updateDefaultSize(android.content.Context context, com.android.server.am.HwPCMultiWindowManager multiWindowMgr) {
        if (multiWindowMgr != null) {
            android.graphics.Rect rect = multiWindowMgr.getMaximizedBounds();
            int appWidth = rect.width();
            int appHeight = rect.height();
            if (android.util.HwPCUtils.enabledInPad()) {
                updateDefaultSizeInPad(context, appWidth, appHeight);
            } else {
                updateDefaultSizeInPhone(context, appWidth, appHeight);
            }
        }
    }

    private static void updateDefaultSizeInPhone(android.content.Context context, int appWidth, int appHeight) {
        int maxHeight = dpToPx(context, mPortraitMaxHeightDp);
        int tmpHeight = ((float) appHeight) * 0.8f;
        mDefPortraitWidth = (int) (((float) ((int) (tmpHeight < ((float) maxHeight) ? tmpHeight : (float) maxHeight))) * mPortraitRatio);
        int maxWidth = dpToPx(context, mLandscapeMaxWidth);
        int tmpWidth = ((float) appWidth) * 0.6f;
        mDefLandscapeHeight = (int) (((float) ((int) (tmpWidth < ((float) maxWidth) ? tmpWidth : (float) maxWidth))) / mLandscapeRatio);
        mWindowMarginTop = (int) (((float) appHeight) * 0.1f);
        mWindowMarginLeft = (int) (((float) appWidth) * 0.1f);
    }

    private static void updateDefaultSizeInPad(android.content.Context context, int appWidth, int appHeight) {
        mPortraitRatio = 0.5625f;
        mDefPortraitWidth = (int) ((((float) appHeight) * 0.9f) * 0.5625f);
        mLandscapeRatio = 1.7777778f;
        mDefLandscapeHeight = (int) ((((float) appWidth) * 0.65f) / 1.7777778f);
        mWindowMarginTop = (int) (((float) appHeight) * 0.04f);
        mWindowMarginLeft = (int) (((float) appWidth) * 0.1f);
    }

    public static void layoutWindowForPadPCMode(com.android.server.policy.WindowManagerPolicy.WindowState win, android.graphics.Rect pf, android.graphics.Rect df, android.graphics.Rect cf, android.graphics.Rect vf, int contentBottom) {
        if (android.util.HwPCUtils.enabledInPad()) {
            int windowState = -1;
            com.android.server.am.ActivityRecord r = com.android.server.am.ActivityRecord.forToken((android.os.IBinder) win.getAppToken());
            if (r != null) {
                if (r instanceof com.android.server.am.HwActivityRecord) {
                    windowState = ((com.android.server.am.HwActivityRecord) r).getWindowState();
                }
                if (windowState != -1) {
                    r.service.mWindowManager.layoutWindowForPadPCMode(win, pf, df, cf, vf, contentBottom);
                }
            }
        }
    }
}
