package com.android.server.am;

public class HwPCMultiWindowSettingsDefault {
    private static final java.lang.String DEFAULT_FILE_PATH = "/system/etc/multiwindow_compat_app.conf";
    public java.util.HashMap<java.lang.String, java.lang.Integer> mSettingsDefaults;

    public HwPCMultiWindowSettingsDefault(com.android.server.am.HwPCMultiWindowManager settings) {
        loadSettingsDefaults();
    }

    public int getAppDefaultMode(java.lang.String pkgName, int screenOrientation) {
        java.lang.Integer mode = (java.lang.Integer) this.mSettingsDefaults.get(pkgName);
        if (mode != null) {
            return mode.intValue();
        }
        if (screenOrientation == 0) {
            return android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction();
        }
        return android.content.res.HwPCMultiWindowCompatibility.getPortraitWithAllAction();
    }

    public int getAppDefaultMode(java.lang.String pkgName) {
        java.lang.Integer in = (java.lang.Integer) this.mSettingsDefaults.get(pkgName);
        if (in != null) {
            return in.intValue();
        }
        return android.content.res.HwPCMultiWindowCompatibility.getPortraitWithAllAction();
    }

    public void setAppDefaultMode(java.lang.String pkgName, int mode) {
        if (!android.text.TextUtils.isEmpty(pkgName)) {
            this.mSettingsDefaults.put(pkgName, java.lang.Integer.valueOf(mode));
        }
    }

    private java.lang.String getDefaultFilePath() {
        return "/system/etc/multiwindow_compat_app.conf";
    }

    private void loadSettingsDefaults() {
        this.mSettingsDefaults = new java.util.HashMap();
        java.io.File file = new java.io.File(getDefaultFilePath());
        if (file.exists()) {
            java.io.FileInputStream fis = null;
            java.io.BufferedReader reader = null;
            try {
                fis = new java.io.FileInputStream(file);
                reader = new java.io.BufferedReader(new java.io.InputStreamReader(fis, java.nio.charset.Charset.defaultCharset()));
                java.lang.String line = reader.readLine();
                if (line != null) {
                    line = line.trim();
                }
                while (line != null) {
                    int index = line.indexOf(32);
                    if (index != -1) {
                        java.lang.String packageName = line.substring(null, index);
                        try {
                            this.mSettingsDefaults.put(packageName, java.lang.Integer.valueOf(java.lang.Integer.parseInt(line.substring(index + 1).trim())));
                        } catch (java.lang.Exception e) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("WindowMode Parse Error: ");
                            stringBuilder.append(line);
                            android.util.Log.e("MultiWindowManager", stringBuilder.toString());
                        }
                    }
                    line = reader.readLine();
                }
                try {
                    reader.close();
                    fis.close();
                } catch (java.io.IOException e2) {
                    android.util.Log.e("MultiWindowManager", "loadSettingsDefaults close IOException");
                }
            } catch (java.io.FileNotFoundException e3) {
                android.util.Log.e("MultiWindowManager", "loadSettingsDefaults FileNotFoundException");
                if (reader != null) {
                    reader.close();
                }
                if (fis != null) {
                    fis.close();
                }
            } catch (java.io.IOException e4) {
                android.util.Log.e("MultiWindowManager", "loadSettingsDefaults IOException");
                if (reader != null) {
                    reader.close();
                }
                if (fis != null) {
                    fis.close();
                }
            } catch (Throwable th) {
                if (reader != null) {
                    try {
                        reader.close();
                    } catch (java.io.IOException e5) {
                        android.util.Log.e("MultiWindowManager", "loadSettingsDefaults close IOException");
                    }
                }
                if (fis != null) {
                    fis.close();
                }
            }
        } else {
            this.mSettingsDefaults.put("com.huawei.desktop.explorer", java.lang.Integer.valueOf(android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction()));
            this.mSettingsDefaults.put("com.chaozhuo.browser", java.lang.Integer.valueOf(android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction()));
            this.mSettingsDefaults.put("com.android.calendar", java.lang.Integer.valueOf(android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction()));
            this.mSettingsDefaults.put("com.android.email", java.lang.Integer.valueOf(android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction()));
            this.mSettingsDefaults.put("com.example.android.notepad", java.lang.Integer.valueOf(android.content.res.HwPCMultiWindowCompatibility.getLandscapeWithAllAction()));
            this.mSettingsDefaults.put("com.huawei.android.internal.app", java.lang.Integer.valueOf(4));
        }
    }
}
