package com.android.server.am;

public class HwPCMultiWindowSettingsWriter {
    private static final int MSG_WRITE = 1;
    private static final int mCurrentVersion = 11;
    private final android.os.Handler mHandler;
    private int mLastVersion = -1;
    private com.android.server.am.HwPCMultiWindowManager mSettings;
    private final android.util.AtomicFile mSettingsFile;

    private final class WorkerHandler extends android.os.Handler {
        public WorkerHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                synchronized (com.android.server.am.HwPCMultiWindowSettingsWriter.this.mSettings.mService) {
                    com.android.server.am.HwPCMultiWindowSettingsWriter.this.writeSettingsLocked();
                }
            }
        }
    }

    public HwPCMultiWindowSettingsWriter(com.android.server.am.HwPCMultiWindowManager settings) {
        this.mSettings = settings;
        this.mHandler = new com.android.server.am.HwPCMultiWindowSettingsWriter.WorkerHandler(this.mSettings.mService.mHandler.getLooper());
        this.mSettingsFile = new android.util.AtomicFile(new java.io.File(new java.io.File(android.os.Environment.getDataDirectory(), "system"), "app_window_settings.xml"));
        loadSettings();
        if (this.mLastVersion < 11) {
            this.mSettings.mEntries.clear();
        }
        loadSpecialPackages();
    }

    public void scheduleWrite() {
        this.mHandler.removeMessages(1);
        this.mHandler.sendEmptyMessageDelayed(1, 5000);
    }

    private void loadSettings() {
        try {
            java.io.FileInputStream stream = this.mSettingsFile.openRead();
            try {
                org.xmlpull.v1.XmlPullParser parser = android.util.Xml.newPullParser();
                parser.setInput(stream, "utf-8");
                com.android.server.am.HwPCMultiWindowManager.Entry entry = null;
                java.lang.String entryKey = null;
                java.lang.String deviceKey = null;
                for (int event = parser.getEventType(); event != 1; event = parser.next()) {
                    if (event != 0) {
                        switch (event) {
                            case 2:
                                if (!"app_window_settings".equals(parser.getName())) {
                                    if (!"pkg".equals(parser.getName())) {
                                        if ("state_bounds".equals(parser.getName())) {
                                            if (entry != null) {
                                                entry.windowState = getIntAttribute(parser, "windowState");
                                                entry.originalWindowState = getIntAttribute(parser, "originalWindowState");
                                                entry.windowBounds.left = getIntAttribute(parser, "left");
                                                entry.windowBounds.top = getIntAttribute(parser, "top");
                                                entry.windowBounds.right = getIntAttribute(parser, "right");
                                                entry.windowBounds.bottom = getIntAttribute(parser, "bottom");
                                                break;
                                            }
                                            break;
                                        }
                                    }
                                    java.lang.String name = parser.getAttributeValue(null, "name");
                                    if (name != null) {
                                        entryKey = name;
                                        entry = new com.android.server.am.HwPCMultiWindowManager.Entry(name);
                                    }
                                    break;
                                }
                                this.mLastVersion = getIntAttribute(parser, "version");
                                deviceKey = parser.getAttributeValue(null, "device");
                                break;
                                break;
                            case 3:
                                if ("pkg".equals(parser.getName())) {
                                    this.mSettings.putEntry(deviceKey, entryKey, entry);
                                    entryKey = null;
                                    entry = null;
                                    break;
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }
            } catch (java.lang.RuntimeException e) {
                throw e;
            } catch (java.lang.Exception e2) {
                android.util.Slog.w("HwPCMultiWindowSettingsWriter", "on loadSettings", e2);
            }
        } catch (java.io.FileNotFoundException e3) {
        }
    }

    private int getIntAttribute(org.xmlpull.v1.XmlPullParser parser, java.lang.String name) {
        int i = 0;
        try {
            java.lang.String str = parser.getAttributeValue(null, name);
            if (str != null) {
                i = java.lang.Integer.parseInt(str);
            }
            return i;
        } catch (java.lang.NumberFormatException e) {
            return 0;
        }
    }

    private void writeSettingsLocked() {
        try {
            java.io.FileOutputStream stream = this.mSettingsFile.startWrite();
            try {
                org.xmlpull.v1.XmlSerializer out = new com.android.internal.util.FastXmlSerializer();
                out.setOutput(stream, "utf-8");
                out.startDocument(null, java.lang.Boolean.valueOf(true));
                for (java.lang.String deviceKey : this.mSettings.mEntries.keySet()) {
                    out.startTag(null, "app_window_settings");
                    out.attribute(null, "version", java.lang.Integer.toString(11));
                    out.attribute(null, "device", deviceKey);
                    out.startTag(null, "system_app_window_mode");
                    out.endTag(null, "system_app_window_mode");
                    for (com.android.server.am.HwPCMultiWindowManager.Entry entry : ((java.util.HashMap) this.mSettings.mEntries.get(deviceKey)).values()) {
                        if (entry != null) {
                            if (entry.windowBounds != null) {
                                out.startTag(null, "pkg");
                                out.attribute(null, "name", entry.pkgName);
                                out.startTag(null, "state_bounds");
                                out.attribute(null, "windowState", java.lang.Integer.toString(entry.windowState));
                                out.attribute(null, "originalWindowState", java.lang.Integer.toString(entry.originalWindowState));
                                out.attribute(null, "left", java.lang.Integer.toString(entry.windowBounds.left));
                                out.attribute(null, "top", java.lang.Integer.toString(entry.windowBounds.top));
                                out.attribute(null, "right", java.lang.Integer.toString(entry.windowBounds.right));
                                out.attribute(null, "bottom", java.lang.Integer.toString(entry.windowBounds.bottom));
                                out.endTag(null, "orientation");
                                out.endTag(null, "pkg");
                            }
                        }
                    }
                    out.endTag(null, "app_window_settings");
                }
                out.endDocument();
                this.mSettingsFile.finishWrite(stream);
            } catch (java.lang.RuntimeException e) {
                throw e;
            } catch (java.lang.Exception e2) {
                this.mSettingsFile.failWrite(stream);
                android.util.Slog.w("HwPCMultiWindowSettingsWriter", "on writeSettingsLocked", e2);
            }
        } catch (java.io.IOException e3) {
        }
    }

    private void loadSpecialPackages() {
        this.mSettings.mSpecialVideosList.clear();
        this.mSettings.mNeedDelayList.clear();
        this.mSettings.mMaximizedOnlyList.clear();
        this.mSettings.mPortraitPkgList.clear();
        this.mSettings.mPortraitMaximizedPkgList.clear();
        this.mSettings.mPadFullscreenList.clear();
        this.mSettings.mFullscreenNoNavigationBar.clear();
        java.util.List<android.util.Pair<java.lang.String, java.lang.Integer>> specialPkgList = com.android.server.pc.whiltestrategy.WhiteListAppStrategyManager.getInstance(this.mSettings.mService.mContext).getSpecailWindowPolicyAppList();
        if (specialPkgList != null) {
            for (android.util.Pair<java.lang.String, java.lang.Integer> specialPkg : specialPkgList) {
                if (specialPkg != null) {
                    switch (((java.lang.Integer) specialPkg.second).intValue()) {
                        case 1:
                            this.mSettings.mSpecialVideosList.add((java.lang.String) specialPkg.first);
                            break;
                        case 2:
                            this.mSettings.mNeedDelayList.add((java.lang.String) specialPkg.first);
                            break;
                        case 3:
                            this.mSettings.mMaximizedOnlyList.add((java.lang.String) specialPkg.first);
                            break;
                        case 4:
                            this.mSettings.mPortraitPkgList.add((java.lang.String) specialPkg.first);
                            break;
                        case 5:
                            this.mSettings.mPortraitMaximizedPkgList.add((java.lang.String) specialPkg.first);
                            break;
                        case 6:
                            this.mSettings.mPadFullscreenList.add((java.lang.String) specialPkg.first);
                            break;
                        case 7:
                            this.mSettings.mFullscreenNoNavigationBar.add((java.lang.String) specialPkg.first);
                            break;
                        default:
                            break;
                    }
                }
            }
        }
    }
}
