package com.android.server.appwidget;

class HwAppWidgetServiceImpl extends com.android.server.appwidget.AppWidgetServiceImpl {
    private static final boolean DEBUG = false;
    private static final int SMCS_APP_WIDGET_SERVICE_GET_BY_USERID = 2;
    private static final int SMCS_APP_WIDGET_SERVICE_GET_VISIBLE = 1;
    static final java.lang.String TAG = "HwAppWidgetServiceImpl";
    private static final int WIDGET_INVISIBLE = 0;
    private static final int WIDGET_VISIBLE = 1;
    private android.content.Context mContext = null;

    public HwAppWidgetServiceImpl(android.content.Context context) {
        super(context);
        this.mContext = context;
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        if (data != null) {
            if (reply != null) {
                if (1599297111 == code) {
                    try {
                        switch (data.readInt()) {
                            case 1:
                                handleGetVisibleWidgets(data, reply);
                                return true;
                            case 2:
                                handleGetVisibleWidgetsByUserId(data.readInt(), reply);
                                return true;
                            default:
                                break;
                        }
                    } catch (java.lang.Exception e) {
                        return false;
                    }
                }
                return super.onTransact(code, data, reply, flags);
            }
        }
        return false;
    }

    private void handleGetVisibleWidgets(android.os.Parcel data, android.os.Parcel reply) {
        java.util.HashSet<java.lang.String> visibleWidgets = new java.util.HashSet();
        if (this.mContext.checkCallingPermission("huawei.permission.IBINDER_APP_WIDGET_SERVICE") == 0) {
            getVisibleWidgets_hwHsm(visibleWidgets);
            reply.writeInt(visibleWidgets.size());
            java.util.Iterator<java.lang.String> it = visibleWidgets.iterator();
            while (it.hasNext()) {
                reply.writeString((java.lang.String) it.next());
            }
        }
    }

    boolean getVisibleWidgets_hwHsm(java.util.HashSet<java.lang.String> sPkgs) {
        int i = 0;
        if (sPkgs == null) {
            return false;
        }
        synchronized (this.mWidgets) {
            int N = this.mWidgets.size();
            while (i < N) {
                com.android.server.appwidget.AppWidgetServiceImpl.Widget aid = (com.android.server.appwidget.AppWidgetServiceImpl.Widget) this.mWidgets.get(i);
                if (aid != null) {
                    com.android.server.appwidget.AppWidgetServiceImpl.Provider provider = aid.provider;
                    if (provider != null) {
                        android.appwidget.AppWidgetProviderInfo info = provider.info;
                        if (info != null) {
                            android.content.ComponentName cn = info.provider;
                            if (cn != null) {
                                sPkgs.add(cn.getPackageName());
                            }
                        }
                    }
                }
                i++;
            }
        }
        return true;
    }

    private void handleGetVisibleWidgetsByUserId(int userId, android.os.Parcel reply) {
        if (android.os.Binder.getCallingUid() == 1000) {
            java.util.HashSet<com.android.server.appwidget.AppWidgetServiceImpl.Widget> widgets = new java.util.HashSet();
            synchronized (this.mWidgets) {
                java.util.Iterator it = this.mWidgets.iterator();
                while (it.hasNext()) {
                    com.android.server.appwidget.AppWidgetServiceImpl.Widget widget = (com.android.server.appwidget.AppWidgetServiceImpl.Widget) it.next();
                    if (!isWidgetAbnormal(widget)) {
                        if (widget.provider.getUserId() == userId) {
                            widgets.add(widget);
                        }
                    }
                }
            }
            reply.writeInt(widgets.size());
            java.util.Iterator<com.android.server.appwidget.AppWidgetServiceImpl.Widget> it2 = widgets.iterator();
            while (it2.hasNext()) {
                com.android.server.appwidget.AppWidgetServiceImpl.Widget widget2 = (com.android.server.appwidget.AppWidgetServiceImpl.Widget) it2.next();
                reply.writeInt(widget2.appWidgetId);
                reply.writeString(widget2.provider.info.provider.getPackageName());
                reply.writeInt(com.android.server.rms.iaware.appmng.AwareAppAssociate.getInstance().isWidgetVisible(widget2.options));
            }
        }
    }

    private boolean isWidgetAbnormal(com.android.server.appwidget.AppWidgetServiceImpl.Widget widget) {
        if (!(widget == null || widget.provider == null || widget.provider.info == null)) {
            if (widget.provider.info.provider != null) {
                return false;
            }
        }
        return true;
    }

    protected void addWidgetReport(int userId, com.android.server.appwidget.AppWidgetServiceImpl.Widget widget) {
        addOrRemoveWidgetReport(userId, widget, 5);
    }

    protected void removeWidgetReport(int userId, com.android.server.appwidget.AppWidgetServiceImpl.Widget widget) {
        addOrRemoveWidgetReport(userId, widget, 6);
    }

    private void addOrRemoveWidgetReport(int userId, com.android.server.appwidget.AppWidgetServiceImpl.Widget widget, int action) {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC)) && !isWidgetAbnormal(widget)) {
            android.os.Bundle args = new android.os.Bundle();
            args.putString("widget", widget.provider.info.provider.getPackageName());
            args.putInt("widgetId", widget.appWidgetId);
            args.putBundle("widgetOpt", widget.options);
            args.putInt("userid", userId);
            args.putInt("relationType", action);
            android.rms.iaware.CollectData data = new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC), java.lang.System.currentTimeMillis(), args);
            long origId = android.os.Binder.clearCallingIdentity();
            resManager.reportData(data);
            android.os.Binder.restoreCallingIdentity(origId);
        }
    }

    protected void updateWidgetOptionsReport(int userId, com.android.server.appwidget.AppWidgetServiceImpl.Widget widget) {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC)) && !isWidgetAbnormal(widget)) {
            android.os.Bundle args = new android.os.Bundle();
            args.putInt("widgetId", widget.appWidgetId);
            args.putString("widget", widget.provider.info.provider.getPackageName());
            args.putBundle("widgetOpt", widget.options);
            args.putInt("userid", userId);
            args.putInt("relationType", 24);
            android.rms.iaware.CollectData data = new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC), java.lang.System.currentTimeMillis(), args);
            long origId = android.os.Binder.clearCallingIdentity();
            resManager.reportData(data);
            android.os.Binder.restoreCallingIdentity(origId);
        }
    }

    protected void clearWidgetReport() {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC))) {
            android.os.Bundle args = new android.os.Bundle();
            args.putInt("relationType", 7);
            android.rms.iaware.CollectData data = new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC), java.lang.System.currentTimeMillis(), args);
            long origId = android.os.Binder.clearCallingIdentity();
            resManager.reportData(data);
            android.os.Binder.restoreCallingIdentity(origId);
        }
    }
}
