package com.android.server.audio;

public class HwMediaFocusControl extends com.android.server.audio.MediaFocusControl {
    private static final boolean DEBUG = false;
    private static final java.lang.String TAG = "HwMediaFocusControl";
    protected volatile boolean mInDestopMode = false;

    public HwMediaFocusControl(android.content.Context cntxt, com.android.server.audio.PlayerFocusEnforcer pfe) {
        super(cntxt, pfe);
    }

    protected boolean isMediaForDPExternalDisplay(android.media.AudioAttributes aa, java.lang.String clientId, java.lang.String pkgName, int uid) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isMediaForDPExternalDisplay aa = ");
        stringBuilder.append(aa);
        stringBuilder.append(", clientId = ");
        stringBuilder.append(clientId);
        stringBuilder.append(", pkgName = ");
        stringBuilder.append(pkgName);
        stringBuilder.append(", mInDestopMode = ");
        stringBuilder.append(this.mInDestopMode);
        stringBuilder.append(", uid = ");
        stringBuilder.append(uid);
        android.util.HwPCUtils.log("HwMediaFocusControl", stringBuilder.toString());
        if (!this.mInDestopMode || "AudioFocus_For_Phone_Ring_And_Calls".compareTo(clientId) == 0 || (33792 & android.media.AudioSystem.getDevicesForStream(3)) == 0) {
            return false;
        }
        boolean isMedia = true;
        if (aa == null || aa.getUsage() != 1) {
            isMedia = false;
        }
        if (isMedia && !android.text.TextUtils.isEmpty(pkgName)) {
            long token;
            try {
                android.pc.IHwPCManager service = android.util.HwPCUtils.getHwPCManager();
                if (service != null) {
                    token = android.os.Binder.clearCallingIdentity();
                    boolean isPackageRunningOnPCMode = service.isPackageRunningOnPCMode(pkgName, uid);
                    android.os.Binder.restoreCallingIdentity(token);
                    return isPackageRunningOnPCMode;
                }
            } catch (android.os.RemoteException e) {
                android.util.Log.e("HwMediaFocusControl", "isMediaForDPExternalDisplay RemoteException");
            } catch (Throwable th) {
                android.os.Binder.restoreCallingIdentity(token);
            }
        }
        return false;
    }

    public void desktopModeChanged(boolean desktopMode) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("changedToDestopMode desktopMode = ");
        stringBuilder.append(desktopMode);
        android.util.HwPCUtils.log("HwMediaFocusControl", stringBuilder.toString());
        if (desktopMode != this.mInDestopMode) {
            this.mInDestopMode = desktopMode;
        }
    }

    public boolean isPkgInExternalDisplay(java.lang.String pkgName) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isPkgInExternalDisplay pkgName = ");
        stringBuilder.append(pkgName);
        android.util.HwPCUtils.log("HwMediaFocusControl", stringBuilder.toString());
        if (pkgName == null) {
            return false;
        }
        synchronized (mAudioFocusLock) {
            java.util.Iterator it = this.mFocusStack.iterator();
            while (it.hasNext()) {
                com.android.server.audio.FocusRequester fr = (com.android.server.audio.FocusRequester) it.next();
                boolean isLargeDisplayApp = false;
                long token;
                try {
                    android.pc.IHwPCManager service = android.util.HwPCUtils.getHwPCManager();
                    if (service != null) {
                        token = android.os.Binder.clearCallingIdentity();
                        isLargeDisplayApp = service.isPackageRunningOnPCMode(pkgName, fr.getClientUid());
                        android.os.Binder.restoreCallingIdentity(token);
                    }
                } catch (android.os.RemoteException e) {
                    android.util.Log.e("HwMediaFocusControl", "isPkgInExternalDisplay RemoteException");
                } catch (Throwable th) {
                    android.os.Binder.restoreCallingIdentity(token);
                }
                if (fr.hasSamePackage(pkgName) && isLargeDisplayApp) {
                    return true;
                }
            }
            return false;
        }
    }

    boolean isInDesktopMode() {
        return this.mInDestopMode;
    }

    protected void travelsFocusedStack() {
        java.util.Iterator<com.android.server.audio.FocusRequester> stackIterator = this.mFocusStack.iterator();
        while (stackIterator.hasNext()) {
            com.android.server.audio.FocusRequester nextFr = (com.android.server.audio.FocusRequester) stackIterator.next();
            boolean isInExternalDisplay = isMediaForDPExternalDisplay(nextFr.getAudioAttributes(), nextFr.getClientId(), nextFr.getPackageName(), nextFr.getClientUid());
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("travelsFocusedStack isInExternalDisplay = ");
            stringBuilder.append(isInExternalDisplay);
            android.util.HwPCUtils.log("HwMediaFocusControl", stringBuilder.toString());
            nextFr.setIsInExternal(isInExternalDisplay);
        }
    }

    protected boolean isUsageAffectDesktopMedia(int usage) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" isUsageAffectDesktopMedia usage = ");
        stringBuilder.append(usage);
        android.util.HwPCUtils.log("HwMediaFocusControl", stringBuilder.toString());
        android.media.AudioManager audioManager = (android.media.AudioManager) this.mContext.getSystemService("audio");
        if (usage == 5 || usage == 1) {
            return true;
        }
        if (usage == 2 && audioManager.getMode() == 3) {
            return true;
        }
        return false;
    }
}
