package com.android.server.devicepolicy;

public class ApnUtils {
    private static final boolean APN_DEBUG = true;
    private static final java.lang.String APN_ID = "apn_id";
    private static final java.lang.String[] APN_KEYS = new java.lang.String[]{"_id", "name", "apn", "proxy", "port", "mmsproxy", "mmsport", "server", "user", "password", "mmsc", "mcc", "mnc", "numeric", "authtype", "type", "ppppwd", "protocol", "carrier_enabled", "bearer", "roaming_protocol", "mvno_match_data", "mvno_type"};
    private static final java.lang.String APN_OP_KEY = "opKey";
    private static final java.lang.String APN_SUB_ID = "sub_id";
    private static final android.net.Uri APN_URI = android.net.Uri.parse("content://telephony/carriers");
    private static final java.lang.String KEY_APN = "apn";
    private static final java.lang.String KEY_ID = "_id";
    private static final java.lang.String KEY_MCC = "mcc";
    private static final java.lang.String KEY_MNC = "mnc";
    private static final java.lang.String KEY_NAME = "name";
    private static final java.lang.String KEY_NUMERIC = "numeric";
    private static final java.lang.String KEY_TYPE = "type";
    private static final java.util.regex.Pattern PATTERN_MCC = java.util.regex.Pattern.compile("[0-9]{3}");
    private static final java.util.regex.Pattern PATTERN_MNC = java.util.regex.Pattern.compile("[0-9]{2,3}");
    private static final android.net.Uri PREFERAPN_URI = android.net.Uri.parse("content://telephony/carriers/preferapn");
    private static final java.lang.String TAG = "ApnUtils";

    public static void addApn(android.content.ContentResolver cr, java.util.Map<java.lang.String, java.lang.String> apnInfo) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("addApn: ");
        stringBuilder.append(apnInfo);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        if (getApnSelectionArgs(apnInfo).length == 0) {
            android.util.Log.e("ApnUtils", "addApn: apn params invalid");
        } else if (android.text.TextUtils.isEmpty((java.lang.String) apnInfo.get("name"))) {
            android.util.Log.e("ApnUtils", "addApn: name cannot be empty");
        } else if (android.text.TextUtils.isEmpty((java.lang.String) apnInfo.get("apn"))) {
            android.util.Log.e("ApnUtils", "addApn: apn cannot be empty");
        } else {
            java.lang.String mcc = (java.lang.String) apnInfo.get("mcc");
            if (mcc != null) {
                if (PATTERN_MCC.matcher(mcc).matches()) {
                    java.lang.String mnc = (java.lang.String) apnInfo.get("mnc");
                    if (mnc != null) {
                        if (PATTERN_MNC.matcher(mnc).matches()) {
                            java.lang.String key;
                            android.content.ContentValues contentValues = new android.content.ContentValues();
                            for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : apnInfo.entrySet()) {
                                key = (java.lang.String) entry.getKey();
                                if (!("_id".equals(key) || "numeric".equals(key))) {
                                    contentValues.put(key, (java.lang.String) entry.getValue());
                                }
                            }
                            if (((java.lang.String) apnInfo.get("type")) == null) {
                                contentValues.put("type", "default");
                            }
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append(mcc);
                            stringBuilder2.append(mnc);
                            contentValues.put("numeric", stringBuilder2.toString());
                            key = huawei.cust.HwCfgFilePolicy.getOpKey(android.telephony.SubscriptionManager.getDefaultSubscriptionId());
                            if (!android.text.TextUtils.isEmpty(key)) {
                                contentValues.put("opKey", key);
                            }
                            cr.insert(APN_URI, contentValues);
                            return;
                        }
                    }
                    android.util.Log.e("ApnUtils", "addApn: mnc empty or invalid");
                    return;
                }
            }
            android.util.Log.e("ApnUtils", "addApn: mcc empty or invalid");
        }
    }

    public static void deleteApn(android.content.ContentResolver cr, java.lang.String apnId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("deleteApn id:");
        stringBuilder.append(apnId);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        if (android.text.TextUtils.isEmpty(apnId)) {
            android.util.Log.e("ApnUtils", "deleteApn: apnId cannot be empty");
            return;
        }
        java.util.Map<java.lang.String, java.lang.String> apnInfo = getApnInfo(cr, apnId);
        if (apnInfo != null) {
            if (!apnInfo.isEmpty()) {
                cr.delete(APN_URI, "_id=?", new java.lang.String[]{apnId});
                return;
            }
        }
        android.util.Log.e("ApnUtils", "deleteApn: apnId does not exist");
    }

    public static void updateApn(android.content.ContentResolver cr, java.util.Map<java.lang.String, java.lang.String> apnInfo, java.lang.String apnId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateApn_map: ");
        stringBuilder.append(apnInfo);
        stringBuilder.append(", id=");
        stringBuilder.append(apnId);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        if (android.text.TextUtils.isEmpty(apnId)) {
            android.util.Log.e("ApnUtils", "updateApn: apnId cannot be empty");
            return;
        }
        java.util.Map<java.lang.String, java.lang.String> apn = getApnInfo(cr, apnId);
        if (apn != null) {
            if (!apn.isEmpty()) {
                if (getApnSelectionArgs(apnInfo).length == 0) {
                    android.util.Log.e("ApnUtils", "updateApn: apn params invalid");
                    return;
                }
                android.content.ContentValues values = new android.content.ContentValues();
                for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : apnInfo.entrySet()) {
                    java.lang.String key = (java.lang.String) entry.getKey();
                    if (!"_id".equals(key)) {
                        values.put(key, (java.lang.String) entry.getValue());
                    }
                }
                cr.update(APN_URI, values, "_id=?", new java.lang.String[]{apnId});
                return;
            }
        }
        android.util.Log.e("ApnUtils", "updateApn: apnId does not exist");
    }

    public static java.util.List<java.lang.String> queryApn(android.content.ContentResolver cr, java.util.Map<java.lang.String, java.lang.String> apnInfo) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("queryApn: ");
        stringBuilder.append(apnInfo);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        java.lang.String selection = getApnSelection(apnInfo);
        if (android.text.TextUtils.isEmpty(selection)) {
            android.util.Log.e("ApnUtils", "queryApn: illegal query params");
            return null;
        }
        java.lang.String[] selectionArgs = getApnSelectionArgs(apnInfo);
        if (selectionArgs.length == 0) {
            android.util.Log.e("ApnUtils", "queryApn: apn params invalid");
            return null;
        }
        android.database.Cursor cursor = cr.query(APN_URI, null, selection, selectionArgs, null);
        if (cursor == null) {
            return null;
        }
        java.util.List<java.lang.String> idlist = new java.util.ArrayList();
        while (cursor.moveToNext()) {
            idlist.add(cursor.getString(cursor.getColumnIndex("_id")));
        }
        cursor.close();
        return idlist;
    }

    public static java.util.Map<java.lang.String, java.lang.String> getApnInfo(android.content.ContentResolver cr, java.lang.String apnId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getApnParameter id: ");
        stringBuilder.append(apnId);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        java.lang.String[] strArr = new java.lang.String[1];
        int i = 0;
        strArr[0] = apnId;
        android.database.Cursor cursor = cr.query(APN_URI, null, "_id=?", strArr, null);
        if (cursor == null) {
            return null;
        }
        java.util.Map<java.lang.String, java.lang.String> apnInfo = new java.util.HashMap();
        java.lang.String[] columns = cursor.getColumnNames();
        if (cursor.moveToNext()) {
            int length = columns.length;
            while (i < length) {
                java.lang.String field = columns[i];
                apnInfo.put(field, cursor.getString(cursor.getColumnIndex(field)));
                i++;
            }
        }
        cursor.close();
        return apnInfo;
    }

    public static void setPreferApn(android.content.ContentResolver cr, java.lang.String apnId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setPreferApn:");
        stringBuilder.append(apnId);
        android.util.Log.i("ApnUtils", stringBuilder.toString());
        java.util.Map<java.lang.String, java.lang.String> apnInfo = getApnInfo(cr, apnId);
        if (apnInfo != null) {
            if (!apnInfo.isEmpty()) {
                android.content.ContentValues values = new android.content.ContentValues();
                values.put("apn_id", apnId);
                if (android.telephony.TelephonyManager.getDefault().isMultiSimEnabled()) {
                    int subId = android.telephony.SubscriptionManager.getDefaultSubscriptionId();
                    if (apnInfo.containsKey("sub_id")) {
                        subId = java.lang.Integer.parseInt((java.lang.String) apnInfo.get("sub_id"));
                    }
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("setPreferApn with sub ");
                    stringBuilder2.append(subId);
                    android.util.Log.i("ApnUtils", stringBuilder2.toString());
                    cr.update(android.content.ContentUris.withAppendedId(PREFERAPN_URI, (long) subId), values, null, null);
                } else {
                    cr.update(PREFERAPN_URI, values, null, null);
                }
                return;
            }
        }
        android.util.Log.e("ApnUtils", "set prefapn: apn does not exist");
    }

    private static java.lang.String getApnSelection(java.util.Map<java.lang.String, java.lang.String> apnInfo) {
        java.lang.String result = "";
        for (java.lang.String key : apnInfo.keySet()) {
            java.lang.StringBuilder stringBuilder;
            if (isApnKey(key)) {
                if (result.length() > 0) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(result);
                    stringBuilder.append(" and ");
                    result = stringBuilder.toString();
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(result);
                stringBuilder.append(key);
                stringBuilder.append("=?");
                result = stringBuilder.toString();
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("invalid key: ");
                stringBuilder.append(key);
                android.util.Log.e("ApnUtils", stringBuilder.toString());
                return null;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("selection: ");
        stringBuilder2.append(result);
        android.util.Log.i("ApnUtils", stringBuilder2.toString());
        return result;
    }

    private static boolean isApnKey(java.lang.String key) {
        if (android.text.TextUtils.isEmpty(key)) {
            return false;
        }
        for (java.lang.Object equals : APN_KEYS) {
            if (key.equals(equals)) {
                return true;
            }
        }
        return false;
    }

    private static java.lang.String[] getApnSelectionArgs(java.util.Map<java.lang.String, java.lang.String> apnInfo) {
        int i = 0;
        java.lang.String[] results = new java.lang.String[apnInfo.keySet().size()];
        for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : apnInfo.entrySet()) {
            java.lang.String key = (java.lang.String) entry.getKey();
            java.lang.StringBuilder stringBuilder;
            if (isApnKey(key)) {
                results[i] = (java.lang.String) entry.getValue();
                if (results[i] == null) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("null value for key: ");
                    stringBuilder.append(key);
                    android.util.Log.e("ApnUtils", stringBuilder.toString());
                    return new java.lang.String[0];
                }
                i++;
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("invalid key: ");
                stringBuilder.append(key);
                android.util.Log.e("ApnUtils", stringBuilder.toString());
                return new java.lang.String[0];
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("selectionArgs: ");
        stringBuilder2.append(java.util.Arrays.toString(results));
        android.util.Log.i("ApnUtils", stringBuilder2.toString());
        return results;
    }
}
