package com.android.server.devicepolicy;

public class CertInstallHelper {
    private static final java.lang.String TAG = "DPMS_CerInstallHelper";

    private static boolean isCa(java.security.cert.X509Certificate cert) {
        com.android.org.bouncycastle.asn1.ASN1InputStream asn1InputString = null;
        try {
            byte[] asn1EncodedBytes = cert.getExtensionValue("2.5.29.19");
            if (asn1EncodedBytes == null) {
                return false;
            }
            com.android.org.bouncycastle.asn1.DEROctetString derOctetString = (com.android.org.bouncycastle.asn1.DEROctetString) new com.android.org.bouncycastle.asn1.ASN1InputStream(asn1EncodedBytes).readObject();
            if (derOctetString == null) {
                return false;
            }
            return com.android.org.bouncycastle.asn1.x509.BasicConstraints.getInstance((com.android.org.bouncycastle.asn1.ASN1Sequence) new com.android.org.bouncycastle.asn1.ASN1InputStream(derOctetString.getOctets()).readObject()).isCA();
        } catch (java.io.IOException e) {
            if (asn1InputString != null) {
                try {
                    asn1InputString.close();
                } catch (java.io.IOException e2) {
                    android.util.Log.d("DPMS_CerInstallHelper", "IOException when close asn1InputString");
                }
            }
            return false;
        }
    }

    public static boolean installPkcs12Cert(java.lang.String password, byte[] certBuffer, java.lang.String certAlias, int certInstallType) throws java.lang.Exception {
        android.util.Log.d("DPMS_CerInstallHelper", "#extracted pkcs12 certs from cert buffer");
        java.security.KeyStore keystore = java.security.KeyStore.getInstance("PKCS12");
        keystore.load(new java.io.ByteArrayInputStream(certBuffer), password.toCharArray());
        java.util.Enumeration<java.lang.String> aliases = keystore.aliases();
        if (!aliases.hasMoreElements()) {
            return false;
        }
        java.security.KeyStore.PasswordProtection pwd = new java.security.KeyStore.PasswordProtection(password.toCharArray());
        while (aliases.hasMoreElements()) {
            java.lang.String alias = (java.lang.String) aliases.nextElement();
            if (keystore.isKeyEntry(alias)) {
                java.security.KeyStore.Entry entry = keystore.getEntry(alias, pwd);
                if (entry instanceof java.security.KeyStore.PrivateKeyEntry) {
                    return installCertToKeyStore((java.security.KeyStore.PrivateKeyEntry) entry, certAlias, certInstallType);
                }
            } else {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Skip non-key entry, alias = ");
                stringBuilder.append(alias);
                android.util.Log.d("DPMS_CerInstallHelper", stringBuilder.toString());
            }
        }
        return true;
    }

    private static boolean installCertToKeyStore(java.security.KeyStore.PrivateKeyEntry entry, java.lang.String alias, int certInstallType) {
        java.security.PrivateKey userKey = entry.getPrivateKey();
        java.security.cert.X509Certificate userCert = (java.security.cert.X509Certificate) entry.getCertificate();
        java.security.cert.Certificate[] certs = entry.getCertificateChain();
        java.util.List<java.security.cert.X509Certificate> caCerts = new java.util.ArrayList(certs.length);
        for (java.security.cert.Certificate c : certs) {
            java.security.cert.X509Certificate cert = (java.security.cert.X509Certificate) c;
            if (isCa(cert)) {
                caCerts.add(cert);
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("# ca certs extracted = ");
        stringBuilder.append(caCerts.size());
        android.util.Log.d("DPMS_CerInstallHelper", stringBuilder.toString());
        return com.android.server.devicepolicy.CertInstaller.installCert(alias == null ? "" : alias, userKey, userCert, caCerts, certInstallType);
    }

    public static boolean installX509Cert(byte[] bytes, java.lang.String alias, int certInstallType) {
        if (bytes == null) {
            return false;
        }
        java.security.cert.X509Certificate userCert = null;
        java.util.List<java.security.cert.X509Certificate> caCerts = new java.util.ArrayList();
        try {
            java.security.cert.X509Certificate cert = (java.security.cert.X509Certificate) java.security.cert.CertificateFactory.getInstance("X.509").generateCertificate(new java.io.ByteArrayInputStream(bytes));
            if (isCa(cert)) {
                android.util.Log.d("DPMS_CerInstallHelper", "got a CA cert");
                caCerts.add(cert);
            } else {
                android.util.Log.d("DPMS_CerInstallHelper", "got a user cert");
                userCert = cert;
            }
        } catch (java.security.cert.CertificateException e) {
            android.util.Log.w("DPMS_CerInstallHelper", "install X509 Cert error");
        }
        return com.android.server.devicepolicy.CertInstaller.installCert(alias == null ? "" : alias, null, userCert, caCerts, certInstallType);
    }
}
