package com.android.server.devicepolicy;

public final class StorageUtils extends com.huawei.utils.reflect.EasyInvokeUtils {
    private static final java.lang.String TAG = "StorageUtils";
    private static final java.lang.String USB_STORAGE = "usb";

    public static java.lang.String[] getSdcardDirFromSystem(android.content.Context context) {
        if (context == null) {
            android.util.Log.e("StorageUtils", "context is null");
            return null;
        }
        int size;
        int i;
        android.os.storage.StorageVolume[] sv = ((android.os.storage.StorageManager) context.getSystemService("storage")).getVolumeList();
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        for (android.os.storage.StorageVolume storageVolume : sv) {
            if (isVolumeExternalSDcard(context, storageVolume)) {
                list.add(storageVolume.getId());
            }
        }
        if (list.size() == 0) {
            android.util.Log.w("StorageUtils", "there is no sdcard on device.");
            return null;
        }
        java.lang.String[] mStr = new java.lang.String[list.size()];
        size = list.size();
        for (i = 0; i < size; i++) {
            mStr[i] = (java.lang.String) list.get(i);
        }
        return mStr;
    }

    public static boolean hasExternalSdcard(android.content.Context context) {
        for (android.os.storage.StorageVolume volume : ((android.os.storage.StorageManager) context.getSystemService("storage")).getVolumeList()) {
            if (isVolumeExternalSDcard(context, volume)) {
                return true;
            }
        }
        return false;
    }

    public static boolean isExternalSdcardMountedRW(android.content.Context context) {
        return isVolumeMountedRW(getExternalSdcardVolume(context));
    }

    public static boolean isExternalSdcardMountedRO(android.content.Context context) {
        return isVolumeMountedRO(getExternalSdcardVolume(context));
    }

    public static boolean isExternalSdcardNotStable(android.content.Context context) {
        return isVolumeNotStable(getExternalSdcardVolume(context));
    }

    public static android.os.storage.StorageVolume getExternalSdcardVolume(android.content.Context context) {
        for (android.os.storage.StorageVolume volume : ((android.os.storage.StorageManager) context.getSystemService("storage")).getVolumeList()) {
            if (isVolumeExternalSDcard(context, volume)) {
                return volume;
            }
        }
        return null;
    }

    public static boolean isVolumeExternalSDcard(android.content.Context context, android.os.storage.StorageVolume storageVolume) {
        if (storageVolume != null) {
            if (context != null) {
                if (storageVolume.isPrimary() || !storageVolume.isRemovable()) {
                    return false;
                }
                android.os.storage.StorageManager sm = (android.os.storage.StorageManager) context.getSystemService("storage");
                if (storageVolume.getUuid() == null) {
                    return false;
                }
                android.os.storage.VolumeInfo volumeInfo = sm.findVolumeByUuid(storageVolume.getUuid());
                if (volumeInfo == null) {
                    return false;
                }
                android.os.storage.DiskInfo diskInfo = volumeInfo.getDisk();
                if (diskInfo != null) {
                    return diskInfo.isSd();
                }
                return false;
            }
        }
        return false;
    }

    public static boolean isVolumeMountedRW(android.os.storage.StorageVolume sv) {
        if (sv == null) {
            return false;
        }
        if ("mounted".equals(sv.getState())) {
            return true;
        }
        return false;
    }

    public static boolean isVolumeMountedRO(android.os.storage.StorageVolume sv) {
        if (sv == null) {
            return false;
        }
        if ("mounted_ro".equals(sv.getState())) {
            return true;
        }
        return false;
    }

    public static boolean isVolumeNotStable(android.os.storage.StorageVolume sv) {
        if (sv == null) {
            return false;
        }
        java.lang.String state = sv.getState();
        if (!"checking".equals(state)) {
            if (!"ejecting".equals(state)) {
                return false;
            }
        }
        return true;
    }

    public static boolean isVolumeUsb(android.os.storage.StorageVolume sv) {
        if (sv != null) {
            if (sv.getPath() != null) {
                return sv.getPath().toLowerCase(java.util.Locale.US).contains("usb");
            }
        }
        return false;
    }

    public static android.os.storage.IStorageManager getMountService() {
        android.os.IBinder service = android.os.ServiceManager.getService("mount");
        if (service != null) {
            return android.os.storage.IStorageManager.Stub.asInterface(service);
        }
        android.util.Log.e("StorageUtils", "Can't get mount service");
        return null;
    }

    public static boolean doMountorUnMountSdcardPath(java.lang.String[] VolIds, boolean isMount) {
        java.lang.StringBuilder stringBuilder;
        if (VolIds != null) {
            if (VolIds.length != 0) {
                android.os.storage.IStorageManager mountService = getMountService();
                if (mountService == null) {
                    android.util.Log.e("StorageUtils", "unMount cannot get IMountService service.");
                    return false;
                }
                long current = java.lang.System.currentTimeMillis();
                int i = 0;
                while (i < VolIds.length) {
                    try {
                        if (isMount) {
                            mountService.mount(VolIds[i]);
                        } else {
                            mountService.unmount(VolIds[i]);
                        }
                        i++;
                    } catch (java.lang.Exception e) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("mount or unmount exception is  ");
                        stringBuilder.append(e);
                        stringBuilder.append(" and ");
                        android.util.Log.e("StorageUtils", stringBuilder.toString());
                        return false;
                    }
                }
                long end = java.lang.System.currentTimeMillis() - current;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mount and unmount cost time is ");
                stringBuilder.append(end);
                android.util.Log.w("StorageUtils", stringBuilder.toString());
                return true;
            }
        }
        return false;
    }

    public static boolean isSwitchPrimaryVolumeSupported() {
        return android.os.SystemProperties.getBoolean("ro.config.switchPrimaryVolume", false);
    }

    public static boolean doMount(android.content.Context context) {
        try {
            java.lang.String[] paths = getSdcardDirFromSystem(context);
            if (paths == null) {
                android.util.Log.w("StorageUtils", "there is no sdcard.");
                return true;
            } else if (doMountorUnMountSdcardPath(paths, true)) {
                return true;
            } else {
                android.util.Log.e("StorageUtils", "can't Mount Volume!");
                return false;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mount exception is ");
            stringBuilder.append(e);
            android.util.Log.e("StorageUtils", stringBuilder.toString());
            return false;
        }
    }

    public static boolean doUnMount(android.content.Context context) {
        try {
            java.lang.String[] paths = getSdcardDirFromSystem(context);
            if (paths == null) {
                android.util.Log.w("StorageUtils", "there is no sdcard.");
                return true;
            } else if (doMountorUnMountSdcardPath(paths, false)) {
                return true;
            } else {
                android.util.Log.e("StorageUtils", "can't unMount Volume!");
                return false;
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("unmount exception is ");
            stringBuilder.append(e);
            android.util.Log.e("StorageUtils", stringBuilder.toString());
            return false;
        }
    }
}
