package com.android.server.devicepolicy.plugins;

public class DeviceFirewallManagerImpl extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String GLOBAL_PROXY = "global-proxy";
    private static final java.lang.String MDM_FIREWALL_PERMISSION = "com.huawei.permission.sec.MDM_FIREWALL";
    public static final java.lang.String TAG = "DeviceFirewallManagerImpl";

    public DeviceFirewallManagerImpl(android.content.Context context) {
        super(context);
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "getFirewallPolicyStruct");
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("global-proxy", com.android.server.devicepolicy.PolicyStruct.PolicyType.CONFIGURATION, new java.lang.String[]{"hostName", "proxyPort", "exclusionList"});
        return struct;
    }

    public boolean onInit(com.android.server.devicepolicy.PolicyStruct policyStruct) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onInit");
        if (policyStruct == null) {
            return false;
        }
        return true;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_FIREWALL", "NEED MDM_FIREWALL PERMISSION");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onSetPolicy");
        if ("global-proxy".equals(policyName)) {
            android.net.ConnectivityManager connectivityManager = (android.net.ConnectivityManager) this.mContext.getSystemService("connectivity");
            java.lang.String hostName = policyData.getString("hostName");
            int proxyPort = 0;
            if (!(hostName == null || policyData.getString("proxyPort") == null)) {
                proxyPort = java.lang.Integer.parseInt(policyData.getString("proxyPort"));
            }
            android.net.ProxyInfo proxyInfo = new android.net.ProxyInfo(hostName, proxyPort, policyData.getString("exclusionList"));
            long ident = android.os.Binder.clearCallingIdentity();
            try {
                connectivityManager.setGlobalProxy(proxyInfo);
                if (connectivityManager.getGlobalProxy() == null && hostName == null) {
                    com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "Set null proxy.");
                    return true;
                } else if (!proxyInfo.equals(connectivityManager.getGlobalProxy())) {
                    com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "Invalid or repeated proxy properties, ignoring.");
                    return false;
                }
            } finally {
                android.os.Binder.restoreCallingIdentity(ident);
            }
        }
        return true;
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onRemovePolicy");
        return true;
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onGetPolicy");
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onActiveAdminRemoved");
        return true;
    }

    public void onActiveAdminRemovedCompleted(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        com.android.server.devicepolicy.HwLog.i("DeviceFirewallManagerImpl", "onActiveAdminRemovedCompleted");
        android.net.ConnectivityManager connectivityManager = (android.net.ConnectivityManager) this.mContext.getSystemService("connectivity");
        android.os.Bundle bundle = new huawei.android.app.admin.HwDevicePolicyManagerEx().getPolicy(null, "global-proxy");
        if (bundle == null || bundle.getString("hostName") == null || bundle.getString("proxyPort") == null) {
            long ident = android.os.Binder.clearCallingIdentity();
            try {
                connectivityManager.setGlobalProxy(null);
            } finally {
                android.os.Binder.restoreCallingIdentity(ident);
            }
        } else {
            android.net.ProxyInfo proxyInfo = new android.net.ProxyInfo(bundle.getString("hostName"), java.lang.Integer.parseInt(bundle.getString("proxyPort")), bundle.getString("exclusionList"));
            long ident2 = android.os.Binder.clearCallingIdentity();
            try {
                connectivityManager.setGlobalProxy(proxyInfo);
            } finally {
                android.os.Binder.restoreCallingIdentity(ident2);
            }
        }
    }
}
