package com.android.server.devicepolicy.plugins;

public class DeviceP2PPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String DEVICE_P2P_POLICY_ITEM_NAME = "wifi_p2p_item_policy_name";
    private static final java.lang.String DEVICE_P2P_POLICY_ITEM_VALUE = "wifi_p2p_policy_item_value";
    private static final java.lang.String LOCATION_CONTROL_PERMSSION = "com.huawei.permission.sec.MDM_WIFI";
    public static final java.lang.String TAG = com.android.server.devicepolicy.plugins.DeviceP2PPlugin.class.getSimpleName();
    private boolean isWiFiDirectConnected = false;
    private android.net.wifi.p2p.WifiP2pManager.Channel mChannel = null;
    android.net.wifi.p2p.WifiP2pManager.ConnectionInfoListener mConnectionInfoListener = null;
    private android.content.Context mContext;
    private android.net.wifi.p2p.WifiP2pManager mWifiP2pManager;

    public DeviceP2PPlugin(android.content.Context context) {
        super(context);
        this.mContext = context;
        this.mConnectionInfoListener = new android.net.wifi.p2p.WifiP2pManager.ConnectionInfoListener() {
            public void onConnectionInfoAvailable(android.net.wifi.p2p.WifiP2pInfo info) {
                if (info != null && info.groupFormed) {
                    com.android.server.devicepolicy.plugins.DeviceP2PPlugin.this.isWiFiDirectConnected = true;
                }
            }
        };
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("wifi_p2p_item_policy_name", com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE, new java.lang.String[]{"wifi_p2p_policy_item_value"});
        return struct;
    }

    public boolean onInit(com.android.server.devicepolicy.PolicyStruct policyStruct) {
        if (policyStruct == null) {
            return false;
        }
        return true;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_WIFI", "need permission com.huawei.permission.sec.MDM");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        if (policyName == null) {
            return false;
        }
        if ("wifi_p2p_item_policy_name".equals(policyName)) {
            disConnectWifiDirect();
        }
        return true;
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        if (policyName == null) {
            return false;
        }
        if ("wifi_p2p_item_policy_name".equals(policyName)) {
            disConnectWifiDirect();
        }
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        return true;
    }

    private void disConnectWifiDirect() {
        if (this.mWifiP2pManager == null || this.mChannel == null) {
            this.mWifiP2pManager = (android.net.wifi.p2p.WifiP2pManager) this.mContext.getSystemService("wifip2p");
            this.mChannel = this.mWifiP2pManager.initialize(this.mContext, this.mContext.getMainLooper(), null);
        }
        this.mWifiP2pManager.requestConnectionInfo(this.mChannel, this.mConnectionInfoListener);
        if (this.mWifiP2pManager != null && this.mChannel != null && this.isWiFiDirectConnected) {
            this.mWifiP2pManager.removeGroup(this.mChannel, new android.net.wifi.p2p.WifiP2pManager.ActionListener() {
                public void onSuccess() {
                }

                public void onFailure(int reason) {
                }
            });
        }
    }
}
