package com.android.server.devicepolicy.plugins;

public class DevicePackageManagerPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String ALLOW_NOTIFY_DB_KEY = "allow_notification_white_apps";
    private static final java.lang.String BROADCAST_PKG_NAME = "com.huawei.systemmanager";
    private static final java.lang.String NOTIFICATION_INTENT_ACTION = "com.huawei.devicepolicy.action.POLICY_CHANGED";
    private static final java.lang.String NOTIFY_APP_WHITE = "notification-app-bt-white-list";
    private static final java.lang.String POLICY_NAME = "policy_name";
    private static final java.lang.String POLICY_UPDATE_NFN_WHITE_LIST_DATA = "com.huawei.systemmanager.update_notification_white_list_data";
    public static final java.lang.String TAG = com.android.server.devicepolicy.plugins.DevicePackageManagerPlugin.class.getSimpleName();

    public DevicePackageManagerPlugin(android.content.Context context) {
        super(context);
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.HwLog.i(TAG, "getPolicyStruct");
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("notification-app-bt-white-list", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value"});
        return struct;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.i(TAG, "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_APP_MANAGEMENT", "does not have app_management MDM permission!");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onSetPolicy");
        if (isNotEffective(who, policyName, policyData, effective)) {
            return false;
        }
        boolean z = true;
        if (policyName.hashCode() == 496906511) {
            if (policyName.equals("notification-app-bt-white-list")) {
                z = false;
            }
        }
        if (z) {
            return true;
        }
        return setNotificationDataToDb(policyData);
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onRemovePolicy");
        if (isNotEffective(who, policyName, policyData, effective)) {
            return false;
        }
        boolean z = true;
        if (policyName.hashCode() == 496906511) {
            if (policyName.equals("notification-app-bt-white-list")) {
                z = false;
            }
        }
        if (z) {
            return true;
        }
        z = removeNotificationDataFromDb(policyData);
        if (z) {
            sendBroadCastForHwSystemManager();
        }
        return z;
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onGetPolicy");
        if (isNotEffective(who, policyName, policyData, true)) {
            return false;
        }
        boolean z = true;
        if (policyName.hashCode() == 496906511) {
            if (policyName.equals("notification-app-bt-white-list")) {
                z = false;
            }
        }
        if (z) {
            return true;
        }
        return getNotificationData(policyData);
    }

    public void onSetPolicyCompleted(android.content.ComponentName who, java.lang.String policyName, boolean changed) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onSetPolicyCompleted");
        if (policyName != null && policyName.equals("notification-app-bt-white-list") && changed) {
            sendBroadCastForHwSystemManager();
        }
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> removedPolicies) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onActiveAdminRemoved");
        if (removedPolicies != null && removedPolicies.size() > 0) {
            int k = removedPolicies.size();
            for (int j = 0; j < k; j++) {
                if (((com.android.server.devicepolicy.PolicyStruct.PolicyItem) removedPolicies.get(j)).getPolicyName().equals("notification-app-bt-white-list")) {
                    cleanAllowNotificationDb();
                    sendBroadCastForHwSystemManager();
                }
            }
        }
        return true;
    }

    private void cleanAllowNotificationDb() {
        android.provider.Settings.Global.putStringForUser(this.mContext.getContentResolver(), "allow_notification_white_apps", "", 0);
    }

    public boolean isNotEffective(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        if (policyData != null && "notification-app-bt-white-list".equals(policyName)) {
            java.util.ArrayList<java.lang.String> packageNames = policyData.getStringArrayList("value");
            if (!com.android.server.devicepolicy.HwDevicePolicyManagerServiceUtil.isValidatePackageNames(packageNames)) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("packageName:");
                stringBuilder.append(packageNames);
                stringBuilder.append(" is invalid.");
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        return false;
    }

    private boolean removeNotificationDataFromDb(android.os.Bundle bundle) {
        java.util.ArrayList<java.lang.String> listData = bundle.getStringArrayList("value");
        if (listData != null) {
            if (!listData.isEmpty()) {
                long identityToken = android.os.Binder.clearCallingIdentity();
                boolean result = false;
                try {
                    java.util.ArrayList<java.lang.String> notifnlistData = getNotificationDataFromDb();
                    java.lang.StringBuffer buffer = new java.lang.StringBuffer();
                    int size = listData.size();
                    for (int i = 0; i < size; i++) {
                        java.lang.String notifyData = (java.lang.String) listData.get(i);
                        if (notifnlistData.contains(notifyData)) {
                            notifnlistData.remove(notifyData);
                        } else {
                            java.lang.String str = new java.lang.StringBuilder();
                            str.append(notifyData);
                            str.append(";");
                            buffer.append(str.toString());
                        }
                    }
                    boolean result2 = android.provider.Settings.Global.putStringForUser(this.mContext.getContentResolver(), "allow_notification_white_apps", formatNotificationData(notifnlistData, buffer.toString()), 0);
                    return result2;
                } finally {
                    android.os.Binder.restoreCallingIdentity(identityToken);
                }
            }
        }
        return false;
    }

    private boolean getNotificationData(android.os.Bundle policyData) {
        if (policyData == null) {
            policyData = new android.os.Bundle();
        }
        policyData.putStringArrayList("value", getNotificationDataFromDb());
        return true;
    }

    private java.util.ArrayList<java.lang.String> getNotificationDataFromDb() {
        java.lang.String notificationWhiteApps = android.provider.Settings.Global.getStringForUser(this.mContext.getContentResolver(), "allow_notification_white_apps", 0);
        if (android.text.TextUtils.isEmpty(notificationWhiteApps)) {
            return null;
        }
        java.util.ArrayList<java.lang.String> list = new java.util.ArrayList();
        java.lang.String[] notificationWhiteAppsArray = notificationWhiteApps.split(";");
        if (notificationWhiteAppsArray.length > 0) {
            java.util.Collections.addAll(list, notificationWhiteAppsArray);
        }
        return list;
    }

    private boolean setNotificationDataToDb(android.os.Bundle bundle) {
        java.util.ArrayList<java.lang.String> list = bundle.getStringArrayList("value");
        boolean result = false;
        if (list == null || list.isEmpty()) {
            return false;
        }
        long identityToken = android.os.Binder.clearCallingIdentity();
        try {
            result = android.provider.Settings.Global.putStringForUser(this.mContext.getContentResolver(), "allow_notification_white_apps", formatNotificationData(list, android.provider.Settings.Global.getStringForUser(this.mContext.getContentResolver(), "allow_notification_white_apps", 0)), 0);
            return result;
        } finally {
            android.os.Binder.restoreCallingIdentity(identityToken);
        }
    }

    private java.lang.String formatNotificationData(java.util.ArrayList<java.lang.String> list, java.lang.String notificationDatas) {
        java.lang.StringBuffer buffer = android.text.TextUtils.isEmpty(notificationDatas) ? new java.lang.StringBuffer() : new java.lang.StringBuffer(notificationDatas);
        int size = list.size();
        for (int i = 0; i < size; i++) {
            java.lang.String str = new java.lang.StringBuilder();
            str.append((java.lang.String) list.get(i));
            str.append(";");
            buffer.append(str.toString());
        }
        return buffer.toString();
    }

    private void sendBroadCastForHwSystemManager() {
        com.android.server.devicepolicy.HwLog.i(TAG, "sendBroadCastForHwSystemManager");
        long callingId = android.os.Binder.clearCallingIdentity();
        try {
            android.content.Intent intent = new android.content.Intent("com.huawei.devicepolicy.action.POLICY_CHANGED");
            intent.setPackage("com.huawei.systemmanager");
            intent.putExtra("policy_name", "com.huawei.systemmanager.update_notification_white_list_data");
            this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.of(android.app.ActivityManager.getCurrentUser()));
        } finally {
            android.os.Binder.restoreCallingIdentity(callingId);
        }
    }
}
