package com.android.server.devicepolicy.plugins;

public class DeviceStorageManagerPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String DISABLE_SDWRITING = "disable-sdwriting";
    private static final int MSG_DO_DISABLE = 0;
    private static final int MSG_DO_ENABLE = 1;
    private static final java.lang.String PERMISSION_MDM_SDCARD_WRITING = "com.huawei.permission.sec.MDM_SDCARD";
    private static final java.lang.String SD_CRYPT_STATE_DECRYPTING = "decrypting";
    private static final java.lang.String SD_CRYPT_STATE_ENCRYPTING = "encrypting";
    public static final java.lang.String TAG = "DeviceStorageManagerPlugin";
    private static final java.lang.Object mLock = new java.lang.Object();
    private static boolean mUnfinishedBusiness = false;
    private android.content.Context mContext;
    private com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.HwPluginHandler mHandler;
    private android.os.HandlerThread mThread = new android.os.HandlerThread("DeviceStorageManagerPlugin");

    private final class HwPluginHandler extends android.os.Handler {
        public HwPluginHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 0:
                    if (com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.this.shouldDoDisableWriting()) {
                        com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.this.doMountandUnMountSdcard();
                        break;
                    }
                    break;
                case 1:
                    if (com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.this.shouldDoEnableWriting()) {
                        com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.this.doMountandUnMountSdcard();
                        break;
                    }
                    break;
                default:
                    break;
            }
            synchronized (com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.mLock) {
                com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.mUnfinishedBusiness = false;
            }
        }
    }

    public DeviceStorageManagerPlugin(android.content.Context context) {
        super(context);
        this.mThread.start();
        this.mHandler = new com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.HwPluginHandler(this.mThread.getLooper());
        this.mContext = context;
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "getPolicyStruct");
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("disable-sdwriting", com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE, new java.lang.String[]{"value"});
        return struct;
    }

    public boolean onInit(com.android.server.devicepolicy.PolicyStruct policyStruct) {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "onInit");
        if (policyStruct == null) {
            return false;
        }
        return true;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_SDCARD", "does not have com.huawei.permission.sec.MDM_SDCARD permission!");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onSetPolicy + policyName :");
        stringBuilder.append(policyName);
        stringBuilder.append(", changed :");
        stringBuilder.append(changed);
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", stringBuilder.toString());
        if (policyName != null) {
            if (policyData != null) {
                return doExecutePolicy(policyName, policyData, changed);
            }
        }
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "policyData is null");
        return false;
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onRemovePolicy+ policyName :");
        stringBuilder.append(policyName);
        stringBuilder.append(", changed :");
        stringBuilder.append(changed);
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", stringBuilder.toString());
        if (policyName != null) {
            if (policyData != null) {
                return doRemovePolicy(policyName, changed);
            }
        }
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "policyData is null");
        return false;
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "onGetPolicy");
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "onActiveAdminRemoved");
        return true;
    }

    public void onActiveAdminRemovedCompleted(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> removedPolicies) {
        com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "onActiveAdminRemovedCompleted");
        if (removedPolicies == null) {
            com.android.server.devicepolicy.HwLog.i("DeviceStorageManagerPlugin", "removedPolicies is null");
            return;
        }
        int size = removedPolicies.size();
        for (int i = 0; i < size; i++) {
            com.android.server.devicepolicy.PolicyStruct.PolicyItem policyItem = (com.android.server.devicepolicy.PolicyStruct.PolicyItem) removedPolicies.get(i);
            doRemovePolicy(policyItem.getPolicyName(), policyItem.isGlobalPolicyChanged());
        }
    }

    /* JADX WARNING: Missing block: B:24:0x003a, code:
            if (r7.getBoolean("value") == false) goto L_0x0042;
     */
    /* JADX WARNING: Missing block: B:25:0x003c, code:
            r5.mHandler.sendEmptyMessage(0);
     */
    /* JADX WARNING: Missing block: B:26:0x0042, code:
            r5.mHandler.sendEmptyMessage(1);
     */
    private boolean doExecutePolicy(java.lang.String r6, android.os.Bundle r7, boolean r8) {
        /*
        r5 = this;
        r0 = 1;
        if (r8 != 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = -1;
        r2 = r6.hashCode();
        r3 = -1002053434; // 0xffffffffc445e0c6 float:-791.5121 double:NaN;
        r4 = 0;
        if (r2 == r3) goto L_0x0010;
    L_0x000f:
        goto L_0x0019;
    L_0x0010:
        r2 = "disable-sdwriting";
        r2 = r6.equals(r2);
        if (r2 == 0) goto L_0x0019;
    L_0x0018:
        r1 = r4;
    L_0x0019:
        if (r1 == 0) goto L_0x001c;
    L_0x001b:
        goto L_0x0048;
    L_0x001c:
        r1 = mLock;
        monitor-enter(r1);
        r2 = mUnfinishedBusiness;	 Catch:{ all -> 0x004b }
        if (r2 != 0) goto L_0x0049;
    L_0x0023:
        r2 = r5.isExternalSdcardDecryptingOrEncrypting();	 Catch:{ all -> 0x004b }
        if (r2 != 0) goto L_0x0049;
    L_0x0029:
        r2 = r5.isExternalSdcardNotStable();	 Catch:{ all -> 0x004b }
        if (r2 == 0) goto L_0x0030;
    L_0x002f:
        goto L_0x0049;
    L_0x0030:
        mUnfinishedBusiness = r0;	 Catch:{ all -> 0x004b }
        monitor-exit(r1);	 Catch:{ all -> 0x004b }
        r1 = "value";
        r1 = r7.getBoolean(r1);
        if (r1 == 0) goto L_0x0042;
    L_0x003c:
        r2 = r5.mHandler;
        r2.sendEmptyMessage(r4);
        goto L_0x0048;
    L_0x0042:
        r2 = r5.mHandler;
        r2.sendEmptyMessage(r0);
    L_0x0048:
        return r0;
    L_0x0049:
        monitor-exit(r1);	 Catch:{ all -> 0x004b }
        return r4;
    L_0x004b:
        r0 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x004b }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.doExecutePolicy(java.lang.String, android.os.Bundle, boolean):boolean");
    }

    /* JADX WARNING: Missing block: B:23:0x0033, code:
            r5.mHandler.sendEmptyMessage(1);
     */
    private boolean doRemovePolicy(java.lang.String r6, boolean r7) {
        /*
        r5 = this;
        r0 = 1;
        if (r7 != 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = -1;
        r2 = r6.hashCode();
        r3 = -1002053434; // 0xffffffffc445e0c6 float:-791.5121 double:NaN;
        r4 = 0;
        if (r2 == r3) goto L_0x0010;
    L_0x000f:
        goto L_0x0019;
    L_0x0010:
        r2 = "disable-sdwriting";
        r2 = r6.equals(r2);
        if (r2 == 0) goto L_0x0019;
    L_0x0018:
        r1 = r4;
    L_0x0019:
        if (r1 == 0) goto L_0x001c;
    L_0x001b:
        goto L_0x0039;
    L_0x001c:
        r1 = mLock;
        monitor-enter(r1);
        r2 = mUnfinishedBusiness;	 Catch:{ all -> 0x003c }
        if (r2 != 0) goto L_0x003a;
    L_0x0023:
        r2 = r5.isExternalSdcardDecryptingOrEncrypting();	 Catch:{ all -> 0x003c }
        if (r2 != 0) goto L_0x003a;
    L_0x0029:
        r2 = r5.isExternalSdcardNotStable();	 Catch:{ all -> 0x003c }
        if (r2 == 0) goto L_0x0030;
    L_0x002f:
        goto L_0x003a;
    L_0x0030:
        mUnfinishedBusiness = r0;	 Catch:{ all -> 0x003c }
        monitor-exit(r1);	 Catch:{ all -> 0x003c }
        r1 = r5.mHandler;
        r1.sendEmptyMessage(r0);
    L_0x0039:
        return r0;
    L_0x003a:
        monitor-exit(r1);	 Catch:{ all -> 0x003c }
        return r4;
    L_0x003c:
        r0 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x003c }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.devicepolicy.plugins.DeviceStorageManagerPlugin.doRemovePolicy(java.lang.String, boolean):boolean");
    }

    private boolean shouldDoEnableWriting() {
        if (com.android.server.devicepolicy.StorageUtils.isExternalSdcardMountedRO(this.mContext)) {
            return true;
        }
        return false;
    }

    private boolean shouldDoDisableWriting() {
        if (com.android.server.devicepolicy.StorageUtils.isExternalSdcardMountedRW(this.mContext)) {
            return true;
        }
        return false;
    }

    private void doMountandUnMountSdcard() {
        com.android.server.devicepolicy.StorageUtils.doUnMount(this.mContext);
        com.android.server.devicepolicy.StorageUtils.doMount(this.mContext);
    }

    private boolean isExternalSdcardNotStable() {
        long token = android.os.Binder.clearCallingIdentity();
        try {
            boolean isExternalSdcardNotStable = com.android.server.devicepolicy.StorageUtils.isExternalSdcardNotStable(this.mContext);
            return isExternalSdcardNotStable;
        } finally {
            android.os.Binder.restoreCallingIdentity(token);
        }
    }

    private boolean isExternalSdcardDecryptingOrEncrypting() {
        long token = android.os.Binder.clearCallingIdentity();
        try {
            boolean z;
            java.lang.String state = android.os.SystemProperties.get("vold.cryptsd.state", "none");
            if (!state.equals("decrypting")) {
                if (!state.equals("encrypting")) {
                    z = false;
                    android.os.Binder.restoreCallingIdentity(token);
                    return z;
                }
            }
            z = true;
            android.os.Binder.restoreCallingIdentity(token);
            return z;
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(token);
        }
    }
}
