package com.android.server.devicepolicy.plugins;

public class DeviceWifiPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String ACTION_WIFI_DEVICE_POLICY = "com.huawei.devicepolicy.action.POLICY_CHANGED";
    private static final int CLEAR_MODE = 2;
    private static final java.lang.String ENTERPRISE_CONFIG_ITEM = "profile-enterprise-config/enterprise-config-item";
    private static final java.lang.String KEY_BLACK_LIST_CHANGE_MODE = "set_or_remove";
    private static final java.lang.String KEY_BLACK_LIST_SSID = "ssid-blacklist";
    private static final java.lang.String KEY_CLASS_NAME = "class_name";
    private static final java.lang.String KEY_PACKAGE_NAME = "package_name";
    private static final java.lang.String KEY_SECURE_LEVEL = "securelevel";
    private static final java.lang.String KEY_SECURITY_LEVEL = "securitylevel";
    private static final java.lang.String KEY_VALUE = "value";
    private static final java.lang.String KEY_WIFI_POLICY_CATEGORY = "wifi_policy_category";
    private static final java.lang.String KEY_WIFI_POLICY_CHANGE_MODE = "change_mode";
    private static final java.lang.String KEY_WIFI_POLICY_DATA = "wifi_policy_data";
    private static final java.lang.String MDM_WIFI_PERMISSION = "com.huawei.permission.sec.MDM_WIFI";
    private static final int OP_AUTO_CONNECT = 4;
    private static final int OP_BLACKLIST = 1;
    private static final int OP_BLACKLIST_ADD = 0;
    private static final int OP_BLACKLIST_CLEAR = 2;
    private static final int OP_BLACKLIST_REMOVE = 1;
    private static final int OP_ENTERPRISE_CONFIG_LIST = 3;
    private static final int OP_OPEN_HOTSPOT = 5;
    private static final int OP_RESTRICT_NETWORK = 2;
    private static final int OP_SECURITY_LEVEL = 0;
    private static final int OP_WHITELIST = 6;
    private static final java.lang.String PACKAGE_ANDROID = "android";
    private static final java.lang.String POLICY_AUTO_CONNECT = "policy-auto-connect";
    private static final java.lang.String POLICY_OPEN_HOTSPOT = "policy-open-hotspot";
    private static final java.lang.String POLICY_RESTRICT_NETWORK = "policy-restrict-network";
    private static final java.lang.String PROFILE_ENTERPRISE_CONFIG = "profile-enterprise-config";
    private static final int REMOVE_MODE = 1;
    private static final int SECURITY_LEVEL_1 = 1;
    private static final int SET_MODE = 0;
    private static final java.lang.String TAG = com.android.server.devicepolicy.plugins.DeviceWifiPlugin.class.getSimpleName();
    private static final java.lang.String VALUE_DISABLE = "value_disable";
    private static final java.lang.String VALUE_STRING_LIST = "value_string_list";
    private static final java.lang.String WIFI_BLACKLIST = "wifi-ssid-blacklist";
    private static final java.lang.String WIFI_BLACKLIST_ITEM = "wifi-ssid-blacklist/wifi-ssid-blacklist-item";
    private static final java.lang.String WIFI_SECURITYLEVEL = "wifi-securitylevel";
    private static final java.lang.String WIFI_WHITELIST = "wifi-ssid-whitelist";
    private static final java.lang.String WIFI_WHITELIST_ITEM = "wifi-ssid-whitelist/wifi-ssid-whitelist-item";

    public DeviceWifiPlugin(android.content.Context context) {
        super(context);
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("wifi-securitylevel", com.android.server.devicepolicy.PolicyStruct.PolicyType.CONFIGURATION, new java.lang.String[]{"securitylevel"});
        struct.addStruct("wifi-ssid-blacklist", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[0]);
        struct.addStruct("wifi-ssid-blacklist/wifi-ssid-blacklist-item", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value"});
        struct.addStruct("wifi-ssid-whitelist", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[0]);
        struct.addStruct("wifi-ssid-whitelist/wifi-ssid-whitelist-item", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value"});
        struct.addStruct("policy-restrict-network", com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE, new java.lang.String[]{"value_disable"});
        struct.addStruct("profile-enterprise-config", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[0]);
        struct.addStruct("profile-enterprise-config/enterprise-config-item", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value_string_list"});
        struct.addStruct("policy-auto-connect", com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE, new java.lang.String[]{"value_disable"});
        struct.addStruct("policy-open-hotspot", com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE, new java.lang.String[]{"value_disable"});
        return struct;
    }

    public boolean onInit(com.android.server.devicepolicy.PolicyStruct policyStruct) {
        com.android.server.devicepolicy.HwLog.d(TAG, "onInit");
        if (policyStruct == null) {
            return false;
        }
        return true;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.d(TAG, "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_WIFI", "need permission com.huawei.permission.sec.MDM_WIFI");
        return true;
    }

    private void sendSecurityLevel(int Level) {
        android.content.Intent intent = new android.content.Intent();
        intent.setAction("com.huawei.devicepolicy.action.POLICY_CHANGED");
        intent.putExtra("wifi_policy_category", 0);
        intent.putExtra("securelevel", Level);
        intent.setPackage("android");
        intent.addFlags(1073741824);
        this.mContext.sendBroadcast(intent);
    }

    private void sendBlackList(java.util.ArrayList<java.lang.String> blacklist, int mode, android.content.ComponentName who) {
        java.lang.String packageName = null;
        java.lang.String className = null;
        if (who != null) {
            packageName = who.getPackageName();
            className = who.getClassName();
        }
        android.content.Intent intent = new android.content.Intent("com.huawei.devicepolicy.action.POLICY_CHANGED");
        intent.setPackage("android");
        intent.addFlags(1073741824);
        intent.putExtra("wifi_policy_category", 1);
        intent.putExtra("set_or_remove", mode);
        intent.putExtra("package_name", packageName);
        intent.putExtra("class_name", className);
        intent.putStringArrayListExtra("ssid-blacklist", blacklist);
        this.mContext.sendBroadcast(intent);
    }

    private void printBlackList(java.util.ArrayList<java.lang.String> blacklist) {
        java.util.Iterator it = blacklist.iterator();
        while (it.hasNext()) {
            java.lang.String ssid = (java.lang.String) it.next();
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("blacklist ssid:");
            stringBuilder.append(ssid);
            com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
        }
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onSetPolicy changed ");
        stringBuilder.append(changed);
        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
        if (policyName == null) {
            com.android.server.devicepolicy.HwLog.e(TAG, "onSetPolicy: policyName is null!");
            return false;
        }
        int i = -1;
        switch (policyName.hashCode()) {
            case -1642980473:
                if (policyName.equals("policy-auto-connect")) {
                    i = 5;
                    break;
                }
                break;
            case -1586435062:
                if (policyName.equals("profile-enterprise-config")) {
                    i = 4;
                    break;
                }
                break;
            case -1152564340:
                if (policyName.equals("wifi-securitylevel")) {
                    i = false;
                    break;
                }
                break;
            case -617970941:
                if (policyName.equals("wifi-ssid-blacklist")) {
                    i = true;
                    break;
                }
                break;
            case 43624280:
                if (policyName.equals("policy-restrict-network")) {
                    i = 3;
                    break;
                }
                break;
            case 690133549:
                if (policyName.equals("wifi-ssid-whitelist")) {
                    i = 2;
                    break;
                }
                break;
            case 1167441671:
                if (policyName.equals("policy-open-hotspot")) {
                    i = 6;
                    break;
                }
                break;
            default:
                break;
        }
        switch (i) {
            case 0:
                if (policyData != null) {
                    i = 1;
                    try {
                        i = java.lang.Integer.parseInt(policyData.getString("securitylevel"));
                    } catch (java.lang.Exception e) {
                        i = 1;
                    }
                    java.lang.String str2 = TAG;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("onSetPolicy WIFI_SECURITYLEVEL ");
                    stringBuilder2.append(i);
                    com.android.server.devicepolicy.HwLog.d(str2, stringBuilder2.toString());
                    sendSecurityLevel(i);
                    break;
                }
                return true;
            case 1:
                if (policyData != null) {
                    java.util.ArrayList<java.lang.String> blacklist = policyData.getStringArrayList("value");
                    if (blacklist != null) {
                        printBlackList(blacklist);
                        sendBlackList(blacklist, 0, who);
                        break;
                    }
                    return true;
                }
                return true;
            case 2:
                if (policyData != null) {
                    if (!changed) {
                        com.android.server.devicepolicy.HwLog.d(TAG, "onSetPolicy: OP_WHITELIST can not be added to list");
                        break;
                    }
                    notifyWifiPolicyChanged(6, policyData, 0);
                    break;
                }
                return true;
            case 3:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onSetPolicy: POLICY_RESTRICT_NETWORK no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(2, policyData, 0);
                    break;
                }
                return true;
            case 4:
                if (policyData == null) {
                    return true;
                }
                if (changed) {
                    notifyWifiPolicyChanged(3, policyData, 0);
                    break;
                }
                com.android.server.devicepolicy.HwLog.e(TAG, "onSetPolicy: ENTERPRISE_CONFIG can not be added to list");
                return false;
            case 5:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onSetPolicy: POLICY_AUTO_CONNECT no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(4, policyData, 0);
                    break;
                }
                return true;
            case 6:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onSetPolicy: POLICY_OPEN_HOTSPOT no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(5, policyData, 0);
                    break;
                }
                return true;
            default:
                com.android.server.devicepolicy.HwLog.e(TAG, "onSetPolicy: nukonw policyName!");
                break;
        }
        return true;
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean changed) {
        com.android.server.devicepolicy.HwLog.d(TAG, "onRemovePolicy");
        if (policyName == null) {
            com.android.server.devicepolicy.HwLog.e(TAG, "onRemovePolicy: policyName is null!");
            return false;
        }
        int i = -1;
        switch (policyName.hashCode()) {
            case -1642980473:
                if (policyName.equals("policy-auto-connect")) {
                    i = 5;
                    break;
                }
                break;
            case -1586435062:
                if (policyName.equals("profile-enterprise-config")) {
                    i = 4;
                    break;
                }
                break;
            case -1152564340:
                if (policyName.equals("wifi-securitylevel")) {
                    i = false;
                    break;
                }
                break;
            case -617970941:
                if (policyName.equals("wifi-ssid-blacklist")) {
                    i = true;
                    break;
                }
                break;
            case 43624280:
                if (policyName.equals("policy-restrict-network")) {
                    i = 3;
                    break;
                }
                break;
            case 690133549:
                if (policyName.equals("wifi-ssid-whitelist")) {
                    i = 2;
                    break;
                }
                break;
            case 1167441671:
                if (policyName.equals("policy-open-hotspot")) {
                    i = 6;
                    break;
                }
                break;
            default:
                break;
        }
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        switch (i) {
            case 0:
                com.android.server.devicepolicy.HwLog.d(TAG, "onRemovePolicy: WIFI_SECURITYLEVEL ");
                sendSecurityLevel(1);
                break;
            case 1:
                if (policyData != null) {
                    java.util.ArrayList<java.lang.String> blacklist = policyData.getStringArrayList("value");
                    if (blacklist != null) {
                        sendBlackList(blacklist, 1, who);
                        break;
                    }
                    return true;
                }
                return true;
            case 2:
                if (policyData != null) {
                    if (!changed) {
                        com.android.server.devicepolicy.HwLog.e(TAG, "onRemovePolicy: OP_WHITELIST can not be removed from list");
                        break;
                    }
                    notifyWifiPolicyChanged(6, policyData, 1);
                    break;
                }
                return true;
            case 3:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onRemovePolicy: POLICY_RESTRICT_NETWORK no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(2, policyData, 1);
                    break;
                }
                return true;
            case 4:
                if (policyData == null) {
                    return true;
                }
                if (changed) {
                    notifyWifiPolicyChanged(3, policyData, 1);
                    break;
                }
                com.android.server.devicepolicy.HwLog.e(TAG, "onRemovePolicy: ENTERPRISE_CONFIG can not be removed from list");
                return false;
            case 5:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onRemovePolicy: POLICY_AUTO_CONNECT no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(4, policyData, 1);
                    break;
                }
                return true;
            case 6:
                if (policyData != null) {
                    if (!changed) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onRemovePolicy: POLICY_OPEN_HOTSPOT no need to change. disable=");
                        stringBuilder.append(policyData.getBoolean("value_disable"));
                        com.android.server.devicepolicy.HwLog.d(str, stringBuilder.toString());
                        break;
                    }
                    notifyWifiPolicyChanged(5, policyData, 1);
                    break;
                }
                return true;
            default:
                com.android.server.devicepolicy.HwLog.e(TAG, "onRemovePolicy: nukonw policyName!");
                break;
        }
        return true;
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        com.android.server.devicepolicy.HwLog.d(TAG, "onGetPolicy");
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> removedPolicies) {
        com.android.server.devicepolicy.HwLog.d(TAG, "onActiveAdminRemoved");
        if (removedPolicies == null) {
            return true;
        }
        java.util.Iterator it = removedPolicies.iterator();
        while (it.hasNext()) {
            com.android.server.devicepolicy.PolicyStruct.PolicyItem policy = (com.android.server.devicepolicy.PolicyStruct.PolicyItem) it.next();
            if (policy != null) {
                java.lang.String policyName = policy.getPolicyName();
                int i = -1;
                switch (policyName.hashCode()) {
                    case -1642980473:
                        if (policyName.equals("policy-auto-connect")) {
                            i = 5;
                            break;
                        }
                        break;
                    case -1586435062:
                        if (policyName.equals("profile-enterprise-config")) {
                            i = 4;
                            break;
                        }
                        break;
                    case -1152564340:
                        if (policyName.equals("wifi-securitylevel")) {
                            i = false;
                            break;
                        }
                        break;
                    case -617970941:
                        if (policyName.equals("wifi-ssid-blacklist")) {
                            i = true;
                            break;
                        }
                        break;
                    case 43624280:
                        if (policyName.equals("policy-restrict-network")) {
                            i = 3;
                            break;
                        }
                        break;
                    case 690133549:
                        if (policyName.equals("wifi-ssid-whitelist")) {
                            i = 2;
                            break;
                        }
                        break;
                    case 1167441671:
                        if (policyName.equals("policy-open-hotspot")) {
                            i = 6;
                            break;
                        }
                        break;
                    default:
                        break;
                }
                android.os.Bundle whiteListBundle;
                android.os.Bundle restrictBundle;
                switch (i) {
                    case 0:
                        sendSecurityLevel(1);
                        break;
                    case 1:
                        sendBlackList(null, 2, who);
                        break;
                    case 2:
                        whiteListBundle = new android.os.Bundle();
                        whiteListBundle.putStringArrayList("value", null);
                        notifyWifiPolicyChanged(6, whiteListBundle, 2);
                        break;
                    case 3:
                        restrictBundle = new android.os.Bundle();
                        restrictBundle.putBoolean("value_disable", false);
                        notifyWifiPolicyChanged(2, restrictBundle, 2);
                        break;
                    case 4:
                        whiteListBundle = new android.os.Bundle();
                        whiteListBundle.putStringArrayList("value_string_list", null);
                        notifyWifiPolicyChanged(3, whiteListBundle, 2);
                        break;
                    case 5:
                        restrictBundle = new android.os.Bundle();
                        restrictBundle.putBoolean("value_disable", false);
                        notifyWifiPolicyChanged(4, restrictBundle, 2);
                        break;
                    case 6:
                        restrictBundle = new android.os.Bundle();
                        restrictBundle.putBoolean("value_disable", false);
                        notifyWifiPolicyChanged(5, restrictBundle, 2);
                        break;
                    default:
                        break;
                }
            }
        }
        return true;
    }

    private void notifyWifiPolicyChanged(int policyMode, android.os.Bundle policyData, int changeMode) {
        android.content.Intent intent = new android.content.Intent();
        intent.setAction("com.huawei.devicepolicy.action.POLICY_CHANGED");
        intent.setPackage("android");
        intent.addFlags(1073741824);
        intent.putExtra("wifi_policy_category", policyMode);
        intent.putExtra("wifi_policy_data", policyData);
        intent.putExtra("change_mode", changeMode);
        this.mContext.sendBroadcast(intent);
    }
}
