package com.android.server.devicepolicy.plugins;

public class HwSystemManagerPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String SYSTEM_MANAGER_PERMISSION = "com.huawei.systemmanager.permission.ACCESS_INTERFACE";
    public static final java.lang.String TAG = com.android.server.devicepolicy.plugins.HwSystemManagerPlugin.class.getSimpleName();
    private static final java.lang.String UPDATE_DATA_SAVER_MODE = "com.huawei.systemmanager.netassistant.traffic.datasaver.update";
    private static final java.lang.String UPDATE_DATA_SAVER_MODE_REMOVED = "com.huawei.systemmanager.netassistant.traffic.datasaver.update.remove";
    private static final java.lang.String UPDATE_NOTIFICATION_SUPERWHITELIST = "com.huawei.notificationmanager.superwhitelist";
    private static final java.lang.String UPDATE_NOTIFICATION_SUPERWHITELIST_REMOVE = "com.huawei.notificationmanager.superwhitelist.remove";
    private android.os.Bundle policyBundle = null;

    public HwSystemManagerPlugin(android.content.Context context) {
        super(context);
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.HwLog.i(TAG, "getPolicyStruct");
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        com.android.server.devicepolicy.PolicyStruct.PolicyType listType = com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST;
        com.android.server.devicepolicy.PolicyStruct.PolicyType stateType = com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE;
        struct.addStruct("super-whitelist-hwsystemmanager/super-whitelist-hwsystemmanager-item", listType, new java.lang.String[]{"value"});
        struct.addStruct("data-saver-mode", stateType, new java.lang.String[]{"value"});
        return struct;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.i(TAG, "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.systemmanager.permission.ACCESS_INTERFACE", "it does not have SYSTEM_MANAGER_PERMISSION permisson");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        this.policyBundle = policyData;
        return true;
    }

    public void onSetPolicyCompleted(android.content.ComponentName who, java.lang.String policyName, boolean changed) {
        if (policyName != null && policyName.equals("data-saver-mode") && changed) {
            this.mContext.sendBroadcast(new android.content.Intent("com.huawei.systemmanager.netassistant.traffic.datasaver.update"), "com.huawei.systemmanager.permission.ACCESS_INTERFACE");
            com.android.server.devicepolicy.HwLog.i(TAG, "Broadcast TO HwSystemManager Data Saver");
        } else if (policyName != null && policyName.equals("super-whitelist-hwsystemmanager")) {
            android.content.Intent intent = new android.content.Intent("com.huawei.notificationmanager.superwhitelist");
            if (this.policyBundle != null) {
                intent.putExtras(this.policyBundle);
            }
            this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.getUserHandleForUid(android.os.Binder.getCallingUid()), "com.huawei.systemmanager.permission.ACCESS_INTERFACE");
            com.android.server.devicepolicy.HwLog.i(TAG, "Broadcast TO HwSystemManager");
        }
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean globalPolicyChanged) {
        if (policyName != null && policyName.equals("data-saver-mode")) {
            this.mContext.sendBroadcast(new android.content.Intent("com.huawei.systemmanager.netassistant.traffic.datasaver.update.remove"), "com.huawei.systemmanager.permission.ACCESS_INTERFACE");
            com.android.server.devicepolicy.HwLog.i(TAG, "onRemove-Broadcast TO HwSystemManager Data Saver");
        } else if (policyName != null && policyName.equals("super-whitelist-hwsystemmanager")) {
            android.content.Intent intent = new android.content.Intent("com.huawei.notificationmanager.superwhitelist.remove");
            intent.putExtras(policyData);
            this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.getUserHandleForUid(android.os.Binder.getCallingUid()), "com.huawei.systemmanager.permission.ACCESS_INTERFACE");
            com.android.server.devicepolicy.HwLog.i(TAG, "onRemove-Broadcast TO HwSystemManager");
        }
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        return true;
    }
}
