package com.android.server.devicepolicy.plugins;

public class PhoneManagerPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String DATA_ROAMING_SIM2 = "data_roaming_sim2";
    private static final java.lang.String INCOMING_DAY_LIMIT = "calls_limitation_incoming_day/mt_day_limit";
    private static final java.lang.String INCOMING_MONTH_LIMIT = "calls_limitation_incoming_month/mt_month_limit";
    private static final java.lang.String INCOMING_WEEK_LIMIT = "calls_limitation_incoming_week/mt_week_limit";
    private static final java.lang.String OUTGOING_DAY_LIMIT = "calls_limitation_outgoing_day/mo_day_limit";
    private static final java.lang.String OUTGOING_MONTH_LIMIT = "calls_limitation_outgoing_month/mo_month_limit";
    private static final java.lang.String OUTGOING_WEEK_LIMIT = "calls_limitation_outgoing_week/mo_week_limit";
    private static final java.lang.String PHONE_NUMBER_INCOMING_LIMIT = "incoming_limit";
    private static final java.lang.String PHONE_NUMBER_INCOMING_LIST_ITEM = "phone-number-incoming-list/phone-number-list-item";
    private static final java.lang.String PHONE_NUMBER_OUTGOING_LIMIT = "outgoing_limit";
    private static final java.lang.String PHONE_NUMBER_OUTGOING_LIST_ITEM = "phone-number-outgoing-list/phone-number-list-item";
    private static final java.lang.String PHONE_PERMISSION = "com.huawei.permission.sec.MDM_PHONE_MANAGER";
    public static final java.lang.String TAG = com.android.server.devicepolicy.plugins.PhoneManagerPlugin.class.getSimpleName();
    private static final java.lang.String TELECOM_PACKAGE_NAME = "com.android.server.telecom";
    private static final java.lang.String TELESERVICE_PACKAGE_NAME = "com.android.phone";
    private android.content.Context mContext;
    private android.content.ContentResolver mResolver = this.mContext.getContentResolver();

    public PhoneManagerPlugin(android.content.Context context) {
        super(context);
        this.mContext = context;
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        com.android.server.devicepolicy.PolicyStruct.PolicyType stateType = com.android.server.devicepolicy.PolicyStruct.PolicyType.STATE;
        struct.addStruct("disallow-data-roaming", stateType, new java.lang.String[]{"value"});
        struct.addStruct("disallow-access-point-name", stateType, new java.lang.String[]{"value"});
        struct.addStruct("phone-number-incoming-is-black-list-mode", stateType, new java.lang.String[]{"value"});
        struct.addStruct("phone-number-outgoing-is-black-list-mode", stateType, new java.lang.String[]{"value"});
        struct.addStruct("apply-to-all-incoming-calls", stateType, new java.lang.String[]{"value"});
        struct.addStruct("apply-to-all-outgoing-calls", stateType, new java.lang.String[]{"value"});
        struct.addStruct("disallow-non-emergency-call", stateType, new java.lang.String[]{"value"});
        struct.addStruct("disallow-roaming-call", stateType, new java.lang.String[]{"value"});
        com.android.server.devicepolicy.PolicyStruct.PolicyType listType = com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST;
        struct.addStruct("phone-number-incoming-list", listType, new java.lang.String[0]);
        struct.addStruct("phone-number-outgoing-list", listType, new java.lang.String[0]);
        struct.addStruct("phone-number-incoming-list/phone-number-list-item", listType, new java.lang.String[]{"value"});
        struct.addStruct("phone-number-outgoing-list/phone-number-list-item", listType, new java.lang.String[]{"value"});
        com.android.server.devicepolicy.PolicyStruct.PolicyType configType = com.android.server.devicepolicy.PolicyStruct.PolicyType.CONFIGURATION;
        struct.addStruct("calls_limitation_outgoing_day", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_outgoing_day/mo_day_limit", configType, new java.lang.String[]{"outgoing_day_limit"});
        struct.addStruct("calls_limitation_outgoing_week", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_outgoing_week/mo_week_limit", configType, new java.lang.String[]{"outgoing_week_limit"});
        struct.addStruct("calls_limitation_outgoing_month", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_outgoing_month/mo_month_limit", configType, new java.lang.String[]{"outgoing_month_limit"});
        struct.addStruct("calls_limitation_incoming_day", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_incoming_day/mt_day_limit", configType, new java.lang.String[]{"incoming_day_limit"});
        struct.addStruct("calls_limitation_incoming_week", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_incoming_week/mt_week_limit", configType, new java.lang.String[]{"incoming_week_limit"});
        struct.addStruct("calls_limitation_incoming_month", configType, new java.lang.String[0]);
        struct.addStruct("calls_limitation_incoming_month/mt_month_limit", configType, new java.lang.String[]{"incoming_month_limit"});
        return struct;
    }

    public boolean onInit(com.android.server.devicepolicy.PolicyStruct policyStruct) {
        if (policyStruct == null) {
            return false;
        }
        return true;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        if (this.mContext == null) {
            return false;
        }
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_PHONE_MANAGER", "Permission not granted to access phone manager.");
        return true;
    }

    public boolean onSetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean globalPolicyChanged) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onSetPolicy: ");
        stringBuilder.append(policyName);
        android.util.Log.i(str, stringBuilder.toString());
        if (!checkCallingPermission(who, policyName) || policyData == null) {
            return false;
        }
        if (!"disallow-data-roaming".equals(policyName)) {
            return true;
        }
        onSetDataRoamingPolicy(policyData);
        return true;
    }

    public void onSetPolicyCompleted(android.content.ComponentName who, java.lang.String policyName, boolean changed) {
        if ("disallow-data-roaming".equals(policyName)) {
            sendConfigChangedBroadcast("com.android.phone", "disallow-data-roaming");
        } else if ("disallow-access-point-name".equals(policyName)) {
            sendConfigChangedBroadcast("com.android.phone", "disallow-access-point-name");
        }
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean globalPolicyChanged) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onRemovePolicy: ");
        stringBuilder.append(policyName);
        android.util.Log.i(str, stringBuilder.toString());
        if (checkCallingPermission(who, policyName)) {
            return true;
        }
        return false;
    }

    public void onRemovePolicyCompleted(android.content.ComponentName who, java.lang.String policyName, boolean changed) {
        if (isCallsLimitPolicy(policyName)) {
            sendCallsLimitRemovedBroadcast("com.android.server.telecom", policyName);
        }
    }

    private boolean isCallsLimitPolicy(java.lang.String policyName) {
        if (!("calls_limitation_outgoing_day".equals(policyName) || "calls_limitation_outgoing_week".equals(policyName) || "calls_limitation_outgoing_month".equals(policyName) || "calls_limitation_incoming_day".equals(policyName) || "calls_limitation_incoming_week".equals(policyName))) {
            if (!"calls_limitation_incoming_month".equals(policyName)) {
                return false;
            }
        }
        return true;
    }

    private void sendCallsLimitRemovedBroadcast(java.lang.String packageName, java.lang.String policyName) {
        if (this.mContext != null) {
            long callingId = android.os.Binder.clearCallingIdentity();
            try {
                android.util.Log.i(TAG, "sendBroadcast sendCallsLimitRemovedBroadcast.");
                android.content.Intent intent = new android.content.Intent("com.huawei.devicepolicy.action.POLICY_CHANGED");
                intent.setPackage("com.android.server.telecom");
                intent.putExtra("policy_name", policyName);
                intent.putExtra("calls_limit_removed", true);
                this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.of(android.app.ActivityManager.getCurrentUser()));
            } finally {
                android.os.Binder.restoreCallingIdentity(callingId);
            }
        }
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        return true;
    }

    public void onActiveAdminRemovedCompleted(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> removedPolicies) {
        if (this.mContext != null) {
            boolean sendToTelecom = false;
            boolean sendToTeleService = false;
            int j = removedPolicies.size();
            for (int i = 0; i < j; i++) {
                com.android.server.devicepolicy.PolicyStruct.PolicyItem pi = (com.android.server.devicepolicy.PolicyStruct.PolicyItem) removedPolicies.get(i);
                if (pi != null) {
                    java.lang.String policyName = pi.getPolicyName();
                    if (pi.isGlobalPolicyChanged()) {
                        if (isCallsLimitPolicy(policyName)) {
                            sendToTelecom = true;
                        } else if ("disallow-data-roaming".equals(policyName) || "disallow-access-point-name".equals(policyName)) {
                            sendToTeleService = true;
                        }
                    }
                }
            }
            if (sendToTelecom) {
                sendAdminRemovedBroadcast("com.android.server.telecom");
            }
            if (sendToTeleService) {
                sendAdminRemovedBroadcast("com.android.phone");
            }
        }
    }

    private void sendAdminRemovedBroadcast(java.lang.String packageName) {
        long callingId = android.os.Binder.clearCallingIdentity();
        try {
            android.util.Log.i(TAG, "sendBroadcast onActiveAdminRemovedCompleted.");
            android.content.Intent intent = new android.content.Intent("com.huawei.devicepolicy.action.POLICY_CHANGED");
            intent.putExtra("admin_removed", true);
            intent.setPackage(packageName);
            this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.of(android.app.ActivityManager.getCurrentUser()));
        } finally {
            android.os.Binder.restoreCallingIdentity(callingId);
        }
    }

    private void onSetDataRoamingPolicy(android.os.Bundle policyData) {
        boolean restrictDataRoaming = policyData.getBoolean("value", false);
        long callingId = android.os.Binder.clearCallingIdentity();
        if (restrictDataRoaming) {
            try {
                disableDataRoaming();
            } catch (Throwable th) {
                android.os.Binder.restoreCallingIdentity(callingId);
            }
        }
        android.os.Binder.restoreCallingIdentity(callingId);
    }

    private void sendConfigChangedBroadcast(java.lang.String packageName, java.lang.String type) {
        if (this.mContext != null) {
            long callingId = android.os.Binder.clearCallingIdentity();
            try {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("sendBroadcast type= ");
                stringBuilder.append(type);
                android.util.Log.i(str, stringBuilder.toString());
                android.content.Intent intent = new android.content.Intent("com.huawei.devicepolicy.action.POLICY_CHANGED");
                intent.setPackage(packageName);
                intent.putExtra("policy_name", type);
                this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.of(android.app.ActivityManager.getCurrentUser()));
            } finally {
                android.os.Binder.restoreCallingIdentity(callingId);
            }
        }
    }

    private void disableDataRoaming() {
        android.provider.Settings.Global.putInt(this.mResolver, "data_roaming", 0);
        if (android.telephony.TelephonyManager.getDefault().getSimCount() != 1) {
            android.provider.Settings.Global.putInt(this.mResolver, "data_roaming_sim2", 0);
        }
    }
}
