package com.android.server.display;

class AmbientLightMonitor implements com.android.server.display.DisplayEffectMonitor.MonitorModule {
    private static final boolean HWDEBUG;
    private static final boolean HWFLOW;
    private static final java.lang.String PARAM_BRIGHTNESS_MODE = "brightnessMode";
    private static final java.lang.String PARAM_COLOR_TEMP_VALUE = "colorTempValue";
    private static final java.lang.String PARAM_DURATION_IN_MS = "durationInMs";
    private static final java.lang.String PARAM_LIGHT_VALUE = "lightValue";
    private static final java.lang.String PARAM_RAW_LIGHT_VALUE = "rawLightValue";
    private static final java.lang.String TAG = "AmbientLightMonitor";
    private static final java.lang.String TYPE_AMBIENT_COLOR_TEMP_COLLECTION = "ambientColorTempCollection";
    private static final java.lang.String TYPE_AMBIENT_LIGHT_COLLECTION = "ambientLightCollection";
    private com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData mAmbientLightDataInAPP = new com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData(com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode.APP);
    private com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData mAmbientLightDataInAuto = new com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData(com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode.AUTO);
    private com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData mAmbientLightDataInFRONT = new com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData(com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode.FRONT);
    private com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData mAmbientLightDataInManual = new com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData(com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode.MANUAL);
    private com.android.server.display.AmbientLightMonitor.ColorTempCollector mColorTempCollector;
    private final com.android.server.display.BackLightCommonData mCommonData;

    private static class AmbientLightCollectionData {
        private static final int UPLOAD_INTERVAL_TIME_IN_MS = 60000;
        private int lux1000To5000TimeInMs;
        private int lux200To500TimeInMs;
        private int lux500To1000TimeInMs;
        private int lux50To200TimeInMs;
        private int luxAbove5000TimeInMs;
        private int luxBelow50TimeInMs;
        private final com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode mMode;
        private int mTotalTimeInMs;

        public enum Mode {
            AUTO,
            MANUAL,
            APP,
            FRONT
        }

        public AmbientLightCollectionData(com.android.server.display.AmbientLightMonitor.AmbientLightCollectionData.Mode mode) {
            this.mMode = mode;
        }

        public void collect(int lux, int durationInMs) {
            if (lux >= 0 && durationInMs > 0) {
                if (durationInMs < 5000) {
                    if (com.android.server.display.AmbientLightMonitor.HWDEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("collect lux=");
                        stringBuilder.append(lux);
                        stringBuilder.append(", durationInMs=");
                        stringBuilder.append(durationInMs);
                        stringBuilder.append(", mode=");
                        stringBuilder.append(this.mMode);
                        android.util.Slog.d("AmbientLightMonitor", stringBuilder.toString());
                    }
                    if (lux <= 50) {
                        this.luxBelow50TimeInMs += durationInMs;
                    } else if (lux <= 200) {
                        this.lux50To200TimeInMs += durationInMs;
                    } else if (lux <= 500) {
                        this.lux200To500TimeInMs += durationInMs;
                    } else if (lux <= 1000) {
                        this.lux500To1000TimeInMs += durationInMs;
                    } else if (lux <= 5000) {
                        this.lux1000To5000TimeInMs += durationInMs;
                    } else {
                        this.luxAbove5000TimeInMs += durationInMs;
                    }
                    this.mTotalTimeInMs += durationInMs;
                    if (this.mTotalTimeInMs >= 60000) {
                        upload();
                        clean();
                    }
                    return;
                }
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("AmbientLightCollectionData.collect() error!input params out of range: lux=");
            stringBuilder2.append(lux);
            stringBuilder2.append(", durationInMs=");
            stringBuilder2.append(durationInMs);
            android.util.Slog.e("AmbientLightMonitor", stringBuilder2.toString());
        }

        private void upload() {
            java.lang.StringBuilder stringBuilder;
            if (com.android.server.display.AmbientLightMonitor.HWDEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("upload ");
                stringBuilder.append(this);
                android.util.Slog.d("AmbientLightMonitor", stringBuilder.toString());
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("DUBAI_TAG_");
            stringBuilder2.append(this.mMode);
            stringBuilder2.append("_AMBIENT_LIGHT");
            java.lang.String stringBuilder3 = stringBuilder2.toString();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("d0=");
            stringBuilder.append(this.luxBelow50TimeInMs);
            stringBuilder.append(" d1=");
            stringBuilder.append(this.lux50To200TimeInMs);
            stringBuilder.append(" d2=");
            stringBuilder.append(this.lux200To500TimeInMs);
            stringBuilder.append(" d3=");
            stringBuilder.append(this.lux500To1000TimeInMs);
            stringBuilder.append(" d4=");
            stringBuilder.append(this.lux1000To5000TimeInMs);
            stringBuilder.append(" d5=");
            stringBuilder.append(this.luxAbove5000TimeInMs);
            android.util.HwLog.dubaie(stringBuilder3, stringBuilder.toString());
        }

        private void clean() {
            this.mTotalTimeInMs = 0;
            this.luxBelow50TimeInMs = 0;
            this.lux50To200TimeInMs = 0;
            this.lux200To500TimeInMs = 0;
            this.lux500To1000TimeInMs = 0;
            this.lux1000To5000TimeInMs = 0;
            this.luxAbove5000TimeInMs = 0;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("AmbientLightCollectionData ");
            stringBuilder.append(this.mMode);
            stringBuilder.append(", lux <50:");
            stringBuilder.append(this.luxBelow50TimeInMs / 1000);
            stringBuilder.append("s, 50~200:");
            stringBuilder.append(this.lux50To200TimeInMs / 1000);
            stringBuilder.append("s, 200~500:");
            stringBuilder.append(this.lux200To500TimeInMs / 1000);
            stringBuilder.append("s, 500~1000:");
            stringBuilder.append(this.lux500To1000TimeInMs / 1000);
            stringBuilder.append("s, 1000~5000:");
            stringBuilder.append(this.lux1000To5000TimeInMs / 1000);
            stringBuilder.append("s, >5000:");
            stringBuilder.append(this.luxAbove5000TimeInMs / 1000);
            stringBuilder.append("s");
            return stringBuilder.toString();
        }
    }

    private static class ColorTempCollector {
        private static final int COLOR_TEMP_MAX = 8000;
        private static final int COLOR_TEMP_MIN = 2500;
        private static final int COLOR_TEMP_MIN2 = 4000;
        private static final int LEVEL_NUM = 7;
        private static final int UPLOAD_UNIT_IN_MS = 60000;
        private int[] timeInMs;

        private ColorTempCollector() {
            this.timeInMs = new int[7];
        }

        public void collect(int colorTemp, int durationInMs) {
            if (colorTemp > 0 && durationInMs > 0) {
                if (durationInMs < 5000) {
                    int index;
                    if (colorTemp < 2500) {
                        index = 0;
                    } else if (colorTemp < 4000) {
                        index = 1;
                    } else if (colorTemp >= 8000) {
                        index = 6;
                    } else {
                        index = ((colorTemp - 4000) / 1000) + 2;
                    }
                    int[] iArr = this.timeInMs;
                    iArr[index] = iArr[index] + durationInMs;
                    if (com.android.server.display.AmbientLightMonitor.HWDEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("ColorTempCollector.collect() colorTemp=");
                        stringBuilder.append(colorTemp);
                        stringBuilder.append(", index=");
                        stringBuilder.append(index);
                        stringBuilder.append(", durationInMs=");
                        stringBuilder.append(durationInMs);
                        android.util.Slog.d("AmbientLightMonitor", stringBuilder.toString());
                    }
                }
            }
        }

        public void upload() {
            if (isEmpty()) {
                clean();
                return;
            }
            byte[] timeInMinute = new byte[7];
            int index = 0;
            for (int index2 = 0; index2 < 7; index2++) {
                int minute = this.timeInMs[index2] / 60000;
                byte b = Byte.MAX_VALUE;
                if (minute < 127) {
                    b = (byte) minute;
                }
                timeInMinute[index2] = b;
            }
            if (com.android.server.display.AmbientLightMonitor.HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("ColorTempCollector.upload() ");
                stringBuilder.append(java.util.Arrays.toString(timeInMinute));
                android.util.Slog.i("AmbientLightMonitor", stringBuilder.toString());
            }
            android.util.IMonitor.EventStream stream = android.util.IMonitor.openEventStream(932040100);
            while (index < 7) {
                if (timeInMinute[index] > (byte) 0) {
                    stream.setParam((short) index, timeInMinute[index]);
                }
                index++;
            }
            android.util.IMonitor.sendEvent(stream);
            android.util.IMonitor.closeEventStream(stream);
            clean();
        }

        private boolean isEmpty() {
            for (int time : this.timeInMs) {
                if (time >= 60000) {
                    return false;
                }
            }
            return true;
        }

        private void clean() {
            java.util.Arrays.fill(this.timeInMs, 0);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001d  */
    static {
        /*
        r0 = android.util.Log.HWLog;
        r1 = 1;
        r2 = 0;
        if (r0 != 0) goto L_0x0016;
    L_0x0006:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x0014;
    L_0x000a:
        r0 = "AmbientLightMonitor";
        r3 = 3;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x0014;
    L_0x0013:
        goto L_0x0016;
    L_0x0014:
        r0 = r2;
        goto L_0x0017;
    L_0x0016:
        r0 = r1;
    L_0x0017:
        HWDEBUG = r0;
        r0 = android.util.Log.HWINFO;
        if (r0 != 0) goto L_0x002d;
    L_0x001d:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x002b;
    L_0x0021:
        r0 = "AmbientLightMonitor";
        r3 = 4;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x002b;
    L_0x002a:
        goto L_0x002d;
    L_0x002b:
        r1 = r2;
    L_0x002d:
        HWFLOW = r1;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.AmbientLightMonitor.<clinit>():void");
    }

    public AmbientLightMonitor(com.android.server.display.DisplayEffectMonitor monitor, com.android.server.display.BackLightMonitorManager manager) {
        this.mCommonData = manager.getBackLightCommonData();
        if (!this.mCommonData.isCommercialVersion()) {
            this.mColorTempCollector = new com.android.server.display.AmbientLightMonitor.ColorTempCollector();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x0029 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x002a A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x0029 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x002a A:{RETURN} */
    public boolean isParamOwner(java.lang.String r5) {
        /*
        r4 = this;
        r0 = r5.hashCode();
        r1 = -1209196900; // 0xffffffffb7ed1e9c float:-2.8266855E-5 double:NaN;
        r2 = 0;
        r3 = 1;
        if (r0 == r1) goto L_0x001b;
    L_0x000b:
        r1 = -313342435; // 0xffffffffed52c61d float:-4.0769598E27 double:NaN;
        if (r0 == r1) goto L_0x0011;
    L_0x0010:
        goto L_0x0025;
    L_0x0011:
        r0 = "ambientColorTempCollection";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0025;
    L_0x0019:
        r0 = r3;
        goto L_0x0026;
    L_0x001b:
        r0 = "ambientLightCollection";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0025;
    L_0x0023:
        r0 = r2;
        goto L_0x0026;
    L_0x0025:
        r0 = -1;
    L_0x0026:
        switch(r0) {
            case 0: goto L_0x002a;
            case 1: goto L_0x002a;
            default: goto L_0x0029;
        };
    L_0x0029:
        return r2;
    L_0x002a:
        return r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.AmbientLightMonitor.isParamOwner(java.lang.String):boolean");
    }

    public void sendMonitorParam(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params != null) {
            if (params.get("paramType") instanceof java.lang.String) {
                java.lang.String paramType = (java.lang.String) params.get("paramType");
                java.lang.Object obj = -1;
                int hashCode = paramType.hashCode();
                if (hashCode != -1209196900) {
                    if (hashCode == -313342435) {
                        if (paramType.equals("ambientColorTempCollection")) {
                            obj = 1;
                        }
                    }
                } else if (paramType.equals("ambientLightCollection")) {
                    obj = null;
                }
                switch (obj) {
                    case null:
                        ambientLightCollection(params);
                        break;
                    case 1:
                        ambientColorTempCollection(params);
                        break;
                    default:
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("sendMonitorParam() undefine paramType: ");
                        stringBuilder.append(paramType);
                        android.util.Slog.e("AmbientLightMonitor", stringBuilder.toString());
                        break;
                }
                return;
            }
        }
        android.util.Slog.e("AmbientLightMonitor", "sendMonitorParam() input params format error!");
    }

    public void triggerUploadTimer() {
        if (this.mColorTempCollector != null) {
            this.mColorTempCollector.upload();
        }
    }

    private void ambientLightCollection(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (ambientLightCollectionCheckParamValid(params)) {
            int lightValue = ((java.lang.Integer) params.get("lightValue")).intValue();
            int durationInMs = ((java.lang.Integer) params.get("durationInMs")).intValue();
            java.lang.String mode = (java.lang.String) params.get("brightnessMode");
            if (this.mCommonData.isWindowManagerBrightnessMode()) {
                this.mAmbientLightDataInAPP.collect(lightValue, durationInMs);
            } else if (mode.equals("AUTO")) {
                this.mAmbientLightDataInAuto.collect(lightValue, durationInMs);
                if (params.get("rawLightValue") instanceof java.lang.Integer) {
                    this.mAmbientLightDataInFRONT.collect(((java.lang.Integer) params.get("rawLightValue")).intValue(), durationInMs);
                }
            } else {
                this.mAmbientLightDataInManual.collect(lightValue, durationInMs);
            }
        }
    }

    private boolean ambientLightCollectionCheckParamValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params == null) {
            return false;
        }
        if (!(params.get("lightValue") instanceof java.lang.Integer)) {
            android.util.Slog.e("AmbientLightMonitor", "ambientLightCollectionCheckParamValid() can't get param: lightValue");
            return false;
        } else if (!(params.get("durationInMs") instanceof java.lang.Integer)) {
            android.util.Slog.e("AmbientLightMonitor", "ambientLightCollectionCheckParamValid() can't get param: durationInMs");
            return false;
        } else if (params.get("brightnessMode") instanceof java.lang.String) {
            java.lang.String mode = (java.lang.String) params.get("brightnessMode");
            if (mode.equals("AUTO") || mode.equals("MANUAL")) {
                return true;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("ambientLightCollectionCheckParamValid() brightnessMode value error: ");
            stringBuilder.append(mode);
            android.util.Slog.e("AmbientLightMonitor", stringBuilder.toString());
            return false;
        } else {
            android.util.Slog.e("AmbientLightMonitor", "ambientLightCollectionCheckParamValid() can't get param: brightnessMode");
            return false;
        }
    }

    private void ambientColorTempCollection(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (this.mCommonData.isProductEnable()) {
            if (!this.mCommonData.isCommercialVersion()) {
                if (ambientColorTempCollectionCheckParamValid(params)) {
                    this.mColorTempCollector.collect(((java.lang.Integer) params.get("colorTempValue")).intValue(), ((java.lang.Integer) params.get("durationInMs")).intValue());
                }
            }
        }
    }

    private boolean ambientColorTempCollectionCheckParamValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params == null) {
            return false;
        }
        if (!(params.get("colorTempValue") instanceof java.lang.Integer)) {
            android.util.Slog.e("AmbientLightMonitor", "ambientColorTempCollectionCheckParamValid() can't get param: colorTempValue");
            return false;
        } else if (params.get("durationInMs") instanceof java.lang.Integer) {
            return true;
        } else {
            android.util.Slog.e("AmbientLightMonitor", "ambientColorTempCollectionCheckParamValid() can't get param: durationInMs");
            return false;
        }
    }
}
