package com.android.server.display;

class BrightnessSeekBarMonitor implements com.android.server.display.DisplayEffectMonitor.MonitorModule {
    private static final boolean HWDEBUG;
    private static final boolean HWFLOW;
    private static final java.lang.String MONITOR_TARGET_PACKAGE = "android.uid.systemui";
    private static final long MOVE_INTERVAL_TIME_IN_MS = 2000;
    private static final long MOVE_LIST_INTERVAL_TIME_IN_MS = 15000;
    private static final int MOVE_MERGE_LUX_CHANGE_MIN_THRESHOLD = 5;
    private static final int MOVE_MERGE_LUX_CHANGE_PERCENT = 50;
    private static final java.lang.String PARAM_BRIGHTNESS = "brightness";
    private static final java.lang.String PARAM_BRIGHTNESS_MODE = "brightnessMode";
    private static final java.lang.String PARAM_IS_ENABLE = "isEnable";
    private static final java.lang.String PARAM_LIGHT_VALUE = "lightValue";
    private static final java.lang.String PARAM_PACKAGE_NAME = "packageName";
    private static final int POWER_MODE_DEFAULT = 2;
    private static final java.lang.String POWER_MODE_PROP = "persist.sys.smart_power";
    private static final java.lang.String TAG = "BrightnessSeekBarMonitor";
    private static final java.lang.String TYPE_ALGO_DEFAULT_BRIGHTNESS = "algoDefaultBrightness";
    private static final java.lang.String TYPE_EYE_PROTECT = "eyeProtect";
    private static final java.lang.String TYPE_TEMP_AUTO_BRIGHTNESS = "tempAutoBrightness";
    private static final java.lang.String TYPE_TEMP_MANUAL_BRIGHTNESS = "tempManualBrightness";
    private static final java.util.Comparator<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> mComparator = new java.util.Comparator<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement>() {
        public int compare(com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement a, com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement b) {
            return (int) (a.startTime - b.startTime);
        }
    };
    private int mAlgoDefaultBrightness;
    private com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement mAutoModeMovement;
    private java.util.List<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> mAutoModeMovementList;
    private final com.android.server.display.BackLightCommonData mCommonData;
    private boolean mIsEyeProtectEnable;
    private boolean mIsManualModeReceiveAmbientLight;
    private com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement mManualModeMovement;
    private java.util.List<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> mManualModeMovementList;
    private final com.android.server.display.DisplayEffectMonitor mMonitor;
    private com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader mSeekBarMovementUploader;
    private java.lang.String mTempAutoBrightnessPackageNameLast;
    private com.android.server.display.DisplayEffectMonitor.ParamLogPrinter mTempAutoBrightnessPrinter;
    private java.lang.String mTempManualBrightnessPackageNameLast;
    private com.android.server.display.DisplayEffectMonitor.ParamLogPrinter mTempManualBrightnessPrinter;

    private static class SeekBarMovement {
        public int algoDefaultLevel;
        public int endLevel;
        public long endTime;
        public java.lang.String foregroundPackageName;
        public boolean isAutoMode;
        public boolean powerSave;
        public boolean protectEye;
        public int startLevel;
        public int startLux;
        public long startTime;
        public boolean thermalLimited;

        private SeekBarMovement() {
        }

        /* synthetic */ SeekBarMovement(com.android.server.display.BrightnessSeekBarMonitor.AnonymousClass1 x0) {
            this();
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SeekBarMovement ");
            stringBuilder.append(this.isAutoMode ? "auto" : "manual");
            stringBuilder.append(", ");
            stringBuilder.append(this.startLevel);
            stringBuilder.append(" -> ");
            stringBuilder.append(this.endLevel);
            stringBuilder.append(", lux ");
            stringBuilder.append(this.startLux);
            stringBuilder.append(", last ");
            stringBuilder.append(this.endTime - this.startTime);
            stringBuilder.append("ms, default ");
            stringBuilder.append(this.algoDefaultLevel);
            stringBuilder.append(", app ");
            stringBuilder.append(this.foregroundPackageName);
            stringBuilder.append(", protectEye ");
            stringBuilder.append(this.protectEye);
            stringBuilder.append(", powerSave ");
            stringBuilder.append(this.powerSave);
            stringBuilder.append(", thermalLimited ");
            stringBuilder.append(this.thermalLimited);
            return stringBuilder.toString();
        }
    }

    private static class SeekBarMovementUploader {
        private static final int HOURS_PER_DAY = 24;
        private static final byte MODE_AUTO = (byte) 1;
        private static final byte MODE_MANUAL = (byte) 2;
        private static final int UPLOAD_TIMES_LIMIT_PER_DAY = 30;
        private static final int UPLOAD_TIMES_LIMIT_PER_HOUR = 10;
        private int mHourCount;
        private java.util.List<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader.SeekBarMovementUploadData> mUploadList = new java.util.ArrayList();
        private int mUploadTimesPerDay;

        private static class SeekBarMovementUploadData {
            public short adjustEndLevel;
            public short adjustStartLevel;
            public short algoCalcDefaultLevel;
            public short ambientLightLux;
            public java.lang.String foregroundPackageName;
            public byte mode;
            public boolean powerSave;
            public boolean protectEye;
            public boolean thermalLimited;

            private SeekBarMovementUploadData() {
            }

            /* synthetic */ SeekBarMovementUploadData(com.android.server.display.BrightnessSeekBarMonitor.AnonymousClass1 x0) {
                this();
            }

            public java.lang.String toString() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("SeekBarMovementUploadData mode ");
                stringBuilder.append(this.mode);
                stringBuilder.append(", ");
                stringBuilder.append(this.adjustStartLevel);
                stringBuilder.append(" -> ");
                stringBuilder.append(this.adjustEndLevel);
                stringBuilder.append(", ambientLightLux ");
                stringBuilder.append(this.ambientLightLux);
                stringBuilder.append(", algoCalcDefaultLevel ");
                stringBuilder.append(this.algoCalcDefaultLevel);
                stringBuilder.append(", app ");
                stringBuilder.append(this.foregroundPackageName);
                stringBuilder.append(", protectEye ");
                stringBuilder.append(this.protectEye);
                stringBuilder.append(", powerSave ");
                stringBuilder.append(this.powerSave);
                stringBuilder.append(", thermalLimited ");
                stringBuilder.append(this.thermalLimited);
                return stringBuilder.toString();
            }
        }

        public void addData(com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement) {
            if (this.mUploadList.size() < 10 && this.mUploadTimesPerDay < 30) {
                byte b = (byte) 1;
                this.mUploadTimesPerDay++;
                com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader.SeekBarMovementUploadData data = new com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader.SeekBarMovementUploadData();
                if (!movement.isAutoMode) {
                    b = (byte) 2;
                }
                data.mode = b;
                data.adjustStartLevel = (short) movement.startLevel;
                data.adjustEndLevel = (short) movement.endLevel;
                int i = 32767;
                if (movement.startLux < 32767) {
                    i = movement.startLux;
                }
                data.ambientLightLux = (short) i;
                data.algoCalcDefaultLevel = (short) movement.algoDefaultLevel;
                data.foregroundPackageName = movement.foregroundPackageName;
                data.protectEye = movement.protectEye;
                data.powerSave = movement.powerSave;
                data.thermalLimited = movement.thermalLimited;
                this.mUploadList.add(data);
            }
        }

        public void upload() {
            if (!this.mUploadList.isEmpty()) {
                for (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader.SeekBarMovementUploadData data : this.mUploadList) {
                    android.util.IMonitor.EventStream stream = android.util.IMonitor.openEventStream(932010102);
                    stream.setParam((short) 0, data.mode);
                    stream.setParam((short) 1, data.adjustStartLevel);
                    stream.setParam((short) 2, data.adjustEndLevel);
                    stream.setParam((short) 3, data.ambientLightLux);
                    stream.setParam((short) 4, data.algoCalcDefaultLevel);
                    stream.setParam((short) 5, data.foregroundPackageName);
                    stream.setParam((short) 6, java.lang.Boolean.valueOf(data.protectEye));
                    stream.setParam((short) 7, java.lang.Boolean.valueOf(data.powerSave));
                    stream.setParam((short) 8, java.lang.Boolean.valueOf(data.thermalLimited));
                    android.util.IMonitor.sendEvent(stream);
                    android.util.IMonitor.closeEventStream(stream);
                    if (com.android.server.display.BrightnessSeekBarMonitor.HWFLOW) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("SeekBarMovementUploader.upload() ");
                        stringBuilder.append(data);
                        android.util.Slog.i("BrightnessSeekBarMonitor", stringBuilder.toString());
                    }
                }
                this.mUploadList.clear();
            }
        }

        public void hourlyTrigger() {
            int i = this.mHourCount + 1;
            this.mHourCount = i;
            if (i >= 24) {
                this.mHourCount = 0;
                this.mUploadTimesPerDay = 0;
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001d  */
    static {
        /*
        r0 = android.util.Log.HWLog;
        r1 = 1;
        r2 = 0;
        if (r0 != 0) goto L_0x0016;
    L_0x0006:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x0014;
    L_0x000a:
        r0 = "BrightnessSeekBarMonitor";
        r3 = 3;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x0014;
    L_0x0013:
        goto L_0x0016;
    L_0x0014:
        r0 = r2;
        goto L_0x0017;
    L_0x0016:
        r0 = r1;
    L_0x0017:
        HWDEBUG = r0;
        r0 = android.util.Log.HWINFO;
        if (r0 != 0) goto L_0x002d;
    L_0x001d:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x002b;
    L_0x0021:
        r0 = "BrightnessSeekBarMonitor";
        r3 = 4;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x002b;
    L_0x002a:
        goto L_0x002d;
    L_0x002b:
        r1 = r2;
    L_0x002d:
        HWFLOW = r1;
        r0 = new com.android.server.display.BrightnessSeekBarMonitor$1;
        r0.<init>();
        mComparator = r0;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.BrightnessSeekBarMonitor.<clinit>():void");
    }

    public BrightnessSeekBarMonitor(com.android.server.display.DisplayEffectMonitor monitor, com.android.server.display.BackLightMonitorManager manager) {
        this.mMonitor = monitor;
        this.mCommonData = manager.getBackLightCommonData();
        if (!this.mCommonData.isCommercialVersion()) {
            this.mAutoModeMovementList = new java.util.ArrayList();
            this.mManualModeMovementList = new java.util.ArrayList();
            com.android.server.display.DisplayEffectMonitor displayEffectMonitor = this.mMonitor;
            java.util.Objects.requireNonNull(displayEffectMonitor);
            this.mTempManualBrightnessPrinter = new com.android.server.display.DisplayEffectMonitor.ParamLogPrinter("tempManualBrightness", "BrightnessSeekBarMonitor");
            displayEffectMonitor = this.mMonitor;
            java.util.Objects.requireNonNull(displayEffectMonitor);
            this.mTempAutoBrightnessPrinter = new com.android.server.display.DisplayEffectMonitor.ParamLogPrinter("tempAutoBrightness", "BrightnessSeekBarMonitor");
            this.mSeekBarMovementUploader = new com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovementUploader();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0049 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x004a A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0049 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x004a A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0049 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x004a A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0049 A:{RETURN} */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x004a A:{RETURN} */
    public boolean isParamOwner(java.lang.String r5) {
        /*
        r4 = this;
        r0 = r5.hashCode();
        r1 = -1659644065; // 0xffffffff9d13d75f float:-1.9566632E-21 double:NaN;
        r2 = 1;
        r3 = 0;
        if (r0 == r1) goto L_0x003b;
    L_0x000b:
        r1 = -1040827554; // 0xffffffffc1f63b5e float:-30.778988 double:NaN;
        if (r0 == r1) goto L_0x0031;
    L_0x0010:
        r1 = 1149740116; // 0x4487a454 float:1085.1353 double:5.68047093E-315;
        if (r0 == r1) goto L_0x0026;
    L_0x0015:
        r1 = 1651298475; // 0x626cd0ab float:1.0921169E21 double:8.158498475E-315;
        if (r0 == r1) goto L_0x001b;
    L_0x001a:
        goto L_0x0045;
    L_0x001b:
        r0 = "tempManualBrightness";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0045;
    L_0x0024:
        r0 = r3;
        goto L_0x0046;
    L_0x0026:
        r0 = "tempAutoBrightness";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0045;
    L_0x002f:
        r0 = r2;
        goto L_0x0046;
    L_0x0031:
        r0 = "eyeProtect";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0045;
    L_0x0039:
        r0 = 3;
        goto L_0x0046;
    L_0x003b:
        r0 = "algoDefaultBrightness";
        r0 = r5.equals(r0);
        if (r0 == 0) goto L_0x0045;
    L_0x0043:
        r0 = 2;
        goto L_0x0046;
    L_0x0045:
        r0 = -1;
    L_0x0046:
        switch(r0) {
            case 0: goto L_0x004a;
            case 1: goto L_0x004a;
            case 2: goto L_0x004a;
            case 3: goto L_0x004a;
            default: goto L_0x0049;
        };
    L_0x0049:
        return r3;
    L_0x004a:
        return r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.BrightnessSeekBarMonitor.isParamOwner(java.lang.String):boolean");
    }

    public void sendMonitorParam(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params != null) {
            if (params.get("paramType") instanceof java.lang.String) {
                java.lang.String paramType = (java.lang.String) params.get("paramType");
                java.lang.Object obj = -1;
                int hashCode = paramType.hashCode();
                if (hashCode != -1659644065) {
                    if (hashCode != -1040827554) {
                        if (hashCode != 1149740116) {
                            if (hashCode == 1651298475) {
                                if (paramType.equals("tempManualBrightness")) {
                                    obj = null;
                                }
                            }
                        } else if (paramType.equals("tempAutoBrightness")) {
                            obj = 1;
                        }
                    } else if (paramType.equals("eyeProtect")) {
                        obj = 3;
                    }
                } else if (paramType.equals("algoDefaultBrightness")) {
                    obj = 2;
                }
                switch (obj) {
                    case null:
                        tempManualBrightness(params);
                        break;
                    case 1:
                        tempAutoBrightness(params);
                        break;
                    case 2:
                        algoDefaultBrightness(params);
                        break;
                    case 3:
                        eyeProtect(params);
                        break;
                    default:
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("sendMonitorParam() undefine paramType: ");
                        stringBuilder.append(paramType);
                        android.util.Slog.e("BrightnessSeekBarMonitor", stringBuilder.toString());
                        break;
                }
                return;
            }
        }
        android.util.Slog.e("BrightnessSeekBarMonitor", "sendMonitorParam() input params format error!");
    }

    public void triggerUploadTimer() {
        seekBarMovementUploader();
    }

    private void tempManualBrightness(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (this.mCommonData.isProductEnable()) {
            if (!this.mCommonData.isCommercialVersion()) {
                if (tempManualBrightnessCheckParamValid(params)) {
                    int brightness = ((java.lang.Integer) params.get("brightness")).intValue();
                    java.lang.String packageName = (java.lang.String) params.get("packageName");
                    tempManualBrightnessPrint(brightness, packageName);
                    if (packageName.equals("android.uid.systemui")) {
                        recordSeekBarMovement(false, brightness);
                    }
                }
            }
        }
    }

    private boolean tempManualBrightnessCheckParamValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params == null) {
            return false;
        }
        if (!(params.get("brightness") instanceof java.lang.Integer)) {
            android.util.Slog.e("BrightnessSeekBarMonitor", "tempManualBrightnessCheckParamValid() can't get param: brightness");
            return false;
        } else if (params.get("packageName") instanceof java.lang.String) {
            return true;
        } else {
            android.util.Slog.e("BrightnessSeekBarMonitor", "tempManualBrightnessCheckParamValid() can't get param: packageName");
            return false;
        }
    }

    private void tempManualBrightnessPrint(int brightness, java.lang.String packageName) {
        if (this.mTempManualBrightnessPackageNameLast == null) {
            this.mTempManualBrightnessPackageNameLast = packageName;
        }
        if (this.mTempManualBrightnessPackageNameLast.equals(packageName)) {
            this.mTempManualBrightnessPrinter.updateParam(brightness, packageName);
            return;
        }
        this.mTempManualBrightnessPrinter.changeName(brightness, packageName);
        this.mTempManualBrightnessPackageNameLast = packageName;
    }

    private void tempAutoBrightness(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (this.mCommonData.isProductEnable()) {
            if (!this.mCommonData.isCommercialVersion()) {
                if (tempAutoBrightnessCheckParamValid(params)) {
                    int brightness = ((java.lang.Integer) params.get("brightness")).intValue();
                    java.lang.String packageName = (java.lang.String) params.get("packageName");
                    tempAutoBrightnessPrint(brightness, packageName);
                    if (brightness != -1 && packageName.equals("android.uid.systemui")) {
                        recordSeekBarMovement(true, brightness);
                    }
                }
            }
        }
    }

    private boolean tempAutoBrightnessCheckParamValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params == null) {
            return false;
        }
        if (!(params.get("brightness") instanceof java.lang.Integer)) {
            android.util.Slog.e("BrightnessSeekBarMonitor", "tempAutoBrightnessCheckParamValid() can't get param: brightness");
            return false;
        } else if (params.get("packageName") instanceof java.lang.String) {
            return true;
        } else {
            android.util.Slog.e("BrightnessSeekBarMonitor", "tempAutoBrightnessCheckParamValid() can't get param: packageName");
            return false;
        }
    }

    private void tempAutoBrightnessPrint(int brightness, java.lang.String packageName) {
        if (this.mTempAutoBrightnessPackageNameLast == null) {
            this.mTempAutoBrightnessPackageNameLast = packageName;
        }
        if (!this.mTempAutoBrightnessPackageNameLast.equals(packageName)) {
            this.mTempAutoBrightnessPrinter.changeName(brightness, packageName);
            this.mTempAutoBrightnessPackageNameLast = packageName;
        } else if (brightness == -1) {
            this.mTempAutoBrightnessPrinter.resetParam(brightness, packageName);
        } else {
            this.mTempAutoBrightnessPrinter.updateParam(brightness, packageName);
        }
    }

    private void algoDefaultBrightness(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (this.mCommonData.isProductEnable()) {
            if (!this.mCommonData.isCommercialVersion()) {
                if (algoDefaultBrightnessCheckParamValid(params)) {
                    this.mCommonData.setSmoothAmbientLight(((java.lang.Integer) params.get("lightValue")).intValue());
                    this.mAlgoDefaultBrightness = ((java.lang.Integer) params.get("brightness")).intValue();
                    java.lang.String mode = (java.lang.String) params.get("brightnessMode");
                    if (HWDEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("algoDefaultBrightness() mAlgoDefaultBrightness=");
                        stringBuilder.append(this.mAlgoDefaultBrightness);
                        android.util.Slog.d("BrightnessSeekBarMonitor", stringBuilder.toString());
                    }
                    if (mode.equals("MANUAL")) {
                        this.mIsManualModeReceiveAmbientLight = true;
                    }
                }
            }
        }
    }

    private boolean algoDefaultBrightnessCheckParamValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params == null) {
            return false;
        }
        if (!(params.get("lightValue") instanceof java.lang.Integer)) {
            android.util.Slog.e("BrightnessSeekBarMonitor", "algoDefaultBrightnessCheckParamValid() can't get param: lightValue");
            return false;
        } else if (!(params.get("brightness") instanceof java.lang.Integer)) {
            android.util.Slog.e("BrightnessSeekBarMonitor", "algoDefaultBrightnessCheckParamValid() can't get param: brightness");
            return false;
        } else if (params.get("brightnessMode") instanceof java.lang.String) {
            return true;
        } else {
            android.util.Slog.e("BrightnessSeekBarMonitor", "algoDefaultBrightnessCheckParamValid() can't get param: brightnessMode");
            return false;
        }
    }

    private void eyeProtect(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (this.mCommonData.isProductEnable()) {
            if (!this.mCommonData.isCommercialVersion()) {
                java.lang.Object enable = params.get("isEnable");
                if (enable instanceof java.lang.Boolean) {
                    this.mIsEyeProtectEnable = ((java.lang.Boolean) enable).booleanValue();
                    if (HWDEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("eyeProtect() mIsEyeProtectEnable=");
                        stringBuilder.append(this.mIsEyeProtectEnable);
                        android.util.Slog.d("BrightnessSeekBarMonitor", stringBuilder.toString());
                    }
                    return;
                }
                android.util.Slog.e("BrightnessSeekBarMonitor", "eyeProtect() can't get param: isEnable");
            }
        }
    }

    private boolean isPowerSaveMode() {
        return 2 != android.os.SystemProperties.getInt("persist.sys.smart_power", 2);
    }

    private void recordSeekBarMovement(boolean isAutoMode, int level) {
        if ((isAutoMode || this.mIsManualModeReceiveAmbientLight) && !this.mCommonData.isWindowManagerBrightnessMode()) {
            long currentTime = android.os.SystemClock.elapsedRealtime();
            com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement = isAutoMode ? this.mAutoModeMovement : this.mManualModeMovement;
            if (movement == null) {
                recordSeekBarMovementStart(new com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement(), isAutoMode, level, currentTime);
                return;
            }
            if (movement.endTime == 0) {
                if (currentTime - movement.startTime > 2000) {
                    recordSeekBarMovementStart(movement, isAutoMode, level, currentTime);
                } else {
                    movement.endTime = currentTime;
                    movement.endLevel = level;
                }
            } else if (currentTime - movement.endTime > 2000) {
                recordSeekBarMovementEnd(movement, isAutoMode);
                recordSeekBarMovementStart(new com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement(), isAutoMode, level, currentTime);
            } else {
                movement.endTime = currentTime;
                movement.endLevel = level;
            }
        }
    }

    private void recordSeekBarMovementStart(com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement, boolean isAutoMode, int level, long time) {
        movement.isAutoMode = isAutoMode;
        movement.startTime = time;
        movement.startLevel = level;
        movement.startLux = this.mCommonData.getSmoothAmbientLight();
        movement.algoDefaultLevel = isAutoMode ? this.mAlgoDefaultBrightness : 0;
        movement.foregroundPackageName = this.mMonitor.getCurrentTopAppName();
        movement.protectEye = this.mIsEyeProtectEnable;
        movement.powerSave = isPowerSaveMode();
        movement.thermalLimited = this.mCommonData.isThermalLimited();
        if (isAutoMode) {
            this.mAutoModeMovement = movement;
        } else {
            this.mManualModeMovement = movement;
        }
    }

    private void recordSeekBarMovementEnd(com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement, boolean isAutoMode) {
        java.lang.Object movement2;
        if (HWFLOW) {
            java.lang.String str = "BrightnessSeekBarMonitor";
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("recordSeekBarMovementEnd() ");
            stringBuilder.append(isAutoMode ? "AUTO" : "MANUAL");
            stringBuilder.append(" ");
            stringBuilder.append(movement2);
            android.util.Slog.i(str, stringBuilder.toString());
        }
        if (movement2.startLevel == movement2.endLevel) {
            movement2 = null;
        }
        if (isAutoMode) {
            if (movement2 != null) {
                this.mAutoModeMovementList.add(movement2);
            }
            this.mAutoModeMovement = null;
            return;
        }
        if (movement2 != null) {
            this.mManualModeMovementList.add(movement2);
        }
        this.mManualModeMovement = null;
    }

    private void seekBarMovementUploader() {
        checkUnfinishedMovement(true);
        checkUnfinishedMovement(false);
        checkMovementListInterval(true);
        checkMovementListInterval(false);
        uploadMovementList();
        this.mSeekBarMovementUploader.hourlyTrigger();
    }

    private void checkUnfinishedMovement(boolean isAutoMode) {
        com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement = isAutoMode ? this.mAutoModeMovement : this.mManualModeMovement;
        if (movement != null) {
            long currentTime = android.os.SystemClock.elapsedRealtime();
            if (movement.endTime != 0 && currentTime - movement.endTime > 2000) {
                recordSeekBarMovementEnd(movement, isAutoMode);
            }
        }
    }

    private void checkMovementListInterval(boolean isAutoMode) {
        java.util.List<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> movementList = isAutoMode ? this.mAutoModeMovementList : this.mManualModeMovementList;
        if (movementList.size() > 1) {
            if (HWDEBUG) {
                for (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement : movementList) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("checkMovementListInterval() before ");
                    stringBuilder.append(movement);
                    android.util.Slog.d("BrightnessSeekBarMonitor", stringBuilder.toString());
                }
            }
            boolean isMerged = false;
            com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement2 = null;
            com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement now = null;
            java.util.Iterator<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> it = movementList.iterator();
            while (it.hasNext()) {
                if (movement2 == null) {
                    movement2 = (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement) it.next();
                } else if (now != null) {
                    movement2 = now;
                }
                now = (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement) it.next();
                if (isMerge2Movement(movement2, now)) {
                    if (HWDEBUG) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("checkMovementListInterval() merge ");
                        stringBuilder2.append(movement2);
                        stringBuilder2.append(" and ");
                        stringBuilder2.append(now);
                        android.util.Slog.d("BrightnessSeekBarMonitor", stringBuilder2.toString());
                    }
                    movement2.endTime = now.endTime;
                    movement2.endLevel = now.endLevel;
                    it.remove();
                    now = null;
                    isMerged = true;
                }
            }
            if (isMerged && HWDEBUG) {
                for (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement3 : movementList) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("checkMovementListInterval() after ");
                    stringBuilder3.append(movement3);
                    android.util.Slog.d("BrightnessSeekBarMonitor", stringBuilder3.toString());
                }
            }
        }
    }

    private boolean isMerge2Movement(com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement pre, com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement now) {
        if (now.startTime - pre.endTime > 15000) {
            return false;
        }
        int deltaLevel = java.lang.Math.abs(now.startLux - pre.startLux);
        int deltaLevelThresholdTmp = (pre.startLux * 50) / 100;
        int deltaLevelThreshold = 5;
        if (deltaLevelThresholdTmp > 5) {
            deltaLevelThreshold = deltaLevelThresholdTmp;
        }
        if (deltaLevel >= deltaLevelThreshold) {
            return false;
        }
        return true;
    }

    private void uploadMovementList() {
        if (!this.mAutoModeMovementList.isEmpty() || !this.mManualModeMovementList.isEmpty()) {
            java.util.List<com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement> allMovementList = new java.util.ArrayList();
            allMovementList.addAll(this.mAutoModeMovementList);
            allMovementList.addAll(this.mManualModeMovementList);
            java.util.Collections.sort(allMovementList, mComparator);
            for (com.android.server.display.BrightnessSeekBarMonitor.SeekBarMovement movement : allMovementList) {
                if (movement.startLevel != movement.endLevel) {
                    this.mSeekBarMovementUploader.addData(movement);
                }
            }
            this.mSeekBarMovementUploader.upload();
            this.mAutoModeMovementList.clear();
            this.mManualModeMovementList.clear();
        }
    }
}
