package com.android.server.display;

class DarkAdaptDetector {
    private static final int DEBUG_ACC_RATE_MAX = 20;
    private static final int DEBUG_ACC_RATE_MIN = 1;
    private static final boolean HWDEBUG;
    private static final boolean HWFLOW;
    private static final java.lang.String TAG = "DarkAdaptDetector";
    private final int DEBUG_ACC_RATE;
    private com.android.server.display.DarkAdaptDetector.State mAdaptedState;
    private com.android.server.display.DarkAdaptDetector.State mAdaptingState;
    private long mAutoModeOffTime;
    private long mAutoModeOnTime;
    private com.android.server.display.HwBrightnessXmlLoader.Data mData;
    private com.android.server.display.DarkAdaptDetector.LuxFilter mFilter;
    private boolean mIsFirst;
    private java.lang.Object mLock = new java.lang.Object();
    private com.android.server.display.DarkAdaptDetector.State mState;
    private com.android.server.display.DarkAdaptDetector.State mUnAdaptedState;

    public enum AdaptState {
        UNADAPTED,
        ADAPTING,
        ADAPTED
    }

    private class LuxFilter {
        private final long LONG_FILTER_LIFE_DURATION_MILLIS;
        private final int MINUTE_PERIOD_MILLIS;
        private final long SHORT_FILTER_LIFE_DURATION_MILLIS;
        private int mContinueMinutes;
        private java.util.Queue<com.android.server.display.DarkAdaptDetector.LuxFilter.Data> mLongFilterQueue;
        private float mMinuteFilteredLuxMax = -1.0f;
        private int mMinuteLuxCnt;
        private float mMinuteLuxSum;
        private long mMinuteStartTime;
        private java.util.Queue<com.android.server.display.DarkAdaptDetector.LuxFilter.Data> mShortFilterQueue;

        private class Data {
            public final float lux;
            public final long time;

            public Data(long time, float lux) {
                this.time = time;
                this.lux = lux;
            }

            public java.lang.String toString() {
                return java.lang.String.format("(%,ds, %.1f)", new java.lang.Object[]{java.lang.Long.valueOf(this.time / 1000), java.lang.Float.valueOf(this.lux)});
            }
        }

        public LuxFilter() {
            this.MINUTE_PERIOD_MILLIS = 60000 / com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE;
            this.LONG_FILTER_LIFE_DURATION_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOffDurationFilterSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.SHORT_FILTER_LIFE_DURATION_MILLIS = ((((long) com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingLongFilterSec) * 2) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.mLongFilterQueue = new java.util.LinkedList();
            this.mShortFilterQueue = new java.util.LinkedList();
        }

        public boolean update(long currentTime, float rawLux, float filteredLux) {
            boolean isLuxChanged = false;
            if (this.mMinuteStartTime != 0 && currentTime - this.mMinuteStartTime >= ((long) this.MINUTE_PERIOD_MILLIS)) {
                float minuteLuxAvg = this.mMinuteLuxSum / ((float) this.mMinuteLuxCnt);
                if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("update() ");
                    stringBuilder.append(java.lang.String.format("avg=%.1f, max=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(minuteLuxAvg), java.lang.Float.valueOf(this.mMinuteFilteredLuxMax)}));
                    android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                }
                queueLongData(new com.android.server.display.DarkAdaptDetector.LuxFilter.Data((this.mMinuteStartTime + currentTime) / 2, minuteLuxAvg), currentTime);
                queueShortData(new com.android.server.display.DarkAdaptDetector.LuxFilter.Data((this.mMinuteStartTime + currentTime) / 2, this.mMinuteFilteredLuxMax), currentTime);
                initMinuteFilter();
                this.mContinueMinutes++;
                isLuxChanged = true;
            }
            if (this.mMinuteStartTime == 0) {
                this.mMinuteStartTime = currentTime;
            }
            if (filteredLux > this.mMinuteFilteredLuxMax) {
                this.mMinuteFilteredLuxMax = filteredLux;
                isLuxChanged = true;
            }
            this.mMinuteLuxSum += rawLux;
            this.mMinuteLuxCnt++;
            return isLuxChanged;
        }

        public void clear(long currentTime) {
            if (this.mMinuteStartTime != 0) {
                if (currentTime - this.mMinuteStartTime >= ((long) (this.MINUTE_PERIOD_MILLIS / 2))) {
                    float minuteLuxAvg = this.mMinuteLuxSum / ((float) this.mMinuteLuxCnt);
                    if (com.android.server.display.DarkAdaptDetector.HWDEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("clear() ");
                        stringBuilder.append(java.lang.String.format("avg=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(minuteLuxAvg)}));
                        android.util.Slog.d("DarkAdaptDetector", stringBuilder.toString());
                    }
                    queueLongData(new com.android.server.display.DarkAdaptDetector.LuxFilter.Data((this.mMinuteStartTime + currentTime) / 2, minuteLuxAvg), currentTime);
                }
                if (com.android.server.display.DarkAdaptDetector.HWDEBUG) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("clear() ");
                    stringBuilder2.append(java.lang.String.format("max=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(this.mMinuteFilteredLuxMax)}));
                    android.util.Slog.d("DarkAdaptDetector", stringBuilder2.toString());
                }
                queueShortData(new com.android.server.display.DarkAdaptDetector.LuxFilter.Data((this.mMinuteStartTime + currentTime) / 2, this.mMinuteFilteredLuxMax), currentTime);
                initMinuteFilter();
                this.mContinueMinutes = 0;
            }
        }

        public float getLongFilterMaxLux(long currentTime, long duration) {
            return dequeueMaxLux(this.mLongFilterQueue, currentTime - duration);
        }

        public int getLongFilterContinueMinutes() {
            return this.mContinueMinutes;
        }

        public float getShortFilterMaxLux(long currentTime, long duration) {
            float max = -1.0f;
            if (duration > 0) {
                max = dequeueMaxLux(this.mShortFilterQueue, currentTime - duration);
            }
            return this.mMinuteFilteredLuxMax > max ? this.mMinuteFilteredLuxMax : max;
        }

        private void initMinuteFilter() {
            this.mMinuteStartTime = 0;
            this.mMinuteLuxSum = 0.0f;
            this.mMinuteFilteredLuxMax = -1.0f;
            this.mMinuteLuxCnt = 0;
        }

        private void queueLongData(com.android.server.display.DarkAdaptDetector.LuxFilter.Data data, long currentTime) {
            queueData(data, this.mLongFilterQueue, currentTime - this.LONG_FILTER_LIFE_DURATION_MILLIS);
            if (com.android.server.display.DarkAdaptDetector.HWDEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("queueLongData() LongFilter=");
                stringBuilder.append(this.mLongFilterQueue);
                android.util.Slog.d("DarkAdaptDetector", stringBuilder.toString());
            }
        }

        private void queueShortData(com.android.server.display.DarkAdaptDetector.LuxFilter.Data data, long currentTime) {
            queueData(data, this.mShortFilterQueue, currentTime - this.SHORT_FILTER_LIFE_DURATION_MILLIS);
            if (com.android.server.display.DarkAdaptDetector.HWDEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("queueShortData() ShortFilter=");
                stringBuilder.append(this.mShortFilterQueue);
                android.util.Slog.d("DarkAdaptDetector", stringBuilder.toString());
            }
        }

        private void queueData(com.android.server.display.DarkAdaptDetector.LuxFilter.Data data, java.util.Queue<com.android.server.display.DarkAdaptDetector.LuxFilter.Data> queue, long lifeTime) {
            if (data != null) {
                if (queue != null) {
                    queue.add(data);
                    while (!queue.isEmpty() && ((com.android.server.display.DarkAdaptDetector.LuxFilter.Data) queue.element()).time < lifeTime) {
                        queue.remove();
                    }
                }
            }
        }

        private float dequeueMaxLux(java.util.Queue<com.android.server.display.DarkAdaptDetector.LuxFilter.Data> queue, long requireTime) {
            float max = -1.0f;
            if (queue == null) {
                return -1.0f;
            }
            for (com.android.server.display.DarkAdaptDetector.LuxFilter.Data data : queue) {
                if (data.time >= requireTime) {
                    max = data.lux > max ? data.lux : max;
                }
            }
            return max;
        }
    }

    private interface State {
        com.android.server.display.DarkAdaptDetector.AdaptState getState();

        void handle(long j);

        void handleFirst(long j);
    }

    private class AdaptedState implements com.android.server.display.DarkAdaptDetector.State {
        private final com.android.server.display.DarkAdaptDetector mDetector;

        public AdaptedState(com.android.server.display.DarkAdaptDetector detector) {
            this.mDetector = detector;
        }

        public com.android.server.display.DarkAdaptDetector.AdaptState getState() {
            return com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTED;
        }

        public void handleFirst(long currentTime) {
            if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) > com.android.server.display.DarkAdaptDetector.this.mData.adapted2UnadaptShortFilterLux) {
                if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("AdaptedState handleFirst() ");
                    stringBuilder.append(java.lang.String.format("shortLux=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(shortLux)}));
                    android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                }
                this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.UNADAPTED);
            }
        }

        public void handle(long currentTime) {
            if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) > com.android.server.display.DarkAdaptDetector.this.mData.adapted2UnadaptShortFilterLux) {
                if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("AdaptedState handle() ");
                    stringBuilder.append(java.lang.String.format("shortLux=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(shortLux)}));
                    android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                }
                this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.UNADAPTED);
            }
        }
    }

    private class AdaptingState implements com.android.server.display.DarkAdaptDetector.State {
        private final long TO_ADAPTED_OFF_DURATION_FILTER_MILLIS;
        private final long TO_ADAPTED_OFF_DURATION_MAX_MILLIS;
        private final long TO_ADAPTED_OFF_DURATION_MIN_MILLIS;
        private final com.android.server.display.DarkAdaptDetector mDetector;

        public AdaptingState(com.android.server.display.DarkAdaptDetector detector) {
            this.mDetector = detector;
            this.TO_ADAPTED_OFF_DURATION_MIN_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOffDurationMinSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.TO_ADAPTED_OFF_DURATION_FILTER_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOffDurationFilterSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.TO_ADAPTED_OFF_DURATION_MAX_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOffDurationMaxSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
        }

        public com.android.server.display.DarkAdaptDetector.AdaptState getState() {
            return com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTING;
        }

        public void handleFirst(long currentTime) {
            if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) > com.android.server.display.DarkAdaptDetector.this.mData.adapting2UnadaptShortFilterLux) {
                if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("AdaptingState handleFirst() ");
                    stringBuilder.append(java.lang.String.format("shortLux=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(shortLux)}));
                    android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                }
                this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.UNADAPTED);
                return;
            }
            long offDurationMillis = this.mDetector.getAutoModeOffDurationMillis();
            if (offDurationMillis > this.TO_ADAPTED_OFF_DURATION_MIN_MILLIS) {
                if (offDurationMillis <= this.TO_ADAPTED_OFF_DURATION_FILTER_MILLIS) {
                    if (this.mDetector.mFilter.getLongFilterMaxLux(currentTime, this.TO_ADAPTED_OFF_DURATION_FILTER_MILLIS) <= com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingLongFilterLux) {
                        if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("AdaptingState handleFirst() ");
                            stringBuilder2.append(java.lang.String.format("offDuration=%,ds, lux=%.1f", new java.lang.Object[]{java.lang.Long.valueOf(offDurationMillis / 1000), java.lang.Float.valueOf(longLux)}));
                            android.util.Slog.i("DarkAdaptDetector", stringBuilder2.toString());
                        }
                        this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTED);
                    }
                } else if (offDurationMillis <= this.TO_ADAPTED_OFF_DURATION_MAX_MILLIS && com.android.server.display.DarkAdaptDetector.this.isHourInRange(com.android.server.display.DarkAdaptDetector.this.getCurrentClockInHour(), com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOnClockNoFilterBeginHour, com.android.server.display.DarkAdaptDetector.this.mData.adapting2AdaptedOnClockNoFilterEndHour)) {
                    this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTED);
                }
            }
        }

        public void handle(long currentTime) {
            if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) > com.android.server.display.DarkAdaptDetector.this.mData.adapting2UnadaptShortFilterLux) {
                if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("AdaptingState handle() ");
                    stringBuilder.append(java.lang.String.format("shortLux=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(shortLux)}));
                    android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                }
                this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.UNADAPTED);
            }
        }
    }

    private class UnAdaptedState implements com.android.server.display.DarkAdaptDetector.State {
        private final long TO_ADAPTED_OFF_DURATION_MILLIS;
        private final long TO_ADAPTING_FILTER_MILLIS;
        private final int TO_ADAPTING_FILTER_MINUTES;
        private final com.android.server.display.DarkAdaptDetector mDetector;

        public UnAdaptedState(com.android.server.display.DarkAdaptDetector detector) {
            this.mDetector = detector;
            this.TO_ADAPTED_OFF_DURATION_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptedOffDurationMinSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.TO_ADAPTING_FILTER_MILLIS = (((long) com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingLongFilterSec) * 1000) / ((long) com.android.server.display.DarkAdaptDetector.this.DEBUG_ACC_RATE);
            this.TO_ADAPTING_FILTER_MINUTES = com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingLongFilterSec / 60;
        }

        public com.android.server.display.DarkAdaptDetector.AdaptState getState() {
            return com.android.server.display.DarkAdaptDetector.AdaptState.UNADAPTED;
        }

        public void handleFirst(long currentTime) {
            if (this.mDetector.getAutoModeOffDurationMillis() > this.TO_ADAPTED_OFF_DURATION_MILLIS) {
                if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) <= com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptedShortFilterLux && com.android.server.display.DarkAdaptDetector.this.isHourInRange(com.android.server.display.DarkAdaptDetector.this.getCurrentClockInHour(), com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptedOnClockNoFilterBeginHour, com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptedOnClockNoFilterEndHour)) {
                    if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("UnAdaptedState handleFirst() ");
                        stringBuilder.append(java.lang.String.format("offDuration=%,ds, lux=%.1f", new java.lang.Object[]{java.lang.Long.valueOf(offDurationMillis / 1000), java.lang.Float.valueOf(shortFilterMaxLux)}));
                        android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                    }
                    this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTED);
                }
            }
        }

        public void handle(long currentTime) {
            if (this.mDetector.mFilter.getLongFilterContinueMinutes() >= this.TO_ADAPTING_FILTER_MINUTES && this.mDetector.mFilter.getShortFilterMaxLux(currentTime, 0) <= com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingShortFilterLux) {
                if (this.mDetector.mFilter.getShortFilterMaxLux(currentTime, this.TO_ADAPTING_FILTER_MILLIS) <= com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingShortFilterLux) {
                    if (this.mDetector.mFilter.getLongFilterMaxLux(currentTime, this.TO_ADAPTING_FILTER_MILLIS) <= com.android.server.display.DarkAdaptDetector.this.mData.unadapt2AdaptingLongFilterLux) {
                        if (com.android.server.display.DarkAdaptDetector.HWFLOW) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("UnAdaptedState handle() ");
                            stringBuilder.append(java.lang.String.format("shortLux=%.1f, longLux=%.1f", new java.lang.Object[]{java.lang.Float.valueOf(shortLux), java.lang.Float.valueOf(longLux)}));
                            android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
                        }
                        this.mDetector.setState(com.android.server.display.DarkAdaptDetector.AdaptState.ADAPTING);
                    }
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001d  */
    static {
        /*
        r0 = android.util.Log.HWLog;
        r1 = 1;
        r2 = 0;
        if (r0 != 0) goto L_0x0016;
    L_0x0006:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x0014;
    L_0x000a:
        r0 = "DarkAdaptDetector";
        r3 = 3;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x0014;
    L_0x0013:
        goto L_0x0016;
    L_0x0014:
        r0 = r2;
        goto L_0x0017;
    L_0x0016:
        r0 = r1;
    L_0x0017:
        HWDEBUG = r0;
        r0 = android.util.Log.HWINFO;
        if (r0 != 0) goto L_0x002d;
    L_0x001d:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x002b;
    L_0x0021:
        r0 = "DarkAdaptDetector";
        r3 = 4;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x002b;
    L_0x002a:
        goto L_0x002d;
    L_0x002b:
        r1 = r2;
    L_0x002d:
        HWFLOW = r1;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.DarkAdaptDetector.<clinit>():void");
    }

    public DarkAdaptDetector(com.android.server.display.HwBrightnessXmlLoader.Data data) {
        int accRate = 1;
        this.mIsFirst = true;
        int accRate2 = android.os.SystemProperties.getInt("persist.darkadaptdetector.rate", 1);
        if (accRate2 >= 1) {
            accRate = accRate2;
        }
        accRate2 = 20;
        if (accRate <= 20) {
            accRate2 = accRate;
        }
        accRate = accRate2;
        this.DEBUG_ACC_RATE = accRate;
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("DarkAdaptDetector() accRate=");
            stringBuilder.append(accRate);
            android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
        }
        this.mData = data;
        this.mFilter = new com.android.server.display.DarkAdaptDetector.LuxFilter();
        this.mUnAdaptedState = new com.android.server.display.DarkAdaptDetector.UnAdaptedState(this);
        this.mAdaptingState = new com.android.server.display.DarkAdaptDetector.AdaptingState(this);
        this.mAdaptedState = new com.android.server.display.DarkAdaptDetector.AdaptedState(this);
        this.mState = this.mUnAdaptedState;
    }

    public void updateLux(float rawLux, float filteredLux) {
        synchronized (this.mLock) {
            long currentTime = android.os.SystemClock.elapsedRealtime();
            boolean isLuxChanged = this.mFilter.update(currentTime, rawLux, filteredLux);
            if (this.mIsFirst) {
                this.mIsFirst = false;
                this.mAutoModeOnTime = currentTime;
                this.mState.handleFirst(currentTime);
            } else if (isLuxChanged) {
                this.mState.handle(currentTime);
            }
        }
    }

    public void setAutoModeOff() {
        synchronized (this.mLock) {
            long currentTime = android.os.SystemClock.elapsedRealtime();
            this.mFilter.clear(currentTime);
            this.mIsFirst = true;
            this.mAutoModeOffTime = currentTime;
        }
    }

    public com.android.server.display.DarkAdaptDetector.AdaptState getState() {
        return this.mState.getState();
    }

    private void setState(com.android.server.display.DarkAdaptDetector.AdaptState state) {
        com.android.server.display.DarkAdaptDetector.AdaptState oldState = this.mState.getState();
        java.lang.StringBuilder stringBuilder;
        if (state == oldState) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setState() same state");
            stringBuilder.append(state);
            android.util.Slog.w("DarkAdaptDetector", stringBuilder.toString());
            return;
        }
        if (HWFLOW) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setState() ");
            stringBuilder.append(oldState);
            stringBuilder.append(" -> ");
            stringBuilder.append(state);
            android.util.Slog.i("DarkAdaptDetector", stringBuilder.toString());
        }
        switch (state) {
            case UNADAPTED:
                this.mState = this.mUnAdaptedState;
                break;
            case ADAPTING:
                this.mState = this.mAdaptingState;
                break;
            case ADAPTED:
                this.mState = this.mAdaptedState;
                break;
            default:
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setState() ");
                stringBuilder.append(state);
                stringBuilder.append(" unknow");
                android.util.Slog.e("DarkAdaptDetector", stringBuilder.toString());
                break;
        }
    }

    private long getAutoModeOffDurationMillis() {
        return this.mAutoModeOnTime - this.mAutoModeOffTime;
    }

    private int getCurrentClockInHour() {
        return java.util.Calendar.getInstance().get(11);
    }

    private boolean isHourInRange(int curr, int begin, int end) {
        boolean z = true;
        if (begin == end) {
            return true;
        }
        if (begin < end) {
            if (curr < begin || curr >= end) {
                z = false;
            }
            return z;
        }
        if (curr < begin) {
            if (curr >= end) {
                z = false;
            }
        }
        return z;
    }
}
