package com.android.server.display;

public class HwAmbientLuxFilterAlgo {
    private static final int AMBIENT_LIGHT_HORIZON = 20000;
    private static final int AMBIENT_MAX_LUX = 40000;
    private static final int AMBIENT_MIN_LUX = 0;
    private static final int AMBIENT_SCENE_HORIZON = 80000;
    private static final boolean DEBUG;
    private static final int EXTRA_DELAY_TIME = 100;
    private static final int MIN_BRIGHTNESS = 4;
    private static final int PROXIMITY_NEGATIVE = 0;
    private static final int PROXIMITY_POSITIVE = 1;
    private static final int PROXIMITY_UNKNOWN = -1;
    private static final java.lang.String TAG = "HwAmbientLuxFilterAlgo";
    private static final long mNormDarkenDebounceTimeForBackSensorCoverMode = 500;
    private static final float mRatioForDarkenBackSensorCoverMode = 0.5f;
    private com.android.server.display.HwRingBuffer mAmbientLightRingBuffer;
    private com.android.server.display.HwRingBuffer mAmbientLightRingBufferFilter;
    private com.android.server.display.HwRingBuffer mAmbientLightRingBufferScene;
    protected float mAmbientLux;
    private float mAmbientLuxNewMax;
    private float mAmbientLuxNewMin;
    public boolean mAutoBrightnessIntervened = false;
    private float mAutoModeEnableFirstLux;
    private int mBackSensorCoverModeBrightness;
    private int mBrightPointCnt = -1;
    private float mBrightenDeltaLuxMax;
    private float mBrightenDeltaLuxMin;
    private boolean mCoverModeDayEnable = false;
    private boolean mCoverState = false;
    private boolean mDarkTimeDelayFromBrightnessEnable = false;
    private float mDarkenDeltaLuxForBackSensorCoverMode;
    private float mDarkenDeltaLuxMax;
    private float mDarkenDeltaLuxMin;
    private final com.android.server.display.HwBrightnessXmlLoader.Data mData;
    private boolean mDayModeEnable = false;
    private boolean mFirstAmbientLux = true;
    private boolean mFirstSetBrightness = true;
    private boolean mGameModeEnable = false;
    private boolean mIsCoverModeFastResponseFlag = false;
    private boolean mIsclosed = false;
    private boolean mKeyguardIsLocked;
    private float mLastCloseScreenLux = 0.0f;
    private com.android.server.display.HwRingBuffer mLastCloseScreenRingBuffer;
    private int mLastCloseTime = -1;
    private float mLastObservedLux;
    private final int mLightSensorRate;
    private final java.lang.Object mLock = new java.lang.Object();
    private float mLuxBufferAvg = 0.0f;
    private float mLuxBufferAvgMax = 0.0f;
    private float mLuxBufferAvgMin = 0.0f;
    private boolean mNeedToSendProximityDebounceMsg = false;
    private boolean mNeedToUpdateBrightness;
    public long mNextTransitionTime = -1;
    protected long mNormBrighenDebounceTime;
    protected long mNormBrighenDebounceTimeForSmallThr;
    protected long mNormDarkenDebounceTime;
    protected long mNormDarkenDebounceTimeForSmallThr;
    private boolean mOffsetResetEnable = false;
    private float mOffsetValidAmbientBrightenDeltaLux;
    private float mOffsetValidAmbientDarkenDeltaLux;
    private float mOffsetValidAmbientLux;
    private int mPendingProximity = -1;
    private long mPendingProximityDebounceTime = -1;
    private boolean mPowerStatus = false;
    private long mPrintLogTime = 0;
    private int mProximity = -1;
    private int mProximityNegativeDebounceTime = 3000;
    private int mProximityPositiveDebounceTime = 150;
    private boolean mProximityPositiveStatus;
    private int mResponseDurationPoints;
    private float mSceneAmbientLuxMax;
    private float mSceneAmbientLuxMin;
    private float mSceneAmbientLuxWeight;
    private float mStability = 0.0f;
    private float mStabilityBrightenConstant = 101.0f;
    private float mStabilityBrightenConstantForSmallThr;
    private float mStabilityDarkenConstant = 101.0f;
    private float mStabilityDarkenConstantForSmallThr;
    private float mStabilityForSmallThr = 0.0f;
    private float mlastFilterLux;

    public interface Callbacks {
        void updateBrightness();
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwAmbientLuxFilterAlgo", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwAmbientLuxFilterAlgo(int lightSensorRate) {
        this.mLightSensorRate = lightSensorRate;
        this.mNeedToUpdateBrightness = false;
        this.mAmbientLightRingBuffer = new com.android.server.display.HwRingBuffer(50);
        this.mAmbientLightRingBufferFilter = new com.android.server.display.HwRingBuffer(50);
        this.mAmbientLightRingBufferScene = new com.android.server.display.HwRingBuffer(250);
        this.mLastCloseScreenRingBuffer = new com.android.server.display.HwRingBuffer(50);
        this.mData = com.android.server.display.HwBrightnessXmlLoader.getData();
    }

    public void isFirstAmbientLux(boolean isFirst) {
        this.mFirstAmbientLux = isFirst;
    }

    public void handleLightSensorEvent(long time, float lux) {
        synchronized (this.mLock) {
            if (!this.mFirstAmbientLux && lux > this.mData.darkLightLuxMinThreshold && lux < this.mData.darkLightLuxMaxThreshold && this.mData.darkLightLuxMinThreshold < this.mData.darkLightLuxMaxThreshold) {
                lux += this.mData.darkLightLuxDelta;
                if (lux < 0.0f) {
                    lux = 0.0f;
                }
            }
            if (lux > 40000.0f) {
                lux = 40000.0f;
            }
            try {
                applyLightSensorMeasurement(time, lux);
                updateAmbientLux(time);
            } catch (java.lang.ArrayIndexOutOfBoundsException e) {
                e.printStackTrace();
            } catch (java.lang.Exception e2) {
                e2.printStackTrace();
            }
        }
    }

    private void applyLightSensorMeasurement(long time, float lux) {
        this.mAmbientLightRingBuffer.prune(time - 20000);
        this.mAmbientLightRingBuffer.push(time, lux);
        this.mLastObservedLux = lux;
    }

    public float getCurrentAmbientLux() {
        return this.mAmbientLux;
    }

    private void setAmbientLux(float lux) {
        this.mAmbientLux = (float) java.lang.Math.round(lux);
        if (this.mAmbientLux < 10.0f) {
            this.mStabilityBrightenConstantForSmallThr = 0.5f;
            this.mStabilityDarkenConstantForSmallThr = 0.5f;
        } else if (this.mAmbientLux < 10.0f || this.mAmbientLux >= 50.0f) {
            this.mStabilityBrightenConstantForSmallThr = 5.0f;
            this.mStabilityDarkenConstantForSmallThr = 5.0f;
        } else {
            this.mStabilityBrightenConstantForSmallThr = 3.0f;
            this.mStabilityDarkenConstantForSmallThr = 3.0f;
        }
        updatepara(this.mAmbientLightRingBuffer, this.mAmbientLux);
        this.mResponseDurationPoints = 0;
    }

    public void updateAmbientLux() {
        synchronized (this.mLock) {
            long time = android.os.SystemClock.uptimeMillis();
            try {
                this.mAmbientLightRingBuffer.push(time, this.mLastObservedLux);
                this.mAmbientLightRingBuffer.prune(time - 20000);
                if (DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("updateAmbientLux:time=");
                    stringBuilder.append(time);
                    stringBuilder.append(",mLastObservedLux=");
                    stringBuilder.append(this.mLastObservedLux);
                    android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                }
                updateAmbientLux(time);
            } catch (java.lang.ArrayIndexOutOfBoundsException e) {
                e.printStackTrace();
            } catch (java.lang.Exception e2) {
                e2.printStackTrace();
            }
        }
    }

    private float modifyFirstAmbientLux(float ambientLux) {
        int N = this.mLastCloseScreenRingBuffer.size();
        if (N > 0 && this.mData.initNumLastBuffer > 0) {
            float tmpLux;
            float sumLux = 0.0f;
            float interfere = this.mData.initDoubleSensorInterfere;
            int cntValidData = 0;
            for (int i = N - 1; i >= 0; i--) {
                tmpLux = this.mLastCloseScreenRingBuffer.getLux(i);
                if (java.lang.Math.abs(this.mAmbientLightRingBuffer.getTime(0) - this.mLastCloseScreenRingBuffer.getTime(i)) < this.mData.initValidCloseTime && java.lang.Math.abs(ambientLux - tmpLux) < 1.5f * interfere) {
                    sumLux += tmpLux;
                    cntValidData++;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("LastScreenBuffer: sumLux=");
            stringBuilder.append(sumLux);
            stringBuilder.append(", cntValidData=");
            stringBuilder.append(cntValidData);
            stringBuilder.append(", InambientLux=");
            stringBuilder.append(ambientLux);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            if (((float) cntValidData) > 1.0E-7f && ambientLux < ((float) this.mData.initUpperLuxThreshold) + 1.0E-6f && sumLux / ((float) cntValidData) < 1.0E-6f + ambientLux) {
                float ave = sumLux / ((float) cntValidData);
                tmpLux = 1.0f / (((float) java.lang.Math.exp((double) ((-this.mData.initSigmoidFuncSlope) * (interfere - java.lang.Math.abs(ambientLux - ave))))) + 1.0f);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("modifyFirstAmbientLux : lambda=");
                stringBuilder2.append(tmpLux);
                stringBuilder2.append(", ave");
                stringBuilder2.append(ave);
                stringBuilder2.append(", ambientLux=");
                stringBuilder2.append(ambientLux);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
                return (tmpLux * ave) + ((1.0f - tmpLux) * ambientLux);
            }
        }
        return ambientLux;
    }

    private float calcAmbientLuxInCoverState(float ambientLux) {
        java.lang.StringBuilder stringBuilder;
        if (this.mPowerStatus) {
            if (!this.mData.coverModelastCloseScreenEnable) {
                ambientLux = this.mLastCloseScreenLux;
                this.mAmbientLightRingBuffer.putLux(0, ambientLux);
                this.mAmbientLightRingBufferFilter.putLux(0, ambientLux);
                if (DEBUG) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("LabcCoverMode1 use lastCloseScreenLux=");
                    stringBuilder.append(this.mLastCloseScreenLux);
                    android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                }
            }
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("LabcCoverMode1 ambientLux=");
                stringBuilder.append(ambientLux);
                stringBuilder.append(",mCoverState=");
                stringBuilder.append(this.mCoverState);
                stringBuilder.append(",mPowerStatus=");
                stringBuilder.append(this.mPowerStatus);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            }
        } else {
            java.lang.StringBuilder stringBuilder2;
            if (this.mData.lastCloseScreenEnable) {
                ambientLux = this.mLastCloseScreenLux;
            } else if (this.mData.backSensorCoverModeEnable) {
                ambientLux = (float) getLuxFromDefaultBrightnessLevel((float) this.mBackSensorCoverModeBrightness);
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("BackSensorCoverMode ambientLux=");
                stringBuilder2.append(ambientLux);
                stringBuilder2.append(", coverModeBrightness=");
                stringBuilder2.append(this.mBackSensorCoverModeBrightness);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
            } else if (!this.mData.coverModeDayEnable) {
                ambientLux = this.mData.coverModeFirstLux;
            } else if (this.mCoverModeDayEnable) {
                ambientLux = (float) getLuxFromDefaultBrightnessLevel((float) this.mData.coverModeDayBrightness);
            } else {
                ambientLux = (float) getLuxFromDefaultBrightnessLevel((float) getCoverModeBrightnessFromLastScreenBrightness());
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("LabcCoverMode NewambientLux=");
                stringBuilder2.append(ambientLux);
                stringBuilder2.append(",LastScreenBrightness=");
                stringBuilder2.append(getCoverModeBrightnessFromLastScreenBrightness());
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
            }
            this.mAmbientLightRingBuffer.putLux(0, ambientLux);
            this.mAmbientLightRingBufferFilter.putLux(0, ambientLux);
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("LabcCoverMode ambientLux=");
                stringBuilder.append(ambientLux);
                stringBuilder.append(",mCoverState=");
                stringBuilder.append(this.mCoverState);
                stringBuilder.append(",mPowerStatus=");
                stringBuilder.append(this.mPowerStatus);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            }
        }
        return ambientLux;
    }

    /* JADX WARNING: Removed duplicated region for block: B:75:0x0239  */
    /* JADX WARNING: Removed duplicated region for block: B:101:0x0333  */
    /* JADX WARNING: Removed duplicated region for block: B:100:0x0330  */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x034b  */
    /* JADX WARNING: Removed duplicated region for block: B:104:0x033f  */
    private void updateAmbientLux(long r34) {
        /*
        r33 = this;
        r7 = r33;
        r8 = r34;
        r0 = r7.mData;
        r0 = r0.preMethodNum;
        r10 = r7.prefilterAmbientLux(r8, r0);
        r11 = r33.getOrigLastAmbientLux(r34);
        r0 = 20000; // 0x4e20 float:2.8026E-41 double:9.8813E-320;
        r7.updateBuffer(r8, r10, r0);
        r0 = 80000; // 0x13880 float:1.12104E-40 double:3.95253E-319;
        r7.updateBufferForScene(r8, r10, r0);
        r0 = r33.getFilterLastAmbientLux(r34);
        r7.mlastFilterLux = r0;
        r0 = r7.mData;
        r0 = r0.postMethodNum;
        r0 = r7.postfilterAmbientLux(r8, r0);
        r1 = r7.mFirstAmbientLux;
        r12 = 1;
        r13 = 0;
        if (r1 == 0) goto L_0x008a;
    L_0x002f:
        r1 = r7.mCoverState;
        if (r1 == 0) goto L_0x0039;
    L_0x0033:
        r7.mCoverState = r13;
        r0 = r7.calcAmbientLuxInCoverState(r0);
    L_0x0039:
        r0 = r7.modifyFirstAmbientLux(r0);
        r7.setAmbientLux(r0);
        r1 = r7.mData;
        r1 = r1.offsetValidAmbientLuxEnable;
        if (r1 == 0) goto L_0x0049;
    L_0x0046:
        r7.setOffsetValidAmbientLux(r0);
    L_0x0049:
        r7.mFirstAmbientLux = r13;
        r7.mCoverModeDayEnable = r13;
        r1 = DEBUG;
        if (r1 == 0) goto L_0x0088;
    L_0x0051:
        r1 = "HwAmbientLuxFilterAlgo";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "updateAmbientLux: Initializing: mAmbientLightRingBuffer=";
        r2.append(r3);
        r3 = r7.mAmbientLightRingBuffer;
        r2.append(r3);
        r3 = ", mAmbientLux=";
        r2.append(r3);
        r3 = r7.mAmbientLux;
        r2.append(r3);
        r3 = ",mLastCloseScreenLux=";
        r2.append(r3);
        r3 = r7.mLastCloseScreenLux;
        r2.append(r3);
        r3 = ",mAmbientLightRingBufferFilter=";
        r2.append(r3);
        r3 = r7.mAmbientLightRingBufferFilter;
        r2.append(r3);
        r2 = r2.toString();
        android.util.Slog.d(r1, r2);
    L_0x0088:
        r7.mNeedToUpdateBrightness = r12;
    L_0x008a:
        r14 = r0;
        r0 = r7.mAmbientLightRingBufferScene;
        r7.updateNewAmbientLuxFromScene(r0);
        r0 = r7.mAmbientLightRingBuffer;
        r1 = r7.mAmbientLux;
        r7.updatepara(r0, r1);
        r15 = r33.nextAmbientLightBrighteningTransition(r34);
        r17 = r33.nextAmbientLightDarkeningTransition(r34);
        r19 = r7.decideToBrighten(r14);
        r20 = r7.decideToBrighten(r11);
        r21 = r7.decideToDarken(r14);
        r22 = r7.decideToDarken(r11);
        r0 = r7.mData;
        r0 = r0.offsetValidAmbientLuxEnable;
        if (r0 == 0) goto L_0x00f1;
    L_0x00b5:
        r23 = r33.nextAmbientLightBrighteningTransitionForOffset(r34);
        r3 = r7.mOffsetValidAmbientLux;
        r4 = r7.mOffsetValidAmbientDarkenDeltaLux;
        r0 = r7.mData;
        r0 = r0.offsetDarkenDebounceTime;
        r5 = (long) r0;
        r0 = r7;
        r1 = r8;
        r0 = r0.nextAmbientLightDarkeningTransitionExtended(r1, r3, r4, r5);
        r2 = r7.decideToBrightenForOffset(r14);
        r3 = r7.decideToDarkenForOffset(r14);
        if (r2 == 0) goto L_0x00d8;
    L_0x00d2:
        r4 = (r23 > r8 ? 1 : (r23 == r8 ? 0 : -1));
        if (r4 > 0) goto L_0x00d8;
    L_0x00d6:
        r4 = r12;
        goto L_0x00d9;
    L_0x00d8:
        r4 = r13;
    L_0x00d9:
        r2 = r4;
        if (r3 == 0) goto L_0x00e2;
    L_0x00dc:
        r4 = (r0 > r8 ? 1 : (r0 == r8 ? 0 : -1));
        if (r4 > 0) goto L_0x00e2;
    L_0x00e0:
        r4 = r12;
        goto L_0x00e3;
    L_0x00e2:
        r4 = r13;
    L_0x00e3:
        r3 = r4;
        r4 = r7.mData;
        r4 = r4.offsetValidAmbientLuxEnable;
        if (r4 == 0) goto L_0x00f1;
    L_0x00ea:
        r4 = r2 | r3;
        if (r4 == 0) goto L_0x00f1;
    L_0x00ee:
        r7.setOffsetValidAmbientLux(r14);
    L_0x00f1:
        r0 = r7.mBrightPointCnt;
        r0 = (float) r0;
        r1 = -1249495107; // 0xffffffffb58637bd float:-1.0E-6 double:NaN;
        r0 = (r0 > r1 ? 1 : (r0 == r1 ? 0 : -1));
        if (r0 <= 0) goto L_0x0100;
    L_0x00fb:
        r0 = r7.mBrightPointCnt;
        r0 = r0 + r12;
        r7.mBrightPointCnt = r0;
    L_0x0100:
        r0 = r7.mBrightPointCnt;
        r1 = r7.mData;
        r1 = r1.outdoorResponseCount;
        if (r0 <= r1) goto L_0x010b;
    L_0x0108:
        r0 = -1;
        r7.mBrightPointCnt = r0;
    L_0x010b:
        r23 = r33.nextAmbientLightBrighteningTransitionForSmallThr(r34);
        r3 = r7.mAmbientLux;
        r4 = r7.mDarkenDeltaLuxMin;
        r5 = r7.mNormDarkenDebounceTimeForSmallThr;
        r0 = r7;
        r1 = r8;
        r0 = r0.nextAmbientLightDarkeningTransitionExtended(r1, r3, r4, r5);
        r2 = r7.decideToBrightenForSmallThr(r14);
        r3 = r7.decideToDarkenForSmallThr(r14);
        if (r2 == 0) goto L_0x012b;
    L_0x0125:
        r4 = (r23 > r8 ? 1 : (r23 == r8 ? 0 : -1));
        if (r4 > 0) goto L_0x012b;
    L_0x0129:
        r4 = r12;
        goto L_0x012c;
    L_0x012b:
        r4 = r13;
    L_0x012c:
        r2 = r4;
        if (r3 == 0) goto L_0x0135;
    L_0x012f:
        r4 = (r0 > r8 ? 1 : (r0 == r8 ? 0 : -1));
        if (r4 > 0) goto L_0x0135;
    L_0x0133:
        r4 = r12;
        goto L_0x0136;
    L_0x0135:
        r4 = r13;
    L_0x0136:
        r3 = r4;
        if (r19 == 0) goto L_0x013f;
    L_0x0139:
        if (r20 == 0) goto L_0x013f;
    L_0x013b:
        r4 = (r15 > r8 ? 1 : (r15 == r8 ? 0 : -1));
        if (r4 <= 0) goto L_0x0141;
    L_0x013f:
        if (r2 == 0) goto L_0x0143;
    L_0x0141:
        r4 = r12;
        goto L_0x0144;
    L_0x0143:
        r4 = r13;
    L_0x0144:
        if (r21 == 0) goto L_0x014c;
    L_0x0146:
        if (r22 == 0) goto L_0x014c;
    L_0x0148:
        r5 = (r17 > r8 ? 1 : (r17 == r8 ? 0 : -1));
        if (r5 <= 0) goto L_0x0157;
    L_0x014c:
        if (r3 != 0) goto L_0x0157;
    L_0x014e:
        r5 = r7.needToDarkenForBackSensorCoverMode(r8, r14);
        if (r5 == 0) goto L_0x0155;
    L_0x0154:
        goto L_0x0157;
    L_0x0155:
        r5 = r13;
        goto L_0x0158;
    L_0x0157:
        r5 = r12;
    L_0x0158:
        r6 = r7.mAmbientLux;
        r12 = r7.mBrightenDeltaLuxMax;
        r6 = r6 + r12;
        r12 = r7.mAmbientLux;
        r13 = r7.mDarkenDeltaLuxMax;
        r12 = r12 - r13;
        r13 = DEBUG;
        r25 = 2000; // 0x7d0 float:2.803E-42 double:9.88E-321;
        r27 = r0;
        if (r13 == 0) goto L_0x0231;
    L_0x016a:
        r0 = r7.mPrintLogTime;
        r0 = r8 - r0;
        r0 = (r0 > r25 ? 1 : (r0 == r25 ? 0 : -1));
        if (r0 <= 0) goto L_0x0231;
    L_0x0172:
        r0 = "HwAmbientLuxFilterAlgo";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r13 = "t=";
        r1.append(r13);
        r1.append(r8);
        r13 = ",lx=";
        r1.append(r13);
        r13 = r7.mAmbientLightRingBuffer;
        r29 = r10;
        r10 = 6;
        r13 = r13.toString(r10);
        r1.append(r13);
        r10 = ",mLx=";
        r1.append(r10);
        r10 = r7.mAmbientLux;
        r1.append(r10);
        r10 = ",s=";
        r1.append(r10);
        r10 = r7.mStability;
        r1.append(r10);
        r10 = ",ss=";
        r1.append(r10);
        r10 = r7.mStabilityForSmallThr;
        r1.append(r10);
        r10 = ",AuIntervened=";
        r1.append(r10);
        r10 = r7.mAutoBrightnessIntervened;
        r1.append(r10);
        r10 = ",mOffLux=";
        r1.append(r10);
        r10 = r7.mOffsetValidAmbientLux;
        r1.append(r10);
        r10 = ",mProximityState=";
        r1.append(r10);
        r10 = r7.mProximityPositiveStatus;
        r1.append(r10);
        r10 = ",bLux=";
        r1.append(r10);
        r1.append(r6);
        r10 = ",dLux=";
        r1.append(r10);
        r1.append(r12);
        r10 = ",mDt=";
        r1.append(r10);
        r30 = r11;
        r10 = r7.mNormDarkenDebounceTime;
        r1.append(r10);
        r10 = ",mBt=";
        r1.append(r10);
        r10 = r7.mNormBrighenDebounceTime;
        r1.append(r10);
        r10 = ",mMax=";
        r1.append(r10);
        r10 = r7.mAmbientLuxNewMax;
        r1.append(r10);
        r10 = ",mMin=";
        r1.append(r10);
        r10 = r7.mAmbientLuxNewMin;
        r1.append(r10);
        r10 = ",mu=";
        r1.append(r10);
        r10 = r7.mSceneAmbientLuxWeight;
        r1.append(r10);
        r10 = ",sMax=";
        r1.append(r10);
        r10 = r7.mSceneAmbientLuxMax;
        r1.append(r10);
        r10 = ",sMin=";
        r1.append(r10);
        r10 = r7.mSceneAmbientLuxMin;
        r1.append(r10);
        r1 = r1.toString();
        android.util.Slog.d(r0, r1);
        r7.mPrintLogTime = r8;
        goto L_0x0235;
    L_0x0231:
        r29 = r10;
        r30 = r11;
    L_0x0235:
        r0 = r4 | r5;
        if (r0 == 0) goto L_0x032c;
    L_0x0239:
        r0 = 0;
        r7.mBrightPointCnt = r0;
        r7.setAmbientLux(r14);
        r0 = r7.mData;
        r0 = r0.offsetValidAmbientLuxEnable;
        if (r0 == 0) goto L_0x024c;
    L_0x0245:
        if (r2 != 0) goto L_0x0249;
    L_0x0247:
        if (r3 == 0) goto L_0x024c;
    L_0x0249:
        r7.setOffsetValidAmbientLux(r14);
    L_0x024c:
        r0 = DEBUG;
        if (r0 == 0) goto L_0x02c5;
    L_0x0250:
        r0 = "HwAmbientLuxFilterAlgo";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r10 = "updateAmbientLux: ";
        r1.append(r10);
        r10 = 1;
        if (r4 != r10) goto L_0x0263;
    L_0x0260:
        r10 = "Brightened";
        goto L_0x0265;
    L_0x0263:
        r10 = "Darkened";
    L_0x0265:
        r1.append(r10);
        r10 = ", mAmbientLightRingBuffer=";
        r1.append(r10);
        r10 = r7.mAmbientLightRingBuffer;
        r11 = 6;
        r10 = r10.toString(r11);
        r1.append(r10);
        r10 = ",mPxs=";
        r1.append(r10);
        r10 = r7.mProximityPositiveStatus;
        r1.append(r10);
        r10 = ", mAmbientLux=";
        r1.append(r10);
        r10 = r7.mAmbientLux;
        r1.append(r10);
        r10 = ",s=";
        r1.append(r10);
        r10 = r7.mStability;
        r1.append(r10);
        r10 = ",ss=";
        r1.append(r10);
        r10 = r7.mStabilityForSmallThr;
        r1.append(r10);
        r10 = ",needBs=";
        r1.append(r10);
        r1.append(r2);
        r10 = ",needDs=";
        r1.append(r10);
        r1.append(r3);
        r10 = ", mAmbientLightRingBufferF=";
        r1.append(r10);
        r10 = r7.mAmbientLightRingBufferFilter;
        r11 = 6;
        r10 = r10.toString(r11);
        r1.append(r10);
        r1 = r1.toString();
        android.util.Slog.d(r0, r1);
    L_0x02c5:
        r0 = DEBUG;
        if (r0 == 0) goto L_0x02f3;
    L_0x02c9:
        r0 = r7.mIsCoverModeFastResponseFlag;
        if (r0 == 0) goto L_0x02f3;
    L_0x02cd:
        r0 = "HwAmbientLuxFilterAlgo";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r10 = "CoverModeBResponseTime=";
        r1.append(r10);
        r10 = r7.mData;
        r10 = r10.coverModeBrightenResponseTime;
        r1.append(r10);
        r10 = ",CoverModeDResponseTime=";
        r1.append(r10);
        r10 = r7.mData;
        r10 = r10.coverModeDarkenResponseTime;
        r1.append(r10);
        r1 = r1.toString();
        android.util.Slog.i(r0, r1);
    L_0x02f3:
        r0 = DEBUG;
        if (r0 == 0) goto L_0x0321;
    L_0x02f7:
        r0 = r7.mPowerStatus;
        if (r0 == 0) goto L_0x0321;
    L_0x02fb:
        r0 = "HwAmbientLuxFilterAlgo";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r10 = "PowerOnBT=";
        r1.append(r10);
        r10 = r7.mData;
        r10 = r10.powerOnBrightenDebounceTime;
        r1.append(r10);
        r10 = ",PowerOnDT=";
        r1.append(r10);
        r10 = r7.mData;
        r10 = r10.powerOnDarkenDebounceTime;
        r1.append(r10);
        r1 = r1.toString();
        android.util.Slog.i(r0, r1);
    L_0x0321:
        r0 = 1;
        r7.mNeedToUpdateBrightness = r0;
        r15 = r33.nextAmbientLightBrighteningTransition(r34);
        r17 = r33.nextAmbientLightDarkeningTransition(r34);
    L_0x032c:
        r0 = (r17 > r15 ? 1 : (r17 == r15 ? 0 : -1));
        if (r0 >= 0) goto L_0x0333;
    L_0x0330:
        r0 = r17;
        goto L_0x0334;
    L_0x0333:
        r0 = r15;
    L_0x0334:
        r7.mNextTransitionTime = r0;
        r0 = r7.mNextTransitionTime;
        r0 = (r0 > r8 ? 1 : (r0 == r8 ? 0 : -1));
        r10 = 100;
        if (r0 <= 0) goto L_0x034b;
    L_0x033f:
        r0 = r7.mNextTransitionTime;
        r13 = r7.mLightSensorRate;
        r31 = r2;
        r32 = r3;
        r2 = (long) r13;
        r0 = r0 + r2;
    L_0x0349:
        r0 = r0 + r10;
        goto L_0x0354;
    L_0x034b:
        r31 = r2;
        r32 = r3;
        r0 = r7.mLightSensorRate;
        r0 = (long) r0;
        r0 = r0 + r8;
        goto L_0x0349;
    L_0x0354:
        r7.mNextTransitionTime = r0;
        r0 = DEBUG;
        if (r0 == 0) goto L_0x0384;
    L_0x035a:
        r0 = r7.mPrintLogTime;
        r0 = r8 - r0;
        r0 = (r0 > r25 ? 1 : (r0 == r25 ? 0 : -1));
        if (r0 <= 0) goto L_0x0384;
    L_0x0362:
        r0 = "HwAmbientLuxFilterAlgo";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "updateAmbientLux: Scheduling ambient lux update for ";
        r1.append(r2);
        r2 = r7.mNextTransitionTime;
        r1.append(r2);
        r2 = r7.mNextTransitionTime;
        r2 = android.util.TimeUtils.formatUptime(r2);
        r1.append(r2);
        r1 = r1.toString();
        android.util.Slog.d(r0, r1);
    L_0x0384:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwAmbientLuxFilterAlgo.updateAmbientLux(long):void");
    }

    private void updateNewAmbientLuxFromScene(com.android.server.display.HwRingBuffer hwBuffer) {
        int N = hwBuffer.size();
        this.mAmbientLuxNewMax = this.mAmbientLux;
        this.mAmbientLuxNewMin = this.mAmbientLux;
        this.mSceneAmbientLuxMax = this.mAmbientLux;
        this.mSceneAmbientLuxMin = this.mAmbientLux;
        if (this.mResponseDurationPoints == Integer.MAX_VALUE) {
            this.mResponseDurationPoints = Integer.MAX_VALUE;
        } else {
            this.mResponseDurationPoints++;
        }
        if (N != 0 && N >= this.mData.sceneGapPoints && this.mResponseDurationPoints - this.mData.sceneMinPoints >= this.mData.sceneGapPoints && this.mData.sceneMaxPoints >= this.mData.sceneMinPoints) {
            if (this.mData.sceneMaxPoints + this.mData.sceneGapPoints <= 228) {
                updateSceneBufferAmbientLuxMaxMinAvg(hwBuffer, this.mResponseDurationPoints < this.mData.sceneMaxPoints + this.mData.sceneGapPoints ? N - this.mResponseDurationPoints : (N - this.mData.sceneMaxPoints) - this.mData.sceneGapPoints, N - this.mData.sceneGapPoints);
                this.mSceneAmbientLuxWeight = ((float) this.mData.sceneGapPoints) / ((float) this.mResponseDurationPoints);
                if (this.mAmbientLux > this.mSceneAmbientLuxMax) {
                    this.mAmbientLuxNewMax = (this.mSceneAmbientLuxWeight * this.mAmbientLux) + ((1.0f - this.mSceneAmbientLuxWeight) * this.mSceneAmbientLuxMax);
                }
                if (this.mAmbientLux > this.mSceneAmbientLuxMin) {
                    this.mAmbientLuxNewMin = (this.mSceneAmbientLuxWeight * this.mAmbientLux) + ((1.0f - this.mSceneAmbientLuxWeight) * this.mSceneAmbientLuxMin);
                }
                correctAmbientLux();
            }
        }
    }

    private void updateSceneBufferAmbientLuxMaxMinAvg(com.android.server.display.HwRingBuffer buffer, int start, int end) {
        int N = buffer.size();
        if (N != 0 && end >= start && start <= N - 1 && end >= 0 && start >= 0) {
            if (end <= N - 1) {
                float luxMin = buffer.getLux(start);
                float luxMax = buffer.getLux(start);
                float luxMin2 = luxMin;
                luxMin = 0.0f;
                for (int i = start; i <= end; i++) {
                    float lux = buffer.getLux(i);
                    if (lux > luxMax) {
                        luxMax = lux;
                    }
                    if (lux < luxMin2) {
                        luxMin2 = lux;
                    }
                    luxMin += lux;
                }
                float luxMean = (float) java.lang.Math.round(luxMin / ((float) ((end - start) + 1)));
                this.mSceneAmbientLuxMax = (this.mData.sceneAmbientLuxMaxWeight * luxMean) + ((1.0f - this.mData.sceneAmbientLuxMaxWeight) * luxMax);
                this.mSceneAmbientLuxMin = (this.mData.sceneAmbientLuxMinWeight * luxMean) + ((1.0f - this.mData.sceneAmbientLuxMinWeight) * luxMin2);
                return;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("SceneBufferAmbientLux input error,end=");
        stringBuilder.append(end);
        stringBuilder.append(",start=");
        stringBuilder.append(start);
        stringBuilder.append(",N=");
        stringBuilder.append(N);
        android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
    }

    private void correctAmbientLux() {
        java.lang.StringBuilder stringBuilder;
        float ambientLuxDarkenDelta = calculateDarkenThresholdDelta(this.mAmbientLux);
        float ambientLuxNewMaxBrightenDelta = calculateBrightenThresholdDelta(this.mAmbientLuxNewMax);
        float ambientLuxNewMinBrightenDelta = calculateBrightenThresholdDelta(this.mAmbientLuxNewMin);
        if (this.mAmbientLux - ambientLuxDarkenDelta > this.mAmbientLuxNewMax - 1.0E-5f) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" Reset mAmbientLuxNewMax:mAmbientLux");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(", ambientLuxDarkenDelta=");
            stringBuilder.append(ambientLuxDarkenDelta);
            stringBuilder.append(", mAmbientLuxNewMax=");
            stringBuilder.append(this.mAmbientLuxNewMax);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            this.mAmbientLuxNewMax = this.mAmbientLux;
        }
        if (this.mAmbientLux > (this.mAmbientLuxNewMax + ambientLuxNewMaxBrightenDelta) - 1.0E-5f) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" Reset mAmbientLuxNewMax:mAmbientLux");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(", ambientLuxNewMaxBrightenDelta=");
            stringBuilder.append(ambientLuxNewMaxBrightenDelta);
            stringBuilder.append(", mAmbientLuxNewMax=");
            stringBuilder.append(this.mAmbientLuxNewMax);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            this.mAmbientLuxNewMax = this.mAmbientLux;
        }
        if (this.mAmbientLux - ambientLuxDarkenDelta > this.mAmbientLuxNewMin - 1.0E-5f) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" Reset mAmbientLuxNewMin:mAmbientLux");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(", ambientLuxDarkenDelta=");
            stringBuilder.append(ambientLuxDarkenDelta);
            stringBuilder.append(", mAmbientLuxNewMin=");
            stringBuilder.append(this.mAmbientLuxNewMin);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            this.mAmbientLuxNewMin = this.mAmbientLux;
        }
        if (this.mAmbientLux > (this.mAmbientLuxNewMin + ambientLuxNewMinBrightenDelta) - 1.0E-5f) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" Reset mAmbientLuxNewMin:mAmbientLux");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(", ambientLuxNewMinBrightenDelta=");
            stringBuilder.append(ambientLuxNewMinBrightenDelta);
            stringBuilder.append(", mAmbientLuxNewMin=");
            stringBuilder.append(this.mAmbientLuxNewMin);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            this.mAmbientLuxNewMin = this.mAmbientLux;
        }
    }

    public boolean needToUpdateBrightness() {
        return this.mNeedToUpdateBrightness;
    }

    public boolean brightnessUpdated() {
        this.mNeedToUpdateBrightness = false;
        return false;
    }

    public boolean needToSendUpdateAmbientLuxMsg() {
        return this.mNextTransitionTime > 0;
    }

    public long getSendUpdateAmbientLuxMsgTime() {
        return this.mNextTransitionTime;
    }

    private long getNextAmbientLightBrighteningTime(long earliedtime) {
        if (this.mIsCoverModeFastResponseFlag) {
            return this.mData.coverModeBrightenResponseTime + earliedtime;
        }
        if (getKeyguardLockedBrightenEnable()) {
            return ((long) this.mData.keyguardResponseBrightenTime) + earliedtime;
        }
        if (getOutdoorModeBrightenEnable()) {
            return ((long) this.mData.outdoorResponseBrightenTime) + earliedtime;
        }
        if (getProximityPositiveBrightenEnable()) {
            return ((long) this.mData.proximityResponseBrightenTime) + earliedtime;
        }
        if (this.mPowerStatus) {
            if (getSlowResponsePowerStatus()) {
                return (((long) this.mData.powerOnBrightenDebounceTime) + earliedtime) + ((long) this.mData.initSlowReponseBrightTime);
            }
            return ((long) this.mData.powerOnBrightenDebounceTime) + earliedtime;
        } else if (this.mGameModeEnable) {
            return this.mData.gameModeBrightenDebounceTime + earliedtime;
        } else {
            return this.mNormBrighenDebounceTime + earliedtime;
        }
    }

    private long getNextAmbientLightDarkeningTime(long earliedtime) {
        if (this.mIsCoverModeFastResponseFlag) {
            return this.mData.coverModeDarkenResponseTime + earliedtime;
        }
        if (getKeyguardLockedDarkenEnable()) {
            return ((long) this.mData.keyguardResponseDarkenTime) + earliedtime;
        }
        if (getOutdoorModeDarkenEnable()) {
            return ((long) this.mData.outdoorResponseDarkenTime) + earliedtime;
        }
        if (this.mPowerStatus) {
            return ((long) this.mData.powerOnDarkenDebounceTime) + earliedtime;
        }
        if (this.mGameModeEnable) {
            return this.mData.gameModeDarkenDebounceTime + earliedtime;
        }
        return this.mNormDarkenDebounceTime + earliedtime;
    }

    /* JADX WARNING: Missing block: B:15:0x0034, code:
            return false;
     */
    private boolean getKeyguardLockedBrightenEnable() {
        /*
        r4 = this;
        r0 = r4.mAmbientLightRingBuffer;
        r0 = r0.size();
        r1 = 0;
        if (r0 != 0) goto L_0x0011;
    L_0x0009:
        r2 = "HwAmbientLuxFilterAlgo";
        r3 = "getKeyguardLocked no lux";
        android.util.Slog.e(r2, r3);
        return r1;
    L_0x0011:
        r2 = r4.mKeyguardIsLocked;
        if (r2 == 0) goto L_0x0034;
    L_0x0015:
        r2 = r4.mAmbientLightRingBuffer;
        r3 = r0 + -1;
        r2 = r2.getLux(r3);
        r3 = r4.mData;
        r3 = r3.keyguardLuxThreshold;
        r2 = (r2 > r3 ? 1 : (r2 == r3 ? 0 : -1));
        if (r2 <= 0) goto L_0x0034;
    L_0x0025:
        r2 = r4.mData;
        r2 = r2.keyguardResponseBrightenTime;
        if (r2 <= 0) goto L_0x0034;
    L_0x002b:
        r2 = r4.getProximityPositiveBrightenEnable();
        if (r2 == 0) goto L_0x0032;
    L_0x0031:
        return r1;
    L_0x0032:
        r1 = 1;
        return r1;
    L_0x0034:
        return r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwAmbientLuxFilterAlgo.getKeyguardLockedBrightenEnable():boolean");
    }

    private boolean getOutdoorModeBrightenEnable() {
        if (((float) this.mBrightPointCnt) <= -1.0E-6f || this.mAmbientLux <= ((float) this.mData.outdoorLowerLuxThreshold) || this.mData.outdoorResponseBrightenTime <= 0) {
            return false;
        }
        return true;
    }

    private boolean getProximityPositiveBrightenEnable() {
        int N = this.mAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "getProximityPositive no lux");
            return false;
        } else if (!this.mData.allowLabcUseProximity || !this.mProximityPositiveStatus || this.mAmbientLightRingBuffer.getLux(N - 1) >= this.mData.proximityLuxThreshold || this.mData.proximityResponseBrightenTime <= 0) {
            return false;
        } else {
            return true;
        }
    }

    private boolean getSlowResponsePowerStatus() {
        int N = this.mAmbientLightRingBuffer.size();
        if (N > 0) {
            for (int i = 0; i < N; i++) {
                if (this.mAmbientLightRingBuffer.getLux(i) > ((float) this.mData.initSlowReponseUpperLuxThreshold) + 1.0E-6f) {
                    return false;
                }
            }
        }
        return true;
    }

    private boolean getKeyguardLockedDarkenEnable() {
        int N = this.mAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "getKeyguardLocked no lux");
            return false;
        } else if (!this.mKeyguardIsLocked || this.mAmbientLightRingBuffer.getLux(N - 1) <= this.mData.keyguardLuxThreshold || this.mData.keyguardResponseDarkenTime <= 0) {
            return false;
        } else {
            return true;
        }
    }

    private boolean getOutdoorModeDarkenEnable() {
        if (((float) this.mBrightPointCnt) <= -1.0E-6f || this.mAmbientLux <= ((float) this.mData.outdoorLowerLuxThreshold) || this.mData.outdoorResponseDarkenTime <= 0) {
            return false;
        }
        return true;
    }

    public void setPowerStatus(boolean powerStatus) {
        this.mPowerStatus = powerStatus;
    }

    public void clear() {
        synchronized (this.mLock) {
            int i;
            int pruneN;
            java.lang.StringBuilder stringBuilder;
            if (DEBUG) {
                android.util.Slog.d("HwAmbientLuxFilterAlgo", "clear buffer data and algo flags");
            }
            this.mLastCloseScreenLux = this.mAmbientLux;
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("LabcCoverMode clear: mLastCloseScreenLux=");
                stringBuilder2.append(this.mLastCloseScreenLux);
                android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
            }
            if (this.mData.initNumLastBuffer > 0) {
                int N = this.mAmbientLightRingBuffer.size();
                for (i = 0; i < N; i++) {
                    this.mLastCloseScreenRingBuffer.push(this.mAmbientLightRingBuffer.getTime(i), this.mAmbientLightRingBuffer.getLux(i));
                }
                i = this.mLastCloseScreenRingBuffer.size() - this.mData.initNumLastBuffer;
                pruneN = i > 0 ? i : 0;
                if (pruneN > 0) {
                    this.mLastCloseScreenRingBuffer.prune(1 + this.mLastCloseScreenRingBuffer.getTime(pruneN - 1));
                }
                if (DEBUG) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("mLastCloseScreenRingBuffer=");
                    stringBuilder.append(this.mLastCloseScreenRingBuffer.toString(this.mLastCloseScreenRingBuffer.size()));
                    android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                }
            } else {
                android.util.Slog.i("HwAmbientLuxFilterAlgo", "mLastCloseScreenRingBuffer is set empty!");
            }
            this.mIsCoverModeFastResponseFlag = false;
            this.mAutoBrightnessIntervened = false;
            this.mProximityPositiveStatus = false;
            this.mProximity = -1;
            this.mPendingProximity = -1;
            this.mAmbientLightRingBuffer.clear();
            this.mAmbientLightRingBufferFilter.clear();
            this.mAmbientLightRingBufferScene.clear();
            this.mBrightPointCnt = -1;
            if (this.mData.dayModeAlgoEnable || this.mData.offsetResetEnable) {
                this.mFirstSetBrightness = false;
                java.util.Calendar c = java.util.Calendar.getInstance();
                int lastCloseDay = c.get(6);
                i = c.get(11);
                pruneN = c.get(12);
                this.mLastCloseTime = (((lastCloseDay * 24) * 60) + (i * 60)) + pruneN;
                if (DEBUG) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("DayMode: lastCloseDay=");
                    stringBuilder.append(lastCloseDay);
                    stringBuilder.append(",lastCloseHour=");
                    stringBuilder.append(i);
                    stringBuilder.append(",lastCloseMinute=");
                    stringBuilder.append(pruneN);
                    stringBuilder.append(",mLastCloseTime=");
                    stringBuilder.append(this.mLastCloseTime);
                    android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                }
            }
        }
    }

    private void updateBuffer(long time, float ambientLux, int horizon) {
        this.mAmbientLightRingBufferFilter.push(time, ambientLux);
        this.mAmbientLightRingBufferFilter.prune(time - ((long) horizon));
    }

    private void updateBufferForScene(long time, float ambientLux, int horizon) {
        this.mAmbientLightRingBufferScene.push(time, ambientLux);
        this.mAmbientLightRingBufferScene.prune(time - ((long) horizon));
    }

    private void updatepara(com.android.server.display.HwRingBuffer buffer, float lux) {
        float stability = calculateStability(buffer);
        float stabilityForSmallThr = calculateStabilityForSmallThr(buffer);
        if (stability > 100.0f) {
            this.mStability = 100.0f;
        } else if (stability < ((float) this.mData.stabilityConstant)) {
            this.mStability = (float) this.mData.stabilityConstant;
        } else {
            this.mStability = stability;
        }
        if (stabilityForSmallThr > 100.0f) {
            this.mStabilityForSmallThr = 100.0f;
        } else {
            this.mStabilityForSmallThr = stabilityForSmallThr;
        }
        float mLux = (float) java.lang.Math.round(lux);
        if (mLux >= this.mData.brightTimeDelayLuxThreshold || this.mlastFilterLux >= this.mData.brightTimeDelayLuxThreshold || !this.mData.brightTimeDelayEnable) {
            this.mNormBrighenDebounceTime = (long) (((float) this.mData.brighenDebounceTime) * (((this.mData.brightenDebounceTimeParaBig * (this.mStability - ((float) this.mData.stabilityConstant))) / 100.0f) + 1.0f));
        } else {
            this.mNormBrighenDebounceTime = (long) this.mData.brightTimeDelay;
        }
        if ((mLux < this.mData.darkTimeDelayLuxThreshold || this.mDarkTimeDelayFromBrightnessEnable) && this.mData.darkTimeDelayEnable) {
            float ambientLuxDarkenDelta = calculateDarkenThresholdDelta(this.mAmbientLux);
            float currentAmbientLux = buffer.getLux(buffer.size() - 1);
            float luxNormalizedFactor = ((this.mData.darkTimeDelayBeta2 * (this.mAmbientLux - currentAmbientLux)) + (this.mData.darkTimeDelayBeta1 * ((this.mAmbientLux - currentAmbientLux) - ambientLuxDarkenDelta))) + 1.0f;
            if (luxNormalizedFactor < 0.001f) {
                this.mNormDarkenDebounceTime = (long) (((float) this.mData.darkTimeDelay) + this.mData.darkTimeDelayBeta0);
            } else {
                this.mNormDarkenDebounceTime = ((long) this.mData.darkTimeDelay) + ((long) ((this.mData.darkTimeDelayBeta0 * (1.0f + (this.mData.darkTimeDelayBeta2 * 1.0f))) / luxNormalizedFactor));
            }
        } else {
            this.mNormDarkenDebounceTime = (long) (((float) this.mData.darkenDebounceTime) * (1.0f + ((this.mData.darkenDebounceTimeParaBig * (this.mStability - ((float) this.mData.stabilityConstant))) / 100.0f)));
        }
        this.mNormBrighenDebounceTimeForSmallThr = (long) this.mData.brighenDebounceTimeForSmallThr;
        this.mNormDarkenDebounceTimeForSmallThr = (long) this.mData.darkenDebounceTimeForSmallThr;
        setDarkenThresholdNew(this.mAmbientLuxNewMin);
        setBrightenThresholdNew(this.mAmbientLuxNewMax);
    }

    private void setBrightenThresholdNew(float amLux) {
        this.mBrightenDeltaLuxMax = calculateBrightenThresholdDelta(amLux);
        this.mBrightenDeltaLuxMin = this.mBrightenDeltaLuxMax * this.mData.ratioForBrightnenSmallThr;
        this.mBrightenDeltaLuxMax *= 1.0f + ((this.mData.brightenDeltaLuxPara * (this.mStability - ((float) this.mData.stabilityConstant))) / 100.0f);
        if (((float) this.mBrightPointCnt) > -1.0E-6f && this.mAmbientLux > ((float) this.mData.outdoorLowerLuxThreshold) && this.mData.outdoorResponseBrightenRatio > 0.0f) {
            this.mBrightenDeltaLuxMax *= this.mData.outdoorResponseBrightenRatio;
        }
    }

    private void setDarkenThresholdNew(float amLux) {
        this.mDarkenDeltaLuxMax = calculateDarkenThresholdDelta(amLux);
        if (this.mAmbientLux < 10.0f) {
            this.mDarkenDeltaLuxMin = this.mDarkenDeltaLuxMax;
        } else {
            this.mDarkenDeltaLuxMin = this.mDarkenDeltaLuxMax * this.mData.ratioForDarkenSmallThr;
        }
        this.mDarkenDeltaLuxForBackSensorCoverMode = this.mDarkenDeltaLuxMax * 0.5f;
        this.mDarkenDeltaLuxMax *= 1.0f + ((this.mData.darkenDeltaLuxPara * (this.mStability - ((float) this.mData.stabilityConstant))) / 100.0f);
        if (((float) this.mBrightPointCnt) > -1.0E-6f && this.mAmbientLux > ((float) this.mData.outdoorLowerLuxThreshold) && this.mData.outdoorResponseDarkenRatio > 0.0f) {
            this.mDarkenDeltaLuxMax *= this.mData.outdoorResponseDarkenRatio;
        }
    }

    private float calculateBrightenThresholdDelta(float amLux) {
        float brightenThreshold = 0.0f;
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.brightenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (amLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x > temp1.x) {
                    return (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (amLux - temp1.x)) + temp1.y;
                }
                if (!DEBUG) {
                    return 1.0f;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Brighten_temp1.x <= temp2.x,x");
                stringBuilder.append(temp.x);
                stringBuilder.append(", y = ");
                stringBuilder.append(temp.y);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                return 1.0f;
            }
            temp1 = temp;
            brightenThreshold = temp1.y;
        }
        return brightenThreshold;
    }

    private float calculateDarkenThresholdDelta(float amLux) {
        float darkenThreshold = 0.0f;
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.darkenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (amLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x > temp1.x) {
                    float darkenThresholdTmp = (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (amLux - temp1.x)) + temp1.y;
                    float f = 1.0f;
                    if (darkenThresholdTmp > 1.0f) {
                        f = darkenThresholdTmp;
                    }
                    return f;
                } else if (!DEBUG) {
                    return 1.0f;
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Darken_temp1.x <= temp2.x,x");
                    stringBuilder.append(temp.x);
                    stringBuilder.append(", y = ");
                    stringBuilder.append(temp.y);
                    android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                    return 1.0f;
                }
            }
            temp1 = temp;
            darkenThreshold = temp1.y;
        }
        return darkenThreshold;
    }

    private float prefilterAmbientLux(long now, int filterMethodNum) {
        if (filterMethodNum == 1) {
            return prefilterMeanFilter(now);
        }
        if (filterMethodNum == 2) {
            return prefilterWeightedMeanFilter(now);
        }
        return prefilterNoFilter(now);
    }

    private float prefilterNoFilter(long now) {
        int N = this.mAmbientLightRingBuffer.size();
        if (N != 0) {
            return this.mAmbientLightRingBuffer.getLux(N - 1);
        }
        android.util.Slog.e("HwAmbientLuxFilterAlgo", "prefilterNoFilter: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float prefilterMeanFilter(long now) {
        int N = this.mAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "prefilterMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.preMeanFilterNum > 0) {
            if (this.mData.preMeanFilterNoFilterNum >= this.mData.preMeanFilterNum) {
                if (N <= this.mData.preMeanFilterNoFilterNum) {
                    return this.mAmbientLightRingBuffer.getLux(N - 1);
                }
                float sum = 0.0f;
                for (int i = N - 1; i >= N - this.mData.preMeanFilterNum; i--) {
                    sum += this.mAmbientLightRingBuffer.getLux(i);
                }
                return (float) java.lang.Math.round(sum / ((float) this.mData.preMeanFilterNum));
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prefilterMeanFilter: ErrorPara, return 0, MeanFilterNum=");
        stringBuilder.append(this.mData.preMeanFilterNum);
        stringBuilder.append(",MeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.preMeanFilterNoFilterNum);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float prefilterWeightedMeanFilter(long now) {
        int N = this.mAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "prefilterWeightedMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.preWeightedMeanFilterNum > 0) {
            if (this.mData.preWeightedMeanFilterNoFilterNum >= this.mData.preWeightedMeanFilterNum) {
                float tempLux = this.mAmbientLightRingBuffer.getLux(N - 1);
                if (N <= this.mData.preWeightedMeanFilterNoFilterNum) {
                    return tempLux;
                }
                int i;
                float maxLux = 0.0f;
                float sum = 0.0f;
                float totalWeight = 0.0f;
                for (i = N - 1; i >= N - this.mData.preWeightedMeanFilterMaxFuncLuxNum; i--) {
                    tempLux = this.mAmbientLightRingBuffer.getLux(i);
                    if (tempLux >= maxLux) {
                        maxLux = tempLux;
                    }
                }
                for (i = N - 1; i >= N - this.mData.preWeightedMeanFilterNum; i--) {
                    float weight;
                    if (this.mAmbientLightRingBuffer.getLux(i) != 0.0f || maxLux > this.mData.preWeightedMeanFilterLuxTh) {
                        weight = 1.0f * 1.0f;
                    } else {
                        weight = this.mData.preWeightedMeanFilterAlpha * 1.0f;
                    }
                    totalWeight += weight;
                    sum += this.mAmbientLightRingBuffer.getLux(i) * weight;
                }
                return (float) java.lang.Math.round(sum / totalWeight);
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prefilterWeightedMeanFilter: ErrorPara, return 0, WeightedMeanFilterNum=");
        stringBuilder.append(this.mData.preWeightedMeanFilterNum);
        stringBuilder.append(",WeightedMeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.preWeightedMeanFilterNoFilterNum);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float getOrigLastAmbientLux(long now) {
        int N = this.mAmbientLightRingBuffer.size();
        if (N != 0) {
            return this.mAmbientLightRingBuffer.getLux(N - 1);
        }
        android.util.Slog.e("HwAmbientLuxFilterAlgo", "OrigAmbient: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float getFilterLastAmbientLux(long now) {
        int N = this.mAmbientLightRingBufferFilter.size();
        if (N != 0) {
            return this.mAmbientLightRingBufferFilter.getLux(N - 1);
        }
        android.util.Slog.e("HwAmbientLuxFilterAlgo", "FilterLastAmbient: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float postfilterAmbientLux(long now, int filterMethodNum) {
        if (filterMethodNum == 1) {
            return postfilterMeanFilter(now);
        }
        if (filterMethodNum == 2) {
            return postfilterMaxMinAvgFilter(now);
        }
        return postfilterNoFilter(now);
    }

    private float postfilterNoFilter(long now) {
        int N = this.mAmbientLightRingBufferFilter.size();
        if (N != 0) {
            return this.mAmbientLightRingBufferFilter.getLux(N - 1);
        }
        android.util.Slog.e("HwAmbientLuxFilterAlgo", "postfilterNoFilter: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float postfilterMeanFilter(long now) {
        int N = this.mAmbientLightRingBufferFilter.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "prefilterMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.postMeanFilterNum > 0) {
            if (this.mData.postMeanFilterNoFilterNum >= this.mData.postMeanFilterNum) {
                if (N <= this.mData.postMeanFilterNoFilterNum) {
                    return this.mAmbientLightRingBufferFilter.getLux(N - 1);
                }
                float sum = 0.0f;
                for (int i = N - 1; i >= N - this.mData.postMeanFilterNum; i--) {
                    sum += this.mAmbientLightRingBufferFilter.getLux(i);
                }
                return (float) java.lang.Math.round(sum / ((float) this.mData.postMeanFilterNum));
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("postfilterMeanFilter: ErrorPara, return 0, MeanFilterNum=");
        stringBuilder.append(this.mData.postMeanFilterNum);
        stringBuilder.append(",MeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.postMeanFilterNum);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float postfilterMaxMinAvgFilter(long now) {
        int N = this.mAmbientLightRingBufferFilter.size();
        if (N == 0) {
            android.util.Slog.e("HwAmbientLuxFilterAlgo", "postfilterMaxMinAvgFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.postMaxMinAvgFilterNum > 0) {
            if (this.mData.postMaxMinAvgFilterNoFilterNum >= this.mData.postMaxMinAvgFilterNum) {
                if (N <= this.mData.postMaxMinAvgFilterNoFilterNum) {
                    return this.mAmbientLightRingBufferFilter.getLux(N - 1);
                }
                float sum = this.mAmbientLightRingBufferFilter.getLux(N - 1);
                float luxMin = this.mAmbientLightRingBufferFilter.getLux(N - 1);
                float luxMax = this.mAmbientLightRingBufferFilter.getLux(N - 1);
                for (int i = N - 2; i >= N - this.mData.postMaxMinAvgFilterNum; i--) {
                    if (luxMin > this.mAmbientLightRingBufferFilter.getLux(i)) {
                        luxMin = this.mAmbientLightRingBufferFilter.getLux(i);
                    }
                    if (luxMax < this.mAmbientLightRingBufferFilter.getLux(i)) {
                        luxMax = this.mAmbientLightRingBufferFilter.getLux(i);
                    }
                    sum += this.mAmbientLightRingBufferFilter.getLux(i);
                }
                return ((sum - luxMin) - luxMax) / 3.0f;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("postfilterMaxMinAvgFilter: ErrorPara, return 0, PostMaxMinAvgFilterNoFilterNum=");
        stringBuilder.append(this.mData.postMaxMinAvgFilterNoFilterNum);
        stringBuilder.append(",PostMaxMinAvgFilterNum=");
        stringBuilder.append(this.mData.postMaxMinAvgFilterNum);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private long nextAmbientLightBrighteningTransition(long time) {
        long earliestValidTime = time;
        for (int i = this.mAmbientLightRingBufferFilter.size() - 1; i >= 0; i--) {
            boolean BrightenChange;
            if (this.mAmbientLightRingBufferFilter.getLux(i) - this.mAmbientLuxNewMax > this.mBrightenDeltaLuxMax) {
                BrightenChange = true;
            } else {
                BrightenChange = false;
            }
            if (!BrightenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return getNextAmbientLightBrighteningTime(earliestValidTime);
    }

    private long nextAmbientLightBrighteningTransitionForSmallThr(long time) {
        long earliestValidTime = time;
        for (int i = this.mAmbientLightRingBufferFilter.size() - 1; i >= 0; i--) {
            boolean BrightenChange;
            if (this.mAmbientLightRingBufferFilter.getLux(i) - this.mAmbientLux > this.mBrightenDeltaLuxMin) {
                BrightenChange = true;
            } else {
                BrightenChange = false;
            }
            if (!BrightenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return this.mNormBrighenDebounceTimeForSmallThr + earliestValidTime;
    }

    private long nextAmbientLightDarkeningTransition(long time) {
        long earliestValidTime = time;
        for (int i = this.mAmbientLightRingBufferFilter.size() - 1; i >= 0; i--) {
            boolean DarkenChange;
            if (this.mAmbientLuxNewMin - this.mAmbientLightRingBufferFilter.getLux(i) >= this.mDarkenDeltaLuxMax) {
                DarkenChange = true;
            } else {
                DarkenChange = false;
            }
            if (!DarkenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return getNextAmbientLightDarkeningTime(earliestValidTime);
    }

    private long nextAmbientLightDarkeningTransitionExtended(long time, float lux, float deltaLux, long debounceTime) {
        long earliestValidTime = time;
        for (int i = this.mAmbientLightRingBufferFilter.size() - 1; i >= 0; i--) {
            if (lux - this.mAmbientLightRingBufferFilter.getLux(i) < deltaLux) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return earliestValidTime + debounceTime;
    }

    private boolean decideToDarkenForBackSensorCoverMode(float ambientLux) {
        boolean needToDarken;
        if (this.mAmbientLux - ambientLux >= this.mDarkenDeltaLuxForBackSensorCoverMode) {
            needToDarken = true;
        } else {
            needToDarken = false;
        }
        return (!needToDarken || this.mAutoBrightnessIntervened || this.mProximityPositiveStatus) ? false : true;
    }

    private boolean needToDarkenForBackSensorCoverMode(long time, float lux) {
        if (this.mData.backSensorCoverModeEnable && this.mIsCoverModeFastResponseFlag && decideToDarkenForBackSensorCoverMode(lux)) {
            if (nextAmbientLightDarkeningTransitionExtended(time, this.mAmbientLux, this.mDarkenDeltaLuxForBackSensorCoverMode, 500) <= time) {
                if (DEBUG) {
                    android.util.Slog.d("HwAmbientLuxFilterAlgo", "BackSensorCoverMode needToDarkenForBackSensorCoverMode");
                }
                return true;
            }
        }
        return false;
    }

    private boolean decideToBrighten(float ambientLux) {
        boolean needToBrighten;
        if (ambientLux - this.mAmbientLuxNewMax < this.mBrightenDeltaLuxMax || this.mStability >= this.mStabilityBrightenConstant) {
            needToBrighten = false;
        } else {
            needToBrighten = true;
        }
        return needToBrighten && !this.mAutoBrightnessIntervened;
    }

    private boolean decideToBrightenForSmallThr(float ambientLux) {
        boolean needToBrighten;
        if (ambientLux - this.mAmbientLux < this.mBrightenDeltaLuxMin || this.mStabilityForSmallThr >= this.mStabilityBrightenConstantForSmallThr) {
            needToBrighten = false;
        } else {
            needToBrighten = true;
        }
        return (!needToBrighten || this.mAutoBrightnessIntervened || this.mProximityPositiveStatus) ? false : true;
    }

    private boolean decideToDarken(float ambientLux) {
        boolean needToDarken;
        if (this.mAmbientLuxNewMin - ambientLux < this.mDarkenDeltaLuxMax || this.mStability > this.mStabilityDarkenConstant) {
            needToDarken = false;
        } else {
            needToDarken = true;
        }
        return (!needToDarken || this.mAutoBrightnessIntervened || this.mProximityPositiveStatus) ? false : true;
    }

    private boolean decideToDarkenForSmallThr(float ambientLux) {
        boolean needToDarken;
        if (this.mAmbientLux - ambientLux < this.mDarkenDeltaLuxMin || this.mStabilityForSmallThr > this.mStabilityDarkenConstantForSmallThr) {
            needToDarken = false;
        } else {
            needToDarken = true;
        }
        return (!needToDarken || this.mAutoBrightnessIntervened || this.mProximityPositiveStatus) ? false : true;
    }

    public boolean getProximityPositiveEnable() {
        return this.mData.allowLabcUseProximity && this.mProximityPositiveStatus;
    }

    public float getOffsetValidAmbientLux() {
        if (this.mData.offsetValidAmbientLuxEnable) {
            return this.mOffsetValidAmbientLux;
        }
        return this.mAmbientLux;
    }

    public float getValidAmbientLux(float lux) {
        float luxtmp = lux;
        if (luxtmp < 0.0f) {
            luxtmp = 0.0f;
        }
        if (luxtmp > 40000.0f) {
            return 40000.0f;
        }
        return luxtmp;
    }

    public void setCurrentAmbientLux(float lux) {
        if (((int) this.mAmbientLux) != ((int) lux)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setOffsetLux mAmbientLux=");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(",lux=");
            stringBuilder.append(lux);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            this.mAmbientLux = getValidAmbientLux(lux);
        }
    }

    private void setOffsetValidAmbientLux(float lux) {
        this.mOffsetValidAmbientLux = (float) java.lang.Math.round(lux);
        this.mOffsetValidAmbientBrightenDeltaLux = calculateBrightenThresholdDelta(this.mOffsetValidAmbientLux);
        this.mOffsetValidAmbientDarkenDeltaLux = calculateDarkenThresholdDelta(this.mOffsetValidAmbientLux);
    }

    private long nextAmbientLightBrighteningTransitionForOffset(long time) {
        long earliestValidTime = time;
        for (int i = this.mAmbientLightRingBufferFilter.size() - 1; i >= 0; i--) {
            boolean BrightenChange;
            if (this.mAmbientLightRingBufferFilter.getLux(i) - this.mOffsetValidAmbientLux > this.mOffsetValidAmbientBrightenDeltaLux) {
                BrightenChange = true;
            } else {
                BrightenChange = false;
            }
            if (!BrightenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return ((long) this.mData.offsetBrightenDebounceTime) + earliestValidTime;
    }

    private boolean decideToBrightenForOffset(float ambientLux) {
        boolean needToBrighten;
        if (ambientLux - this.mOffsetValidAmbientLux >= this.mOffsetValidAmbientBrightenDeltaLux) {
            needToBrighten = true;
        } else {
            needToBrighten = false;
        }
        return needToBrighten && !this.mAutoBrightnessIntervened;
    }

    private boolean decideToDarkenForOffset(float ambientLux) {
        boolean needToDarken;
        if (this.mOffsetValidAmbientLux - ambientLux >= this.mOffsetValidAmbientDarkenDeltaLux) {
            needToDarken = true;
        } else {
            needToDarken = false;
        }
        return needToDarken && !this.mAutoBrightnessIntervened;
    }

    private float calculateStability(com.android.server.display.HwRingBuffer buffer) {
        com.android.server.display.HwRingBuffer hwRingBuffer = buffer;
        int N = buffer.size();
        if (N <= 1) {
            return 0.0f;
        }
        float lux1;
        float luxT1;
        int indexMax;
        int index1;
        int index2;
        float luxk3;
        float tmp;
        float currentLux = hwRingBuffer.getLux(N - 1);
        calculateAvg(buffer);
        int indexMax2 = 0;
        float luxT2Max = currentLux;
        float luxT1Max = currentLux;
        int indexMin = 0;
        float luxT2Min = currentLux;
        float luxT1Min = currentLux;
        int index = 0;
        int T2 = 0;
        int T1 = 0;
        float luxT2 = currentLux;
        float luxT12 = currentLux;
        int j = 0;
        while (j < N - 1) {
            lux1 = hwRingBuffer.getLux((N - 1) - j);
            float currentLux2 = currentLux;
            currentLux = hwRingBuffer.getLux(((N - 1) - j) - 1);
            luxT1 = luxT12;
            if (((this.mLuxBufferAvg > lux1 || this.mLuxBufferAvg < currentLux) && (this.mLuxBufferAvg < lux1 || this.mLuxBufferAvg > currentLux)) || (java.lang.Math.abs(this.mLuxBufferAvg - lux1) < 1.0E-7f && java.lang.Math.abs(this.mLuxBufferAvg - currentLux) < 1.0E-7f)) {
                luxT12 = luxT1;
            } else {
                luxT12 = lux1;
                luxT2 = currentLux;
                index = j;
                T2 = ((N - 1) - j) - 1;
                T1 = (N - 1) - j;
            }
            float luxT13 = luxT12;
            if (((this.mLuxBufferAvgMin <= lux1 && this.mLuxBufferAvgMin >= currentLux) || (this.mLuxBufferAvgMin >= lux1 && this.mLuxBufferAvgMin <= currentLux)) && (java.lang.Math.abs(this.mLuxBufferAvgMin - lux1) >= 1.0E-7f || java.lang.Math.abs(this.mLuxBufferAvgMin - currentLux) >= 1.0E-7f)) {
                indexMin = j;
                luxT2Min = currentLux;
                luxT1Min = lux1;
            }
            if (((this.mLuxBufferAvgMax > lux1 || this.mLuxBufferAvgMax < currentLux) && (this.mLuxBufferAvgMax < lux1 || this.mLuxBufferAvgMax > currentLux)) || (java.lang.Math.abs(this.mLuxBufferAvgMax - lux1) < 1.0E-7f && java.lang.Math.abs(this.mLuxBufferAvgMax - currentLux) < 1.0E-7f)) {
                luxT12 = luxT2Max;
                indexMax = indexMax2;
            } else {
                indexMax = j;
                luxT1Max = lux1;
                luxT12 = currentLux;
            }
            if (index != 0) {
                if (indexMin != 0 || indexMax != 0) {
                    if (index > indexMin || index < indexMax) {
                        if (index >= indexMin && index <= indexMax) {
                        }
                    }
                    luxT1 = luxT13;
                    break;
                }
            }
            j++;
            indexMax2 = indexMax;
            currentLux = currentLux2;
            luxT2Max = luxT12;
            luxT12 = luxT13;
        }
        luxT1 = luxT12;
        luxT12 = luxT2Max;
        indexMax = indexMax2;
        if (indexMax <= indexMin) {
            index1 = indexMax;
            index2 = indexMin;
        } else {
            index1 = indexMin;
            index2 = indexMax;
        }
        j = (N - 1) - index1;
        while (true) {
            int index12 = index1;
            float f;
            if (j > N - 1) {
                break;
            } else if (j == N - 1) {
                f = luxT12;
                break;
            } else {
                lux1 = hwRingBuffer.getLux(j);
                f = luxT12;
                luxT12 = hwRingBuffer.getLux(j + 1);
                if (indexMax > indexMin) {
                    if (lux1 <= luxT12) {
                        break;
                    }
                    T1 = j + 1;
                } else if (lux1 >= luxT12) {
                    break;
                } else {
                    T1 = j + 1;
                }
                j++;
                index1 = index12;
                luxT12 = f;
            }
        }
        for (index1 = (N - 1) - index2; index1 >= 0; index1--) {
            if (index1 == 0) {
                break;
            }
            luxk3 = hwRingBuffer.getLux(index1);
            luxT12 = hwRingBuffer.getLux(index1 - 1);
            if (indexMax > indexMin) {
                if (luxk3 >= luxT12) {
                    break;
                }
                T2 = index1 - 1;
            } else if (luxk3 <= luxT12) {
                break;
            } else {
                T2 = index1 - 1;
            }
        }
        index1 = (N - 1) - T1;
        j = T2;
        luxT12 = calculateStabilityFactor(hwRingBuffer, T1, N - 1);
        currentLux = calcluateAvg(hwRingBuffer, T1, N - 1);
        float s2 = calculateStabilityFactor(hwRingBuffer, 0, T2);
        float avg2 = calcluateAvg(hwRingBuffer, 0, T2);
        luxT2 = java.lang.Math.abs(currentLux - avg2);
        float k = 0.0f;
        if (T1 != T2) {
            k = java.lang.Math.abs((hwRingBuffer.getLux(T1) - hwRingBuffer.getLux(T2)) / ((float) (T1 - T2)));
        }
        if (k < 10.0f / (k + 5.0f)) {
            tmp = k;
        } else {
            tmp = 10.0f / (k + 5.0f);
        }
        if (tmp > 20.0f / (luxT2 + 10.0f)) {
            tmp = 20.0f / (luxT2 + 10.0f);
        }
        if (index1 > this.mData.stabilityTime1) {
            avg2 = luxT12;
            float f2 = luxT2;
            int i = T1;
        } else {
            avg2 = (float) java.lang.Math.exp((double) (index1 - this.mData.stabilityTime1));
            luxT2 = (float) (this.mData.stabilityTime1 - index1);
            avg2 = ((avg2 * luxT12) + (luxT2 * tmp)) / (avg2 + luxT2);
        }
        if (j > this.mData.stabilityTime2) {
            luxT2 = s2;
            float f3 = luxT12;
        } else {
            float Stability2 = 0.0f;
            luxT12 = (float) java.lang.Math.exp((double) (j - this.mData.stabilityTime2));
            luxT2 = (float) (this.mData.stabilityTime2 - j);
            luxT2 = ((luxT12 * s2) + (luxT2 * tmp)) / (luxT12 + luxT2);
        }
        if (index1 > this.mData.stabilityTime1) {
            luxT12 = avg2;
            float f4 = currentLux;
            int i2 = j;
        } else {
            currentLux = (float) java.lang.Math.exp((double) (index1 - this.mData.stabilityTime1));
            luxk3 = (float) (this.mData.stabilityTime1 - index1);
            luxT12 = ((currentLux * avg2) + (luxk3 * luxT2)) / (currentLux + luxk3);
        }
        return luxT12;
    }

    private void calculateAvg(com.android.server.display.HwRingBuffer buffer) {
        int N = buffer.size();
        if (N != 0) {
            float currentLux = buffer.getLux(N - 1);
            float luxBufferSum = 0.0f;
            float luxBufferMin = currentLux;
            float luxBufferMax = currentLux;
            for (int i = N - 1; i >= 0; i--) {
                float lux = buffer.getLux(i);
                if (lux > luxBufferMax) {
                    luxBufferMax = lux;
                }
                if (lux < luxBufferMin) {
                    luxBufferMin = lux;
                }
                luxBufferSum += lux;
            }
            this.mLuxBufferAvg = luxBufferSum / ((float) N);
            this.mLuxBufferAvgMax = (this.mLuxBufferAvg + luxBufferMax) / 2.0f;
            this.mLuxBufferAvgMin = (this.mLuxBufferAvg + luxBufferMin) / 2.0f;
        }
    }

    private float calculateStabilityForSmallThr(com.android.server.display.HwRingBuffer buffer) {
        float sstablity;
        int N = buffer.size();
        if (N <= 1) {
            sstablity = 0.0f;
        } else if (N > 15) {
            return calculateStabilityFactor(buffer, 0, 14);
        } else {
            sstablity = calculateStabilityFactor(buffer, 0, N - 1);
        }
        return sstablity;
    }

    private float calcluateAvg(com.android.server.display.HwRingBuffer buffer, int start, int end) {
        float sum = 0.0f;
        for (int i = start; i <= end; i++) {
            sum += buffer.getLux(i);
        }
        if (end < start) {
            return 0.0f;
        }
        return sum / ((float) ((end - start) + 1));
    }

    private float calculateStabilityFactor(com.android.server.display.HwRingBuffer buffer, int start, int end) {
        int size = (end - start) + 1;
        float sum = 0.0f;
        float sigma = 0.0f;
        if (size <= 1) {
            return 0.0f;
        }
        for (int i = start; i <= end; i++) {
            sum += buffer.getLux(i);
        }
        float avg = sum / ((float) size);
        for (int i2 = start; i2 <= end; i2++) {
            sigma += (buffer.getLux(i2) - avg) * (buffer.getLux(i2) - avg);
        }
        float ss = sigma / ((float) (size - 1));
        if (avg == 0.0f) {
            return 0.0f;
        }
        return ss / avg;
    }

    public boolean reportValueWhenSensorOnChange() {
        return this.mData.reportValueWhenSensorOnChange;
    }

    public int getProximityState() {
        return this.mProximity;
    }

    public boolean needToUseProximity() {
        return this.mData.allowLabcUseProximity;
    }

    public boolean needToSendProximityDebounceMsg() {
        return this.mNeedToSendProximityDebounceMsg;
    }

    public long getPendingProximityDebounceTime() {
        return this.mPendingProximityDebounceTime;
    }

    public void setCoverModeStatus(boolean isclosed) {
        if (!isclosed && this.mIsclosed) {
            this.mCoverState = true;
        }
        this.mIsclosed = isclosed;
    }

    public void setCoverModeFastResponseFlag(boolean isFast) {
        this.mIsCoverModeFastResponseFlag = isFast;
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("LabcCoverMode mIsCoverModeFastResponseFlag=");
            stringBuilder.append(this.mIsCoverModeFastResponseFlag);
            android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        }
    }

    public void setBackSensorCoverModeBrightness(int brightness) {
        if (brightness > 0) {
            this.mBackSensorCoverModeBrightness = brightness;
        }
    }

    public boolean getLastCloseScreenEnable() {
        return this.mData.lastCloseScreenEnable ^ 1;
    }

    private void setProximityState(boolean proximityPositive) {
        this.mProximityPositiveStatus = proximityPositive;
        if (!this.mProximityPositiveStatus) {
            this.mNeedToUpdateBrightness = true;
            if (DEBUG) {
                android.util.Slog.i("HwAmbientLuxFilterAlgo", "Proximity sets brightness");
            }
        }
    }

    private void clearPendingProximityDebounceTime() {
        if (this.mPendingProximityDebounceTime >= 0) {
            this.mPendingProximityDebounceTime = -1;
        }
    }

    public void handleProximitySensorEvent(long time, boolean positive) {
        if (this.mPendingProximity == 0 && !positive) {
            return;
        }
        if (this.mPendingProximity != 1 || !positive) {
            if (positive) {
                this.mPendingProximity = 1;
                this.mPendingProximityDebounceTime = ((long) this.mProximityPositiveDebounceTime) + time;
            } else {
                this.mPendingProximity = 0;
                this.mPendingProximityDebounceTime = ((long) this.mProximityNegativeDebounceTime) + time;
            }
            debounceProximitySensor();
        }
    }

    public void debounceProximitySensor() {
        this.mNeedToSendProximityDebounceMsg = false;
        if (this.mPendingProximity != -1 && this.mPendingProximityDebounceTime >= 0) {
            if (this.mPendingProximityDebounceTime <= android.os.SystemClock.uptimeMillis()) {
                this.mProximity = this.mPendingProximity;
                if (this.mProximity == 1) {
                    setProximityState(true);
                } else if (this.mProximity == 0) {
                    setProximityState(false);
                }
                if (DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("debounceProximitySensor:mProximity=");
                    stringBuilder.append(this.mProximity);
                    android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                }
                clearPendingProximityDebounceTime();
                return;
            }
            this.mNeedToSendProximityDebounceMsg = true;
        }
    }

    public int getpowerOnFastResponseLuxNum() {
        return this.mData.powerOnFastResponseLuxNum;
    }

    public boolean getCameraModeBrightnessLineEnable() {
        return this.mData.cameraModeEnable;
    }

    public boolean getReadingModeBrightnessLineEnable() {
        return this.mData.readingModeEnable;
    }

    public void setKeyguardLockedStatus(boolean isLocked) {
        this.mKeyguardIsLocked = isLocked;
    }

    public boolean getOutdoorAnimationFlag() {
        return ((float) this.mData.outdoorLowerLuxThreshold) < this.mAmbientLux;
    }

    public boolean getDayModeEnable() {
        return this.mDayModeEnable;
    }

    public boolean getOffsetResetEnable() {
        return this.mOffsetResetEnable;
    }

    public void setAutoModeEnableFirstLux(float lux) {
        this.mAutoModeEnableFirstLux = getValidAmbientLux(lux);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setAutoModeEnableFirstLux=");
        stringBuilder.append(this.mAutoModeEnableFirstLux);
        android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
    }

    public void setDayModeEnable() {
        java.lang.StringBuilder stringBuilder;
        java.util.Calendar c = java.util.Calendar.getInstance();
        int openDay = c.get(6);
        int openHour = c.get(11);
        int openMinute = c.get(12);
        int openTime = (((openDay * 24) * 60) + (openHour * 60)) + openMinute;
        if (this.mData.dayModeAlgoEnable && (this.mFirstSetBrightness || openTime - this.mLastCloseTime >= this.mData.dayModeSwitchTime)) {
            this.mDayModeEnable = false;
            if (this.mData.dayModeBeginTime < this.mData.dayModeEndTime) {
                if (openHour >= this.mData.dayModeBeginTime && openHour < this.mData.dayModeEndTime) {
                    this.mDayModeEnable = true;
                }
            } else if (openHour >= this.mData.dayModeBeginTime || openHour < this.mData.dayModeEndTime) {
                this.mDayModeEnable = true;
            }
        }
        if (this.mData.offsetResetEnable) {
            this.mOffsetResetEnable = false;
            if (openTime - this.mLastCloseTime >= this.mData.offsetResetSwitchTime) {
                this.mOffsetResetEnable = true;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("offsetResetEnable detime=");
                stringBuilder.append(openTime - this.mLastCloseTime);
                android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder.toString());
            } else {
                float luxBright = this.mAutoModeEnableFirstLux + calculateBrightenThresholdDelta(this.mAutoModeEnableFirstLux);
                float luxDark = this.mAutoModeEnableFirstLux - calculateDarkenThresholdDelta(this.mAutoModeEnableFirstLux);
                if (java.lang.Math.abs(this.mAutoModeEnableFirstLux - this.mLastCloseScreenLux) > ((float) this.mData.offsetResetShortLuxDelta) && ((luxBright > this.mLastCloseScreenLux || luxDark < this.mLastCloseScreenLux) && openTime - this.mLastCloseTime >= this.mData.offsetResetShortSwitchTime)) {
                    this.mOffsetResetEnable = true;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("offsetResetEnableShort detime=");
                    stringBuilder2.append(openTime - this.mLastCloseTime);
                    stringBuilder2.append(",mFirstLux=");
                    stringBuilder2.append(this.mAutoModeEnableFirstLux);
                    stringBuilder2.append(",mCloseLux=");
                    stringBuilder2.append(this.mLastCloseScreenLux);
                    stringBuilder2.append(",luxBright=");
                    stringBuilder2.append(luxBright);
                    stringBuilder2.append(",luxDark=");
                    stringBuilder2.append(luxDark);
                    android.util.Slog.i("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
                }
            }
        }
        if (DEBUG) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("DayMode:openDay=");
            stringBuilder.append(openDay);
            stringBuilder.append(",openHour=");
            stringBuilder.append(openHour);
            stringBuilder.append(",openMinute=");
            stringBuilder.append(openMinute);
            stringBuilder.append(",openTime=");
            stringBuilder.append(openTime);
            stringBuilder.append(", mLastCloseTime");
            stringBuilder.append(this.mLastCloseTime);
            stringBuilder.append(", mFirstSetBrightness");
            stringBuilder.append(this.mFirstSetBrightness);
            stringBuilder.append(",mDayModeEnable=");
            stringBuilder.append(this.mDayModeEnable);
            stringBuilder.append(",mOffsetResetEnable=");
            stringBuilder.append(this.mOffsetResetEnable);
            stringBuilder.append(",offsetResetSwitchTime=");
            stringBuilder.append(this.mData.offsetResetSwitchTime);
            android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        }
    }

    public int getCoverModeBrightnessFromLastScreenBrightness() {
        if (this.mData.coverModeDayEnable) {
            return getCoverModeBrightnessFromLastScreenLux(this.mAmbientLux);
        }
        return this.mData.coverModeDayBrightness;
    }

    public void setCoverModeDayEnable(boolean coverModeDayEnable) {
        this.mCoverModeDayEnable = coverModeDayEnable;
    }

    public boolean getCoverModeDayEnable() {
        return this.mCoverModeDayEnable;
    }

    private int getCoverModeBrightnessFromLastScreenLux(float amLux) {
        if (this.mData.coverModeBrighnessLinePoints != null) {
            if (amLux >= 0.0f) {
                float coverModebrightness = 0.0f;
                android.graphics.PointF temp1 = null;
                for (android.graphics.PointF temp : this.mData.coverModeBrighnessLinePoints) {
                    if (temp1 == null) {
                        temp1 = temp;
                    }
                    if (amLux < temp.x) {
                        android.graphics.PointF temp2 = temp;
                        if (temp2.x <= temp1.x) {
                            coverModebrightness = 4.0f;
                            if (DEBUG) {
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("LabcCoverMode,set MIN_BRIGHTNESS,Brighten_temp1.x <= temp2.x,x");
                                stringBuilder.append(temp.x);
                                stringBuilder.append(", y = ");
                                stringBuilder.append(temp.y);
                                android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                            }
                        } else {
                            coverModebrightness = (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (amLux - temp1.x)) + temp1.y;
                        }
                        return (int) coverModebrightness;
                    }
                    temp1 = temp;
                    coverModebrightness = temp1.y;
                }
                return (int) coverModebrightness;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("LabcCoverMode error input,set MIN_BRIGHTNESS,amLux=");
        stringBuilder2.append(amLux);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
        return 4;
    }

    private int getLuxFromDefaultBrightnessLevel(float brightnessLevel) {
        if (this.mData.defaultBrighnessLinePoints != null) {
            if (brightnessLevel >= 0.0f) {
                if (brightnessLevel == 255.0f) {
                    android.util.Slog.i("HwAmbientLuxFilterAlgo", "LabcCoverMode,brightnessLevel=MAX_Brightness,getMaxLux=40000");
                    return 40000;
                }
                float lux = 0.0f;
                android.graphics.PointF temp1 = null;
                for (android.graphics.PointF temp : this.mData.defaultBrighnessLinePoints) {
                    if (temp1 == null) {
                        temp1 = temp;
                    }
                    if (brightnessLevel < temp.y) {
                        android.graphics.PointF temp2 = temp;
                        if (temp2.y <= temp1.y) {
                            lux = 0.0f;
                            if (DEBUG) {
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("LabcCoverMode,set MIN_Lux,Brighten_temp1.x <= temp2.x,x");
                                stringBuilder.append(temp.x);
                                stringBuilder.append(", y = ");
                                stringBuilder.append(temp.y);
                                android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
                            }
                        } else {
                            lux = (((temp2.x - temp1.x) / (temp2.y - temp1.y)) * (brightnessLevel - temp1.y)) + temp1.x;
                        }
                        return (int) lux;
                    }
                    temp1 = temp;
                    lux = temp1.x;
                }
                return (int) lux;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("LabcCoverMode,error input,set MIN_Lux,brightnessLevel=");
        stringBuilder2.append(brightnessLevel);
        android.util.Slog.e("HwAmbientLuxFilterAlgo", stringBuilder2.toString());
        return 0;
    }

    public void setGameModeEnable(boolean enable) {
        this.mGameModeEnable = enable;
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("GameBrightMode set mGameModeEnable=");
            stringBuilder.append(this.mGameModeEnable);
            android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        }
    }

    public void setDarkTimeDelayFromBrightnessEnable(boolean enable) {
        if (DEBUG && enable != this.mDarkTimeDelayFromBrightnessEnable) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("DarkTimeDelayFromBrightnessEnable=");
            stringBuilder.append(this.mDarkTimeDelayFromBrightnessEnable);
            stringBuilder.append(",enable=");
            stringBuilder.append(enable);
            android.util.Slog.d("HwAmbientLuxFilterAlgo", stringBuilder.toString());
        }
        this.mDarkTimeDelayFromBrightnessEnable = enable;
    }
}
