package com.android.server.display;

public class HwBrightnessPgSceneDetection {
    private static final boolean DEBUG;
    private static final int LOW_LIGHT_MAX = 55;
    private static final int LOW_LIGHT_MIN = 20;
    private static final int LOW_LIGHT_REFERENCE_RATIO = ((int) (55.0f * PG_POWER_SAVE_MODE_LIGHT_RATIO));
    private static final int MAXDEFAULTBRIGHTNESS = 255;
    private static final int MINDEFAULTBRIGHTNESS = 4;
    private static final int MSG_REG_POWER_MODE_LISTENER = 2;
    private static final int MSG_UPDATE_PGBRIGHTNESS = 1;
    private static final int PG_DEFAULT_MODE = 2;
    private static final java.lang.String PG_EXTREME_MODE_ACTION = "huawei.intent.action.PG_EXTREME_MODE_ENABLE_ACTION";
    private static final int PG_POWER_SAVE_MODE = 1;
    private static final float PG_POWER_SAVE_MODE_LIGHT_RATIO = (((float) android.os.SystemProperties.getInt("ro.powersavemode.backlight_ratio", 56)) / 100.0f);
    private static final int PG_SUPER_POWER_SAVE_MODE = 4;
    private static final java.lang.String POWERMODE_PROP = "persist.sys.smart_power";
    private static final java.lang.String POWER_MODE_CHANGED_ACTION = "huawei.intent.action.POWER_MODE_CHANGED_ACTION";
    private static final int POWER_MODE_MIN_LIGHT_VAL = 25;
    private static final int SUPER_MODE_MAX_LIGHT_VAL = 35;
    private static final java.lang.String TAG = "HwBrightnessPgSceneDetection";
    private int mAppType = -1;
    private java.util.List<java.lang.Integer> mBacklightAppList = null;
    private com.android.server.display.HwBrightnessPgSceneDetection.HwBrightnessPgSceneDetectionCallbacks mCallbacks;
    private final android.content.Context mContext;
    private android.os.Handler mHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 1:
                    com.android.server.display.HwBrightnessPgSceneDetection.this.mCallbacks.updateStateRecognition(com.android.server.display.HwBrightnessPgSceneDetection.this.mShouldUpdateBLight, com.android.server.display.HwBrightnessPgSceneDetection.this.mAppType);
                    return;
                case 2:
                    com.android.server.display.HwBrightnessPgSceneDetection.this.registerPowerModeChangedListener();
                    return;
                default:
                    android.util.Slog.e("HwBrightnessPgSceneDetection", "Invalid message");
                    return;
            }
        }
    };
    private boolean mPGBLListenerRegisted = false;
    private com.huawei.pgmng.plug.PGSdk mPGSdk = null;
    private android.content.BroadcastReceiver mPgModeChangedBroadcastReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent == null) {
                android.util.Slog.e("HwBrightnessPgSceneDetection", "onReceive() intent is NULL!");
                return;
            }
            java.lang.String action = intent.getAction();
            if ("huawei.intent.action.POWER_MODE_CHANGED_ACTION".equals(action)) {
                com.android.server.display.HwBrightnessPgSceneDetection.this.sendUpdatePgBrightness(false);
            } else if ("huawei.intent.action.PG_EXTREME_MODE_ENABLE_ACTION".equals(action)) {
                com.android.server.display.HwBrightnessPgSceneDetection.this.sendUpdatePgBrightness(false);
            }
        }
    };
    private int mPgSceneDetectionBrightenDelayTime = 500;
    private int mPgSceneDetectionDarkenDelayTime = 2500;
    private boolean mShouldUpdateBLight;
    private com.huawei.pgmng.plug.PGSdk.Sink mStateRecognitionListener = new com.huawei.pgmng.plug.PGSdk.Sink() {
        public void onStateChanged(int stateType, int eventType, int pid, java.lang.String pkg, int uid) {
            int appType = -1;
            boolean z = false;
            boolean exempStateType = stateType == 10015;
            if (eventType == 1) {
                try {
                    appType = com.android.server.display.HwBrightnessPgSceneDetection.this.mPGSdk.getPkgType(com.android.server.display.HwBrightnessPgSceneDetection.this.mContext, pkg);
                    com.android.server.display.HwBrightnessPgSceneDetection.this.mAppType = appType;
                } catch (android.os.RemoteException e) {
                    android.util.Slog.w("HwBrightnessPgSceneDetection", "getPkgType failed!");
                }
                boolean pdtCfgAdjApp = pkg == null ? false : com.huawei.pgmng.plug.PGSdk.isApkShouldAdjBackLight(pkg);
                boolean pdtNotCfgAdjApp = com.android.server.display.HwBrightnessPgSceneDetection.isNoUsePowerCureAppEnable(pkg);
                if (com.android.server.display.HwBrightnessPgSceneDetection.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("in onStateChanged, pkg = ");
                    stringBuilder.append(pkg);
                    stringBuilder.append(", appType = ");
                    stringBuilder.append(appType);
                    stringBuilder.append(", pdtCfgAdjApp = ");
                    stringBuilder.append(pdtCfgAdjApp);
                    stringBuilder.append(",pdtNotCfgAdjApp=");
                    stringBuilder.append(pdtNotCfgAdjApp);
                    android.util.Slog.d("HwBrightnessPgSceneDetection", stringBuilder.toString());
                }
                if (pkg != null && com.android.server.display.HwBrightnessPgSceneDetection.this.mBacklightAppList != null) {
                    boolean shouldUpdateBLight;
                    com.android.server.display.HwBrightnessPgSceneDetection hwBrightnessPgSceneDetection;
                    if (com.android.server.display.HwBrightnessPgSceneDetection.this.mBacklightAppList.contains(java.lang.Integer.valueOf(appType))) {
                        if (!pdtCfgAdjApp) {
                            shouldUpdateBLight = false;
                            if (pdtNotCfgAdjApp && shouldUpdateBLight) {
                                shouldUpdateBLight = false;
                            }
                            hwBrightnessPgSceneDetection = com.android.server.display.HwBrightnessPgSceneDetection.this;
                            if (shouldUpdateBLight && !exempStateType) {
                                z = true;
                            }
                            hwBrightnessPgSceneDetection.mShouldUpdateBLight = z;
                            com.android.server.display.HwBrightnessPgSceneDetection.this.sendUpdatePgBrightness(com.android.server.display.HwBrightnessPgSceneDetection.this.mShouldUpdateBLight);
                        }
                    }
                    shouldUpdateBLight = true;
                    shouldUpdateBLight = false;
                    hwBrightnessPgSceneDetection = com.android.server.display.HwBrightnessPgSceneDetection.this;
                    z = true;
                    hwBrightnessPgSceneDetection.mShouldUpdateBLight = z;
                    com.android.server.display.HwBrightnessPgSceneDetection.this.sendUpdatePgBrightness(com.android.server.display.HwBrightnessPgSceneDetection.this.mShouldUpdateBLight);
                }
            }
        }
    };

    public interface HwBrightnessPgSceneDetectionCallbacks {
        void updateStateRecognition(boolean z, int i);
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwBrightnessPgSceneDetection", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwBrightnessPgSceneDetection(com.android.server.display.HwBrightnessPgSceneDetection.HwBrightnessPgSceneDetectionCallbacks callbacks, int pgSceneDetectionDarkenDelayTime, int pgSceneDetectionBrightenDelayTime, android.content.Context context) {
        this.mCallbacks = callbacks;
        this.mContext = context;
        parsePowerSavingAppType(android.os.SystemProperties.get("ro.blight.exempt_app_type", ""));
        this.mHandler.sendEmptyMessage(2);
        this.mPgSceneDetectionDarkenDelayTime = pgSceneDetectionDarkenDelayTime;
        this.mPgSceneDetectionBrightenDelayTime = pgSceneDetectionBrightenDelayTime;
    }

    private void registerPowerModeChangedListener() {
        android.content.IntentFilter intentFilter = new android.content.IntentFilter("huawei.intent.action.POWER_MODE_CHANGED_ACTION");
        intentFilter.addAction("huawei.intent.action.PG_EXTREME_MODE_ENABLE_ACTION");
        this.mContext.registerReceiver(this.mPgModeChangedBroadcastReceiver, intentFilter);
    }

    public static int getAdjsutLightVal(int rawLight) {
        int retVal = rawLight;
        if (rawLight >= 20 && rawLight <= 55) {
            return (((rawLight - 20) * (LOW_LIGHT_REFERENCE_RATIO - 20)) / 35) + 20;
        }
        if (rawLight > 55) {
            return (int) ((((float) rawLight) * PG_POWER_SAVE_MODE_LIGHT_RATIO) + 0.5f);
        }
        return retVal;
    }

    public float getPgPowerModeRatio() {
        return PG_POWER_SAVE_MODE_LIGHT_RATIO;
    }

    public int getPgPowerMode() {
        return android.os.SystemProperties.getInt("persist.sys.smart_power", 2);
    }

    public int getPowerSaveModeLightValFromRaw(int rawLightVal) {
        int retRatioVal = getAdjsutLightVal(rawLightVal);
        if (retRatioVal < 4) {
            retRatioVal = 4;
            android.util.Slog.w("HwBrightnessPgSceneDetection", "warning retRatioVal < min,retRatioVal=4");
        }
        if (retRatioVal <= 255) {
            return retRatioVal;
        }
        android.util.Slog.w("HwBrightnessPgSceneDetection", "warning retRatioVal > max,retRatioVal=255");
        return 255;
    }

    public int getSuperPowerSaveModeArbLightVal(int rawLightVal) {
        int calRawVal = rawLightVal > 0 ? rawLightVal : 25;
        return calRawVal < 35 ? calRawVal : 35;
    }

    public int getAdjustLightValByPgMode(int rawLightVal) {
        int retVal = rawLightVal;
        int nowPgMode = getPgPowerMode();
        java.lang.StringBuilder stringBuilder;
        if (nowPgMode == 1) {
            retVal = getPowerSaveModeLightValFromRaw(rawLightVal);
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PG_POWER_SAVE_MODE,nowPgMode");
                stringBuilder.append(nowPgMode);
                stringBuilder.append(",rawLightVal=");
                stringBuilder.append(rawLightVal);
                stringBuilder.append(",retVal=");
                stringBuilder.append(retVal);
                android.util.Slog.d("HwBrightnessPgSceneDetection", stringBuilder.toString());
            }
        } else if (nowPgMode == 4) {
            retVal = getSuperPowerSaveModeArbLightVal(rawLightVal);
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PG_SUPER_POWER_SAVE_MODE,nowPgMode");
                stringBuilder.append(nowPgMode);
                stringBuilder.append(",rawLightVal=");
                stringBuilder.append(rawLightVal);
                stringBuilder.append(",retVal=");
                stringBuilder.append(retVal);
                android.util.Slog.d("HwBrightnessPgSceneDetection", stringBuilder.toString());
            }
        }
        return retVal;
    }

    private void parsePowerSavingAppType(java.lang.String exempt_app_type) {
        if (exempt_app_type != null) {
            if (exempt_app_type.length() > 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PowerSaving exempt_app_type=");
                stringBuilder.append(exempt_app_type);
                android.util.Slog.i("HwBrightnessPgSceneDetection", stringBuilder.toString());
                if (this.mBacklightAppList != null) {
                    this.mBacklightAppList.clear();
                } else {
                    this.mBacklightAppList = new java.util.ArrayList();
                }
                java.lang.String[] powerSavingAppType = exempt_app_type.split(",");
                int i = 0;
                while (i < powerSavingAppType.length) {
                    try {
                        this.mBacklightAppList.add(java.lang.Integer.valueOf(java.lang.Integer.parseInt(powerSavingAppType[i])));
                        i++;
                    } catch (java.lang.NumberFormatException e) {
                        this.mBacklightAppList.clear();
                        android.util.Slog.w("HwBrightnessPgSceneDetection", "parse mBacklightAppList error");
                        return;
                    }
                }
                return;
            }
        }
        android.util.Slog.w("HwBrightnessPgSceneDetection", "exempt_app_type == null");
    }

    public static boolean isNoUsePowerCureAppEnable(java.lang.String pkgName) {
        return com.android.server.display.HwPgSceneDetectionAppName.isNoUsePowerCureAppEnable(pkgName);
    }

    private synchronized void sendUpdatePgBrightness(boolean shouldUpdateBackLight) {
        this.mHandler.removeMessages(1);
        if (shouldUpdateBackLight) {
            this.mHandler.sendEmptyMessageDelayed(1, (long) this.mPgSceneDetectionDarkenDelayTime);
        } else {
            this.mHandler.sendEmptyMessageDelayed(1, (long) this.mPgSceneDetectionBrightenDelayTime);
        }
    }

    public boolean registerPgBLightSceneListener(android.content.Context context) {
        if (!this.mPGBLListenerRegisted) {
            this.mPGSdk = com.huawei.pgmng.plug.PGSdk.getInstance();
            if (this.mPGSdk != null) {
                this.mPGBLListenerRegisted = registerPGSdkListener();
            }
        }
        return this.mPGBLListenerRegisted;
    }

    private boolean registerPGSdkListener() {
        boolean retVal = false;
        if (this.mPGSdk == null) {
            return false;
        }
        try {
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10000);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10001);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10002);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10003);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10004);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10007);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10008);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10009);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10010);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10011);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10013);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10015);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10016);
            this.mPGSdk.enableStateEvent(this.mStateRecognitionListener, 10017);
            retVal = true;
        } catch (android.os.RemoteException e) {
            this.mPGSdk = null;
            android.util.Slog.e("HwBrightnessPgSceneDetection", "mPGSdk registerSink && enableStateEvent happend RemoteException ");
        } catch (java.lang.NullPointerException e2) {
            this.mPGSdk = null;
            android.util.Slog.e("HwBrightnessPgSceneDetection", "mPGSdk registerSink && enableStateEvent happend NullPointerException ");
        }
        return retVal;
    }

    public void unregisterPgBLightSceneListener(android.content.Context context) {
        if (this.mPGBLListenerRegisted) {
            this.mPGBLListenerRegisted = unRegisterPGSdkListener() ^ 1;
        }
    }

    private boolean unRegisterPGSdkListener() {
        if (this.mPGSdk == null) {
            return true;
        }
        boolean retVal;
        try {
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10000);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10001);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10002);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10003);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10004);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10007);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10008);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10009);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10010);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10011);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10013);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10015);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10016);
            this.mPGSdk.disableStateEvent(this.mStateRecognitionListener, 10017);
            retVal = true;
        } catch (android.os.RemoteException e) {
            retVal = false;
            android.util.Slog.e("HwBrightnessPgSceneDetection", "callPG unRegisterListener happend RemoteException ");
        } catch (java.lang.NullPointerException e2) {
            retVal = false;
            android.util.Slog.e("HwBrightnessPgSceneDetection", "callPG unRegisterListener happend NullPointerException ");
        }
        return retVal;
    }

    public boolean getPGBLListenerRegisted() {
        return this.mPGBLListenerRegisted;
    }
}
