package com.android.server.display;

public class HwEyeProtectionAmbientLuxFilterAlgo {
    private static final float AMBIENT_LUX_INVALID = 0.0f;
    private static final int AMBIENT_MAX_LUX = 40000;
    private static final boolean DEBUG;
    private static final int FILTER_TYPE_AVERAGE = 1;
    private static final int FILTER_TYPE_MAX_MIN_AVERAGE = 3;
    private static final int FILTER_TYPE_NONE = 0;
    private static final int FILTER_TYPE_WEIGHT_AVERAGE = 2;
    private static final int INTIAL_RING_BUFFER_SIZE = 50;
    private static final long MAX_RECORD_TIME = 20000;
    private static final java.lang.String TAG = "HwEyeProtectionAmbientLuxFilterAlgo";
    private com.android.server.display.HwRingBuffer mAmbientLightRingBuffer = new com.android.server.display.HwRingBuffer(50);
    private float mAmbientLux = 0.0f;
    private float mBrightenDeltaLuxMax;
    private float mDarkenDeltaLuxMax;
    com.android.server.display.HwEyeProtectionXmlLoader.Data mData;
    private com.android.server.display.HwRingBuffer mFilteredAmbientLightRingBuffer = new com.android.server.display.HwRingBuffer(50);
    private boolean mFirstAmbientLux = true;
    private float mLastFilterLux = 0.0f;
    private final java.lang.Object mLock = new java.lang.Object();
    private boolean mNeedToBrighten = false;
    private boolean mNeedToDarken = false;
    private long mNormBrightenDebounceTime;
    private long mNormDarkenDebounceTime;

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwEyeProtectionAmbientLuxFilterAlgo", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwEyeProtectionAmbientLuxFilterAlgo(com.android.server.display.HwEyeProtectionXmlLoader.Data filterParameters) {
        if (filterParameters == null) {
            this.mData = new com.android.server.display.HwEyeProtectionXmlLoader.Data();
        } else {
            this.mData = filterParameters;
        }
    }

    public float updateAmbientLux(float ambientLux) {
        float retLux;
        java.lang.StringBuilder stringBuilder;
        synchronized (this.mLock) {
            retLux = 0.0f;
            long currentTime = android.os.SystemClock.uptimeMillis();
            if (ambientLux > 40000.0f) {
                ambientLux = 40000.0f;
                try {
                    if (DEBUG) {
                        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "ambientLux exceeds limitation.");
                    }
                } catch (java.lang.ArrayIndexOutOfBoundsException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("updateAmbientLux: ");
                    stringBuilder.append(e);
                    android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
                } catch (java.lang.ArrayIndexOutOfBoundsException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("updateAmbientLux: ");
                    stringBuilder.append(e2);
                    android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
                }
            }
            updateAmbientLuxBuffer(currentTime, ambientLux, 20000);
            retLux = updateAmbientLux(ambientLux, currentTime);
            if (DEBUG != null) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("updateAmbientLux:currentTime=");
                stringBuilder2.append(currentTime);
                stringBuilder2.append(" ambientLux = ");
                stringBuilder2.append(ambientLux);
                stringBuilder2.append(" retLux = ");
                stringBuilder2.append(retLux);
                android.util.Slog.d("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder2.toString());
            }
        }
        return retLux;
    }

    private float updateAmbientLux(float lux, long currentTime) {
        long j = currentTime;
        float filterLux = filterAmbientLux(j, this.mData.preMethodNum);
        boolean z = false;
        if (this.mFirstAmbientLux) {
            this.mAmbientLux = (float) java.lang.Math.round(lux);
            this.mFirstAmbientLux = false;
        }
        float latestLux = getOriginLatestAmbientLux(j);
        updateFilteredAmbientLuxBuffer(j, filterLux, 20000);
        this.mLastFilterLux = getFilterLastAmbientLux(j);
        float ambientLux = filterCurrentAmbientLux(j, this.mData.postMethodNum);
        updateParameters(this.mAmbientLightRingBuffer, this.mAmbientLux);
        long nextBrightenTransition = nextAmbientLightBrighteningTransition(j);
        long nextDarkenTransition = nextAmbientLightDarkeningTransition(j);
        boolean needToBrighten = decideToBrighten(ambientLux);
        boolean needToBrightenNew = decideToBrighten(latestLux);
        boolean needToDarken = decideToDarken(ambientLux);
        boolean needToDarkenNew = decideToDarken(latestLux);
        boolean z2 = true;
        if (needToBrighten && needToBrightenNew && nextBrightenTransition <= j) {
            z = true;
        }
        this.mNeedToBrighten = z;
        if (!needToDarken || !needToDarkenNew || nextDarkenTransition > j) {
            z2 = false;
        }
        this.mNeedToDarken = z2;
        if (!this.mNeedToBrighten) {
            if (!this.mNeedToDarken) {
                long j2 = nextBrightenTransition;
                return ambientLux;
            }
        }
        this.mAmbientLux = (float) java.lang.Math.round(lux);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mNeedToBrighten = ");
        stringBuilder.append(this.mNeedToBrighten);
        stringBuilder.append("mNeedToDarken = ");
        stringBuilder.append(this.mNeedToDarken);
        android.util.Slog.d("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
        return ambientLux;
    }

    private void updateAmbientLuxBuffer(long currentTime, float ambientLux, long maxRecordTime) {
        this.mAmbientLightRingBuffer.push(currentTime, ambientLux);
        this.mAmbientLightRingBuffer.prune(currentTime - maxRecordTime);
    }

    private void updateFilteredAmbientLuxBuffer(long currentTime, float ambientLux, long elapsedRecordTime) {
        this.mFilteredAmbientLightRingBuffer.push(currentTime, ambientLux);
        this.mFilteredAmbientLightRingBuffer.prune(currentTime - elapsedRecordTime);
    }

    private float filterAmbientLux(long currentTime, int filterType) {
        float retFilteredLux;
        switch (filterType) {
            case 0:
                retFilteredLux = prefilterNoneFilter(currentTime);
                break;
            case 1:
                retFilteredLux = prefilterAverageFilter(currentTime);
                break;
            case 2:
                retFilteredLux = prefilterWeightedAverageFilter(currentTime);
                break;
            default:
                retFilteredLux = prefilterNoneFilter(currentTime);
                break;
        }
        return retFilteredLux;
    }

    private float prefilterNoneFilter(long currentTime) {
        int bufferSize = this.mAmbientLightRingBuffer.size();
        if (bufferSize != 0) {
            return this.mAmbientLightRingBuffer.getLux(bufferSize - 1);
        }
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "prefilterNoFilter: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float prefilterAverageFilter(long currentTime) {
        int bufferSize = this.mAmbientLightRingBuffer.size();
        if (bufferSize == 0) {
            android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "prefilterMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.preMeanFilterNum > 0) {
            if (this.mData.preMeanFilterNoFilterNum >= this.mData.preMeanFilterNum) {
                if (bufferSize <= this.mData.preMeanFilterNoFilterNum) {
                    return this.mAmbientLightRingBuffer.getLux(bufferSize - 1);
                }
                float sum = 0.0f;
                for (int i = bufferSize - 1; i >= bufferSize - this.mData.preMeanFilterNum; i--) {
                    sum += this.mAmbientLightRingBuffer.getLux(i);
                }
                return (float) java.lang.Math.round(sum / ((float) this.mData.preMeanFilterNum));
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prefilterMeanFilter: ErrorPara, return 0, MeanFilterNum=");
        stringBuilder.append(this.mData.preMeanFilterNum);
        stringBuilder.append(",MeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.preMeanFilterNoFilterNum);
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float prefilterWeightedAverageFilter(long currentTime) {
        int bufferSize = this.mAmbientLightRingBuffer.size();
        if (bufferSize == 0) {
            android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "prefilterWeightedMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.preWeightedMeanFilterNum > 0) {
            if (this.mData.preWeightedMeanFilterNoFilterNum >= this.mData.preWeightedMeanFilterNum) {
                float tempLux = this.mAmbientLightRingBuffer.getLux(bufferSize - 1);
                if (bufferSize <= this.mData.preWeightedMeanFilterNoFilterNum) {
                    return tempLux;
                }
                int i;
                float maxLux = 0.0f;
                float sum = 0.0f;
                float totalWeight = 0.0f;
                for (i = bufferSize - 1; i >= bufferSize - this.mData.preWeightedMeanFilterMaxFuncLuxNum; i--) {
                    tempLux = this.mAmbientLightRingBuffer.getLux(i);
                    if (tempLux >= maxLux) {
                        maxLux = tempLux;
                    }
                }
                for (i = bufferSize - 1; i >= bufferSize - this.mData.preWeightedMeanFilterNum; i--) {
                    float weight;
                    if (this.mAmbientLightRingBuffer.getLux(i) != 0.0f || maxLux > this.mData.preWeightedMeanFilterLuxTh) {
                        weight = 1.0f * 1.0f;
                    } else {
                        weight = this.mData.preWeightedMeanFilterAlpha * 1.0f;
                    }
                    totalWeight += weight;
                    sum += this.mAmbientLightRingBuffer.getLux(i) * weight;
                }
                return (float) java.lang.Math.round(sum / totalWeight);
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prefilterWeightedMeanFilter: ErrorPara, return 0, WeightedMeanFilterNum=");
        stringBuilder.append(this.mData.preWeightedMeanFilterNum);
        stringBuilder.append(",WeightedMeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.preWeightedMeanFilterNoFilterNum);
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float filterCurrentAmbientLux(long currentTime, int filterType) {
        float retFilteredLux;
        if (filterType != 3) {
            switch (filterType) {
                case 0:
                    retFilteredLux = obtainCurrentAmbientLuxFromNoneFilter(currentTime);
                    break;
                case 1:
                    retFilteredLux = obtainCurrentAmbientLuxFromAverageFilter(currentTime);
                    break;
                default:
                    retFilteredLux = obtainCurrentAmbientLuxFromNoneFilter(currentTime);
                    break;
            }
        }
        retFilteredLux = obtainCurrentAmbientLuxFromMaxMinAverageFilter(currentTime);
        return retFilteredLux;
    }

    private float obtainCurrentAmbientLuxFromNoneFilter(long currentTime) {
        int N = this.mFilteredAmbientLightRingBuffer.size();
        if (N != 0) {
            return this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
        }
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "postfilterNoFilter: No ambient light readings available, return 0");
        return 0.0f;
    }

    private float obtainCurrentAmbientLuxFromAverageFilter(long currentTime) {
        int N = this.mFilteredAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "prefilterMeanFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.postMeanFilterNum > 0) {
            if (this.mData.postMeanFilterNoFilterNum >= this.mData.postMeanFilterNum) {
                if (N <= this.mData.postMeanFilterNoFilterNum) {
                    return this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
                }
                float sum = 0.0f;
                for (int i = N - 1; i >= N - this.mData.postMeanFilterNum; i--) {
                    sum += this.mFilteredAmbientLightRingBuffer.getLux(i);
                }
                return (float) java.lang.Math.round(sum / ((float) this.mData.postMeanFilterNum));
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("postfilterMeanFilter: ErrorPara, return 0, MeanFilterNum=");
        stringBuilder.append(this.mData.postMeanFilterNum);
        stringBuilder.append(",MeanFilterNoFilterNum=");
        stringBuilder.append(this.mData.postMeanFilterNum);
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private float obtainCurrentAmbientLuxFromMaxMinAverageFilter(long currentTime) {
        int N = this.mFilteredAmbientLightRingBuffer.size();
        if (N == 0) {
            android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "postfilterMaxMinAvgFilter: No ambient light readings available, return 0");
            return 0.0f;
        }
        if (this.mData.postMaxMinAvgFilterNum > 0) {
            if (this.mData.postMaxMinAvgFilterNoFilterNum >= this.mData.postMaxMinAvgFilterNum) {
                if (N <= this.mData.postMaxMinAvgFilterNoFilterNum) {
                    return this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
                }
                float sum = this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
                float luxMin = this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
                float luxMax = this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
                for (int i = N - 2; i >= N - this.mData.postMaxMinAvgFilterNum; i--) {
                    if (luxMin > this.mFilteredAmbientLightRingBuffer.getLux(i)) {
                        luxMin = this.mFilteredAmbientLightRingBuffer.getLux(i);
                    }
                    if (luxMax < this.mFilteredAmbientLightRingBuffer.getLux(i)) {
                        luxMax = this.mFilteredAmbientLightRingBuffer.getLux(i);
                    }
                    sum += this.mFilteredAmbientLightRingBuffer.getLux(i);
                }
                return ((sum - luxMin) - luxMax) / 3.0f;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("postfilterMaxMinAvgFilter: ErrorPara, return 0, PostMaxMinAvgFilterNoFilterNum=");
        stringBuilder.append(this.mData.postMaxMinAvgFilterNoFilterNum);
        stringBuilder.append(",PostMaxMinAvgFilterNum=");
        stringBuilder.append(this.mData.postMaxMinAvgFilterNum);
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
        return 0.0f;
    }

    private void updateParameters(com.android.server.display.HwRingBuffer buffer, float lux) {
        float luxInteger = (float) java.lang.Math.round(lux);
        if (luxInteger >= this.mData.brightTimeDelayLuxThreshold || this.mLastFilterLux >= this.mData.brightTimeDelayLuxThreshold || !this.mData.brightTimeDelayEnable) {
            this.mNormBrightenDebounceTime = (long) this.mData.brightenDebounceTime;
        } else {
            this.mNormBrightenDebounceTime = (long) this.mData.brightTimeDelay;
        }
        if (luxInteger >= this.mData.darkTimeDelayLuxThreshold || !this.mData.darkTimeDelayEnable) {
            this.mNormDarkenDebounceTime = (long) this.mData.darkenDebounceTime;
        } else {
            float ambientLuxDarkenDelta = calculateDarkenThresholdDelta(this.mAmbientLux);
            float currentAmbientLux = buffer.getLux(buffer.size() - 1);
            float luxNormalizedFactor = ((this.mData.darkTimeDelayBeta2 * (this.mAmbientLux - currentAmbientLux)) + (this.mData.darkTimeDelayBeta1 * ((this.mAmbientLux - currentAmbientLux) - ambientLuxDarkenDelta))) + 1.0f;
            if (luxNormalizedFactor < 0.001f) {
                this.mNormDarkenDebounceTime = (long) (((float) this.mData.darkTimeDelay) + this.mData.darkTimeDelayBeta0);
            } else {
                this.mNormDarkenDebounceTime = ((long) this.mData.darkTimeDelay) + ((long) ((this.mData.darkTimeDelayBeta0 * (1.0f + (this.mData.darkTimeDelayBeta2 * 1.0f))) / luxNormalizedFactor));
            }
        }
        setDarkenThresholdNew(this.mAmbientLux);
        setBrightenThresholdNew(this.mAmbientLux);
    }

    private float getOriginLatestAmbientLux(long currentTime) {
        int bufferSize = this.mAmbientLightRingBuffer.size();
        if (bufferSize != 0) {
            return this.mAmbientLightRingBuffer.getLux(bufferSize - 1);
        }
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "getOriginLatestAmbientLux: No ambient light readings available, return 0");
        return 0.0f;
    }

    private void setBrightenThresholdNew(float amLux) {
        this.mBrightenDeltaLuxMax = calculateBrightenThresholdDelta(amLux);
    }

    private void setDarkenThresholdNew(float amLux) {
        this.mDarkenDeltaLuxMax = calculateDarkenThresholdDelta(amLux);
    }

    private float calculateBrightenThresholdDelta(float amLux) {
        float brightenThreshold = 0.0f;
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.brightenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (amLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x > temp1.x) {
                    return (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (amLux - temp1.x)) + temp1.y;
                }
                if (!DEBUG) {
                    return 1.0f;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Brighten_temp1.x <= temp2.x,x");
                stringBuilder.append(temp.x);
                stringBuilder.append(", y = ");
                stringBuilder.append(temp.y);
                android.util.Slog.i("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
                return 1.0f;
            }
            temp1 = temp;
            brightenThreshold = temp1.y;
        }
        return brightenThreshold;
    }

    private float calculateDarkenThresholdDelta(float amLux) {
        float darkenThreshold = 0.0f;
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.darkenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (amLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x > temp1.x) {
                    float darkenThresholdTmp = (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (amLux - temp1.x)) + temp1.y;
                    float f = 1.0f;
                    if (darkenThresholdTmp > 1.0f) {
                        f = darkenThresholdTmp;
                    }
                    return f;
                } else if (!DEBUG) {
                    return 1.0f;
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Darken_temp1.x <= temp2.x,x");
                    stringBuilder.append(temp.x);
                    stringBuilder.append(", y = ");
                    stringBuilder.append(temp.y);
                    android.util.Slog.i("HwEyeProtectionAmbientLuxFilterAlgo", stringBuilder.toString());
                    return 1.0f;
                }
            }
            temp1 = temp;
            darkenThreshold = temp1.y;
        }
        return darkenThreshold;
    }

    private long nextAmbientLightBrighteningTransition(long time) {
        long earliestValidTime = time;
        for (int i = this.mFilteredAmbientLightRingBuffer.size() - 1; i >= 0; i--) {
            boolean BrightenChange;
            if (this.mFilteredAmbientLightRingBuffer.getLux(i) - this.mAmbientLux > this.mBrightenDeltaLuxMax) {
                BrightenChange = true;
            } else {
                BrightenChange = false;
            }
            if (!BrightenChange) {
                break;
            }
            earliestValidTime = this.mFilteredAmbientLightRingBuffer.getTime(i);
        }
        return getNextAmbientLightBrighteningTime(earliestValidTime);
    }

    private long nextAmbientLightDarkeningTransition(long time) {
        long earliestValidTime = time;
        for (int i = this.mFilteredAmbientLightRingBuffer.size() - 1; i >= 0; i--) {
            boolean DarkenChange;
            if (this.mAmbientLux - this.mFilteredAmbientLightRingBuffer.getLux(i) >= this.mDarkenDeltaLuxMax) {
                DarkenChange = true;
            } else {
                DarkenChange = false;
            }
            if (!DarkenChange) {
                break;
            }
            earliestValidTime = this.mFilteredAmbientLightRingBuffer.getTime(i);
        }
        return getNextAmbientLightDarkeningTime(earliestValidTime);
    }

    private long getNextAmbientLightBrighteningTime(long earliedtime) {
        return this.mNormBrightenDebounceTime + earliedtime;
    }

    private long getNextAmbientLightDarkeningTime(long earliedtime) {
        return this.mNormDarkenDebounceTime + earliedtime;
    }

    private boolean decideToBrighten(float ambientLux) {
        if (ambientLux - this.mAmbientLux >= this.mBrightenDeltaLuxMax) {
            return true;
        }
        return false;
    }

    private boolean decideToDarken(float ambientLux) {
        if (this.mAmbientLux - ambientLux >= this.mDarkenDeltaLuxMax) {
            return true;
        }
        return false;
    }

    public boolean getNeedToBrighten() {
        return this.mNeedToBrighten;
    }

    public boolean getNeedToDarken() {
        return this.mNeedToDarken;
    }

    private float getFilterLastAmbientLux(long now) {
        int N = this.mFilteredAmbientLightRingBuffer.size();
        if (N != 0) {
            return this.mFilteredAmbientLightRingBuffer.getLux(N - 1);
        }
        android.util.Slog.e("HwEyeProtectionAmbientLuxFilterAlgo", "FilterLastAmbient: No ambient light readings available, return 0");
        return 0.0f;
    }

    public void clear() {
        synchronized (this.mLock) {
            if (DEBUG) {
                android.util.Slog.d("HwEyeProtectionAmbientLuxFilterAlgo", "clear buffer data");
            }
            this.mAmbientLightRingBuffer.clear();
            this.mFilteredAmbientLightRingBuffer.clear();
            this.mFirstAmbientLux = true;
        }
    }
}
