package com.android.server.display;

public class HwEyeProtectionControllerImpl extends com.android.server.display.HwEyeProtectionController {
    private static final java.lang.String ACTION_TURN_OFF_EYEPROTECTION = "com.android.server.action.ACTION_TURN_OFF_EYEPROTECTION";
    private static final boolean DEBUG = false;
    private static final java.lang.String KEY_EYES_PROTECTION = "eyes_protection_mode";
    private static final java.lang.String LCD_PANEL_TYPE_PATH = "/sys/class/graphics/fb0/lcd_model";
    private static final float[] LuxDefaultLevel = new float[]{0.0f, 100.0f, 1000.0f, 3000.0f};
    private static final java.lang.String SETTINGS_ACTION = "com.android.settings.EyeComfortSettings";
    private static final java.lang.String SETTINGS_PACKAGE_NAME = "com.android.settings";
    private static final java.lang.String TAG = "EyeProtectionControllerImpl";
    private static final int mLightSensorRate = 300;
    private static boolean mLoadLibraryFailed;
    private static int mMaxLightCtData = 10000;
    private static int mMinLightCtData = 2000;
    private float mAmbientCct = -1.0f;
    private float mAmbientLux = -1.0f;
    private com.android.server.display.HwEyeProtectionAmbientLuxFilterAlgo mAmbientLuxFilterAlgo;
    private int mBlueLightFilterReal;
    private int mBluelightAnimationTarget;
    private int mBluelightAnimationTimes;
    private int mBluelightBeforeAnimation;
    private boolean mBootCompleted;
    private int mColorBeforeAnimation;
    private int mColorTemperatureCloudy;
    private int mColorTemperatureInDoor;
    private int mColorTemperatureNight;
    private int mColorTemperatureSunny;
    private int mColorTemperatureTarget;
    private int mColorTemperatureTimes = 1;
    private android.content.Context mContext;
    private int mCurrentColorTemperature;
    private int mCurrentFilterValue;
    private int mCurrentUserId;
    private com.android.server.display.DisplayEffectMonitor mDisplayEffectMonitor;
    private com.huawei.displayengine.DisplayEngineManager mDisplayEngineManager;
    private long mEyeComfortValidValue = 0;
    private boolean mEyeProtectionControlFlag = false;
    private com.android.server.display.HwEyeProtectionDividedTimeControl mEyeProtectionDividedTimeControl;
    private boolean mEyeProtectionScreenOff = false;
    private int mEyeProtectionScreenOffMode = 0;
    private int mEyeProtectionTempMode = 0;
    private int mEyeScheduleBeginTime;
    private int mEyeScheduleEndTime;
    private int mEyeScheduleSwitchMode;
    private int mEyesProtectionMode;
    private java.lang.String mFilterConfigFilePath = null;
    private boolean mFilterEnable;
    private com.android.server.display.HwEyeProtectionXmlLoader.Data mFilterParameters;
    private com.android.server.display.HwEyeProtectionControllerImpl.SmartDisplayHandler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private int mKidsEyesProtectionMode = 1;
    private android.database.ContentObserver mKidsEyesProtectionModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            com.android.server.display.HwEyeProtectionControllerImpl.this.mKidsEyesProtectionMode = android.provider.Settings.Global.getInt(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "blue_eye_protection", 1);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("eyes protection mode changed in Kids mode. mKidsEyesProtectionMode:");
            stringBuilder.append(com.android.server.display.HwEyeProtectionControllerImpl.this.mKidsEyesProtectionMode);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
        }
    };
    private int mKidsMode;
    private android.database.ContentObserver mKidsModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            com.android.server.display.HwEyeProtectionControllerImpl.this.mKidsMode = android.provider.Settings.Global.getInt(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "hwkidsmode_running", 0);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Kids mode changed. mKidsMode:");
            stringBuilder.append(com.android.server.display.HwEyeProtectionControllerImpl.this.mKidsMode);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
        }
    };
    private java.lang.String mLcdPanelName = null;
    private int mLessWarm;
    private android.hardware.Sensor mLightSensor;
    private final android.hardware.SensorEventListener mLightSensorListener = new android.hardware.SensorEventListener() {
        public void onSensorChanged(android.hardware.SensorEvent event) {
            com.android.server.display.HwEyeProtectionControllerImpl.this.handleLightSensor(android.os.SystemClock.uptimeMillis(), event.values[0], event.values[1]);
        }

        public void onAccuracyChanged(android.hardware.Sensor sensor, int accuracy) {
        }
    };
    private java.util.ArrayList<java.lang.Float> mLuxLevel = null;
    private int mMoreWarm;
    private android.database.ContentObserver mProtectionModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            int tempProtectionMode = com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode;
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode = android.provider.Settings.System.getIntForUser(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Eyes-Protect mode in Settings changed, mEyesProtectionMode =");
            stringBuilder.append(com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode);
            stringBuilder.append(", user =");
            stringBuilder.append(-2);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            com.android.server.display.HwEyeProtectionControllerImpl.this.setValidTimeOnProtectionMode(tempProtectionMode);
            if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 3) {
                com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
                return;
            }
            if (tempProtectionMode == 3 && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 0 && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 0);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 1);
            }
            if (tempProtectionMode == 1 && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 0) {
                if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleSwitchMode == 1) {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                    if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.isNeedDelay()) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 0);
                        com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 1);
                    } else {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(0, 0);
                        com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(0, 1);
                    }
                } else {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(0);
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(1);
                }
            }
            if (tempProtectionMode == 0 && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 1 && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleSwitchMode == 1) {
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(0);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(1);
            }
            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
        }
    };
    private android.database.ContentObserver mScheduleBeginTimeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            int eyeScheduleBeginTime = com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleBeginTime;
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleBeginTime = android.provider.Settings.System.getIntForUser(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "eye_comfort_starttime", -1, -2);
            android.util.Slog.i("EyeProtectionControllerImpl", "Eyes-schedule begin time changed");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setValidTime(false);
            if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleBeginTime != -1) {
                if (eyeScheduleBeginTime != com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleBeginTime) {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.resetTimeControlAlarm();
                    if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
                        if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 0) {
                            com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(3);
                        } else {
                            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
                        }
                    } else if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 3) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(0);
                    } else {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
                    }
                }
            }
        }
    };
    private android.database.ContentObserver mScheduleEndTimeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            int eyeScheduleEndTime = com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleEndTime;
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleEndTime = android.provider.Settings.System.getIntForUser(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "eye_comfort_endtime", -1, -2);
            android.util.Slog.i("EyeProtectionControllerImpl", "Eyes-schedule end time changed");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setValidTime(false);
            if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleEndTime != -1) {
                if (eyeScheduleEndTime != com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleEndTime) {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.resetTimeControlAlarm();
                    if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
                        if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 0) {
                            com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(3);
                        } else {
                            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
                        }
                    } else if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 3) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(0);
                    } else {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
                    }
                }
            }
        }
    };
    private android.database.ContentObserver mScheduleModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleSwitchMode = android.provider.Settings.System.getIntForUser(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "eye_comfort_schedule_switch", 0, -2);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Eyes-schedule mode in Settings changed, mEyeScheduleSwitchMode =");
            stringBuilder.append(com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleSwitchMode);
            stringBuilder.append(", user =");
            stringBuilder.append(-2);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setValidTime(false);
            if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeScheduleSwitchMode == 0) {
                if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag() && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 3) {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(0);
                }
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(0);
                com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(1);
            } else {
                com.android.server.display.HwEyeProtectionControllerImpl.this.resetTimeControlAlarm();
                if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag() && com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 0) {
                    com.android.server.display.HwEyeProtectionControllerImpl.this.setEyeScheduleSwitchToUserMode(3);
                    return;
                }
            }
            com.android.server.display.HwEyeProtectionControllerImpl.this.updateGlobalSceneState();
        }
    };
    private com.android.server.display.HwEyeProtectionControllerImpl.ScreenStateReceiver mScreenStateReceiver;
    private android.hardware.SensorManager mSensorManager;
    private boolean mSetBlueFilterDirect = false;
    private android.database.ContentObserver mSetColorTempValueObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            com.android.server.display.HwEyeProtectionControllerImpl.this.mUserSetColorTempValue = android.provider.Settings.System.getIntForUser(com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.getContentResolver(), "user_set_warm", 0, -2);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Eyes set warm mode in Settings changed, mUserSetColorTempValue =");
            stringBuilder.append(com.android.server.display.HwEyeProtectionControllerImpl.this.mUserSetColorTempValue);
            stringBuilder.append(", user =");
            stringBuilder.append(-2);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            com.android.server.display.HwEyeProtectionControllerImpl.this.mAmbientLux = -1.0f;
            if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode != 0) {
                com.android.server.display.HwEyeProtectionControllerImpl.this.mSetBlueFilterDirect = true;
                com.android.server.display.HwEyeProtectionControllerImpl.this.setUserColorTemperature();
            }
        }
    };
    private boolean mSetForce3DColorTemp = true;
    private boolean mSuperPowerMode = false;
    private boolean mSupportAjustWithCt = false;
    private boolean mSupportDisplayEngine3DColorTemperature;
    private boolean mSupportDisplayEngineEyeProtection;
    private boolean mSupportSceneSwitch = false;
    private int mUserSetColorTempValue;
    private boolean mfirstSceneSwitchOn = true;

    private class ScreenStateReceiver extends android.content.BroadcastReceiver {
        public ScreenStateReceiver() {
            android.content.IntentFilter userSwitchFilter = new android.content.IntentFilter();
            userSwitchFilter.addAction("android.intent.action.USER_SWITCHED");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.registerReceiverAsUser(this, android.os.UserHandle.ALL, userSwitchFilter, null, null);
            android.content.IntentFilter bootCompletedFilter = new android.content.IntentFilter();
            bootCompletedFilter.addAction("android.intent.action.BOOT_COMPLETED");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.registerReceiverAsUser(this, android.os.UserHandle.ALL, bootCompletedFilter, null, null);
            android.content.IntentFilter superPowerFilter = new android.content.IntentFilter();
            superPowerFilter.addAction("huawei.intent.action.PG_EXTREME_MODE_ENABLE_ACTION");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.registerReceiverAsUser(this, android.os.UserHandle.ALL, superPowerFilter, null, null);
            android.content.IntentFilter timeChageFilter = new android.content.IntentFilter();
            timeChageFilter.addAction("android.intent.action.TIME_SET");
            timeChageFilter.addAction("android.intent.action.TIMEZONE_CHANGED");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.registerReceiverAsUser(this, android.os.UserHandle.ALL, timeChageFilter, null, null);
            android.content.IntentFilter screenOnChangeFilter = new android.content.IntentFilter();
            screenOnChangeFilter.addAction("android.intent.action.SCREEN_ON");
            com.android.server.display.HwEyeProtectionControllerImpl.this.mContext.registerReceiverAsUser(this, android.os.UserHandle.ALL, screenOnChangeFilter, null, null);
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onReceive intent action = ");
                stringBuilder.append(intent.getAction());
                android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
                if (intent.getAction() != null) {
                    android.os.Message message = new android.os.Message();
                    if ("huawei.intent.action.PG_EXTREME_MODE_ENABLE_ACTION".equals(intent.getAction())) {
                        message.what = 5;
                        if (intent.getBooleanExtra("enable", false)) {
                            message.arg1 = 1;
                        } else {
                            message.arg1 = 0;
                        }
                    } else if ("android.intent.action.USER_SWITCHED".equals(intent.getAction())) {
                        message.what = 4;
                        message.arg1 = intent.getIntExtra("android.intent.extra.user_handle", 0);
                    } else {
                        if (!"android.intent.action.TIME_SET".equals(intent.getAction())) {
                            if (!"android.intent.action.TIMEZONE_CHANGED".equals(intent.getAction())) {
                                if ("android.intent.action.SCREEN_ON".equals(intent.getAction())) {
                                    message.what = 8;
                                } else if ("android.intent.action.BOOT_COMPLETED".equals(intent.getAction())) {
                                    com.android.server.display.HwEyeProtectionControllerImpl.this.mBootCompleted = true;
                                    message.what = 9;
                                }
                            }
                        }
                        message.what = 6;
                    }
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mHandler.sendMessage(message);
                }
            }
        }
    }

    private final class SmartDisplayHandler extends android.os.Handler {
        public SmartDisplayHandler(android.os.Looper looper) {
            super(looper, null, true);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 0:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.colorTemperatureAnimationTo(com.android.server.display.HwEyeProtectionControllerImpl.this.mColorTemperatureTarget, 40);
                    return;
                case 1:
                    if (!com.android.server.display.HwEyeProtectionControllerImpl.this.mSetBlueFilterDirect) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.blueLightAnimationTo(com.android.server.display.HwEyeProtectionControllerImpl.this.mBluelightAnimationTarget, 40);
                        return;
                    }
                    return;
                case 2:
                    if (com.android.server.display.HwEyeProtectionControllerImpl.this.mAutomaticBrightnessController != null) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.mAutomaticBrightnessController.updateAutoBrightness(true);
                        android.util.Slog.i("EyeProtectionControllerImpl", "updateAutoBrightness.");
                        return;
                    }
                    return;
                case 3:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.setBootEyeProtectionControlStatus();
                    return;
                case 4:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.handleUserSwitch(msg.arg1);
                    return;
                case 5:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.handleSuperPower(msg.arg1);
                    return;
                case 6:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.handleTimeAndTimezoneChanged();
                    return;
                case 8:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.setScreenOffEyeProtection();
                    com.android.server.display.HwEyeProtectionControllerImpl.this.resetEyeProtectionScreenTurnOffMode();
                    return;
                case 9:
                    if (com.android.server.display.HwEyeProtectionControllerImpl.this.mEyesProtectionMode == 1) {
                        com.android.server.display.HwEyeProtectionControllerImpl.this.startStateEvent();
                        return;
                    }
                    return;
                case 10:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.mScreenStateReceiver = new com.android.server.display.HwEyeProtectionControllerImpl.ScreenStateReceiver();
                    return;
                case 11:
                    com.android.server.display.HwEyeProtectionControllerImpl.this.initDataState();
                    return;
                default:
                    android.util.Slog.e("EyeProtectionControllerImpl", "Invalid message");
                    return;
            }
        }
    }

    private static native void finalize_native();

    private static native void init_native();

    protected native int nativeFilterBlueLight(int i);

    protected native int nativeFilterBlueLight3DNew(int i);

    protected native int nativeGetDisplayFeatureSupported(int i);

    protected native int nativeSetColorTemperatureNew(int i);

    static {
        mLoadLibraryFailed = false;
        try {
            java.lang.System.loadLibrary("eyeprotection_jni");
            android.util.Slog.i("EyeProtectionControllerImpl", "libeyeprotection_jni library load!");
        } catch (java.lang.UnsatisfiedLinkError e) {
            mLoadLibraryFailed = true;
            android.util.Slog.w("EyeProtectionControllerImpl", "libeyeprotection_jni library not found!");
        }
    }

    protected void finalize() {
        if (!mLoadLibraryFailed) {
            finalize_native();
        }
        try {
            super.finalize();
        } catch (Throwable th) {
        }
    }

    private void startStateEvent() {
    }

    private void stopStateEvent() {
    }

    private void setValidTimeOnProtectionMode(int tempProtectionMode) {
        if (this.mEyesProtectionMode != 2) {
            if (tempProtectionMode != 2) {
                if (tempProtectionMode == 3 && this.mEyesProtectionMode == 0 && this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
                    this.mEyeProtectionDividedTimeControl.setValidTime(true);
                } else if (tempProtectionMode == 1 && this.mEyesProtectionMode == 0 && this.mEyeScheduleSwitchMode == 1 && this.mEyeProtectionDividedTimeControl.isNeedDelay()) {
                    this.mEyeProtectionDividedTimeControl.setValidTime(true);
                } else {
                    this.mEyeProtectionDividedTimeControl.setValidTime(false);
                }
            }
        }
    }

    private void registerLightSensor() {
        if (this.mSupportDisplayEngineEyeProtection) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return;
        }
        this.mSensorManager = (android.hardware.SensorManager) this.mContext.getSystemService("sensor");
        this.mLightSensor = this.mSensorManager.getDefaultSensor(5);
        this.mSensorManager.registerListener(this.mLightSensorListener, this.mLightSensor, 300000, null);
    }

    private void unregisterLightSensor() {
        if (this.mSensorManager != null) {
            this.mSensorManager.unregisterListener(this.mLightSensorListener);
        }
    }

    private void handleLightSensor(long time, float lux, float cct) {
        if (this.mSupportAjustWithCt) {
            handleLightSensorEvent(time, lux, cct);
        } else {
            handleLightSensorEvent(time, lux);
        }
    }

    private void handleLightSensorEvent(long time, float lux) {
        if (this.mfirstSceneSwitchOn && this.mEyeProtectionControlFlag) {
            if (this.mFilterEnable && this.mAmbientLuxFilterAlgo != null) {
                this.mAmbientLuxFilterAlgo.clear();
                lux = this.mAmbientLuxFilterAlgo.updateAmbientLux(lux);
            }
            this.mAmbientLux = lux;
            updateColorTemperature();
            this.mfirstSceneSwitchOn = false;
        } else if (!this.mEyeProtectionControlFlag) {
        } else {
            if (this.mFilterEnable && this.mAmbientLuxFilterAlgo != null) {
                lux = this.mAmbientLuxFilterAlgo.updateAmbientLux(lux);
                if (this.mAmbientLuxFilterAlgo.getNeedToBrighten() || this.mAmbientLuxFilterAlgo.getNeedToDarken()) {
                    this.mAmbientLux = lux;
                    updateColorTemperature();
                }
            } else if (lux > this.mAmbientLux * 1.2f || lux < this.mAmbientLux * 0.8f) {
                this.mAmbientLux = lux;
                updateColorTemperature();
            }
        }
    }

    private void handleLightSensorEvent(long time, float lux, float cct) {
    }

    private void updateColorTemperature() {
        if (!this.mSupportDisplayEngineEyeProtection) {
            if (com.android.server.display.Utils.isFunctionExist(4)) {
                float luxLevel0 = ((java.lang.Float) this.mLuxLevel.get(0)).floatValue();
                float luxLevel1 = ((java.lang.Float) this.mLuxLevel.get(1)).floatValue();
                float luxLevel2 = ((java.lang.Float) this.mLuxLevel.get(2)).floatValue();
                float luxLevel3 = ((java.lang.Float) this.mLuxLevel.get(3)).floatValue();
                if (this.mAmbientLux >= luxLevel0 && this.mAmbientLux < luxLevel1) {
                    this.mColorTemperatureTarget = this.mColorTemperatureNight;
                }
                if (this.mAmbientLux >= luxLevel1 && this.mAmbientLux < luxLevel2) {
                    this.mColorTemperatureTarget = this.mColorTemperatureInDoor;
                }
                if (this.mAmbientLux < 0.0f || (this.mAmbientLux >= luxLevel2 && this.mAmbientLux < luxLevel3)) {
                    this.mColorTemperatureTarget = this.mColorTemperatureCloudy;
                }
                if (this.mAmbientLux >= luxLevel3) {
                    this.mColorTemperatureTarget = this.mColorTemperatureSunny;
                }
                if (this.mColorTemperatureTarget != this.mCurrentColorTemperature) {
                    this.mColorTemperatureTimes = 1;
                    this.mColorBeforeAnimation = this.mCurrentColorTemperature;
                    colorTemperatureAnimationTo(this.mColorTemperatureTarget, 40);
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("updateColorTemperature mAmbientLux = ");
                    stringBuilder.append(this.mAmbientLux);
                    stringBuilder.append(", target =");
                    stringBuilder.append(this.mColorTemperatureTarget);
                    android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
                }
                return;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("mSupportDisplayEngineEyeProtection=");
        stringBuilder2.append(this.mSupportDisplayEngineEyeProtection);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder2.toString());
    }

    private void setColorTemperatureAccordingToSetting() {
        int operation;
        android.util.Slog.i("EyeProtectionControllerImpl", "setColorTemperatureAccordingToSetting");
        if (!this.mSupportDisplayEngine3DColorTemperature) {
            if (!isDisplayFeatureSupported(1)) {
                operation = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "color_temperature", 128, -2);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setColorTemperatureAccordingToSetting old:");
                stringBuilder.append(operation);
                android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
                setColorTemperature(operation);
                return;
            }
        }
        android.util.Slog.i("EyeProtectionControllerImpl", "setColorTemperatureAccordingToSetting new.");
        try {
            java.lang.String ctNewRGB = android.provider.Settings.System.getStringForUser(this.mContext.getContentResolver(), "color_temperature_rgb", -2);
            if (ctNewRGB != null) {
                java.util.List<java.lang.String> rgbarryList = new java.util.ArrayList(java.util.Arrays.asList(ctNewRGB.split(",")));
                float red = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(0)).floatValue();
                float green = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(1)).floatValue();
                float blue = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(2)).floatValue();
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("ColorTemperature read from setting:");
                stringBuilder2.append(ctNewRGB);
                stringBuilder2.append(red);
                stringBuilder2.append(green);
                stringBuilder2.append(blue);
                android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder2.toString());
                updateRgbGamma(red, green, blue);
                return;
            }
            operation = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "color_temperature", 128, -2);
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("ColorTemperature read from old setting:");
            stringBuilder3.append(operation);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder3.toString());
            setColorTemperature(operation);
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.w("EyeProtectionControllerImpl", "ColorTemperature read from setting exception!");
            updateRgbGamma(1.0f, 1.0f, 1.0f);
        }
    }

    public boolean isDisplayFeatureSupported(int feature) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isDisplayFeatureSupported feature:");
        stringBuilder.append(feature);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        boolean z = false;
        try {
            if (mLoadLibraryFailed) {
                android.util.Slog.i("EyeProtectionControllerImpl", "Display feature not supported because of library not found!");
                return false;
            }
            if (nativeGetDisplayFeatureSupported(feature) != 0) {
                z = true;
            }
            return z;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("EyeProtectionControllerImpl", "Display feature not supported because of exception!");
            return false;
        }
    }

    private int updateRgbGamma(float red, float green, float blue) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateRgbGamma:red=");
        stringBuilder.append(red);
        stringBuilder.append(" green=");
        stringBuilder.append(green);
        stringBuilder.append(" blue=");
        stringBuilder.append(blue);
        stringBuilder.append("mSupportDisplayEngine3DColorTemperature=");
        stringBuilder.append(this.mSupportDisplayEngine3DColorTemperature);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        if (this.mSupportDisplayEngine3DColorTemperature) {
            int[] xccCoef = new int[]{(int) (red * 32768.0f), (int) (green * 32768.0f), (int) (32768.0f * blue)};
            android.os.PersistableBundle bundle = new android.os.PersistableBundle();
            bundle.putIntArray("Buffer", xccCoef);
            bundle.putInt("BufferLength", 12);
            int ret = this.mDisplayEngineManager.setData(7, bundle);
            if (ret != 0) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("setData DATA_TYPE_3D_COLORTEMP failed, ret = ");
                stringBuilder2.append(ret);
                android.util.Slog.e("EyeProtectionControllerImpl", stringBuilder2.toString());
            }
            return ret;
        }
        try {
            return android.os.IPowerManager.Stub.asInterface(android.os.ServiceManager.getService("power")).updateRgbGamma(red, green, blue);
        } catch (android.os.RemoteException e) {
            return -1;
        }
    }

    private int setColorTemperature(int colorTemper) {
        if (this.mSupportDisplayEngineEyeProtection) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return -1;
        }
        try {
            return android.os.IPowerManager.Stub.asInterface(android.os.ServiceManager.getService("power")).setColorTemperature(colorTemper);
        } catch (android.os.RemoteException e) {
            return -1;
        }
    }

    private int setColorTemperatureNew(int colorTemper) {
        if (this.mSupportDisplayEngineEyeProtection) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return -1;
        }
        try {
            if (!mLoadLibraryFailed) {
                return nativeSetColorTemperatureNew(colorTemper);
            }
            android.util.Slog.i("EyeProtectionControllerImpl", "nativeSetColorTemperatureNew not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.w("EyeProtectionControllerImpl", "nativeSetColorTemperatureNew not found!");
            return -1;
        }
    }

    private int filterBlueLight(int value) {
        java.lang.StringBuilder stringBuilder;
        if (this.mSupportDisplayEngineEyeProtection) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return -1;
        }
        try {
            if (mLoadLibraryFailed) {
                android.util.Slog.i("EyeProtectionControllerImpl", "filterBlueLight not valid!");
                return 0;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("filterBlueLight value is");
            stringBuilder.append(value);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            if (this.mSupportAjustWithCt) {
                return nativeFilterBlueLight3DNew(value);
            }
            return nativeFilterBlueLight(value);
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.w("EyeProtectionControllerImpl", "filterBlueLight not found!");
            return -1;
        }
    }

    private void updateBrightness() {
        if (com.android.server.display.Utils.isFunctionExist(2)) {
            this.mHandler.sendEmptyMessageDelayed(2, 200);
        }
    }

    public void updateGlobalSceneState() {
        updateProtectionControlFlag();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateGlobalSceneState, mEyeProtectionControlFlag =");
        stringBuilder.append(this.mEyeProtectionControlFlag);
        stringBuilder.append(", mSupportDisplayEngineEyeProtection=");
        stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
        stringBuilder.append(", mUserSetColorTempValue=");
        stringBuilder.append(this.mUserSetColorTempValue);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        this.mSetBlueFilterDirect = false;
        if (this.mEyeProtectionControlFlag) {
            this.mfirstSceneSwitchOn = true;
            if (this.mSupportDisplayEngineEyeProtection) {
                java.lang.StringBuilder stringBuilder2;
                int ret = this.mDisplayEngineManager.setScene(15, 16);
                if (ret != 0) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("setScene DE_SCENE_EYEPROTECTION DE_ACTION_MODE_ON error:");
                    stringBuilder2.append(ret);
                    android.util.Slog.e("EyeProtectionControllerImpl", stringBuilder2.toString());
                }
                ret = this.mDisplayEngineManager.setScene(11, this.mUserSetColorTempValue);
                if (ret != 0) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("setScene DE_SCENE_COLORTEMP mUserSetColorTempValue error: ");
                    stringBuilder2.append(ret);
                    android.util.Slog.e("EyeProtectionControllerImpl", stringBuilder2.toString());
                }
                sendEyeProtectEnableToMonitor(true);
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateGlobalSceneState:  mBlueLightFilterReal = ");
                stringBuilder.append(this.mBlueLightFilterReal);
                stringBuilder.append(" ; mUserSetColorTempValue = ");
                stringBuilder.append(this.mUserSetColorTempValue);
                android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
                updateBlueLightLevel(this.mBlueLightFilterReal + this.mUserSetColorTempValue);
                registerLightSensor();
            }
            if (this.mBootCompleted) {
                startStateEvent();
            }
        } else {
            this.mfirstSceneSwitchOn = false;
            if (this.mSupportDisplayEngineEyeProtection) {
                int ret2 = this.mDisplayEngineManager.setScene(15, 17);
                if (this.mSupportDisplayEngine3DColorTemperature && this.mSetForce3DColorTemp) {
                    float red = 1.0f;
                    float green = 1.0f;
                    float blue = 1.0f;
                    try {
                        java.lang.String ctNewRGB = android.provider.Settings.System.getStringForUser(this.mContext.getContentResolver(), "color_temperature_rgb", -2);
                        if (ctNewRGB != null) {
                            java.util.List<java.lang.String> rgbarryList = new java.util.ArrayList(java.util.Arrays.asList(ctNewRGB.split(",")));
                            red = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(0)).floatValue();
                            green = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(1)).floatValue();
                            blue = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(2)).floatValue();
                        } else {
                            android.util.Slog.e("EyeProtectionControllerImpl", "ColorTemperature read from setting failed, and set default values");
                        }
                        updateRgbGamma(red, green, blue);
                    } catch (java.lang.UnsatisfiedLinkError e) {
                        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("ColorTemperature read from setting exception:");
                        stringBuilder3.append(1.0f);
                        stringBuilder3.append(", ");
                        stringBuilder3.append(1.0f);
                        stringBuilder3.append(", ");
                        stringBuilder3.append(1.0f);
                        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder3.toString());
                        updateRgbGamma(1.0f, 1.0f, 1.0f);
                    }
                }
                if (ret2 != 0) {
                    java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                    stringBuilder4.append("setScene DE_SCENE_EYEPROTECTION  DE_ACTION_MODE_OFF error:");
                    stringBuilder4.append(ret2);
                    android.util.Slog.e("EyeProtectionControllerImpl", stringBuilder4.toString());
                }
                this.mSetForce3DColorTemp = false;
                sendEyeProtectEnableToMonitor(false);
            } else {
                updateBlueLightLevel(0);
                this.mAmbientLux = -1.0f;
                updateColorTemperature();
                unregisterLightSensor();
            }
            stopStateEvent();
        }
        updateBrightness();
    }

    private void sendEyeProtectEnableToMonitor(boolean isEnable) {
        if (this.mDisplayEffectMonitor != null) {
            android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
            params.put("paramType", "eyeProtect");
            params.put("isEnable", java.lang.Boolean.valueOf(isEnable));
            this.mDisplayEffectMonitor.sendMonitorParam(params);
        }
    }

    private void updateBlueLightLevel(int level) {
        if (com.android.server.display.Utils.isFunctionExist(1)) {
            this.mBluelightAnimationTarget = level;
            this.mBluelightAnimationTimes = 1;
            this.mBluelightBeforeAnimation = this.mCurrentFilterValue;
            this.mHandler.sendEmptyMessageDelayed(1, 0);
        }
    }

    public void onScreenStateChanged(boolean powerStatus) {
        if (powerStatus && this.mEyeProtectionControlFlag) {
            registerLightSensor();
        } else if (this.mEyeProtectionControlFlag) {
            this.mHandler.removeMessages(0);
            unregisterLightSensor();
        }
    }

    private void setDefaultConfigValue() {
        int i = 0;
        this.mSupportAjustWithCt = false;
        this.mSupportSceneSwitch = false;
        this.mBlueLightFilterReal = 30;
        this.mColorTemperatureSunny = 191;
        this.mColorTemperatureCloudy = 127;
        this.mColorTemperatureInDoor = 64;
        this.mColorTemperatureNight = 0;
        if (this.mLuxLevel == null) {
            this.mLuxLevel = new java.util.ArrayList();
        } else {
            this.mLuxLevel.clear();
        }
        while (i < LuxDefaultLevel.length) {
            this.mLuxLevel.add(new java.lang.Float(LuxDefaultLevel[i]));
            i++;
        }
    }

    /* JADX WARNING: Missing block: B:32:0x00da, code:
            if (r1 == null) goto L_0x00e8;
     */
    private boolean getConfig() throws java.io.IOException {
        /*
        r13 = this;
        r0 = "ro.build.version.emui";
        r1 = 0;
        r0 = android.os.SystemProperties.get(r0, r1);
        r2 = 0;
        r3 = "EyeProtectionControllerImpl";
        r4 = "HwEyeProtectionControllerImpl getConfig";
        android.util.Slog.i(r3, r4);
        r3 = android.text.TextUtils.isEmpty(r0);
        r4 = 0;
        if (r3 == 0) goto L_0x001e;
    L_0x0016:
        r1 = "EyeProtectionControllerImpl";
        r3 = "get ro.build.version.emui failed!";
        android.util.Slog.w(r1, r3);
        return r4;
    L_0x001e:
        r3 = "EmotionUI_";
        r3 = r0.split(r3);
        r5 = r3.length;
        r6 = 2;
        if (r5 >= r6) goto L_0x0040;
    L_0x0028:
        r1 = "EyeProtectionControllerImpl";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "split failed! version = ";
        r5.append(r6);
        r5.append(r0);
        r5 = r5.toString();
        android.util.Slog.w(r1, r5);
        return r4;
    L_0x0040:
        r5 = 1;
        r2 = r3[r5];
        r7 = android.text.TextUtils.isEmpty(r2);
        if (r7 == 0) goto L_0x0051;
    L_0x0049:
        r1 = "EyeProtectionControllerImpl";
        r5 = "get emuiVersion failed!";
        android.util.Slog.w(r1, r5);
        return r4;
    L_0x0051:
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "EyeProtectionConfig_";
        r7.append(r8);
        r8 = r13.mLcdPanelName;
        r7.append(r8);
        r8 = ".xml";
        r7.append(r8);
        r7 = r7.toString();
        r8 = "/xml/lcd/%s/%s";
        r9 = new java.lang.Object[r6];
        r9[r4] = r2;
        r10 = "EyeProtectionConfig.xml";
        r9[r5] = r10;
        r8 = java.lang.String.format(r8, r9);
        r9 = huawei.cust.HwCfgFilePolicy.getCfgFile(r8, r4);
        if (r9 != 0) goto L_0x00b9;
    L_0x007d:
        r10 = "/xml/lcd/%s";
        r11 = new java.lang.Object[r5];
        r12 = "EyeProtectionConfig.xml";
        r11[r4] = r12;
        r8 = java.lang.String.format(r10, r11);
        r9 = huawei.cust.HwCfgFilePolicy.getCfgFile(r8, r4);
        if (r9 != 0) goto L_0x00b9;
    L_0x008f:
        r10 = "/xml/lcd/%s/%s";
        r6 = new java.lang.Object[r6];
        r6[r4] = r2;
        r6[r5] = r7;
        r8 = java.lang.String.format(r10, r6);
        r9 = huawei.cust.HwCfgFilePolicy.getCfgFile(r8, r4);
        if (r9 != 0) goto L_0x00b9;
    L_0x00a1:
        r6 = "/xml/lcd/%s";
        r10 = new java.lang.Object[r5];
        r10[r4] = r7;
        r8 = java.lang.String.format(r6, r10);
        r9 = huawei.cust.HwCfgFilePolicy.getCfgFile(r8, r4);
        if (r9 != 0) goto L_0x00b9;
    L_0x00b1:
        r1 = "EyeProtectionControllerImpl";
        r5 = "get xmlFile failed!";
        android.util.Slog.w(r1, r5);
        return r4;
        r6 = new java.io.FileInputStream;	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r6.<init>(r9);	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r1 = r6;
        r6 = r9.getAbsolutePath();	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r13.mFilterConfigFilePath = r6;	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r13.getConfigFromXML(r1);	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r1.close();	 Catch:{ FileNotFoundException -> 0x00e4, IOException -> 0x00e0, Exception -> 0x00d9, all -> 0x00d2 }
        r1.close();
        return r5;
    L_0x00d2:
        r4 = move-exception;
        if (r1 == 0) goto L_0x00d8;
    L_0x00d5:
        r1.close();
    L_0x00d8:
        throw r4;
    L_0x00d9:
        r5 = move-exception;
        if (r1 == 0) goto L_0x00e8;
    L_0x00dc:
        r1.close();
        goto L_0x00e8;
    L_0x00e0:
        r5 = move-exception;
        if (r1 == 0) goto L_0x00e8;
    L_0x00e3:
        goto L_0x00dc;
    L_0x00e4:
        r5 = move-exception;
        if (r1 == 0) goto L_0x00e8;
    L_0x00e7:
        goto L_0x00dc;
    L_0x00e8:
        return r4;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwEyeProtectionControllerImpl.getConfig():boolean");
    }

    /* JADX WARNING: Removed duplicated region for block: B:70:0x01c1 A:{Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }} */
    private boolean getConfigFromXML(java.io.InputStream r13) {
        /*
        r12 = this;
        r0 = 0;
        r1 = 0;
        r2 = 0;
        r3 = 0;
        r4 = 0;
        r5 = android.util.Xml.newPullParser();
        r6 = 0;
        r7 = "UTF-8";
        r5.setInput(r13, r7);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r7 = r5.getEventType();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
    L_0x0013:
        r8 = 1;
        if (r7 == r8) goto L_0x01bf;
    L_0x0016:
        switch(r7) {
            case 2: goto L_0x0046;
            case 3: goto L_0x001b;
            default: goto L_0x0019;
        };	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
    L_0x0019:
        goto L_0x01b5;
    L_0x001b:
        r9 = r5.getName();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r4 = r9;
        r9 = "EyeProtectionConfig";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x002e;
    L_0x0028:
        if (r0 == 0) goto L_0x002e;
    L_0x002a:
        r3 = 1;
        r0 = 0;
        goto L_0x01b5;
    L_0x002e:
        r9 = "LuxLevel";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x01b5;
    L_0x0036:
        r1 = 0;
        r9 = r12.mLuxLevel;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x003e;
    L_0x003b:
        r2 = 1;
        goto L_0x01b5;
    L_0x003e:
        r8 = "EyeProtectionControllerImpl";
        r9 = "no luxlevel  loaded!";
        android.util.Slog.e(r8, r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        return r6;
    L_0x0046:
        r9 = r5.getName();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r4 = r9;
        r9 = "EyeProtectionConfig";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x0056;
    L_0x0053:
        r0 = 1;
        goto L_0x01b5;
    L_0x0056:
        r9 = "BlueLightFilterReal";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x006a;
    L_0x005e:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mBlueLightFilterReal = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x006a:
        r9 = "ColorTemperatureSunny";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x007e;
    L_0x0072:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mColorTemperatureSunny = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x007e:
        r9 = "ColorTemperatureCloudy";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x0092;
    L_0x0086:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mColorTemperatureCloudy = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x0092:
        r9 = "ColorTemperatureInDoor";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x00a6;
    L_0x009a:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mColorTemperatureInDoor = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x00a6:
        r9 = "ColorTemperatureNight";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x00ba;
    L_0x00ae:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mColorTemperatureNight = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x00ba:
        r9 = "LessWarm";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x00ce;
    L_0x00c2:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mLessWarm = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x00ce:
        r9 = "MoreWarm";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x00e2;
    L_0x00d6:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mMoreWarm = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x00e2:
        r9 = "SupportSceneSwitch";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x010e;
    L_0x00ea:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Boolean.parseBoolean(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mSupportSceneSwitch = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = "EyeProtectionControllerImpl";
        r10 = new java.lang.StringBuilder;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.<init>();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = "SupportSceneSwitch is:";
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = r12.mSupportSceneSwitch;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10 = r10.toString();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        android.util.Slog.d(r9, r10);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x010e:
        r9 = "MinLightCtData";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x013a;
    L_0x0116:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        mMinLightCtData = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = "EyeProtectionControllerImpl";
        r10 = new java.lang.StringBuilder;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.<init>();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = "mMinLightCtData is:";
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = mMinLightCtData;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10 = r10.toString();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        android.util.Slog.d(r9, r10);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x013a:
        r9 = "MaxLightCtData";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x0165;
    L_0x0142:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Integer.parseInt(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        mMaxLightCtData = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = "EyeProtectionControllerImpl";
        r10 = new java.lang.StringBuilder;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.<init>();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = "mMaxLightCtData is:";
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = mMaxLightCtData;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.append(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10 = r10.toString();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        android.util.Slog.d(r9, r10);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x0165:
        r9 = "LuxLevel";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x016f;
    L_0x016d:
        r1 = 1;
        goto L_0x01b5;
    L_0x016f:
        r9 = "FilterEnable";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x018e;
    L_0x0177:
        r9 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = java.lang.Boolean.parseBoolean(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mFilterEnable = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = r12.mFilterEnable;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x01b5;
    L_0x0185:
        r9 = r12.mFilterConfigFilePath;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9 = com.android.server.display.HwEyeProtectionXmlLoader.getData(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mFilterParameters = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        goto L_0x01b5;
    L_0x018e:
        r9 = "Value";
        r9 = r4.equals(r9);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 == 0) goto L_0x01b5;
    L_0x0196:
        if (r1 == 0) goto L_0x01b5;
    L_0x0198:
        r9 = r12.mLuxLevel;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        if (r9 != 0) goto L_0x01a3;
    L_0x019c:
        r9 = new java.util.ArrayList;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9.<init>();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r12.mLuxLevel = r9;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
    L_0x01a3:
        r9 = r12.mLuxLevel;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10 = new java.lang.Float;	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = r5.nextText();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r11 = java.lang.Float.parseFloat(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r10.<init>(r11);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r9.add(r10);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
    L_0x01b5:
        if (r3 == 0) goto L_0x01b8;
    L_0x01b7:
        goto L_0x01bf;
    L_0x01b8:
        r8 = r5.next();	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        r7 = r8;
        goto L_0x0013;
    L_0x01bf:
        if (r3 == 0) goto L_0x01d0;
    L_0x01c1:
        r9 = "EyeProtectionControllerImpl";
        r10 = "getConfigFromeXML success!";
        android.util.Slog.i(r9, r10);	 Catch:{ XmlPullParserException -> 0x01cf, IOException -> 0x01cd, NumberFormatException -> 0x01cb, Exception -> 0x01c9 }
        return r8;
    L_0x01c9:
        r7 = move-exception;
        goto L_0x01d1;
    L_0x01cb:
        r7 = move-exception;
        goto L_0x01d0;
    L_0x01cd:
        r7 = move-exception;
        goto L_0x01d0;
    L_0x01cf:
        r7 = move-exception;
    L_0x01d1:
        r7 = "EyeProtectionControllerImpl";
        r8 = "getConfigFromeXML false!";
        android.util.Slog.e(r7, r8);
        return r6;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwEyeProtectionControllerImpl.getConfigFromXML(java.io.InputStream):boolean");
    }

    private java.lang.String getLcdPanelName() {
        java.lang.String panelName = null;
        try {
            panelName = android.os.FileUtils.readTextFile(new java.io.File("/sys/class/graphics/fb0/lcd_model"), 0, null).trim();
            return panelName.replace(' ', '_');
        } catch (java.io.IOException e) {
            android.util.Slog.e("EyeProtectionControllerImpl", "Error reading lcd panel name", e);
            return panelName;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x00be  */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x00bc  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x00eb A:{Catch:{ Exception -> 0x00f6 }} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x016d A:{Catch:{ UnsatisfiedLinkError -> 0x0175 }} */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x0169 A:{Catch:{ UnsatisfiedLinkError -> 0x0175 }} */
    public HwEyeProtectionControllerImpl(android.content.Context r7, com.android.server.display.HwNormalizedAutomaticBrightnessController r8) {
        /*
        r6 = this;
        r6.<init>(r7, r8);
        r0 = 0;
        r6.mLcdPanelName = r0;
        r1 = 1;
        r6.mKidsEyesProtectionMode = r1;
        r2 = 0;
        r6.mEyeProtectionControlFlag = r2;
        r6.mEyeProtectionTempMode = r2;
        r6.mfirstSceneSwitchOn = r1;
        r6.mEyeProtectionScreenOff = r2;
        r6.mEyeProtectionScreenOffMode = r2;
        r3 = 0;
        r6.mEyeComfortValidValue = r3;
        r6.mLuxLevel = r0;
        r6.mFilterConfigFilePath = r0;
        r6.mSetForce3DColorTemp = r1;
        r6.mSupportAjustWithCt = r2;
        r6.mSupportSceneSwitch = r2;
        r6.mSetBlueFilterDirect = r2;
        r6.mSuperPowerMode = r2;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$1;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mProtectionModeObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$2;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mSetColorTempValueObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$3;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mScheduleModeObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$4;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mScheduleBeginTimeObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$5;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mScheduleEndTimeObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$6;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mKidsModeObserver = r0;
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$7;
        r3 = new android.os.Handler;
        r3.<init>();
        r0.<init>(r3);
        r6.mKidsEyesProtectionModeObserver = r0;
        r0 = -1082130432; // 0xffffffffbf800000 float:-1.0 double:NaN;
        r6.mAmbientLux = r0;
        r6.mAmbientCct = r0;
        r3 = new com.android.server.display.HwEyeProtectionControllerImpl$8;
        r3.<init>();
        r6.mLightSensorListener = r3;
        r6.mColorTemperatureTimes = r1;
        r6.mContext = r7;
        r3 = r6.getLcdPanelName();
        r6.mLcdPanelName = r3;
        r3 = new com.huawei.displayengine.DisplayEngineManager;
        r3.<init>();
        r6.mDisplayEngineManager = r3;
        r3 = r6.mDisplayEngineManager;
        r4 = 17;
        r3 = r3.getSupported(r4);
        if (r3 == r1) goto L_0x00af;
    L_0x00a2:
        r3 = r6.mDisplayEngineManager;
        r4 = 21;
        r3 = r3.getSupported(r4);
        if (r3 != r1) goto L_0x00ad;
    L_0x00ac:
        goto L_0x00af;
    L_0x00ad:
        r3 = r2;
        goto L_0x00b0;
    L_0x00af:
        r3 = r1;
    L_0x00b0:
        r6.mSupportDisplayEngineEyeProtection = r3;
        r3 = r6.mDisplayEngineManager;
        r4 = 18;
        r3 = r3.getSupported(r4);
        if (r3 != r1) goto L_0x00be;
    L_0x00bc:
        r3 = r1;
        goto L_0x00bf;
    L_0x00be:
        r3 = r2;
    L_0x00bf:
        r6.mSupportDisplayEngine3DColorTemperature = r3;
        r3 = "EyeProtectionControllerImpl";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "mSupportDisplayEngineEyeProtection=";
        r4.append(r5);
        r5 = r6.mSupportDisplayEngineEyeProtection;
        r4.append(r5);
        r5 = ", mSupportDisplayEngine3DColorTemperature=";
        r4.append(r5);
        r5 = r6.mSupportDisplayEngine3DColorTemperature;
        r4.append(r5);
        r4 = r4.toString();
        android.util.Slog.i(r3, r4);
        r6.mFilterEnable = r2;
        r3 = r6.getConfig();	 Catch:{ Exception -> 0x00f6 }
        if (r3 != 0) goto L_0x00f5;
    L_0x00eb:
        r3 = "EyeProtectionControllerImpl";
        r4 = "getConfig failed!";
        android.util.Slog.e(r3, r4);	 Catch:{ Exception -> 0x00f6 }
        r6.setDefaultConfigValue();	 Catch:{ Exception -> 0x00f6 }
    L_0x00f5:
        goto L_0x00f7;
    L_0x00f6:
        r3 = move-exception;
    L_0x00f7:
        r3 = r6.mFilterEnable;
        if (r3 == 0) goto L_0x0108;
    L_0x00fb:
        r3 = r6.mFilterParameters;
        if (r3 == 0) goto L_0x0108;
    L_0x00ff:
        r3 = new com.android.server.display.HwEyeProtectionAmbientLuxFilterAlgo;
        r4 = r6.mFilterParameters;
        r3.<init>(r4);
        r6.mAmbientLuxFilterAlgo = r3;
    L_0x0108:
        r6.mAmbientLux = r0;
        r6.mCurrentFilterValue = r2;
        r0 = r6.mColorTemperatureCloudy;
        r6.mCurrentColorTemperature = r0;
        r0 = r6.mColorTemperatureCloudy;
        r6.mColorTemperatureTarget = r0;
        r0 = "EyeProtectionControllerImpl";
        r2 = "HwEyeProtectionControllerImpl";
        android.util.Slog.i(r0, r2);
        r0 = com.android.server.display.Utils.isFunctionExist(r1);
        if (r0 != 0) goto L_0x012f;
    L_0x0121:
        r0 = 4;
        r0 = com.android.server.display.Utils.isFunctionExist(r0);
        if (r0 != 0) goto L_0x012f;
    L_0x0128:
        r0 = 2;
        r0 = com.android.server.display.Utils.isFunctionExist(r0);
        if (r0 == 0) goto L_0x0165;
    L_0x012f:
        r0 = new android.os.HandlerThread;
        r1 = "EyeProtectionControllerImpl";
        r0.<init>(r1);
        r6.mHandlerThread = r0;
        r0 = r6.mHandlerThread;
        r0.start();
        r0 = new com.android.server.display.HwEyeProtectionControllerImpl$SmartDisplayHandler;
        r1 = r6.mHandlerThread;
        r1 = r1.getLooper();
        r0.<init>(r1);
        r6.mHandler = r0;
        r0 = new com.android.server.display.HwEyeProtectionDividedTimeControl;
        r0.<init>(r7, r6);
        r6.mEyeProtectionDividedTimeControl = r0;
        r0 = r6.mHandler;
        r1 = 11;
        r0.sendEmptyMessage(r1);
        r0 = r6.mHandler;
        r1 = 10;
        r0.sendEmptyMessage(r1);
        r0 = r6.mHandler;
        r1 = 3;
        r0.sendEmptyMessage(r1);
    L_0x0165:
        r0 = mLoadLibraryFailed;	 Catch:{ UnsatisfiedLinkError -> 0x0175 }
        if (r0 != 0) goto L_0x016d;
    L_0x0169:
        init_native();	 Catch:{ UnsatisfiedLinkError -> 0x0175 }
        goto L_0x0174;
    L_0x016d:
        r0 = "EyeProtectionControllerImpl";
        r1 = "init_native not valid!";
        android.util.Slog.w(r0, r1);	 Catch:{ UnsatisfiedLinkError -> 0x0175 }
    L_0x0174:
        goto L_0x017d;
    L_0x0175:
        r0 = move-exception;
        r1 = "EyeProtectionControllerImpl";
        r2 = "init_native not found!";
        android.util.Slog.w(r1, r2);
    L_0x017d:
        r0 = com.android.server.display.DisplayEffectMonitor.getInstance(r7);
        r6.mDisplayEffectMonitor = r0;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwEyeProtectionControllerImpl.<init>(android.content.Context, com.android.server.display.HwNormalizedAutomaticBrightnessController):void");
    }

    private void initDataState() {
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("eyes_protection_mode"), true, this.mProtectionModeObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("user_set_warm"), true, this.mSetColorTempValueObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("eye_comfort_schedule_switch"), true, this.mScheduleModeObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("eye_comfort_starttime"), true, this.mScheduleBeginTimeObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("eye_comfort_endtime"), true, this.mScheduleEndTimeObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Global.getUriFor("hwkidsmode_running"), true, this.mKidsModeObserver);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Global.getUriFor("blue_eye_protection"), true, this.mKidsEyesProtectionModeObserver);
        this.mKidsMode = android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "hwkidsmode_running", 0);
        this.mKidsEyesProtectionMode = android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "blue_eye_protection", 1);
        this.mUserSetColorTempValue = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "user_set_warm", 0, -2);
        this.mEyeComfortValidValue = android.provider.Settings.System.getLongForUser(this.mContext.getContentResolver(), "eye_comfort_valid", 0, -2);
        this.mEyesProtectionMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
        this.mEyeScheduleSwitchMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_schedule_switch", 0, -2);
        this.mEyeScheduleBeginTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_starttime", -1, -2);
        this.mEyeScheduleEndTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_endtime", -1, -2);
        this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleBeginTime, 0);
        this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleEndTime, 1);
        setDefaultColorTemptureValue();
        this.mEyeProtectionDividedTimeControl.init();
        if (this.mEyeScheduleSwitchMode == 1) {
            this.mEyeProtectionDividedTimeControl.updateDiviedTimeFlag();
        }
    }

    private void blueLightAnimationTo(int target, int delayed) {
        this.mHandler.removeMessages(1);
        if (this.mSupportDisplayEngineEyeProtection) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return;
        }
        int value;
        int value2 = target;
        if (this.mBluelightAnimationTarget > this.mCurrentFilterValue) {
            value = (this.mBluelightAnimationTarget * this.mBluelightAnimationTimes) / 20;
            if (value > this.mBluelightAnimationTarget) {
                value = this.mBluelightAnimationTarget;
            }
        } else if (this.mBluelightAnimationTarget < this.mCurrentFilterValue) {
            value = (this.mBluelightBeforeAnimation * (20 - this.mBluelightAnimationTimes)) / 20;
            if (value < this.mBluelightAnimationTarget) {
                value = this.mBluelightAnimationTarget;
            }
        } else {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("no need to set blueLightAnimationTo target is");
            stringBuilder2.append(target);
            android.util.Slog.w("EyeProtectionControllerImpl", stringBuilder2.toString());
            return;
        }
        filterBlueLight(value);
        this.mBluelightAnimationTimes++;
        this.mCurrentFilterValue = value;
        if (this.mBluelightAnimationTimes <= 20 && this.mBluelightAnimationTarget != this.mCurrentFilterValue) {
            this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(1, this.mBluelightAnimationTarget, this.mCurrentFilterValue), (long) delayed);
        }
    }

    private void colorTemperatureAnimationTo(int target, int delayed) {
        this.mHandler.removeMessages(0);
        if (this.mSupportDisplayEngineEyeProtection) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportDisplayEngineEyeProtection=");
            stringBuilder.append(this.mSupportDisplayEngineEyeProtection);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            return;
        }
        int value = target;
        if (this.mColorTemperatureTarget > this.mColorBeforeAnimation) {
            value = this.mColorBeforeAnimation + (((this.mColorTemperatureTarget - this.mColorBeforeAnimation) * this.mColorTemperatureTimes) / 20);
            if (value > this.mColorTemperatureTarget) {
                value = this.mColorTemperatureTarget;
            }
        } else if (this.mColorTemperatureTarget < this.mColorBeforeAnimation) {
            value = this.mColorBeforeAnimation - (((this.mColorBeforeAnimation - this.mColorTemperatureTarget) * this.mColorTemperatureTimes) / 20);
            if (value < this.mColorTemperatureTarget) {
                value = this.mColorTemperatureTarget;
            }
        }
        setColorTemperatureNew(value);
        this.mColorTemperatureTimes++;
        this.mCurrentColorTemperature = value;
        if (this.mColorTemperatureTimes <= 20 && this.mColorTemperatureTarget != this.mCurrentColorTemperature) {
            this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(0, this.mColorTemperatureTarget, this.mCurrentColorTemperature), (long) delayed);
        } else if (this.mAmbientLux < 0.0f) {
            setColorTemperatureAccordingToSetting();
        }
    }

    private void handleUserSwitch(int userId) {
        this.mCurrentUserId = userId;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onReceive ACTION_USER_SWITCHED  mCurrentUserId= ");
        stringBuilder.append(this.mCurrentUserId);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        setDefaultColorTemptureValue();
        this.mCurrentColorTemperature = this.mColorTemperatureCloudy;
        this.mKidsMode = android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "hwkidsmode_running", 0);
        this.mKidsEyesProtectionMode = android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "blue_eye_protection", 1);
        this.mEyesProtectionMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, this.mCurrentUserId);
        this.mEyeScheduleSwitchMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_schedule_switch", 0, this.mCurrentUserId);
        this.mEyeScheduleBeginTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_starttime", -1, this.mCurrentUserId);
        this.mEyeScheduleEndTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_endtime", -1, this.mCurrentUserId);
        this.mUserSetColorTempValue = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "user_set_warm", 0, -2);
        this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleBeginTime, 0);
        this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleEndTime, 1);
        if (this.mEyeScheduleSwitchMode == 1) {
            this.mEyeProtectionDividedTimeControl.updateDiviedTimeFlag();
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onReceive  mEyesProtectionMode =");
        stringBuilder.append(this.mEyesProtectionMode);
        stringBuilder.append(",mEyeScheduleSwitchMode=");
        stringBuilder.append(this.mEyeScheduleSwitchMode);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        if ((this.mEyesProtectionMode == 0 && this.mEyeScheduleSwitchMode == 0) || this.mEyesProtectionMode == 1) {
            this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
            this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(0);
            this.mEyeProtectionDividedTimeControl.cancelTimeControlAlarm(1);
            updateGlobalSceneState();
            return;
        }
        if (this.mEyeScheduleSwitchMode == 1) {
            setEyeModeOnSwitchMode();
        }
    }

    private void handleSuperPower(int status) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onReceive ACTION_SUPER_POWERMODE mEyesProtectionMode =");
        stringBuilder.append(this.mEyesProtectionMode);
        stringBuilder.append(",status =");
        stringBuilder.append(status);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        this.mSuperPowerMode = status == 1;
        if (this.mSuperPowerMode) {
            if (this.mEyesProtectionMode == 1 || this.mEyeScheduleSwitchMode == 1) {
                android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 2, -2);
                this.mEyeProtectionTempMode = this.mEyesProtectionMode;
            }
        } else if (this.mEyesProtectionMode == 2) {
            if (this.mEyeProtectionTempMode == 1) {
                android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 1, -2);
            } else if (this.mEyeScheduleSwitchMode == 1) {
                setEyeModeOnSwitchMode();
            }
            this.mEyeProtectionTempMode = 0;
        }
    }

    private void handleTimeAndTimezoneChanged() {
        this.mEyeScheduleSwitchMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_schedule_switch", 0, this.mCurrentUserId);
        if (this.mEyeScheduleSwitchMode != 0 && this.mEyesProtectionMode != 1) {
            setEyeModeOnSwitchMode();
        }
    }

    private void setEyeModeOnSwitchMode() {
        boolean isScreenOn = ((android.os.PowerManager) this.mContext.getSystemService("power")).isScreenOn();
        this.mEyeProtectionDividedTimeControl.updateDiviedTimeFlag();
        if (!this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
            if (isScreenOn) {
                if (this.mEyesProtectionMode == 0) {
                    updateGlobalSceneState();
                } else {
                    android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
                }
            }
            resetTimeControlAlarm();
        } else if (eyeComfortTimeIsValid()) {
            this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
            if (isScreenOn) {
                if (this.mEyesProtectionMode == 0) {
                    updateGlobalSceneState();
                } else {
                    android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
                }
            }
            this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 0);
            this.mEyeProtectionDividedTimeControl.setTimeControlAlarm(86400000, 1);
        } else {
            if (isScreenOn) {
                if (this.mEyesProtectionMode == 3) {
                    updateGlobalSceneState();
                } else {
                    android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 3, -2);
                }
            }
            resetTimeControlAlarm();
        }
    }

    protected void updateProtectionControlFlag() {
        boolean flag = false;
        java.lang.StringBuilder stringBuilder;
        if (this.mKidsMode == 1) {
            if (this.mKidsEyesProtectionMode == 1) {
                flag = true;
            } else {
                flag = false;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateProtectionControlFlag mKidsMode =");
            stringBuilder.append(this.mKidsMode);
            stringBuilder.append(",mKidsEyesProtectionMode=");
            stringBuilder.append(this.mKidsEyesProtectionMode);
            android.util.Slog.d("EyeProtectionControllerImpl", stringBuilder.toString());
        } else {
            if (this.mEyesProtectionMode == 1) {
                flag = true;
            }
            if (this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag()) {
                flag = true;
            }
            if (this.mSuperPowerMode) {
                flag = false;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateProtectionControlFlag mEyesProtectionMode =");
            stringBuilder.append(this.mEyesProtectionMode);
            stringBuilder.append(",inDividedTimeFlag=");
            stringBuilder.append(this.mEyeProtectionDividedTimeControl.getInDividedTimeFlag());
            android.util.Slog.d("EyeProtectionControllerImpl", stringBuilder.toString());
        }
        this.mEyeProtectionControlFlag = flag;
        this.mAutomaticBrightnessController.setSplineEyeProtectionControlFlag(flag);
    }

    protected void resetTimeControlAlarm() {
        android.util.Slog.d("EyeProtectionControllerImpl", "resetTimeControlAlarm");
        this.mEyeScheduleBeginTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_starttime", -1, -2);
        this.mEyeScheduleEndTime = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eye_comfort_endtime", -1, -2);
        if (this.mEyeScheduleBeginTime >= 0 && this.mEyeScheduleEndTime >= 0 && this.mEyesProtectionMode != 1) {
            if (this.mEyeScheduleSwitchMode != 0) {
                this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleBeginTime, 0);
                this.mEyeProtectionDividedTimeControl.setTime(this.mEyeScheduleEndTime, 1);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("resetTimeControlAlarm mEyeScheduleBeginTime =");
                stringBuilder.append(this.mEyeScheduleBeginTime);
                stringBuilder.append(",mEyeScheduleEndTime=");
                stringBuilder.append(this.mEyeScheduleEndTime);
                android.util.Slog.d("EyeProtectionControllerImpl", stringBuilder.toString());
                this.mEyeProtectionDividedTimeControl.reSetTimeControlAlarm();
            }
        }
    }

    private void setBootEyeProtectionControlStatus() {
        android.util.Slog.i("EyeProtectionControllerImpl", "setBootEyeProtectionControlStatus ");
        if (this.mKidsMode == 1) {
            updateGlobalSceneState();
        } else if (this.mEyesProtectionMode == 1) {
            updateGlobalSceneState();
        } else {
            if (this.mEyeScheduleSwitchMode == 1) {
                setEyeModeOnSwitchMode();
            } else if (this.mEyesProtectionMode == 2) {
                android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 1, -2);
            }
        }
    }

    public void setEyeScheduleSwitchToUserMode(int type) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setEyeScheduleSwitchToUserMode type is ");
        stringBuilder.append(type);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        if (!this.mSuperPowerMode) {
            android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", type, -2);
        }
    }

    private void setDefaultColorTemptureValue() {
        if (this.mLessWarm != 0 || this.mMoreWarm != 0) {
            android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eye_comfort_lesswarm", this.mLessWarm, -2);
            android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eye_comfort_morewarm", this.mMoreWarm, -2);
        }
    }

    public void setEyeProtectionScreenTurnOffMode(int mode) {
        this.mEyeProtectionScreenOff = true;
        this.mEyeProtectionScreenOffMode = mode;
    }

    private void resetEyeProtectionScreenTurnOffMode() {
        this.mEyeProtectionScreenOff = false;
        this.mEyeProtectionScreenOffMode = 0;
    }

    private void setScreenOffEyeProtection() {
        if (this.mEyeProtectionScreenOff && !this.mSuperPowerMode) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setScreenOffEyeProtection mEyeProtectionScreenOffMode =");
            stringBuilder.append(this.mEyeProtectionScreenOffMode);
            android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
            if (this.mEyeProtectionScreenOffMode == 2) {
                this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(true);
                android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 3, -2);
            } else if (this.mEyeProtectionScreenOffMode == 1) {
                this.mEyeProtectionDividedTimeControl.setInDividedTimeFlag(false);
                android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
            }
        }
    }

    private boolean eyeComfortTimeIsValid() {
        this.mEyeComfortValidValue = android.provider.Settings.System.getLongForUser(this.mContext.getContentResolver(), "eye_comfort_valid", 0, -2);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("eyeComfortTimeIsValid mEyeComfortValidValue =");
        stringBuilder.append(this.mEyeComfortValidValue);
        android.util.Slog.i("EyeProtectionControllerImpl", stringBuilder.toString());
        return this.mEyeProtectionDividedTimeControl.testTimeIsValid(this.mEyeComfortValidValue);
    }

    private int setUserColorTemperature() {
        int i = -1;
        if (this.mSupportDisplayEngineEyeProtection) {
            int ret = this.mDisplayEngineManager.setScene(11, this.mUserSetColorTempValue);
            if (ret != 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setScene DE_SCENE_COLORTEMP: ");
                stringBuilder.append(this.mUserSetColorTempValue);
                stringBuilder.append(", ret=");
                stringBuilder.append(ret);
                android.util.Slog.e("EyeProtectionControllerImpl", stringBuilder.toString());
            }
            if (ret == 0) {
                i = 1;
            }
            return i;
        }
        try {
            if (mLoadLibraryFailed) {
                android.util.Slog.i("EyeProtectionControllerImpl", "setUserColorTemperature not valid!");
                return 0;
            }
            this.mCurrentFilterValue = this.mBlueLightFilterReal + this.mUserSetColorTempValue;
            if (this.mSupportAjustWithCt) {
                return nativeFilterBlueLight3DNew(this.mCurrentFilterValue);
            }
            return nativeFilterBlueLight(this.mCurrentFilterValue);
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.w("EyeProtectionControllerImpl", "setUserColorTemperature not found!");
            return -1;
        }
    }
}
