package com.android.server.display;

public class HwLightSensorController {
    private static boolean DEBUG = false;
    private static final int MSG_TIMER = 1;
    private static final java.lang.String TAG = "HwLightSensorController";
    private int SENSOR_OPTION;
    private int mBackSensorValue;
    private final com.android.server.display.HwLightSensorController.LightSensorCallbacks mCallbacks;
    private final android.content.Context mContext;
    private java.util.List<java.lang.Integer> mCtDataList;
    private java.util.List<java.lang.Integer> mDataList;
    private boolean mEnable;
    private long mEnableTime;
    private android.os.Handler mHandler;
    private com.android.server.display.HwDualSensorEventListenerImpl mHwDualSensorEventListenerImpl;
    private int mLastSensorCtValue;
    private int mLastSensorValue;
    private android.hardware.Sensor mLightSensor;
    private int mRateMillis;
    private final android.hardware.SensorEventListener mSensorEventListener;
    private android.hardware.SensorManager mSensorManager;
    private com.android.server.display.HwLightSensorController.SensorObserver mSensorObserver;
    private boolean mWarmUpFlg;

    public interface LightSensorCallbacks {
        void processSensorData(long j, int i, int i2);
    }

    private class SensorObserver implements java.util.Observer {
        public void update(java.util.Observable o, java.lang.Object arg) {
            long[] data = (long[]) arg;
            int lux = (int) data[0];
            int cct = (int) data[1];
            long timeStamp = data[2];
            if (com.android.server.display.HwLightSensorController.this.SENSOR_OPTION == 2) {
                com.android.server.display.HwLightSensorController.this.mBackSensorValue = (int) data[5];
            } else if (com.android.server.display.HwLightSensorController.this.SENSOR_OPTION == 1) {
                com.android.server.display.HwLightSensorController.this.mBackSensorValue = lux;
            }
            if (com.android.server.display.HwLightSensorController.this.mEnable && lux >= 0 && cct >= 0 && timeStamp >= 0) {
                com.android.server.display.HwLightSensorController.this.mCallbacks.processSensorData(timeStamp, lux, cct);
            }
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwLightSensorController", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwLightSensorController(android.content.Context context, com.android.server.display.HwLightSensorController.LightSensorCallbacks callbacks, android.hardware.SensorManager sensorManager, int sensorRateMillis) {
        this(context, callbacks, sensorManager, sensorRateMillis, "HwLightSensorController");
    }

    public HwLightSensorController(android.content.Context context, com.android.server.display.HwLightSensorController.LightSensorCallbacks callbacks, android.hardware.SensorManager sensorManager, int sensorRateMillis, java.lang.String TagForDualSensor) {
        this.mLastSensorValue = -1;
        this.mLastSensorCtValue = -1;
        this.mWarmUpFlg = true;
        this.mRateMillis = 300;
        com.android.server.display.HwDualSensorEventListenerImpl hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
        this.SENSOR_OPTION = -1;
        this.mBackSensorValue = -1;
        this.mSensorEventListener = new android.hardware.SensorEventListener() {
            public void onSensorChanged(android.hardware.SensorEvent event) {
                if (com.android.server.display.HwLightSensorController.this.mEnable) {
                    int lux = (int) event.values[0];
                    int cct = (int) event.values[1];
                    long timeStamp = event.timestamp / 1000000;
                    if (!com.android.server.display.HwLightSensorController.this.mWarmUpFlg) {
                        com.android.server.display.HwLightSensorController.this.setSensorData(lux);
                        com.android.server.display.HwLightSensorController.this.setSensorCtData(cct);
                    } else if (timeStamp < com.android.server.display.HwLightSensorController.this.mEnableTime) {
                        if (com.android.server.display.HwLightSensorController.DEBUG) {
                            android.util.Slog.i("HwLightSensorController", "sensor not ready yet");
                        }
                    } else {
                        com.android.server.display.HwLightSensorController.this.setSensorData(lux);
                        com.android.server.display.HwLightSensorController.this.setSensorCtData(cct);
                        com.android.server.display.HwLightSensorController.this.mWarmUpFlg = false;
                        com.android.server.display.HwLightSensorController.this.mHandler.sendEmptyMessage(1);
                    }
                }
            }

            public void onAccuracyChanged(android.hardware.Sensor sensor, int accuracy) {
            }
        };
        this.mHandler = new android.os.Handler() {
            public void handleMessage(android.os.Message msg) {
                if (msg.what != 1) {
                    android.util.Slog.e("HwLightSensorController", "Invalid message");
                    return;
                }
                int lux = com.android.server.display.HwLightSensorController.this.getSensorData();
                int cct = com.android.server.display.HwLightSensorController.this.getSensorCtData();
                if (lux >= 0 && cct >= 0) {
                    try {
                        com.android.server.display.HwLightSensorController.this.mCallbacks.processSensorData(android.os.SystemClock.elapsedRealtime(), lux, cct);
                    } catch (java.lang.Exception e) {
                        e.printStackTrace();
                    }
                }
                if (com.android.server.display.HwLightSensorController.this.mEnable) {
                    sendEmptyMessageDelayed(1, (long) com.android.server.display.HwLightSensorController.this.mRateMillis);
                }
            }
        };
        this.mContext = context;
        this.mCallbacks = callbacks;
        this.mSensorManager = sensorManager;
        this.mRateMillis = sensorRateMillis;
        this.mLightSensor = this.mSensorManager.getDefaultSensor(5);
        this.mDataList = new java.util.ArrayList();
        this.mCtDataList = new java.util.ArrayList();
        this.mHwDualSensorEventListenerImpl = com.android.server.display.HwDualSensorEventListenerImpl.getInstance(this.mSensorManager, this.mContext);
        this.SENSOR_OPTION = this.mHwDualSensorEventListenerImpl.getModuleSensorOption(TagForDualSensor);
        this.mSensorObserver = new com.android.server.display.HwLightSensorController.SensorObserver();
    }

    public void enableSensor() {
        if (!this.mEnable) {
            this.mEnable = true;
            this.mWarmUpFlg = true;
            this.mEnableTime = android.os.SystemClock.elapsedRealtime();
            int i = this.SENSOR_OPTION;
            com.android.server.display.HwDualSensorEventListenerImpl hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
            if (i == -1) {
                this.mSensorManager.registerListener(this.mSensorEventListener, this.mLightSensor, this.mRateMillis * 1000);
                return;
            }
            i = this.SENSOR_OPTION;
            hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
            if (i == 0) {
                this.mHwDualSensorEventListenerImpl.attachFrontSensorData(this.mSensorObserver);
                return;
            }
            i = this.SENSOR_OPTION;
            hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
            if (i == 1) {
                this.mHwDualSensorEventListenerImpl.attachBackSensorData(this.mSensorObserver);
                return;
            }
            int i2 = this.SENSOR_OPTION;
            com.android.server.display.HwDualSensorEventListenerImpl hwDualSensorEventListenerImpl2 = this.mHwDualSensorEventListenerImpl;
            if (i2 == 2) {
                this.mHwDualSensorEventListenerImpl.attachFusedSensorData(this.mSensorObserver);
            }
        }
    }

    public void disableSensor() {
        if (this.mEnable) {
            this.mEnable = false;
            int i = this.SENSOR_OPTION;
            com.android.server.display.HwDualSensorEventListenerImpl hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
            if (i == -1) {
                this.mSensorManager.unregisterListener(this.mSensorEventListener);
                this.mHandler.removeMessages(1);
            } else {
                i = this.SENSOR_OPTION;
                hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
                if (i == 0) {
                    this.mHwDualSensorEventListenerImpl.detachFrontSensorData(this.mSensorObserver);
                } else {
                    i = this.SENSOR_OPTION;
                    hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
                    if (i == 1) {
                        this.mHwDualSensorEventListenerImpl.detachBackSensorData(this.mSensorObserver);
                    } else {
                        i = this.SENSOR_OPTION;
                        hwDualSensorEventListenerImpl = this.mHwDualSensorEventListenerImpl;
                        if (i == 2) {
                            this.mHwDualSensorEventListenerImpl.detachFusedSensorData(this.mSensorObserver);
                        }
                    }
                }
            }
            clearSensorData();
            clearSensorCtData();
        }
    }

    public boolean isBackSensorEnable() {
        if (this.SENSOR_OPTION != 2) {
            return this.SENSOR_OPTION == 1;
        } else {
            return true;
        }
    }

    public int getBackSensorValue() {
        return this.mBackSensorValue;
    }

    private void setSensorData(int lux) {
        synchronized (this.mDataList) {
            this.mDataList.add(java.lang.Integer.valueOf(lux));
        }
    }

    private void setSensorCtData(int cct) {
        synchronized (this.mCtDataList) {
            this.mCtDataList.add(java.lang.Integer.valueOf(cct));
        }
    }

    private int getSensorData() {
        synchronized (this.mDataList) {
            int i;
            if (this.mDataList.isEmpty()) {
                i = this.mLastSensorValue;
                return i;
            }
            int average;
            i = 0;
            int sum = 0;
            for (java.lang.Integer data : this.mDataList) {
                sum += data.intValue();
                i++;
            }
            if (i != 0) {
                average = sum / i;
                if (average >= 0) {
                    this.mLastSensorValue = average;
                }
            }
            this.mDataList.clear();
            average = this.mLastSensorValue;
            return average;
        }
    }

    private int getSensorCtData() {
        synchronized (this.mCtDataList) {
            int i;
            if (this.mCtDataList.isEmpty()) {
                i = this.mLastSensorCtValue;
                return i;
            }
            int average;
            i = 0;
            int sum = 0;
            for (java.lang.Integer data : this.mCtDataList) {
                sum += data.intValue();
                i++;
            }
            if (i != 0) {
                average = sum / i;
                if (average >= 0) {
                    this.mLastSensorCtValue = average;
                }
            }
            this.mCtDataList.clear();
            average = this.mLastSensorCtValue;
            return average;
        }
    }

    private void clearSensorData() {
        synchronized (this.mDataList) {
            this.mDataList.clear();
            this.mLastSensorValue = -1;
        }
    }

    private void clearSensorCtData() {
        synchronized (this.mCtDataList) {
            this.mCtDataList.clear();
            this.mLastSensorCtValue = -1;
        }
    }
}
