package com.android.server.display;

public class HwNormalizedManualBrightnessController extends com.android.server.display.ManualBrightnessController implements com.android.server.display.HwLightSensorController.LightSensorCallbacks, com.android.server.display.HwBrightnessPgSceneDetection.HwBrightnessPgSceneDetectionCallbacks {
    private static final int BACK_SENSOR_REPORT_TIMEOUT = 300;
    private static boolean DEBUG = false;
    private static final int DEFAULT = 0;
    private static final float DEFAULT_POWERSAVING_RATIO = 1.0f;
    private static final int INDOOR = 1;
    private static final int MAXDEFAULTBRIGHTNESS = 255;
    private static final int MINDEFAULTBRIGHTNESS = 4;
    private static final int MSG_SENSOR_TIMEOUT = 1;
    private static final int OUTDOOR = 2;
    private static java.lang.String TAG = "HwNormalizedManualBrightnessController";
    private int mAlgoSmoothLightValue;
    private boolean mAmbientLuxTimeOut;
    private boolean mAmbientLuxValid;
    private int mAutoBrightnessLevel = -1;
    private int mBackSensorCoverBrightness = -1;
    private int mBackSensorCoverLux = -1;
    private int mBrightnessNoLimitSetByApp = -1;
    private boolean mBrightnessNoLimitSetByAppAnimationEnable = false;
    private boolean mBrightnessNoLimitSetByAppEnable = false;
    private final android.content.Context mContext;
    private int mCurrentUserId = 0;
    private final com.android.server.display.HwBrightnessXmlLoader.Data mData = com.android.server.display.HwBrightnessXmlLoader.getData();
    private float mDefaultBrightness = 100.0f;
    private com.android.server.display.DisplayEffectMonitor mDisplayEffectMonitor;
    private android.os.Handler mHandler;
    private com.android.server.display.HwBrightnessMapping mHwBrightnessMapping;
    private com.android.server.display.HwBrightnessPgSceneDetection mHwBrightnessPgSceneDetection;
    private final boolean mIsBackSensorEnable;
    private long mLastAmbientLightToMonitorTime;
    private com.android.server.display.HwLightSensorController mLightSensorController = null;
    private boolean mLightSensorEnable;
    private int mManualAmbientLux;
    private boolean mManualModeAnimationEnable = false;
    private boolean mManualModeEnable;
    private boolean mManualPowerSavingAnimationEnable = false;
    private boolean mManualPowerSavingBrighnessLineDisableForDemo = false;
    private boolean mManualPowerSavingEnable = false;
    private int mManualbrightness = -1;
    private int mManualbrightnessLog = -1;
    private int mManualbrightnessOut = -1;
    private int mMaxBrightnessSetByThermal = 255;
    private com.android.server.display.HwNormalizedManualBrightnessThresholdDetector mOutdoorDetector = null;
    private int mOutdoorScene;
    private float mPowerRatio = 1.0f;
    java.util.List<float[]> mPowerSavingBrighnessLinePointsList = null;
    private boolean mThermalModeAnimationEnable = false;
    private boolean mThermalModeEnable = false;
    private boolean mUsePowerSavingModeCurveEnable = false;

    private final class HwNormalizedManualBrightnessHandler extends android.os.Handler {
        private HwNormalizedManualBrightnessHandler() {
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                com.android.server.display.HwNormalizedManualBrightnessController.this.updateBrightnessIfNoAmbientLuxReported();
            }
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable(TAG, 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwNormalizedManualBrightnessController(com.android.server.display.ManualBrightnessController.ManualBrightnessCallbacks callbacks, android.content.Context context, android.hardware.SensorManager sensorManager) {
        super(callbacks);
        this.mLightSensorController = new com.android.server.display.HwLightSensorController(context, this, sensorManager, this.mData.lightSensorRateMills, TAG);
        this.mOutdoorDetector = new com.android.server.display.HwNormalizedManualBrightnessThresholdDetector(this.mData);
        this.mDisplayEffectMonitor = com.android.server.display.DisplayEffectMonitor.getInstance(context);
        if (this.mDisplayEffectMonitor == null) {
            android.util.Slog.e(TAG, "getDisplayEffectMonitor failed!");
        }
        parseManualModePowerSavingCure(android.os.SystemProperties.get("ro.config.blight_power_curve", ""));
        this.mContext = context;
        this.mHwBrightnessPgSceneDetection = new com.android.server.display.HwBrightnessPgSceneDetection(this, this.mData.pgSceneDetectionDarkenDelayTime, this.mData.pgSceneDetectionBrightenDelayTime, this.mContext);
        this.mHwBrightnessMapping = new com.android.server.display.HwBrightnessMapping(this.mData.brightnessMappingPoints);
        this.mIsBackSensorEnable = this.mLightSensorController.isBackSensorEnable();
        if (this.mData.backSensorCoverModeEnable) {
            this.mHandler = new com.android.server.display.HwNormalizedManualBrightnessController.HwNormalizedManualBrightnessHandler();
        }
        if (this.mData.manualPowerSavingBrighnessLineDisableForDemo) {
            this.mManualPowerSavingBrighnessLineDisableForDemo = isDemoVersion();
        }
    }

    private void parseManualModePowerSavingCure(java.lang.String powerSavingCure) {
        if (powerSavingCure != null) {
            if (powerSavingCure.length() > 0) {
                if (this.mPowerSavingBrighnessLinePointsList != null) {
                    this.mPowerSavingBrighnessLinePointsList.clear();
                } else {
                    this.mPowerSavingBrighnessLinePointsList = new java.util.ArrayList();
                }
                java.lang.String[] powerSavingPoints = powerSavingCure.split(";");
                int i = 0;
                while (i < powerSavingPoints.length) {
                    try {
                        java.lang.String[] point = powerSavingPoints[i].split(",");
                        float x = java.lang.Float.parseFloat(point[0]);
                        float y = java.lang.Float.parseFloat(point[1]);
                        this.mPowerSavingBrighnessLinePointsList.add(new float[]{x, y});
                        i++;
                    } catch (java.lang.NumberFormatException e) {
                        this.mPowerSavingBrighnessLinePointsList.clear();
                        android.util.Slog.w(TAG, "parse ManualPowerSaving curve error");
                        return;
                    }
                }
                if (this.mPowerSavingBrighnessLinePointsList != null) {
                    i = this.mPowerSavingBrighnessLinePointsList.size();
                    for (int i2 = 0; i2 < i; i2++) {
                        float[] temp = (float[]) this.mPowerSavingBrighnessLinePointsList.get(i2);
                        if (DEBUG) {
                            java.lang.String str = TAG;
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("ManualPowerSavingPointsList x = ");
                            stringBuilder.append(temp[0]);
                            stringBuilder.append(", y = ");
                            stringBuilder.append(temp[1]);
                            android.util.Slog.d(str, stringBuilder.toString());
                        }
                    }
                }
                return;
            }
        }
        android.util.Slog.i(TAG, "powerSavingCure == null");
    }

    private static boolean wantScreenOn(int state) {
        switch (state) {
            case 2:
            case 3:
                return true;
            default:
                return false;
        }
    }

    public void updatePowerState(int state, boolean enable) {
        if (this.mManualModeEnable != enable) {
            if (DEBUG) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("HBM SensorEnable change ");
                stringBuilder.append(this.mManualModeEnable);
                stringBuilder.append(" -> ");
                stringBuilder.append(enable);
                android.util.Slog.i(str, stringBuilder.toString());
            }
            this.mManualModeEnable = enable;
        }
        if (this.mManualModeEnable) {
            setLightSensorEnabled(wantScreenOn(state));
        } else {
            setLightSensorEnabled(this.mManualModeEnable);
        }
    }

    private void setLightSensorEnabled(boolean enable) {
        if (enable) {
            if (!this.mLightSensorEnable) {
                this.mLightSensorEnable = true;
                this.mLightSensorController.enableSensor();
                this.mAmbientLuxValid = false;
                this.mAmbientLuxTimeOut = false;
                this.mBackSensorCoverLux = -1;
                this.mBackSensorCoverBrightness = -1;
                if (this.mHandler != null) {
                    this.mHandler.sendEmptyMessageDelayed(1, 300);
                }
                if (DEBUG) {
                    android.util.Slog.i(TAG, "ManualMode sensor enable");
                }
            }
            boolean pGBLListenerRegisted = this.mHwBrightnessPgSceneDetection.getPGBLListenerRegisted();
            if (this.mData.manualPowerSavingBrighnessLineEnable && !pGBLListenerRegisted) {
                this.mHwBrightnessPgSceneDetection.registerPgBLightSceneListener(this.mContext);
                if (DEBUG) {
                    java.lang.String str = TAG;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("PowerSaving Manul in registerPgBLightSceneChangedListener,=");
                    stringBuilder.append(this.mHwBrightnessPgSceneDetection.getPGBLListenerRegisted());
                    android.util.Slog.d(str, stringBuilder.toString());
                }
            }
        } else if (this.mLightSensorEnable) {
            this.mLightSensorEnable = false;
            this.mLightSensorController.disableSensor();
            this.mOutdoorDetector.clearAmbientLightRingBuffer();
            if (this.mHandler != null) {
                this.mHandler.removeMessages(1);
            }
            if (DEBUG) {
                android.util.Slog.i(TAG, "ManualMode sensor disable");
            }
        }
        this.mLastAmbientLightToMonitorTime = 0;
    }

    public void updateManualBrightness(int brightness) {
        this.mManualbrightness = brightness;
        this.mManualbrightnessOut = brightness;
    }

    private static boolean isDemoVersion() {
        java.lang.String vendor = android.os.SystemProperties.get("ro.hw.vendor", "");
        java.lang.String country = android.os.SystemProperties.get("ro.hw.country", "");
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("vendor:");
        stringBuilder.append(vendor);
        stringBuilder.append(",country:");
        stringBuilder.append(country);
        android.util.Slog.i(str, stringBuilder.toString());
        boolean VENDOR_DEMO = "demo".equalsIgnoreCase(vendor);
        boolean COUNTRY_DEMO = "demo".equalsIgnoreCase(country);
        if (!VENDOR_DEMO) {
            if (!COUNTRY_DEMO) {
                return false;
            }
        }
        return true;
    }

    public void updateStateRecognition(boolean usePwrBLightCurve, int appType) {
        if (this.mData.manualPowerSavingBrighnessLineEnable && this.mManualModeEnable && !this.mManualPowerSavingBrighnessLineDisableForDemo) {
            this.mManualPowerSavingEnable = usePwrBLightCurve;
            this.mManualPowerSavingAnimationEnable = getPowerSavingModeBrightnessChangeEnable(this.mManualbrightness, usePwrBLightCurve);
            float powerRatio = covertBrightnessToPowerRatio(this.mManualbrightness);
            int tembrightness = (int) (((float) this.mManualbrightness) * powerRatio);
            int pgModeBrightness = this.mHwBrightnessPgSceneDetection.getAdjustLightValByPgMode(tembrightness);
            if (pgModeBrightness != this.mManualbrightness) {
                powerRatio = this.mHwBrightnessPgSceneDetection.getPgPowerModeRatio();
                tembrightness = pgModeBrightness;
            }
            if (this.mManualbrightnessLog != tembrightness) {
                int brightnessNit = covertBrightnessLevelToNit(this.mManualbrightness);
                if (DEBUG) {
                    java.lang.String str = TAG;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("PowerSaving,ManualMode mManualbrightness=");
                    stringBuilder.append(this.mManualbrightness);
                    stringBuilder.append(",brightnessNit=");
                    stringBuilder.append(brightnessNit);
                    stringBuilder.append(",powerRatio=");
                    stringBuilder.append(powerRatio);
                    stringBuilder.append(",maxNit=");
                    stringBuilder.append(this.mData.screenBrightnessMaxNit);
                    stringBuilder.append(",MinNit=");
                    stringBuilder.append(this.mData.screenBrightnessMinNit);
                    stringBuilder.append(",usePwrBLightCurve=");
                    stringBuilder.append(usePwrBLightCurve);
                    stringBuilder.append(",appType=");
                    stringBuilder.append(appType);
                    android.util.Slog.d(str, stringBuilder.toString());
                }
                this.mManualbrightnessLog = tembrightness;
                this.mCallbacks.updateManualBrightnessForLux();
            }
            return;
        }
        this.mManualPowerSavingAnimationEnable = false;
        this.mManualPowerSavingEnable = false;
    }

    private boolean getPowerSavingModeBrightnessChangeEnable(int brightness, boolean usePowerSavingModeCurveEnable) {
        boolean powerSavingModeBrightnessChangeEnable = false;
        if (this.mUsePowerSavingModeCurveEnable != usePowerSavingModeCurveEnable) {
            int tembrightness = (int) (((float) brightness) * covertBrightnessLevelToPowerRatio(brightness));
            if (brightness != tembrightness) {
                powerSavingModeBrightnessChangeEnable = true;
                if (DEBUG) {
                    java.lang.String str = TAG;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("PowerSaving Enable=");
                    stringBuilder.append(true);
                    stringBuilder.append(",Pgbrightness=");
                    stringBuilder.append(tembrightness);
                    stringBuilder.append(",brightness=");
                    stringBuilder.append(brightness);
                    android.util.Slog.d(str, stringBuilder.toString());
                }
            }
        }
        this.mUsePowerSavingModeCurveEnable = usePowerSavingModeCurveEnable;
        return powerSavingModeBrightnessChangeEnable;
    }

    private float covertBrightnessLevelToPowerRatio(int brightness) {
        if ((!this.mData.manualMode || this.mManualbrightness < this.mData.manualBrightnessMaxLimit) && this.mData.manualPowerSavingBrighnessLineEnable) {
            return getPowerSavingRatio(covertBrightnessLevelToNit(this.mManualbrightness));
        }
        return 1.0f;
    }

    public int getManualBrightness() {
        if (this.mBrightnessNoLimitSetByApp > 0) {
            return this.mBrightnessNoLimitSetByApp;
        }
        int brightnessNit;
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        java.lang.String str2;
        java.lang.StringBuilder stringBuilder2;
        if (this.mData.backSensorCoverModeEnable) {
            if (this.mBackSensorCoverBrightness > 0) {
                if (this.mAutoBrightnessLevel != this.mBackSensorCoverBrightness && android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "screen_brightness_mode", 0, this.mCurrentUserId) == 1) {
                    android.provider.Settings.System.putIntForUser(this.mContext.getContentResolver(), "screen_auto_brightness", this.mBackSensorCoverBrightness, this.mCurrentUserId);
                    if (DEBUG) {
                        java.lang.String str3 = TAG;
                        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("LabcCoverMode mAutoBrightnessLevel=");
                        stringBuilder3.append(this.mAutoBrightnessLevel);
                        stringBuilder3.append(",mBackSensorCoverBrightness=");
                        stringBuilder3.append(this.mBackSensorCoverBrightness);
                        android.util.Slog.d(str3, stringBuilder3.toString());
                    }
                }
                this.mAutoBrightnessLevel = this.mBackSensorCoverBrightness;
                return this.mBackSensorCoverBrightness;
            } else if (!(this.mAmbientLuxValid || this.mAmbientLuxTimeOut || !com.android.server.HwServiceFactory.isCoverClosed())) {
                this.mAutoBrightnessLevel = -1;
                return -1;
            }
        }
        float powerSavingRatio = covertBrightnessToPowerRatio(this.mManualbrightness);
        if (DEBUG && java.lang.Math.abs(this.mPowerRatio - powerSavingRatio) > 1.0E-7f) {
            brightnessNit = covertBrightnessLevelToNit(this.mManualbrightness);
            this.mPowerRatio = powerSavingRatio;
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PowerSaving powerSavingRatio=");
            stringBuilder.append(powerSavingRatio);
            stringBuilder.append(",mManualbrightness=");
            stringBuilder.append(this.mManualbrightness);
            stringBuilder.append(",brightnessNit=");
            stringBuilder.append(brightnessNit);
            android.util.Slog.d(str, stringBuilder.toString());
        }
        brightnessNit = (int) (((float) this.mManualbrightness) * powerSavingRatio);
        if (brightnessNit < 4) {
            brightnessNit = 4;
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("warning mManualbrightness < min,Manualbrightness=");
            stringBuilder.append(4);
            android.util.Slog.w(str, stringBuilder.toString());
        }
        if (brightnessNit > 255) {
            brightnessNit = 255;
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("warning mManualbrightness > max,Manualbrightness=");
            stringBuilder.append(255);
            android.util.Slog.w(str, stringBuilder.toString());
        }
        this.mManualbrightnessOut = brightnessNit;
        if (!this.mData.manualMode) {
            this.mManualbrightnessOut = brightnessNit;
            if (DEBUG) {
                str = TAG;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mManualbrightnessOut=");
                stringBuilder.append(this.mManualbrightnessOut);
                stringBuilder.append(",mData.manualMode=");
                stringBuilder.append(this.mData.manualMode);
                android.util.Slog.i(str, stringBuilder.toString());
            }
        } else if (this.mManualbrightnessOut >= this.mData.manualBrightnessMaxLimit) {
            float defaultBrightness = getDefaultBrightnessLevelNew(this.mData.defaultBrighnessLinePoints, (float) this.mManualAmbientLux);
            if (this.mOutdoorScene == 2) {
                int mManualbrightnessTmpMin = brightnessNit < this.mData.manualBrightnessMaxLimit ? brightnessNit : this.mData.manualBrightnessMaxLimit;
                this.mManualbrightnessOut = mManualbrightnessTmpMin > ((int) defaultBrightness) ? mManualbrightnessTmpMin : (int) defaultBrightness;
                if (DEBUG) {
                    java.lang.String str4 = TAG;
                    java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                    stringBuilder4.append("mManualbrightnessOut=");
                    stringBuilder4.append(this.mManualbrightnessOut);
                    stringBuilder4.append(",defaultBrightness=");
                    stringBuilder4.append(defaultBrightness);
                    stringBuilder4.append(",AutoLux=");
                    stringBuilder4.append(this.mManualAmbientLux);
                    android.util.Slog.i(str4, stringBuilder4.toString());
                }
            } else {
                this.mManualbrightnessOut = brightnessNit < this.mData.manualBrightnessMaxLimit ? brightnessNit : this.mData.manualBrightnessMaxLimit;
                if (DEBUG) {
                    str2 = TAG;
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("mManualbrightnessOut1=");
                    stringBuilder2.append(this.mManualbrightnessOut);
                    stringBuilder2.append(",defaultBrightness=");
                    stringBuilder2.append(defaultBrightness);
                    stringBuilder2.append(",AutoLux=");
                    stringBuilder2.append(this.mManualAmbientLux);
                    android.util.Slog.i(str2, stringBuilder2.toString());
                }
            }
        }
        int pgModeBrightness = this.mHwBrightnessPgSceneDetection.getAdjustLightValByPgMode(this.mManualbrightnessOut);
        if (this.mData.pgModeBrightnessMappingEnable && this.mManualbrightnessOut > this.mData.manualBrightnessMaxLimit) {
            pgModeBrightness = this.mHwBrightnessMapping.getMappingBrightnessForRealNit(pgModeBrightness);
        }
        if (pgModeBrightness != this.mManualbrightnessOut) {
            this.mPowerRatio = this.mHwBrightnessPgSceneDetection.getPgPowerModeRatio();
            this.mManualbrightnessOut = pgModeBrightness;
            if (DEBUG) {
                str2 = TAG;
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("PG_POWER_SAVE_MODE mManualbrightnessOut=");
                stringBuilder2.append(this.mManualbrightnessOut);
                stringBuilder2.append(",mManualbrightness=");
                stringBuilder2.append(this.mManualbrightness);
                stringBuilder2.append(",mPowerRatio=");
                stringBuilder2.append(this.mPowerRatio);
                android.util.Slog.d(str2, stringBuilder2.toString());
            }
        }
        if (this.mManualbrightnessOut > this.mMaxBrightnessSetByThermal) {
            if (DEBUG) {
                str2 = TAG;
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("ThermalMode OrgManualbrightnessOut=");
                stringBuilder2.append(this.mManualbrightnessOut);
                stringBuilder2.append(",mMaxBrightnessSetByThermal=");
                stringBuilder2.append(this.mMaxBrightnessSetByThermal);
                android.util.Slog.d(str2, stringBuilder2.toString());
            }
            this.mManualbrightnessOut = this.mMaxBrightnessSetByThermal;
        }
        return this.mManualbrightnessOut;
    }

    public int getMaxBrightnessForSeekbar() {
        return this.mData.manualMode ? this.mData.manualBrightnessMaxLimit : 255;
    }

    public void processSensorData(long timeInMs, int lux, int cct) {
        this.mAmbientLuxValid = true;
        boolean needUpdateManualBrightness = false;
        if (this.mData.backSensorCoverModeEnable && needUpdateBrightWhileCoverClosed(lux)) {
            needUpdateManualBrightness = true;
        }
        this.mOutdoorDetector.handleLightSensorEvent(timeInMs, (float) lux);
        this.mOutdoorScene = this.mOutdoorDetector.getIndoorOutdoorFlagForHBM();
        if (this.mOutdoorDetector.getLuxChangedFlagForHBM()) {
            needUpdateManualBrightness = true;
            this.mManualModeAnimationEnable = true;
        }
        this.mManualAmbientLux = (int) this.mOutdoorDetector.getAmbientLuxForHBM();
        if (needUpdateManualBrightness) {
            this.mCallbacks.updateManualBrightnessForLux();
            this.mOutdoorDetector.setLuxChangedFlagForHBM();
            if (DEBUG) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mManualAmbientLux =");
                stringBuilder.append(this.mManualAmbientLux);
                stringBuilder.append(", mManualModeAnimationEnable=");
                stringBuilder.append(this.mManualModeAnimationEnable);
                android.util.Slog.i(str, stringBuilder.toString());
            }
        } else {
            this.mManualModeAnimationEnable = false;
        }
        sendAmbientLightToMonitor(timeInMs, (float) lux);
        sendDefaultBrightnessToMonitor();
    }

    private void updateBrightnessIfNoAmbientLuxReported() {
        if (!this.mAmbientLuxValid) {
            this.mAmbientLuxTimeOut = true;
            if (DEBUG) {
                android.util.Slog.d(TAG, "BackSensorCoverMode sensor doesn't report lux in 300ms");
            }
            this.mCallbacks.updateManualBrightnessForLux();
        }
    }

    private boolean isManualMode() {
        return android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "screen_brightness_mode", 1, this.mCurrentUserId) == 0;
    }

    private boolean needUpdateBrightWhileCoverClosed(int mixedSensorValue) {
        if (!this.mIsBackSensorEnable) {
            return false;
        }
        if (com.android.server.HwServiceFactory.isCoverClosed()) {
            int backSensorValue = this.mLightSensorController.getBackSensorValue();
            this.mBackSensorCoverLux = this.mBackSensorCoverLux > backSensorValue ? this.mBackSensorCoverLux : backSensorValue;
            this.mBackSensorCoverLux = this.mBackSensorCoverLux > mixedSensorValue ? this.mBackSensorCoverLux : mixedSensorValue;
            if (this.mData.backSensorCoverModeMinLuxInRing > 0 && isPhoneInRing()) {
                this.mBackSensorCoverLux = this.mBackSensorCoverLux > this.mData.backSensorCoverModeMinLuxInRing ? this.mBackSensorCoverLux : this.mData.backSensorCoverModeMinLuxInRing;
            }
            int backSensorCoverBrightness = (int) getDefaultBrightnessLevelNew(this.mData.backSensorCoverModeBrighnessLinePoints, (float) this.mBackSensorCoverLux);
            boolean isManualMode = isManualMode();
            if (isManualMode && backSensorCoverBrightness < this.mManualbrightness) {
                backSensorCoverBrightness = -1;
            }
            if (backSensorCoverBrightness == this.mBackSensorCoverBrightness) {
                return false;
            }
            if (DEBUG) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("BackSensorCoverMode mixed=");
                stringBuilder.append(mixedSensorValue);
                stringBuilder.append(", back=");
                stringBuilder.append(backSensorValue);
                stringBuilder.append(", lux=");
                stringBuilder.append(this.mBackSensorCoverLux);
                stringBuilder.append(", bright=");
                stringBuilder.append(backSensorCoverBrightness);
                stringBuilder.append(", isManualMode=");
                stringBuilder.append(isManualMode);
                android.util.Slog.d(str, stringBuilder.toString());
            }
            this.mBackSensorCoverBrightness = backSensorCoverBrightness;
            return true;
        }
        if (this.mBackSensorCoverBrightness > 0) {
            boolean isManualMode2 = isManualMode();
            if (DEBUG) {
                java.lang.String str2 = TAG;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("BackSensorCoverMode cover open, isManualMode=");
                stringBuilder2.append(isManualMode2);
                android.util.Slog.d(str2, stringBuilder2.toString());
            }
            this.mBackSensorCoverLux = -1;
            this.mBackSensorCoverBrightness = -1;
            if (isManualMode2) {
                return true;
            }
        }
        return false;
    }

    private boolean isPhoneInRing() {
        boolean phoneInRinging = false;
        if (android.telephony.TelephonyManager.getDefault().isMultiSimEnabled()) {
            int phoneCount = android.telephony.TelephonyManager.getDefault().getPhoneCount();
            for (int i = 0; i < phoneCount; i++) {
                if (android.telephony.TelephonyManager.getDefault().getCallState(i) != 0) {
                    phoneInRinging = true;
                    break;
                }
            }
            return phoneInRinging;
        } else if (android.telephony.TelephonyManager.getDefault().getCallState(android.telephony.SubscriptionManager.getDefaultSubscriptionId()) != 0) {
            return true;
        } else {
            return false;
        }
    }

    public void updateCurrentUserId(int userId) {
        if (userId != this.mCurrentUserId) {
            if (DEBUG) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("user change from  ");
                stringBuilder.append(this.mCurrentUserId);
                stringBuilder.append(" into ");
                stringBuilder.append(userId);
                android.util.Slog.d(str, stringBuilder.toString());
            }
            this.mCurrentUserId = userId;
        }
    }

    public boolean needFastestRateForManualBrightness() {
        if (this.mData.backSensorCoverModeEnable && this.mBackSensorCoverBrightness > 0 && com.android.server.HwServiceFactory.isCoverClosed()) {
            return true;
        }
        return false;
    }

    private float covertBrightnessToPowerRatio(int brightness) {
        if ((this.mData.manualMode && this.mManualbrightness >= this.mData.manualBrightnessMaxLimit) || !this.mData.manualPowerSavingBrighnessLineEnable) {
            return 1.0f;
        }
        int brightnessNit = covertBrightnessLevelToNit(this.mManualbrightness);
        float powerRatio = 1.0f;
        if (this.mManualPowerSavingEnable) {
            powerRatio = getPowerSavingRatio(brightnessNit);
        }
        return powerRatio;
    }

    private int covertBrightnessLevelToNit(int brightness) {
        if (brightness == 0) {
            return brightness;
        }
        if (brightness < 4) {
            brightness = 4;
        }
        if (brightness > 255) {
            brightness = 255;
        }
        return (int) (((((float) (brightness - 4)) * (this.mData.screenBrightnessMaxNit - this.mData.screenBrightnessMinNit)) / 251.0f) + this.mData.screenBrightnessMinNit);
    }

    private float getPowerSavingRatio(int brightnssnit) {
        java.lang.StringBuilder stringBuilder;
        if (!(this.mPowerSavingBrighnessLinePointsList == null || this.mPowerSavingBrighnessLinePointsList.size() == 0)) {
            if (brightnssnit >= 0) {
                int linePointsListLength = this.mPowerSavingBrighnessLinePointsList.size();
                float[] temp = (float[]) this.mPowerSavingBrighnessLinePointsList.get(0);
                if (((float) brightnssnit) < temp[0]) {
                    return 1.0f;
                }
                java.lang.String str;
                float tmpPowerSavingRatio = 1.0f;
                float[] temp1 = null;
                for (int i = 0; i <= linePointsListLength - 1; i++) {
                    float[] temp2 = (float[]) this.mPowerSavingBrighnessLinePointsList.get(i);
                    if (temp1 == null) {
                        temp1 = temp2;
                    }
                    if (((float) brightnssnit) < temp2[0]) {
                        float[] temp22 = temp2;
                        if (temp22[0] <= temp1[0]) {
                            tmpPowerSavingRatio = 1.0f;
                            android.util.Slog.w(TAG, "temp2[0] <= temp1[0] warning,set default tmpPowerSavingRatio");
                        } else {
                            tmpPowerSavingRatio = (((temp22[1] - temp1[1]) / (temp22[0] - temp1[0])) * (((float) brightnssnit) - temp1[0])) + temp1[1];
                        }
                        if (tmpPowerSavingRatio > 1.0f || tmpPowerSavingRatio < 0.0f) {
                            str = TAG;
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("tmpPowerSavingRatio warning,set default value, tmpPowerSavingRatio= ");
                            stringBuilder.append(this.mPowerRatio);
                            android.util.Slog.w(str, stringBuilder.toString());
                            tmpPowerSavingRatio = 1.0f;
                        }
                        return tmpPowerSavingRatio;
                    }
                    temp1 = temp2;
                    tmpPowerSavingRatio = temp1[1];
                }
                str = TAG;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("tmpPowerSavingRatio warning,set default value, tmpPowerSavingRatio= ");
                stringBuilder.append(this.mPowerRatio);
                android.util.Slog.w(str, stringBuilder.toString());
                tmpPowerSavingRatio = 1.0f;
                return tmpPowerSavingRatio;
            }
        }
        java.lang.String str2 = TAG;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("PowerSavingBrighnessLinePointsList warning,set PowerSavingRatio,brightnssnit=");
        stringBuilder.append(brightnssnit);
        android.util.Slog.e(str2, stringBuilder.toString());
        return 1.0f;
    }

    private void sendAmbientLightToMonitor(long time, float lux) {
        if (this.mDisplayEffectMonitor != null) {
            if (this.mLastAmbientLightToMonitorTime != 0) {
                if (time > this.mLastAmbientLightToMonitorTime) {
                    int durationInMs = (int) (time - this.mLastAmbientLightToMonitorTime);
                    this.mLastAmbientLightToMonitorTime = time;
                    android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
                    params.put("paramType", "ambientLightCollection");
                    params.put("lightValue", java.lang.Integer.valueOf((int) lux));
                    params.put("durationInMs", java.lang.Integer.valueOf(durationInMs));
                    params.put("brightnessMode", "MANUAL");
                    this.mDisplayEffectMonitor.sendMonitorParam(params);
                    return;
                }
            }
            this.mLastAmbientLightToMonitorTime = time;
        }
    }

    private void sendDefaultBrightnessToMonitor() {
        if (this.mDisplayEffectMonitor != null) {
            int lightValue = (int) this.mOutdoorDetector.getFilterLuxFromManualMode();
            if (this.mAlgoSmoothLightValue != lightValue) {
                this.mAlgoSmoothLightValue = lightValue;
                android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
                params.put("paramType", "algoDefaultBrightness");
                params.put("lightValue", java.lang.Integer.valueOf(lightValue));
                params.put("brightness", java.lang.Integer.valueOf(0));
                params.put("brightnessMode", "MANUAL");
                this.mDisplayEffectMonitor.sendMonitorParam(params);
            }
        }
    }

    public float getDefaultBrightnessLevelNew(java.util.List<android.graphics.PointF> linePointsList, float lux) {
        java.util.List<android.graphics.PointF> linePointsListIn = linePointsList;
        float brightnessLevel = this.mDefaultBrightness;
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : linePointsListIn) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (lux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x > temp1.x) {
                    return (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (lux - temp1.x)) + temp1.y;
                }
                brightnessLevel = this.mDefaultBrightness;
                if (!DEBUG) {
                    return brightnessLevel;
                }
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("DefaultBrighness_temp1.x <= temp2.x,x");
                stringBuilder.append(temp.x);
                stringBuilder.append(", y = ");
                stringBuilder.append(temp.y);
                android.util.Slog.i(str, stringBuilder.toString());
                return brightnessLevel;
            }
            temp1 = temp;
            brightnessLevel = temp1.y;
        }
        return brightnessLevel;
    }

    public boolean getManualModeAnimationEnable() {
        return this.mManualModeAnimationEnable;
    }

    public boolean getManualModeEnable() {
        return this.mData.manualMode;
    }

    public boolean getManualPowerSavingAnimationEnable() {
        return this.mManualPowerSavingAnimationEnable;
    }

    public void setManualPowerSavingAnimationEnable(boolean manualPowerSavingAnimationEnable) {
        this.mManualPowerSavingAnimationEnable = manualPowerSavingAnimationEnable;
    }

    public boolean getManualThermalModeEnable() {
        return this.mManualModeEnable && this.mThermalModeEnable;
    }

    public boolean getManualThermalModeAnimationEnable() {
        return this.mThermalModeAnimationEnable;
    }

    public void setManualThermalModeAnimationEnable(boolean thermalModeAnimationEnable) {
        this.mThermalModeAnimationEnable = thermalModeAnimationEnable;
    }

    public void setMaxBrightnessFromThermal(int brightness) {
        int mappingBrightness = brightness;
        if (brightness > 0) {
            if (this.mData.thermalModeBrightnessMappingEnable) {
                mappingBrightness = this.mHwBrightnessMapping.getMappingBrightnessForRealNit(brightness);
            }
            this.mMaxBrightnessSetByThermal = mappingBrightness;
        } else {
            this.mMaxBrightnessSetByThermal = 255;
        }
        if (this.mManualModeEnable) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("ThermalMode set Manual MaxBrightness=");
            stringBuilder.append(brightness);
            stringBuilder.append(",mappingBrightness=");
            stringBuilder.append(mappingBrightness);
            android.util.Slog.i(str, stringBuilder.toString());
            this.mThermalModeAnimationEnable = true;
            this.mThermalModeEnable = true;
            this.mCallbacks.updateManualBrightnessForLux();
            return;
        }
        this.mThermalModeAnimationEnable = false;
        this.mThermalModeEnable = false;
    }

    public boolean getBrightnessSetByAppEnable() {
        return this.mBrightnessNoLimitSetByAppEnable;
    }

    public boolean getBrightnessSetByAppAnimationEnable() {
        return this.mBrightnessNoLimitSetByAppAnimationEnable;
    }

    public void setBrightnessNoLimit(int brightness, int time) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setBrightnessNoLimit set brightness=");
        stringBuilder.append(brightness);
        stringBuilder.append(",time=");
        stringBuilder.append(time);
        android.util.Slog.i(str, stringBuilder.toString());
        if (brightness > 0) {
            this.mBrightnessNoLimitSetByApp = brightness;
        } else {
            this.mBrightnessNoLimitSetByApp = -1;
        }
        if (brightness <= 0 || brightness > 255) {
            this.mBrightnessNoLimitSetByAppAnimationEnable = false;
            this.mBrightnessNoLimitSetByAppEnable = false;
        } else {
            this.mBrightnessNoLimitSetByAppAnimationEnable = true;
            this.mBrightnessNoLimitSetByAppEnable = true;
        }
        if (this.mManualModeEnable) {
            this.mCallbacks.updateManualBrightnessForLux();
        }
    }
}
