package com.android.server.display;

public class HwNormalizedManualBrightnessThresholdDetector {
    private static final int AMBIENT_LIGHT_HORIZON = 10000;
    private static final int AMBIENT_MAX_LUX = 40000;
    private static boolean DEBUG = false;
    private static final int INDOOR_UI = 1;
    private static final int OUTDOOR_UI = 2;
    private static java.lang.String TAG = "HwNormalizedManualBrightnessThresholdDetector";
    protected boolean mAmChangeFlagForHBM = false;
    protected com.android.server.display.HwRingBuffer mAmbientLightRingBuffer;
    protected com.android.server.display.HwRingBuffer mAmbientLightRingBufferFilter;
    protected float mAmbientLux;
    private float mBrightenDeltaLuxMax = 0.0f;
    private float mDarkenDeltaLuxMax = 0.0f;
    private final com.android.server.display.HwBrightnessXmlLoader.Data mData;
    private float mFilterLux;
    private int mLastInOutState = 1;

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable(TAG, 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwNormalizedManualBrightnessThresholdDetector(com.android.server.display.HwBrightnessXmlLoader.Data data) {
        this.mData = data;
        this.mAmbientLightRingBuffer = new com.android.server.display.HwRingBuffer(50);
        this.mAmbientLightRingBufferFilter = new com.android.server.display.HwRingBuffer(50);
    }

    public void clearAmbientLightRingBuffer() {
        this.mAmbientLightRingBuffer.clear();
        this.mAmbientLightRingBufferFilter.clear();
    }

    public void handleLightSensorEvent(long time, float lux) {
        if (lux > 40000.0f) {
            lux = 40000.0f;
        }
        applyLightSensorMeasurement(time, lux);
        updateAmbientLux(time);
    }

    private void applyLightSensorMeasurement(long time, float lux) {
        this.mAmbientLightRingBuffer.prune(time - 10000);
        this.mAmbientLightRingBuffer.push(time, lux);
    }

    private float calculateAmbientLuxForNewPolicy(long now) {
        int N = this.mAmbientLightRingBuffer.size();
        if (N == 0) {
            if (DEBUG) {
                android.util.Slog.v(TAG, "calculateAmbientLux: No ambient light readings available");
            }
            return -1.0f;
        } else if (N < 5) {
            return this.mAmbientLightRingBuffer.getLux(N - 1);
        } else {
            float sum = this.mAmbientLightRingBuffer.getLux(N - 1);
            float luxMin = this.mAmbientLightRingBuffer.getLux(N - 1);
            float luxMax = this.mAmbientLightRingBuffer.getLux(N - 1);
            for (int i = N - 2; i >= (N - 1) - 4; i--) {
                if (luxMin > this.mAmbientLightRingBuffer.getLux(i)) {
                    luxMin = this.mAmbientLightRingBuffer.getLux(i);
                }
                if (luxMax < this.mAmbientLightRingBuffer.getLux(i)) {
                    luxMax = this.mAmbientLightRingBuffer.getLux(i);
                }
                sum += this.mAmbientLightRingBuffer.getLux(i);
            }
            return ((sum - luxMin) - luxMax) / 3.0f;
        }
    }

    private long nextAmbientLightBrighteningTransitionForNewPolicy(long time) {
        int N = this.mAmbientLightRingBufferFilter.size();
        long debounceTime = (long) this.mData.manualBrighenDebounceTime;
        if (1 == N) {
            debounceTime = 0;
        }
        long earliestValidTime = time;
        for (int i = N - 1; i >= 0; i--) {
            boolean BrightenChange;
            if (this.mAmbientLightRingBufferFilter.getLux(i) - this.mAmbientLux > this.mBrightenDeltaLuxMax) {
                BrightenChange = true;
            } else {
                BrightenChange = false;
            }
            if (!BrightenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return earliestValidTime + debounceTime;
    }

    private long nextAmbientLightDarkeningTransitionForNewPolicy(long time) {
        int N = this.mAmbientLightRingBufferFilter.size();
        long debounceTime = (long) this.mData.manualDarkenDebounceTime;
        if (1 == N) {
            debounceTime = 0;
        }
        long earliestValidTime = time;
        for (int i = N - 1; i >= 0; i--) {
            boolean DarkenChange;
            if (this.mAmbientLux - this.mAmbientLightRingBufferFilter.getLux(i) >= this.mDarkenDeltaLuxMax) {
                DarkenChange = true;
            } else {
                DarkenChange = false;
            }
            if (!DarkenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
        }
        return earliestValidTime + debounceTime;
    }

    private long nextAmbientLightDarkeningTransitionForInOut(long time) {
        int N = this.mAmbientLightRingBufferFilter.size();
        long debounceTime = (long) this.mData.manualBrighenDebounceTime;
        if (1 == N) {
            debounceTime = 0;
        }
        long earliestValidTime = time;
        int i = N - 1;
        while (i >= 0) {
            boolean DarkenChange;
            if (this.mAmbientLightRingBufferFilter.getLux(i) <= ((float) this.mData.inDoorThreshold) || this.mAmbientLightRingBufferFilter.getLux(i) >= ((float) this.mData.outDoorThreshold)) {
                DarkenChange = false;
            } else {
                DarkenChange = true;
            }
            if (!DarkenChange) {
                break;
            }
            earliestValidTime = this.mAmbientLightRingBufferFilter.getTime(i);
            i--;
        }
        return earliestValidTime + debounceTime;
    }

    private void setBrightenThresholdNew() {
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.manualBrightenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (this.mAmbientLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                if (temp2.x <= temp1.x) {
                    this.mBrightenDeltaLuxMax = 1.0f;
                    if (DEBUG) {
                        java.lang.String str = TAG;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Brighten_temp1.x <= temp2.x,x");
                        stringBuilder.append(temp.x);
                        stringBuilder.append(", y = ");
                        stringBuilder.append(temp.y);
                        android.util.Slog.i(str, stringBuilder.toString());
                        return;
                    }
                    return;
                }
                this.mBrightenDeltaLuxMax = (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (this.mAmbientLux - temp1.x)) + temp1.y;
                return;
            }
            temp1 = temp;
            this.mBrightenDeltaLuxMax = temp1.y;
        }
    }

    private void setDarkenThresholdNew() {
        android.graphics.PointF temp1 = null;
        for (android.graphics.PointF temp : this.mData.manualDarkenlinePoints) {
            if (temp1 == null) {
                temp1 = temp;
            }
            if (this.mAmbientLux < temp.x) {
                android.graphics.PointF temp2 = temp;
                float f = 1.0f;
                if (temp2.x <= temp1.x) {
                    this.mDarkenDeltaLuxMax = 1.0f;
                    if (DEBUG) {
                        java.lang.String str = TAG;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Darken_temp1.x <= temp2.x,x");
                        stringBuilder.append(temp.x);
                        stringBuilder.append(", y = ");
                        stringBuilder.append(temp.y);
                        android.util.Slog.i(str, stringBuilder.toString());
                        return;
                    }
                    return;
                }
                float DarkenDeltaLuxMaxtmp = (((temp2.y - temp1.y) / (temp2.x - temp1.x)) * (this.mAmbientLux - temp1.x)) + temp1.y;
                if (DarkenDeltaLuxMaxtmp > 1.0f) {
                    f = DarkenDeltaLuxMaxtmp;
                }
                this.mDarkenDeltaLuxMax = f;
                return;
            }
            temp1 = temp;
            this.mDarkenDeltaLuxMax = temp1.y;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:25:0x0077  */
    private void updateAmbientLux(long r11) {
        /*
        r10 = this;
        r0 = r10.calculateAmbientLuxForNewPolicy(r11);
        r10.mFilterLux = r0;
        r0 = r10.mAmbientLightRingBuffer;
        r0 = r0.size();
        r1 = 1;
        if (r0 != r1) goto L_0x002f;
    L_0x000f:
        r0 = TAG;
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "fist sensor lux and filteredlux=";
        r2.append(r3);
        r3 = r10.mFilterLux;
        r2.append(r3);
        r3 = ",time=";
        r2.append(r3);
        r2.append(r11);
        r2 = r2.toString();
        android.util.Slog.i(r0, r2);
    L_0x002f:
        r0 = r10.mAmbientLightRingBufferFilter;
        r2 = r10.mFilterLux;
        r0.push(r11, r2);
        r0 = r10.mAmbientLightRingBufferFilter;
        r2 = 10000; // 0x2710 float:1.4013E-41 double:4.9407E-320;
        r2 = r11 - r2;
        r0.prune(r2);
        r2 = r10.nextAmbientLightBrighteningTransitionForNewPolicy(r11);
        r4 = r10.nextAmbientLightDarkeningTransitionForNewPolicy(r11);
        r6 = r10.nextAmbientLightDarkeningTransitionForInOut(r11);
        r0 = 0;
        r10.mAmChangeFlagForHBM = r0;
        r8 = (r2 > r11 ? 1 : (r2 == r11 ? 0 : -1));
        if (r8 <= 0) goto L_0x0068;
    L_0x0052:
        r8 = (r4 > r11 ? 1 : (r4 == r11 ? 0 : -1));
        if (r8 <= 0) goto L_0x0068;
    L_0x0056:
        r8 = (r2 > r11 ? 1 : (r2 == r11 ? 0 : -1));
        if (r8 > 0) goto L_0x005e;
    L_0x005a:
        r8 = (r6 > r11 ? 1 : (r6 == r11 ? 0 : -1));
        if (r8 <= 0) goto L_0x0068;
    L_0x005e:
        r8 = (r4 > r11 ? 1 : (r4 == r11 ? 0 : -1));
        if (r8 > 0) goto L_0x0067;
    L_0x0062:
        r8 = (r6 > r11 ? 1 : (r6 == r11 ? 0 : -1));
        if (r8 > 0) goto L_0x0067;
    L_0x0066:
        goto L_0x0068;
    L_0x0067:
        goto L_0x0069;
    L_0x0068:
        r0 = r1;
    L_0x0069:
        r1 = (r2 > r11 ? 1 : (r2 == r11 ? 0 : -1));
        if (r1 <= 0) goto L_0x0073;
    L_0x006d:
        r1 = (r4 > r11 ? 1 : (r4 == r11 ? 0 : -1));
        if (r1 <= 0) goto L_0x0073;
    L_0x0071:
        if (r0 == 0) goto L_0x00bd;
    L_0x0073:
        r1 = DEBUG;
        if (r1 == 0) goto L_0x00b8;
    L_0x0077:
        r1 = TAG;
        r8 = new java.lang.StringBuilder;
        r8.<init>();
        r9 = "update_Flag=";
        r8.append(r9);
        r8.append(r0);
        r9 = ",filteredlux=";
        r8.append(r9);
        r9 = r10.mFilterLux;
        r8.append(r9);
        r9 = ",time=";
        r8.append(r9);
        r8.append(r11);
        r9 = ",nextBTime=";
        r8.append(r9);
        r8.append(r2);
        r9 = ",nextDTime=";
        r8.append(r9);
        r8.append(r4);
        r9 = ",nextInOutTime=";
        r8.append(r9);
        r8.append(r6);
        r8 = r8.toString();
        android.util.Slog.i(r1, r8);
    L_0x00b8:
        r1 = r10.mFilterLux;
        r10.updateParaForHBM(r1);
    L_0x00bd:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.HwNormalizedManualBrightnessThresholdDetector.updateAmbientLux(long):void");
    }

    private void updateParaForHBM(float lux) {
        float mAmbientLuxTmp = lux;
        if (mAmbientLuxTmp >= ((float) this.mData.outDoorThreshold)) {
            this.mAmbientLux = mAmbientLuxTmp;
            this.mLastInOutState = 2;
            this.mAmChangeFlagForHBM = true;
        }
        if (mAmbientLuxTmp < ((float) this.mData.inDoorThreshold)) {
            this.mAmbientLux = mAmbientLuxTmp;
            this.mLastInOutState = 1;
            this.mAmChangeFlagForHBM = true;
        }
        if (mAmbientLuxTmp < ((float) this.mData.outDoorThreshold) && mAmbientLuxTmp >= ((float) this.mData.inDoorThreshold)) {
            this.mAmbientLux = mAmbientLuxTmp;
            if (this.mAmbientLightRingBufferFilter.size() == 1) {
                this.mLastInOutState = 1;
            }
            this.mAmChangeFlagForHBM = true;
        }
        setBrightenThresholdNew();
        setDarkenThresholdNew();
        if (DEBUG) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("update_lux =");
            stringBuilder.append(this.mAmbientLux);
            stringBuilder.append(",IN_OUT_DoorFlag =");
            stringBuilder.append(this.mLastInOutState);
            stringBuilder.append(",mBrightenDeltaLuxMax=");
            stringBuilder.append(this.mBrightenDeltaLuxMax);
            stringBuilder.append(",mDarkenDeltaLuxMax=");
            stringBuilder.append(this.mDarkenDeltaLuxMax);
            android.util.Slog.i(str, stringBuilder.toString());
        }
    }

    public float getAmbientLuxForHBM() {
        return this.mAmbientLux;
    }

    public boolean getLuxChangedFlagForHBM() {
        return this.mAmChangeFlagForHBM;
    }

    public void setLuxChangedFlagForHBM() {
        this.mAmChangeFlagForHBM = false;
    }

    public int getIndoorOutdoorFlagForHBM() {
        return this.mLastInOutState;
    }

    public float getFilterLuxFromManualMode() {
        return this.mFilterLux;
    }
}
