package com.android.server.display;

class TouchProximityDetector {
    private static final int CONTINUE_INVALID_PRINT_PERIOD_MS = 30000;
    private static final boolean HWDEBUG;
    private static final boolean HWFLOW;
    private static final java.lang.String TAG = "TouchProximityDetector";
    private int mContinueInvalidCnt;
    private final int mContinueInvalidPrintPeriod;
    private volatile boolean mCurrentLuxValid = true;
    private boolean mEnable;
    private com.android.server.wm.WindowManagerService.HwInnerWindowManagerService mHwInnerWindowManagerService;
    private com.android.server.display.TouchProximityDetector.MyRotateObserver mIHwRotateObserver;
    private boolean mInited;
    private com.android.server.display.TouchProximityDetector.MyPointerEventListener mPointerEventListener;
    private com.android.server.wm.WindowManagerService mWindowManagerService;
    private int mXThreshold270;
    private int mXThreshold90;
    private int mYMaxPixels;
    private int mYThreshold0;
    private int mYThreshold180;

    private class MyPointerEventListener implements android.view.WindowManagerPolicyConstants.PointerEventListener {
        private boolean mIsCovered;
        private int mNearbyPointBits;
        private int mUsedOrientation;

        private MyPointerEventListener() {
            this.mIsCovered = false;
            this.mNearbyPointBits = 0;
            this.mUsedOrientation = 0;
        }

        public void onPointerEvent(android.view.MotionEvent motionEvent) {
            updatePointState(motionEvent);
        }

        private void updatePointState(android.view.MotionEvent motionEvent) {
            if (com.android.server.display.TouchProximityDetector.this.mEnable) {
                int action = motionEvent.getActionMasked();
                boolean stateChanged = false;
                float y;
                int id;
                float realX;
                float realY;
                switch (action) {
                    case 0:
                    case 5:
                    case 6:
                        int index = motionEvent.getActionIndex();
                        if (motionEvent.getToolType(index) == 1) {
                            if (action == 0) {
                                this.mNearbyPointBits = 0;
                                if (com.android.server.display.TouchProximityDetector.this.mIHwRotateObserver != null) {
                                    this.mUsedOrientation = com.android.server.display.TouchProximityDetector.this.mIHwRotateObserver.getOrientation();
                                }
                            }
                            float x = motionEvent.getX(index);
                            y = motionEvent.getY(index);
                            id = motionEvent.getPointerId(index);
                            realX = x * motionEvent.getXPrecision();
                            realY = y * motionEvent.getYPrecision();
                            if (action != 6) {
                                if (nearbyProximity(realX, realY)) {
                                    this.mNearbyPointBits |= 1 << id;
                                    break;
                                }
                            }
                            this.mNearbyPointBits &= ~(1 << id);
                            break;
                        }
                        break;
                        break;
                    case 1:
                    case 3:
                        if (motionEvent.getToolType(motionEvent.getActionIndex()) == 1) {
                            this.mNearbyPointBits = 0;
                            break;
                        }
                        break;
                    case 2:
                        int pointCount = motionEvent.getPointerCount();
                        float realY2 = 0.0f;
                        realY = 0.0f;
                        realX = 0.0f;
                        y = 0.0f;
                        for (int i = 0; i < pointCount; i++) {
                            if (motionEvent.getToolType(i) == 1) {
                                y = motionEvent.getX(i);
                                realX = motionEvent.getY(i);
                                id = motionEvent.getPointerId(i);
                                float realX2 = motionEvent.getXPrecision() * y;
                                realY = motionEvent.getYPrecision() * realX;
                                if (nearbyProximity(realX2, realY)) {
                                    this.mNearbyPointBits |= 1 << id;
                                } else {
                                    this.mNearbyPointBits &= ~(1 << id);
                                }
                                realY2 = realY;
                                realY = realX2;
                            }
                        }
                        break;
                    default:
                        break;
                }
                if (this.mIsCovered != (this.mNearbyPointBits != 0)) {
                    stateChanged = true;
                }
                if (stateChanged) {
                    this.mIsCovered = 1 ^ this.mIsCovered;
                    if (this.mIsCovered) {
                        com.android.server.display.TouchProximityDetector.this.setCurrentLuxInvalid();
                    }
                    if (com.android.server.display.TouchProximityDetector.HWDEBUG) {
                        java.lang.String str = "TouchProximityDetector";
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(this.mIsCovered ? "one more" : "no");
                        stringBuilder.append(" finger(s) nearby the proximity sensor");
                        android.util.Slog.d(str, stringBuilder.toString());
                    }
                }
            }
        }

        private boolean nearbyProximity(float x, float y) {
            boolean z = true;
            switch (this.mUsedOrientation) {
                case 0:
                    if (y <= ((float) com.android.server.display.TouchProximityDetector.this.mYThreshold0)) {
                        z = false;
                    }
                    return z;
                case 1:
                    if (x <= ((float) com.android.server.display.TouchProximityDetector.this.mXThreshold90)) {
                        z = false;
                    }
                    return z;
                case 2:
                    if (y >= ((float) com.android.server.display.TouchProximityDetector.this.mYThreshold180)) {
                        z = false;
                    }
                    return z;
                case 3:
                    if (x >= ((float) com.android.server.display.TouchProximityDetector.this.mXThreshold270)) {
                        z = false;
                    }
                    return z;
                default:
                    if (com.android.server.display.TouchProximityDetector.HWFLOW) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("unknow mOrientation=");
                        stringBuilder.append(this.mUsedOrientation);
                        android.util.Slog.i("TouchProximityDetector", stringBuilder.toString());
                    }
                    return false;
            }
        }

        public boolean isCovered() {
            return this.mIsCovered;
        }

        public void clear() {
            this.mIsCovered = false;
        }
    }

    private class MyRotateObserver extends android.view.IHwRotateObserver.Stub {
        private int mOrientation;

        private MyRotateObserver() {
            this.mOrientation = 0;
        }

        public int getOrientation() {
            return this.mOrientation;
        }

        public void onRotate(int oldRotation, int newRotation) {
            if (com.android.server.display.TouchProximityDetector.HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("RotateObserver onRotate ");
                stringBuilder.append(oldRotation);
                stringBuilder.append("->");
                stringBuilder.append(newRotation);
                android.util.Slog.i("TouchProximityDetector", stringBuilder.toString());
            }
            this.mOrientation = newRotation;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001d  */
    static {
        /*
        r0 = android.util.Log.HWLog;
        r1 = 1;
        r2 = 0;
        if (r0 != 0) goto L_0x0016;
    L_0x0006:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x0014;
    L_0x000a:
        r0 = "TouchProximityDetector";
        r3 = 3;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x0014;
    L_0x0013:
        goto L_0x0016;
    L_0x0014:
        r0 = r2;
        goto L_0x0017;
    L_0x0016:
        r0 = r1;
    L_0x0017:
        HWDEBUG = r0;
        r0 = android.util.Log.HWINFO;
        if (r0 != 0) goto L_0x002d;
    L_0x001d:
        r0 = android.util.Log.HWModuleLog;
        if (r0 == 0) goto L_0x002b;
    L_0x0021:
        r0 = "TouchProximityDetector";
        r3 = 4;
        r0 = android.util.Log.isLoggable(r0, r3);
        if (r0 == 0) goto L_0x002b;
    L_0x002a:
        goto L_0x002d;
    L_0x002b:
        r1 = r2;
    L_0x002d:
        HWFLOW = r1;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.display.TouchProximityDetector.<clinit>():void");
    }

    public TouchProximityDetector(com.android.server.display.HwBrightnessXmlLoader.Data data) {
        this.mContinueInvalidPrintPeriod = 30000 / (data.lightSensorRateMills > 0 ? data.lightSensorRateMills : 300);
        android.hardware.display.IDisplayManager iDisplayManager = (android.hardware.display.IDisplayManager) android.os.ServiceManager.getService("display");
        if (iDisplayManager == null) {
            android.util.Slog.e("TouchProximityDetector", "init failed, display manager is null");
            return;
        }
        this.mWindowManagerService = (com.android.server.wm.WindowManagerService) android.os.ServiceManager.getService("window");
        if (this.mWindowManagerService == null) {
            android.util.Slog.e("TouchProximityDetector", "init failed, window manager is null");
            return;
        }
        this.mHwInnerWindowManagerService = (com.android.server.wm.WindowManagerService.HwInnerWindowManagerService) this.mWindowManagerService.getHwInnerService();
        if (this.mHwInnerWindowManagerService == null) {
            android.util.Slog.e("TouchProximityDetector", "init failed, inner window manager is null");
            return;
        }
        this.mPointerEventListener = new com.android.server.display.TouchProximityDetector.MyPointerEventListener();
        this.mIHwRotateObserver = new com.android.server.display.TouchProximityDetector.MyRotateObserver();
        try {
            this.mYMaxPixels = iDisplayManager.getStableDisplaySize().y;
            this.mYThreshold0 = this.mYMaxPixels - ((int) (((float) this.mYMaxPixels) * data.touchProximityYNearbyRatio));
            this.mXThreshold90 = this.mYThreshold0;
            this.mXThreshold270 = (int) (((float) this.mYMaxPixels) * data.touchProximityYNearbyRatio);
            this.mYThreshold180 = this.mXThreshold270;
            if (this.mYMaxPixels > 0 && this.mYThreshold0 > 0) {
                if (this.mXThreshold270 < this.mYMaxPixels) {
                    this.mInited = true;
                }
            }
            android.util.Slog.e("TouchProximityDetector", "init the threeshold failed, invalid parameter value");
            this.mInited = false;
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("TouchProximityDetector", "getStableDisplaySize failed ");
        }
    }

    public void enable() {
        if (this.mInited && !this.mEnable) {
            this.mCurrentLuxValid = true;
            this.mEnable = true;
            this.mPointerEventListener.clear();
            this.mWindowManagerService.registerPointerEventListener(this.mPointerEventListener);
            this.mHwInnerWindowManagerService.registerRotateObserver(this.mIHwRotateObserver);
            if (HWFLOW) {
                android.util.Slog.i("TouchProximityDetector", "enable()");
            }
        }
    }

    public void disable() {
        if (this.mInited && this.mEnable) {
            this.mWindowManagerService.unregisterPointerEventListener(this.mPointerEventListener);
            this.mHwInnerWindowManagerService.unregisterRotateObserver(this.mIHwRotateObserver);
            this.mPointerEventListener.clear();
            this.mEnable = false;
            if (HWFLOW) {
                android.util.Slog.i("TouchProximityDetector", "disable()");
            }
        }
    }

    public boolean isCurrentLuxValid() {
        if (!this.mInited) {
            return true;
        }
        continueInvalidPrint(this.mCurrentLuxValid ^ 1);
        return this.mCurrentLuxValid;
    }

    public void startNextLux() {
        if (this.mInited) {
            this.mCurrentLuxValid = this.mPointerEventListener.isCovered() ^ 1;
        }
    }

    private void setCurrentLuxInvalid() {
        this.mCurrentLuxValid = false;
    }

    private void continueInvalidPrint(boolean isInvalid) {
        if (isInvalid) {
            int i = this.mContinueInvalidCnt + 1;
            this.mContinueInvalidCnt = i;
            if (i % this.mContinueInvalidPrintPeriod == 0 && HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("lux continue invalid for ");
                stringBuilder.append(this.mContinueInvalidCnt);
                stringBuilder.append(" times");
                android.util.Slog.i("TouchProximityDetector", stringBuilder.toString());
                return;
            }
            return;
        }
        this.mContinueInvalidCnt = 0;
    }
}
