package com.android.server.fingerprint.fingerprintAnimation;

public class GLHelper {
    private static final int BUFFER_SIZE = 32768;
    private static final boolean LOGGER_ON = false;
    private static final java.lang.String TAG = "GLHelper";

    private static int compileShader(int type, java.lang.String shaderCode) {
        int shaderObjectId = android.opengl.GLES20.glCreateShader(type);
        if (shaderObjectId == 0) {
            return 0;
        }
        android.opengl.GLES20.glShaderSource(shaderObjectId, shaderCode);
        android.opengl.GLES20.glCompileShader(shaderObjectId);
        int[] compileStatus = new int[1];
        android.opengl.GLES20.glGetShaderiv(shaderObjectId, 35713, compileStatus, 0);
        if (compileStatus[0] != 0) {
            return shaderObjectId;
        }
        android.opengl.GLES20.glDeleteShader(shaderObjectId);
        return 0;
    }

    private static int linkProgram(int vertexShaderId, int fragmentShaderId) {
        int programObjectId = android.opengl.GLES20.glCreateProgram();
        if (programObjectId == 0) {
            return 0;
        }
        android.opengl.GLES20.glAttachShader(programObjectId, vertexShaderId);
        android.opengl.GLES20.glAttachShader(programObjectId, fragmentShaderId);
        android.opengl.GLES20.glLinkProgram(programObjectId);
        int[] linkStatus = new int[1];
        android.opengl.GLES20.glGetProgramiv(programObjectId, 35714, linkStatus, 0);
        if (linkStatus[0] != 0) {
            return programObjectId;
        }
        android.opengl.GLES20.glDeleteProgram(programObjectId);
        return 0;
    }

    private static boolean validateProgram(int programObjectId) {
        android.opengl.GLES20.glValidateProgram(programObjectId);
        int[] validateStatus = new int[1];
        android.opengl.GLES20.glGetProgramiv(programObjectId, 35715, validateStatus, 0);
        if (validateStatus[0] != 0) {
            return true;
        }
        return false;
    }

    public static int buildProgram(java.lang.String vertexShaderSource, java.lang.String fragmentShaderSource) {
        int program = linkProgram(compileShader(35633, vertexShaderSource), compileShader(35632, fragmentShaderSource));
        validateProgram(program);
        return program;
    }

    public static int loadTexture(android.content.Context context, int resourceId) {
        android.graphics.BitmapFactory.Options options = new android.graphics.BitmapFactory.Options();
        options.inScaled = false;
        return loadTexture(android.graphics.BitmapFactory.decodeResource(context.getResources(), resourceId, options));
    }

    public static int loadTexture(android.graphics.Bitmap bitmap) {
        int[] textureObjectIds = new int[1];
        android.opengl.GLES20.glGenTextures(1, textureObjectIds, 0);
        if (textureObjectIds[0] == 0) {
            return 0;
        }
        android.opengl.GLES20.glBindTexture(3553, textureObjectIds[0]);
        android.opengl.GLES20.glTexParameteri(3553, 10241, 9987);
        android.opengl.GLES20.glTexParameteri(3553, 10240, 9729);
        android.opengl.GLES20.glTexParameteri(3553, 10242, 33071);
        android.opengl.GLES20.glTexParameteri(3553, 10243, 33071);
        android.opengl.GLUtils.texImage2D(3553, 0, 6408, bitmap, 5121, 0);
        android.opengl.GLES20.glGenerateMipmap(3553);
        android.opengl.GLES20.glBindTexture(3553, 0);
        return textureObjectIds[0];
    }

    public static java.lang.String loadShaderSource(android.content.Context context, java.lang.String fileName) {
        if (context == null) {
            android.util.Log.w("GLHelper", "readShaderSource context is null");
            return "";
        }
        android.content.res.AssetManager assetManager = context.getAssets();
        if (assetManager == null) {
            android.util.Log.w("GLHelper", "readShaderSource asset is null");
            return "";
        }
        java.io.InputStream inputStream = null;
        java.io.InputStreamReader inputStreamReader = null;
        java.io.Reader reader = null;
        java.io.Writer writer = new java.io.StringWriter();
        char[] buffer = new char[32768];
        try {
            inputStream = assetManager.open(fileName);
            if (inputStream != null) {
                inputStreamReader = new java.io.InputStreamReader(inputStream, "UTF-8");
                reader = new java.io.BufferedReader(inputStreamReader);
                while (true) {
                    int read = reader.read(buffer);
                    int readLength = read;
                    if (read == -1) {
                        break;
                    }
                    writer.write(buffer, 0, readLength);
                }
                java.lang.String result = writer.toString();
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (java.io.IOException e) {
                        android.util.Log.e("GLHelper", "loadShaderSource, IOException when close inputStream");
                    }
                }
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e2) {
                    android.util.Log.e("GLHelper", "loadShaderSource, IOException when close inputStreamReader");
                }
                try {
                    reader.close();
                } catch (java.io.IOException e3) {
                    android.util.Log.e("GLHelper", "loadShaderSource, IOException when close reader");
                }
                return result;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Error: Null InputStream from app's asset manager:");
            stringBuilder.append(fileName);
            throw new java.lang.RuntimeException(stringBuilder.toString());
        } catch (java.io.IOException e4) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("Error: Cannot get InputStream from app's asset manager:");
            stringBuilder2.append(fileName);
            throw new java.lang.RuntimeException(stringBuilder2.toString());
        } catch (Throwable th) {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (java.io.IOException e5) {
                    android.util.Log.e("GLHelper", "loadShaderSource, IOException when close inputStream");
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e6) {
                    android.util.Log.e("GLHelper", "loadShaderSource, IOException when close inputStreamReader");
                }
            }
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e7) {
                    android.util.Log.e("GLHelper", "loadShaderSource, IOException when close reader");
                }
            }
        }
    }

    public static void setVertexAttributePointer(java.nio.FloatBuffer floatBuffer, int dataOffset, int attributeLocation, int componentCount, int stride) {
        floatBuffer.position(dataOffset);
        android.opengl.GLES20.glVertexAttribPointer(attributeLocation, componentCount, 5126, false, stride, floatBuffer);
        android.opengl.GLES20.glEnableVertexAttribArray(attributeLocation);
        floatBuffer.position(0);
    }
}
