package com.android.server.fingerprint.fingerprintAnimation;

public class WaterEffectRender implements android.opengl.GLSurfaceView.Renderer {
    private static final long ANIM_DURATION = 200;
    private static final long ANIM_IN_DURATION = 200;
    private static final long ANIM_OUT_DURATION = 1000;
    private static final int A_POSITION_LOCATION = 0;
    private static final int BYTES_PER_FLOAT = 4;
    private static final boolean DEBUG = true;
    private static final boolean DEBUG_PER = false;
    private static final float DIFFUSE_FACTOR = 0.15f;
    private static final float[] LIGHT_COLOR = new float[]{1.0f, 1.0f, 1.0f, 1.0f};
    private static final float LIGHT_DEGREE = 64.0f;
    private static final int RECT_STRIDE = 8;
    private static final float SPACE_SCALE = 1.2f;
    private static final float SPECULAR_FACTOR = 0.85f;
    private static final java.lang.String TAG = "WaterEffectRender";
    private static final float WAVE_CYCLE_DURATION_F = 1500.0f;
    private static final int WAVE_CYCLE_DURATION_I = 1500;
    private static final float WAVE_START_PHASE_OFFSET = 0.35f;
    private static final float WAVE_START_RADIUS = 0.2f;
    private float mAlpha;
    private android.animation.ObjectAnimator mAnimator;
    private float mCenterX;
    private float mCenterY;
    private android.content.Context mContext;
    private float mDiffuseFactor;
    private float mDrawRadius;
    private int mHeight;
    private float mLightDegree;
    private float[] mLightDirection;
    private boolean mPaused;
    private float mPhaseOffset;
    private int mProgram;
    private float[] mProjectionMatrix = new float[16];
    private java.nio.FloatBuffer mRectBuffer;
    private float[] mRectData = new float[]{-1.0f, 2.0f, -1.0f, -2.0f, 1.0f, 2.0f, 1.0f, 2.0f, -1.0f, -2.0f, 1.0f, -2.0f};
    private com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.ReverseInterpolator mReverseInterpolator = new com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.ReverseInterpolator(200, 200, 1000);
    private boolean mShouldDrawNext;
    private float mSpecularFactor;
    private long mStartTime;
    private int mWidth;
    private float mXOffset;
    private float mYOffset;
    private int uAlpha;
    private int uDiffuseFactor;
    private int uLightColor;
    private int uLightDirection;
    private int uMvpMatrix;
    private int uPhaseOffset;
    private int uRadius;
    private int uSpecularFactor;
    private int uXOffset;
    private int uYOffset;

    private static class ReverseInterpolator implements android.animation.TimeInterpolator {
        float mFirstPoint = 0.0f;
        float mFirstScale = 0.0f;
        float mSecondPoint = 1.0f;
        float mSecondScale = 0.0f;
        android.animation.TimeInterpolator mStandardInterpolator = new android.view.animation.PathInterpolator(0.4f, 0.0f, 0.2f, 1.0f);

        public float getInterpolation(float input) {
            if (input < this.mFirstPoint) {
                return this.mStandardInterpolator.getInterpolation(this.mFirstScale * input);
            }
            if (input >= this.mFirstPoint && input < this.mSecondPoint) {
                return 1.0f;
            }
            if (input >= this.mSecondPoint) {
                return 1.0f - this.mStandardInterpolator.getInterpolation((input - this.mSecondPoint) * this.mSecondScale);
            }
            return 0.0f;
        }

        ReverseInterpolator(long inDuration, long animDuration, long outDuration) {
            long total = (inDuration + animDuration) + outDuration;
            if (inDuration >= 0 && animDuration >= 0 && outDuration >= 0 && total > 0) {
                this.mFirstPoint = (((float) inDuration) * 1.0f) / ((float) total);
                this.mSecondPoint = (((float) (inDuration + animDuration)) * 1.0f) / ((float) total);
            }
            if (this.mFirstPoint > 0.0f) {
                this.mFirstScale = 1.0f / this.mFirstPoint;
            }
            if (this.mSecondPoint < 1.0f) {
                this.mSecondScale = 1.0f / (1.0f - this.mSecondPoint);
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("ReverseInterpolator: ");
            stringBuilder.append(this.mFirstPoint);
            stringBuilder.append("  ");
            stringBuilder.append(this.mFirstScale);
            stringBuilder.append("  ");
            stringBuilder.append(this.mSecondPoint);
            stringBuilder.append("  ");
            stringBuilder.append(this.mSecondScale);
            android.util.Log.d("WaterEffectRender", stringBuilder.toString());
        }
    }

    public WaterEffectRender(android.content.Context context) {
        this.mContext = context;
        synchronized (this) {
            this.mPaused = true;
            this.mStartTime = 0;
            setAlpha(0.0f);
            this.mCenterX = 0.0f;
            this.mCenterY = 0.0f;
            this.mWidth = 0;
            this.mHeight = 0;
            updateOffset();
        }
        setDiffuseFactor(0.15f);
        setSpecularFactor(0.85f);
        setLightDegree(64.0f);
    }

    public synchronized void setAlpha(float alpha) {
        if (alpha < 0.0f) {
            try {
                this.mAlpha = 0.0f;
            } catch (Throwable th) {
            }
        } else if (alpha > 1.0f) {
            this.mAlpha = 1.0f;
        } else {
            this.mAlpha = alpha;
        }
    }

    public void setDiffuseFactor(float value) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setDiffuseFactor: value = ");
        stringBuilder.append(value);
        android.util.Log.d("WaterEffectRender", stringBuilder.toString());
        if (value < 0.0f) {
            this.mDiffuseFactor = 0.0f;
        } else if (value > 1.0f) {
            this.mDiffuseFactor = 1.0f;
        } else {
            this.mDiffuseFactor = value;
        }
    }

    public void setSpecularFactor(float value) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setSpecularFactor: value = ");
        stringBuilder.append(value);
        android.util.Log.d("WaterEffectRender", stringBuilder.toString());
        if (value < 0.0f) {
            this.mSpecularFactor = 0.0f;
        } else if (value > 1.0f) {
            this.mSpecularFactor = 1.0f;
        } else {
            this.mSpecularFactor = value;
        }
    }

    public void setLightDegree(float value) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setLightDegree: value = ");
        stringBuilder.append(value);
        android.util.Log.d("WaterEffectRender", stringBuilder.toString());
        if (value < -90.0f) {
            this.mLightDegree = -90.0f;
        } else if (value > 90.0f) {
            this.mLightDegree = 90.0f;
        } else {
            this.mLightDegree = value;
        }
        float theta = (float) (((double) (this.mLightDegree / 180.0f)) * 3.141592653589793d);
        this.mLightDirection = new float[]{0.0f, (float) java.lang.Math.sin((double) theta), (float) java.lang.Math.cos((double) theta)};
    }

    public synchronized void setXOffset(float value) {
        this.mXOffset = value;
    }

    public synchronized void setYOffset(float value) {
        this.mYOffset = value;
    }

    public float getDiffuseFactor() {
        return this.mDiffuseFactor;
    }

    public float getSpecularFactor() {
        return this.mSpecularFactor;
    }

    public float getLightDegree() {
        return this.mLightDegree;
    }

    public synchronized float getXOffset() {
        return this.mXOffset;
    }

    public synchronized float getYOffset() {
        return this.mYOffset;
    }

    private synchronized void updateOffset() {
        if (this.mWidth <= 0 || this.mHeight <= 0) {
            this.mXOffset = 0.0f;
            this.mYOffset = 0.0f;
        } else if (this.mWidth > this.mHeight) {
            this.mXOffset = (1.2f * ((this.mCenterX * 2.0f) - ((float) this.mWidth))) / ((float) this.mHeight);
            this.mYOffset = (-1.2f * ((2.0f * this.mCenterY) - ((float) this.mHeight))) / ((float) this.mHeight);
        } else {
            this.mXOffset = (1.2f * ((this.mCenterX * 2.0f) - ((float) this.mWidth))) / ((float) this.mWidth);
            this.mYOffset = (-1.2f * ((2.0f * this.mCenterY) - ((float) this.mHeight))) / ((float) this.mWidth);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateOffset: xOffset = ");
        stringBuilder.append(this.mXOffset);
        stringBuilder.append(" yOffset = ");
        stringBuilder.append(this.mYOffset);
        android.util.Log.d("WaterEffectRender", stringBuilder.toString());
    }

    public void onSurfaceCreated(javax.microedition.khronos.opengles.GL10 gl, javax.microedition.khronos.egl.EGLConfig config) {
        android.util.Log.d("WaterEffectRender", "onSurfaceCreated: ");
        this.mProgram = com.android.server.fingerprint.fingerprintAnimation.GLHelper.buildProgram(com.android.server.fingerprint.fingerprintAnimation.GLHelper.loadShaderSource(this.mContext, "water.vert"), com.android.server.fingerprint.fingerprintAnimation.GLHelper.loadShaderSource(this.mContext, "water.frag"));
        this.uMvpMatrix = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_mvpMatrix");
        this.uXOffset = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_xOffset");
        this.uYOffset = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_yOffset");
        this.uAlpha = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_alpha");
        this.uPhaseOffset = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_phaseOffset");
        this.uRadius = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_drawRadius");
        this.uLightDirection = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_lightDirection");
        this.uLightColor = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_lightColor");
        this.uDiffuseFactor = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_diffuseFactor");
        this.uSpecularFactor = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "u_specularFactor");
        android.opengl.Matrix.orthoM(this.mProjectionMatrix, 0, -1.0f, 1.0f, -1.0f, 1.0f, -1.0f, 1.0f);
        this.mRectBuffer = java.nio.ByteBuffer.allocateDirect(this.mRectData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mRectData);
    }

    public void onSurfaceChanged(javax.microedition.khronos.opengles.GL10 gl, int width, int height) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onSurfaceChanged: width = ");
        stringBuilder.append(width);
        stringBuilder.append(" height = ");
        stringBuilder.append(height);
        android.util.Log.d("WaterEffectRender", stringBuilder.toString());
        if (width > 0) {
            if (height > 0) {
                float aspectRatio;
                float f;
                float x;
                if (width > height) {
                    aspectRatio = (float) width;
                    f = (float) height;
                } else {
                    aspectRatio = (float) height;
                    f = (float) width;
                }
                aspectRatio /= f;
                if (width > height) {
                    x = 1.2f * aspectRatio;
                    f = 1.2f;
                } else {
                    f = 1.2f * aspectRatio;
                    x = 1.2f;
                }
                android.opengl.Matrix.orthoM(this.mProjectionMatrix, 0, -x, x, -f, f, -1.0f, 1.0f);
                this.mRectData = new float[]{-x, f, -x, -f, x, f, x, f, -x, -f, x, -f};
                this.mRectBuffer = java.nio.ByteBuffer.allocateDirect(this.mRectData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mRectData);
                android.opengl.GLES30.glViewport(0, 0, width, height);
                synchronized (this) {
                    this.mWidth = width;
                    this.mHeight = height;
                    updateOffset();
                }
                return;
            }
        }
        android.util.Log.w("WaterEffectRender", "onSurfaceChanged: width and height should not be zero");
    }

    void playAnim(float centerX, float centerY) {
        playAnim();
        synchronized (this) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("playAnim: centerX = ");
            stringBuilder.append(centerX);
            stringBuilder.append(" centerY = ");
            stringBuilder.append(centerY);
            android.util.Log.d("WaterEffectRender", stringBuilder.toString());
            this.mCenterX = centerX;
            this.mCenterY = centerY;
            updateOffset();
        }
    }

    void playAnim() {
        android.util.Log.d("WaterEffectRender", "playAnim: ");
        if (this.mAnimator != null) {
            this.mAnimator.cancel();
        }
        this.mAnimator = android.animation.ObjectAnimator.ofFloat(this, "alpha", new float[]{0.0f, 1.0f});
        this.mAnimator.setDuration(1400);
        this.mAnimator.setInterpolator(this.mReverseInterpolator);
        this.mAnimator.addListener(new android.animation.AnimatorListenerAdapter() {
            public void onAnimationEnd(android.animation.Animator animation) {
                synchronized (com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.this) {
                    com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.this.mPaused = true;
                    com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.this.mAlpha = 0.0f;
                    com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender.this.mShouldDrawNext = true;
                }
            }

            public void onAnimationCancel(android.animation.Animator animation) {
                animation.removeAllListeners();
            }
        });
        this.mAnimator.start();
        synchronized (this) {
            this.mAlpha = 0.0f;
            this.mStartTime = android.os.SystemClock.elapsedRealtime();
            this.mPaused = false;
        }
    }

    void pauseAnim() {
        if (this.mAnimator != null) {
            this.mAnimator.cancel();
        }
        synchronized (this) {
            this.mPaused = true;
        }
    }

    void clearAnim() {
        synchronized (this) {
            pauseAnim();
            this.mAlpha = 0.0f;
            this.mShouldDrawNext = true;
        }
    }

    boolean shouldRequest() {
        boolean z;
        synchronized (this) {
            if (this.mPaused) {
                if (!this.mShouldDrawNext) {
                    z = false;
                }
            }
            z = true;
        }
        return z;
    }

    public void onDrawFrame(javax.microedition.khronos.opengles.GL10 gl) {
        boolean paused;
        long startTime;
        float alpha;
        float xOffset;
        float yOffset;
        synchronized (this) {
            this.mShouldDrawNext = false;
            paused = this.mPaused;
            startTime = this.mStartTime;
            alpha = this.mAlpha;
            xOffset = this.mXOffset;
            yOffset = this.mYOffset;
        }
        android.opengl.GLES30.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
        android.opengl.GLES30.glClear(16384);
        if (!paused) {
            long duration = android.os.SystemClock.elapsedRealtime() - startTime;
            this.mDrawRadius = (((((float) duration) / 1500.0f) * 2.0f) + 0.2f) + 0.35f;
            this.mPhaseOffset = (2.0f * (((float) (duration % 1500)) / 1500.0f)) + 0.35f;
        }
        if (alpha >= 0.01f) {
            android.opengl.GLES30.glUseProgram(this.mProgram);
            android.opengl.GLES30.glUniformMatrix4fv(this.uMvpMatrix, 1, false, this.mProjectionMatrix, 0);
            android.opengl.GLES30.glUniform1f(this.uXOffset, xOffset);
            android.opengl.GLES30.glUniform1f(this.uYOffset, yOffset);
            android.opengl.GLES30.glUniform1f(this.uAlpha, alpha);
            android.opengl.GLES30.glUniform1f(this.uPhaseOffset, this.mPhaseOffset);
            android.opengl.GLES30.glUniform1f(this.uRadius, this.mDrawRadius);
            android.opengl.GLES30.glUniform3fv(this.uLightDirection, 1, this.mLightDirection, 0);
            android.opengl.GLES30.glUniform4fv(this.uLightColor, 1, LIGHT_COLOR, 0);
            android.opengl.GLES30.glUniform1f(this.uDiffuseFactor, this.mDiffuseFactor);
            android.opengl.GLES30.glUniform1f(this.uSpecularFactor, this.mSpecularFactor);
            com.android.server.fingerprint.fingerprintAnimation.GLHelper.setVertexAttributePointer(this.mRectBuffer, 0, 0, 2, 8);
            android.opengl.GLES30.glEnable(3042);
            android.opengl.GLES30.glBlendFunc(770, 771);
            android.opengl.GLES30.glDrawArrays(4, 0, 6);
            android.opengl.GLES30.glDisable(3042);
        }
    }

    void onPause() {
        clearAnim();
    }

    void onResume() {
        clearAnim();
    }
}
