package com.android.server.fingerprint.fingerprintAnimation;

public class WaterEffectView extends android.opengl.GLSurfaceView {
    private static final boolean DEBUG = true;
    private static final boolean DEBUG_PER = false;
    private static final long DEFAULT_REFRESH_PERIOD = 16;
    private static final int MSG_REQUEST_RENDER = 0;
    private static final java.lang.String TAG = "WaterEffectView";
    private com.android.server.fingerprint.fingerprintAnimation.WaterEffectView.RenderHandler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private long mRefreshPeriod;
    private com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender mRenderer;
    private final java.lang.ref.WeakReference<com.android.server.fingerprint.fingerprintAnimation.WaterEffectView> mThisWeakRef;

    private static class RenderHandler extends android.os.Handler {
        private boolean mQuitting;
        private java.lang.ref.WeakReference<com.android.server.fingerprint.fingerprintAnimation.WaterEffectView> mViewRef;

        private RenderHandler(android.os.Looper looper, java.lang.ref.WeakReference<com.android.server.fingerprint.fingerprintAnimation.WaterEffectView> viewRef) {
            super(looper);
            this.mViewRef = viewRef;
            this.mQuitting = false;
        }

        private void setQuitting(boolean quitting) {
            this.mQuitting = quitting;
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 0) {
                com.android.server.fingerprint.fingerprintAnimation.WaterEffectView view = (com.android.server.fingerprint.fingerprintAnimation.WaterEffectView) this.mViewRef.get();
                if (view != null && view.isRenderWhenDirty()) {
                    view.requestRender();
                    removeMessages(0);
                    if (!this.mQuitting) {
                        sendEmptyMessageDelayed(0, view.getRefreshPeriod());
                    }
                }
            }
        }
    }

    public WaterEffectView(android.content.Context context) {
        this(context, null);
    }

    public WaterEffectView(android.content.Context context, android.util.AttributeSet attrs) {
        super(context, attrs);
        this.mRefreshPeriod = 16;
        this.mThisWeakRef = new java.lang.ref.WeakReference(this);
        init(context);
    }

    private void init(android.content.Context context) {
        if (context == null) {
            android.util.Log.w("WaterEffectView", "init: context is null, cannot finish init");
            return;
        }
        android.app.ActivityManager activityManager = (android.app.ActivityManager) context.getSystemService("activity");
        if (activityManager != null) {
            if (activityManager.getDeviceConfigurationInfo().reqGlEsVersion >= 196608) {
                setEGLContextClientVersion(3);
                setZOrderOnTop(true);
                getHolder().setFormat(1);
                setEGLConfigChooser(8, 8, 8, 8, 16, 0);
                this.mRenderer = new com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender(context);
                setRenderer(this.mRenderer);
                setRenderMode(0);
            }
        }
    }

    public void setYOffset(float value) {
        if (this.mRenderer != null) {
            this.mRenderer.setYOffset(value);
        }
    }

    public void setRefreshPeriod(long refreshPeriod) {
        this.mRefreshPeriod = refreshPeriod;
    }

    public long getRefreshPeriod() {
        return this.mRefreshPeriod;
    }

    public void playAnim() {
        if (this.mRenderer != null) {
            this.mRenderer.playAnim();
        }
    }

    public void playAnim(float x, float y) {
        if (this.mRenderer != null) {
            this.mRenderer.playAnim(x, y);
        }
    }

    public void pauseAnim() {
        if (this.mRenderer != null) {
            this.mRenderer.pauseAnim();
        }
    }

    public void clearAnim() {
        if (this.mRenderer != null) {
            this.mRenderer.clearAnim();
        }
    }

    public com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender getRenderer() {
        return this.mRenderer;
    }

    public void setRenderer(android.opengl.GLSurfaceView.Renderer renderer) {
        super.setRenderer(renderer);
        if (renderer instanceof com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender) {
            this.mRenderer = (com.android.server.fingerprint.fingerprintAnimation.WaterEffectRender) renderer;
            return;
        }
        throw new java.lang.RuntimeException("You must use WaterEffectRenderer");
    }

    public void requestRender() {
        if (this.mRenderer != null && this.mRenderer.shouldRequest()) {
            super.requestRender();
        }
    }

    public void onResume() {
        android.util.Log.d("WaterEffectView", "onResume: ");
        super.onResume();
        if (this.mRenderer != null) {
            this.mRenderer.onResume();
        }
        quitHandlerThread();
        if (isRenderWhenDirty()) {
            this.mHandlerThread = new android.os.HandlerThread("WaterEffect-RenderHandler");
            this.mHandlerThread.start();
            this.mHandler = new com.android.server.fingerprint.fingerprintAnimation.WaterEffectView.RenderHandler(this.mHandlerThread.getLooper(), this.mThisWeakRef);
            this.mHandler.removeMessages(0);
            this.mHandler.sendEmptyMessage(0);
        }
    }

    public void onPause() {
        android.util.Log.d("WaterEffectView", "onPause: ");
        super.onPause();
        if (isRenderWhenDirty()) {
            this.mHandler.removeMessages(0);
        }
        if (this.mRenderer != null) {
            this.mRenderer.onPause();
        }
        quitHandlerThread();
    }

    private void quitHandlerThread() {
        if (this.mHandlerThread != null) {
            this.mHandlerThread.quitSafely();
            this.mHandlerThread = null;
        }
        if (this.mHandler != null) {
            this.mHandler.setQuitting(true);
            this.mHandler = null;
        }
    }

    private boolean isRenderWhenDirty() {
        return getRenderMode() == 0;
    }
}
