package com.android.server.forcerotation;

public class HwForceRotationLayout implements android.view.View.OnSystemUiVisibilityChangeListener {
    private static final java.lang.String KEY_ENABLE_NAVBAR_DB = "enable_navbar";
    private static final java.lang.String TAG = "ForceRotationLayout";
    private final int NAV_BAR_HEIGHT_LAND;
    private final int STATUS_BAR_HEIGHT;
    private android.content.Context mContext;
    private android.view.Display mDisplay;
    private boolean mHwHideNavBar;
    private android.graphics.Rect mLayoutFrame;
    private android.database.ContentObserver mObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            com.android.server.forcerotation.HwForceRotationLayout hwForceRotationLayout = com.android.server.forcerotation.HwForceRotationLayout.this;
            boolean z = false;
            if (android.provider.Settings.System.getInt(com.android.server.forcerotation.HwForceRotationLayout.this.mContext.getContentResolver(), "enable_navbar", 0) <= 0) {
                z = true;
            }
            hwForceRotationLayout.mHwHideNavBar = z;
            com.android.server.forcerotation.HwForceRotationLayout.this.calculateFrame();
        }
    };
    private int mSplitNavigationBarDp;
    private int mSystemUiVisibility;

    public HwForceRotationLayout(android.content.Context context, android.os.Handler uiHandler, com.android.server.forcerotation.HwForceRotationManagerService service) {
        this.mContext = context;
        this.STATUS_BAR_HEIGHT = getResource(context, "status_bar_height", 48);
        this.NAV_BAR_HEIGHT_LAND = getResource(context, "navigation_bar_width", 96);
        boolean z = false;
        if (android.provider.Settings.System.getInt(this.mContext.getContentResolver(), "enable_navbar", 0) <= 0) {
            z = true;
        }
        this.mHwHideNavBar = z;
        this.mSplitNavigationBarDp = 600;
        calculateFrame();
        registerObserver();
    }

    private void calculateFrame() {
        this.mLayoutFrame = new android.graphics.Rect();
        this.mDisplay = ((android.view.WindowManager) this.mContext.getSystemService("window")).getDefaultDisplay();
        android.util.DisplayMetrics dm = new android.util.DisplayMetrics();
        this.mDisplay.getRealMetrics(dm);
        if (dm.widthPixels >= dm.heightPixels) {
            int shortSize = dm.heightPixels;
            int longSize = dm.widthPixels;
            boolean mNavigationBarCanMove = (shortSize * 160) / dm.densityDpi <= this.mSplitNavigationBarDp;
            int statusBarH = getStatusBarHeight();
            int navBarH = getNavBarHeight();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("statusBarH = ");
            stringBuilder.append(statusBarH);
            stringBuilder.append(", navBarH = ");
            stringBuilder.append(navBarH);
            stringBuilder.append(", mNavigationBarCanMove =");
            stringBuilder.append(mNavigationBarCanMove);
            android.util.Slog.v("ForceRotationLayout", stringBuilder.toString());
            if (mNavigationBarCanMove) {
                this.mLayoutFrame.left = ((longSize - shortSize) - navBarH) / 2;
                this.mLayoutFrame.top = statusBarH;
                this.mLayoutFrame.right = ((longSize + shortSize) - navBarH) / 2;
                this.mLayoutFrame.bottom = shortSize;
            } else {
                this.mLayoutFrame.left = (longSize - shortSize) / 2;
                this.mLayoutFrame.top = statusBarH;
                this.mLayoutFrame.right = this.mLayoutFrame.left + shortSize;
                this.mLayoutFrame.bottom = shortSize - navBarH;
            }
        }
    }

    public android.graphics.Rect getForceRotationLayout() {
        if (this.mLayoutFrame == null || this.mLayoutFrame.width() == 0 || this.mLayoutFrame.height() == 0 || this.mLayoutFrame.left == 0) {
            calculateFrame();
        }
        return this.mLayoutFrame;
    }

    public int getStatusBarHeight() {
        return this.STATUS_BAR_HEIGHT;
    }

    public int getNavBarHeight() {
        if (this.mHwHideNavBar || this.mSystemUiVisibility != 0) {
            return 0;
        }
        return this.NAV_BAR_HEIGHT_LAND;
    }

    private int getResource(android.content.Context context, java.lang.String name, int defaultVal) {
        android.content.res.Resources resources = context.getResources();
        int val = defaultVal;
        int resourceId = resources.getIdentifier(name, "dimen", "android");
        if (resourceId > 0) {
            return resources.getDimensionPixelSize(resourceId);
        }
        return val;
    }

    public void onSystemUiVisibilityChange(int visibility) {
        this.mSystemUiVisibility = visibility;
        calculateFrame();
    }

    private void registerObserver() {
        if (this.mContext != null) {
            this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("enable_navbar"), true, this.mObserver);
        }
    }
}
