package com.android.server.gesture;

public class DeviceStateController {
    private static final java.lang.String TAG = "DeviceStateController";
    private static com.android.server.gesture.DeviceStateController sInstance;
    private final android.content.ContentResolver mContentResolver;
    private final android.content.Context mContext;
    private int mCurrentUserId;
    private final android.net.Uri mDeviceProvisionedUri;
    private final java.util.ArrayList<com.android.server.gesture.DeviceStateController.DeviceChangedListener> mListeners = new java.util.ArrayList();
    private com.android.server.policy.WindowManagerPolicy mPolicy;
    private final android.content.BroadcastReceiver mPreferChangedReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            boolean isPrefer;
            if (!"android.intent.action.ACTION_PREFERRED_ACTIVITY_CHANGED".equals(intent.getAction())) {
                isPrefer = false;
            } else if (intent.getIntExtra("android.intent.extra.user_handle", -10000) != -10000) {
                isPrefer = true;
            } else {
                return;
            }
            com.android.server.gesture.DeviceStateController.this.notifyPreferredActivityChanged(isPrefer);
        }
    };
    protected final android.database.ContentObserver mSettingsObserver = new android.database.ContentObserver(new android.os.Handler(android.os.Looper.getMainLooper())) {
        public void onChange(boolean selfChange, android.net.Uri uri, int userId) {
            if (com.android.server.gesture.DeviceStateController.this.mDeviceProvisionedUri.equals(uri)) {
                com.android.server.gesture.DeviceStateController.this.notifyProvisionedChanged(com.android.server.gesture.DeviceStateController.this.isDeviceProvisioned());
            } else if (com.android.server.gesture.DeviceStateController.this.mUserSetupUri.equals(uri)) {
                com.android.server.gesture.DeviceStateController.this.notifySetupChanged(com.android.server.gesture.DeviceStateController.this.isCurrentUserSetup());
            }
        }
    };
    private final android.net.Uri mUserSetupUri;
    private final android.content.BroadcastReceiver mUserSwitchedReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            com.android.server.gesture.DeviceStateController.this.mCurrentUserId = intent.getIntExtra("android.intent.extra.user_handle", 0);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("User swtiched receiver, userId=");
            stringBuilder.append(com.android.server.gesture.DeviceStateController.this.mCurrentUserId);
            android.util.Log.i("DeviceStateController", stringBuilder.toString());
            com.android.server.gesture.DeviceStateController.this.onUserSwitched(com.android.server.gesture.DeviceStateController.this.mCurrentUserId);
        }
    };

    public static abstract class DeviceChangedListener {
        void onDeviceProvisionedChanged(boolean provisioned) {
        }

        void onUserSwitched(int newUserId) {
        }

        void onUserSetupChanged(boolean setup) {
        }

        void onConfigurationChanged() {
        }

        void onPreferredActivityChanged(boolean isPrefer) {
        }
    }

    private DeviceStateController(android.content.Context context) {
        this.mContext = context;
        this.mContentResolver = this.mContext.getContentResolver();
        this.mDeviceProvisionedUri = android.provider.Settings.Global.getUriFor("device_provisioned");
        this.mUserSetupUri = android.provider.Settings.Secure.getUriFor("user_setup_complete");
        this.mCurrentUserId = android.app.ActivityManager.getCurrentUser();
        this.mPolicy = (com.android.server.policy.WindowManagerPolicy) com.android.server.LocalServices.getService(com.android.server.policy.WindowManagerPolicy.class);
    }

    public static com.android.server.gesture.DeviceStateController getInstance(android.content.Context context) {
        com.android.server.gesture.DeviceStateController deviceStateController;
        synchronized (com.android.server.gesture.DeviceStateController.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.gesture.DeviceStateController(context);
            }
            deviceStateController = sInstance;
        }
        return deviceStateController;
    }

    public boolean isDeviceProvisioned() {
        return android.provider.Settings.Global.getInt(this.mContentResolver, "device_provisioned", 0) != 0;
    }

    public boolean isCurrentUserSetup() {
        return android.provider.Settings.Secure.getIntForUser(this.mContentResolver, "user_setup_complete", 0, -2) != 0;
    }

    public int getCurrentUser() {
        return android.app.ActivityManager.getCurrentUser();
    }

    public boolean isKeyguardOccluded() {
        return this.mPolicy.isKeyguardOccluded();
    }

    public boolean isKeyguardSecure() {
        return this.mPolicy.isKeyguardSecure(0);
    }

    public boolean isKeyguardShowingOrOccluded() {
        return this.mPolicy.isKeyguardShowingOrOccluded();
    }

    public boolean isStatusBarKeyguardShowing() {
        return this.mPolicy.isStatusBarKeyguardShowing();
    }

    public boolean isKeyguardLocked() {
        return this.mPolicy.isKeyguardLocked();
    }

    public boolean isKeyguardShowingAndNotOccluded() {
        return this.mPolicy.isKeyguardShowingAndNotOccluded();
    }

    public com.android.server.policy.WindowManagerPolicy.WindowState getFocusWindow() {
        if (this.mPolicy instanceof com.android.server.policy.HwPhoneWindowManager) {
            return this.mPolicy.getFocusedWindow();
        }
        return null;
    }

    public java.lang.String getFocusWindowName() {
        com.android.server.policy.WindowManagerPolicy.WindowState focusWindowState = getFocusWindow();
        if (focusWindowState == null || focusWindowState.getAttrs() == null) {
            return null;
        }
        return focusWindowState.getAttrs().getTitle().toString();
    }

    public java.lang.String getFocusPackageName() {
        com.android.server.policy.WindowManagerPolicy.WindowState focusWindowState = getFocusWindow();
        if (focusWindowState == null || focusWindowState.getAttrs() == null) {
            return null;
        }
        return focusWindowState.getAttrs().packageName;
    }

    public boolean isNavBarAtBottom() {
        return this.mPolicy.getNavBarPosition() == 4;
    }

    public int getSystemUIFlag() {
        if (this.mPolicy instanceof com.android.server.policy.HwPhoneWindowManager) {
            return this.mPolicy.getLastSystemUiFlags();
        }
        return 0;
    }

    public boolean isWindowBackDisabled() {
        return (getSystemUIFlag() & 4194304) != 0;
    }

    public boolean isWindowHomeDisabled() {
        return (getSystemUIFlag() & 2097152) != 0;
    }

    public boolean isWindowRecentDisabled() {
        return (getSystemUIFlag() & 16777216) != 0;
    }

    public java.lang.String getCurrentHomeActivity() {
        return getCurrentHomeActivity(this.mCurrentUserId);
    }

    public java.lang.String getCurrentHomeActivity(int userId) {
        android.content.pm.ResolveInfo resolveInfo = this.mContext.getPackageManager().resolveActivityAsUser(getHomeIntent(), 786432, userId);
        if (resolveInfo == null || resolveInfo.activityInfo == null) {
            return null;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(resolveInfo.activityInfo.packageName);
        stringBuilder.append("/");
        stringBuilder.append(resolveInfo.activityInfo.name);
        return stringBuilder.toString();
    }

    public void onConfigurationChanged() {
        notifyConfigurationChanged();
    }

    public void addCallback(com.android.server.gesture.DeviceStateController.DeviceChangedListener listener) {
        this.mListeners.add(listener);
        if (this.mListeners.size() == 1) {
            startListening(getCurrentUser());
        }
        listener.onDeviceProvisionedChanged(isDeviceProvisioned());
        listener.onUserSetupChanged(isCurrentUserSetup());
    }

    public void removeCallback(com.android.server.gesture.DeviceStateController.DeviceChangedListener listener) {
        this.mListeners.remove(listener);
        if (this.mListeners.size() == 0) {
            stopListening();
        }
    }

    private void registerObserver(int userId) {
        this.mContentResolver.registerContentObserver(this.mDeviceProvisionedUri, true, this.mSettingsObserver, 0);
        this.mContentResolver.registerContentObserver(this.mUserSetupUri, true, this.mSettingsObserver, userId);
    }

    private void startListening(int userId) {
        android.util.Log.i("DeviceStateController", "start listening.");
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("android.intent.action.USER_SWITCHED");
        this.mContext.registerReceiver(this.mUserSwitchedReceiver, filter, null, null);
        filter = new android.content.IntentFilter("android.intent.action.ACTION_PREFERRED_ACTIVITY_CHANGED");
        filter.setPriority(1000);
        this.mContext.registerReceiver(this.mPreferChangedReceiver, filter, null, null);
        android.content.IntentFilter packageFilter = new android.content.IntentFilter("android.intent.action.PACKAGE_CHANGED");
        packageFilter.addDataScheme("package");
        this.mContext.registerReceiver(this.mPreferChangedReceiver, packageFilter, null, null);
        registerObserver(userId);
    }

    private void stopListening() {
        this.mContext.unregisterReceiver(this.mUserSwitchedReceiver);
        this.mContext.unregisterReceiver(this.mPreferChangedReceiver);
        this.mContentResolver.unregisterContentObserver(this.mSettingsObserver);
        android.util.Log.i("DeviceStateController", "stop listening.");
    }

    private void onUserSwitched(int newUserId) {
        this.mContentResolver.unregisterContentObserver(this.mSettingsObserver);
        registerObserver(newUserId);
        notifyUserChanged(newUserId);
    }

    private void notifyUserChanged(int newUserId) {
        for (int i = this.mListeners.size() - 1; i >= 0; i--) {
            ((com.android.server.gesture.DeviceStateController.DeviceChangedListener) this.mListeners.get(i)).onUserSwitched(newUserId);
        }
    }

    private void notifyProvisionedChanged(boolean provisioned) {
        for (int i = this.mListeners.size() - 1; i >= 0; i--) {
            ((com.android.server.gesture.DeviceStateController.DeviceChangedListener) this.mListeners.get(i)).onDeviceProvisionedChanged(provisioned);
        }
    }

    private void notifySetupChanged(boolean setup) {
        for (int i = this.mListeners.size() - 1; i >= 0; i--) {
            ((com.android.server.gesture.DeviceStateController.DeviceChangedListener) this.mListeners.get(i)).onUserSetupChanged(setup);
        }
    }

    private void notifyConfigurationChanged() {
        for (int i = this.mListeners.size() - 1; i >= 0; i--) {
            ((com.android.server.gesture.DeviceStateController.DeviceChangedListener) this.mListeners.get(i)).onConfigurationChanged();
        }
    }

    private void notifyPreferredActivityChanged(boolean isPrefer) {
        for (int i = this.mListeners.size() - 1; i >= 0; i--) {
            ((com.android.server.gesture.DeviceStateController.DeviceChangedListener) this.mListeners.get(i)).onPreferredActivityChanged(isPrefer);
        }
    }

    private android.content.Intent getHomeIntent() {
        android.content.Intent intent = new android.content.Intent("android.intent.action.MAIN");
        intent.addCategory("android.intent.category.HOME");
        intent.addCategory("android.intent.category.DEFAULT");
        return intent;
    }
}
