package com.android.server.gesture;

public class GestureNavAnimProxy implements com.android.server.gesture.GestureNavView.IGestureNavBackAnim {
    private static final int DEFAULT_ANIM_MAX_TIME = 2000;
    private static final int MSG_ANIM_TIMEOUT = 1;
    private static final java.lang.String TAG = "GestureNavAnim";
    private com.android.server.gesture.anim.GLGestureBackView mBackAnimView;
    private com.android.server.gesture.GestureNavAnimProxy.GestureAnimContainer mBackContainer;
    private android.content.Context mContext;
    private boolean mGestureNavReady;
    private android.os.Handler mHandler;
    private final java.lang.Object mLock = new java.lang.Object();
    private com.android.server.gesture.GestureNavView.WindowConfig mWindowConfig = new com.android.server.gesture.GestureNavView.WindowConfig();
    private android.view.WindowManager mWindowManager;
    private boolean mWindowViewSetuped;

    interface AnimContainerListener {
        void onAttachedToWindow();

        void onDetachedFromWindow();
    }

    private final class AnimHandler extends android.os.Handler {
        public AnimHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                android.util.Log.i("GestureNavAnim", "animation timeout, force hide views");
                com.android.server.gesture.GestureNavAnimProxy.this.showBackContainer(false);
            }
        }
    }

    static class GestureAnimContainer extends android.widget.FrameLayout {
        private com.android.server.gesture.GestureNavAnimProxy.AnimContainerListener mListener;

        public GestureAnimContainer(android.content.Context context) {
            super(context);
        }

        public void setListener(com.android.server.gesture.GestureNavAnimProxy.AnimContainerListener listener) {
            this.mListener = listener;
        }

        protected void onAttachedToWindow() {
            super.onAttachedToWindow();
            if (this.mListener != null) {
                this.mListener.onAttachedToWindow();
            }
        }

        protected void onDetachedFromWindow() {
            super.onDetachedFromWindow();
            if (this.mListener != null) {
                this.mListener.onDetachedFromWindow();
            }
        }
    }

    private final class AnimContainerListenerImpl implements com.android.server.gesture.GestureNavAnimProxy.AnimContainerListener {
        private AnimContainerListenerImpl() {
        }

        public void onAttachedToWindow() {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                android.util.Log.d("GestureNavAnim", "container attached to window");
            }
            if (com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView != null) {
                com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView.onResume();
            }
        }

        public void onDetachedFromWindow() {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                android.util.Log.d("GestureNavAnim", "container detached from window");
            }
            if (com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView != null) {
                com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView.onPause();
            }
        }
    }

    private final class GestureBackAnimListenerImpl implements com.android.server.gesture.anim.GLGestureBackView.GestureBackAnimListener {
        private GestureBackAnimListenerImpl() {
        }

        public void onAnimationEnd(int animType) {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("back anim end, animType=");
                stringBuilder.append(animType);
                android.util.Log.d("GestureNavAnim", stringBuilder.toString());
            }
            com.android.server.gesture.GestureNavAnimProxy.this.mHandler.removeMessages(1);
            if (com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView != null) {
                com.android.server.gesture.GestureNavAnimProxy.this.mBackAnimView.setDraw(false);
            }
            com.android.server.gesture.GestureNavAnimProxy.this.showBackContainer(false);
        }
    }

    public GestureNavAnimProxy(android.content.Context context, android.os.Looper looper) {
        this.mContext = context;
        this.mHandler = new com.android.server.gesture.GestureNavAnimProxy.AnimHandler(looper);
        this.mWindowManager = (android.view.WindowManager) this.mContext.getSystemService("window");
    }

    private void showBackContainer(boolean show) {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("showBackContainer show=");
            stringBuilder.append(show);
            android.util.Log.d("GestureNavAnim", stringBuilder.toString());
        }
        if (this.mBackContainer != null) {
            this.mBackContainer.setVisibility(show ? 0 : 8);
        }
    }

    private void updateGestureNavAnimWindow() {
        synchronized (this.mLock) {
            updateAnimWindowLocked();
        }
    }

    private void updateAnimWindowLocked() {
        if (this.mGestureNavReady) {
            if (this.mWindowViewSetuped) {
                updateAnimWindows();
            } else {
                createAnimWindows();
            }
        } else if (this.mWindowViewSetuped) {
            destroyNavWindows();
        }
    }

    private void createAnimWindows() {
        android.util.Log.i("GestureNavAnim", "createAnimWindows");
        this.mBackContainer = new com.android.server.gesture.GestureNavAnimProxy.GestureAnimContainer(this.mContext);
        this.mBackContainer.setListener(new com.android.server.gesture.GestureNavAnimProxy.AnimContainerListenerImpl());
        this.mBackAnimView = new com.android.server.gesture.anim.GLGestureBackView(this.mContext);
        this.mBackAnimView.addAnimationListener(new com.android.server.gesture.GestureNavAnimProxy.GestureBackAnimListenerImpl());
        this.mBackContainer.addView(this.mBackAnimView, -1, -1);
        com.android.server.gesture.GestureUtils.addWindowView(this.mWindowManager, this.mBackContainer, createLayoutParams("GestureNavAnim", this.mWindowConfig));
        showBackContainer(false);
        this.mWindowViewSetuped = true;
    }

    private void updateAnimWindows() {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            android.util.Log.d("GestureNavAnim", "updateAnimWindows");
        }
        com.android.server.gesture.GestureUtils.updateViewLayout(this.mWindowManager, this.mBackContainer, createLayoutParams("GestureNavAnim", this.mWindowConfig));
    }

    private void destroyNavWindows() {
        android.util.Log.i("GestureNavAnim", "destroyNavWindows");
        this.mWindowViewSetuped = false;
        showBackContainer(false);
        com.android.server.gesture.GestureUtils.removeWindowView(this.mWindowManager, this.mBackContainer, true);
        this.mBackContainer = null;
    }

    private android.view.WindowManager.LayoutParams createLayoutParams(java.lang.String title, com.android.server.gesture.GestureNavView.WindowConfig config) {
        android.view.WindowManager.LayoutParams lp = new android.view.WindowManager.LayoutParams(2024, 312);
        if (android.app.ActivityManager.isHighEndGfx()) {
            lp.flags |= 16777216;
        }
        lp.format = -2;
        lp.gravity = 51;
        lp.x = config.startX;
        lp.y = config.startY;
        lp.width = config.width;
        lp.height = config.height;
        lp.windowAnimations = 0;
        lp.softInputMode = 49;
        lp.setTitle(title);
        if (config.usingNotch) {
            lp.hwFlags |= 65536;
        } else {
            lp.hwFlags &= -65537;
        }
        return lp;
    }

    public void updateViewConfig(int _displayWidth, int _displayHeight, int _startX, int _startY, int _width, int _height, int _locationOnScreenX, int _locationOnScreenY) {
        synchronized (this.mLock) {
            this.mWindowConfig.update(_displayWidth, _displayHeight, _startX, _startY, _width, _height, _locationOnScreenX, _locationOnScreenY);
        }
    }

    public void updateViewNotchState(boolean usingNotch) {
        synchronized (this.mLock) {
            this.mWindowConfig.udpateNotch(usingNotch);
        }
    }

    public void onNavCreate() {
        this.mGestureNavReady = true;
        updateGestureNavAnimWindow();
    }

    public void onNavUpdate() {
        updateGestureNavAnimWindow();
    }

    public void onNavDestroy() {
        this.mGestureNavReady = false;
        updateGestureNavAnimWindow();
    }

    public void onGestureAction(boolean down) {
    }

    public void setSide(boolean isLeft) {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setSide isLeft=");
            stringBuilder.append(isLeft);
            android.util.Log.d("GestureNavAnim", stringBuilder.toString());
        }
        if (this.mBackAnimView != null) {
            this.mBackAnimView.setSide(isLeft);
        }
    }

    public void setAnimPosition(float y) {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setAnimPosition y=");
            stringBuilder.append(y);
            android.util.Log.d("GestureNavAnim", stringBuilder.toString());
        }
        if (this.mBackAnimView != null) {
            showBackContainer(true);
            this.mBackAnimView.setDraw(true);
            this.mHandler.removeMessages(1);
            this.mBackAnimView.setAnimPosition(y);
        }
    }

    public boolean setAnimProcess(float process) {
        if (this.mBackAnimView == null) {
            return false;
        }
        this.mBackAnimView.setAnimProcess(process);
        return true;
    }

    public void playDisappearAnim() {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            android.util.Log.d("GestureNavAnim", "playDisappearAnim");
        }
        if (this.mBackAnimView != null) {
            if (!this.mHandler.hasMessages(1)) {
                this.mHandler.sendEmptyMessageDelayed(1, 2000);
            }
            this.mBackAnimView.playDisappearAnim();
        }
    }

    public void playFastSlidingAnim() {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            android.util.Log.d("GestureNavAnim", "playFastSlidingAnim");
        }
        if (this.mBackAnimView != null) {
            if (!this.mHandler.hasMessages(1)) {
                this.mHandler.sendEmptyMessageDelayed(1, 2000);
            }
            this.mBackAnimView.playFastSlidingAnim();
        }
    }
}
