package com.android.server.gesture;

public class GestureNavBackStrategy extends com.android.server.gesture.GestureNavBaseStrategy {
    private static final int MSG_CHECK_HAPTICS_VIBRATOR = 1;
    private boolean mAnimPositionSetup;
    private boolean mAnimProcessedOnce;
    private boolean mAnimProcessing;
    private android.os.Handler mBackHandler;
    private int mBackMaxDistance1;
    private int mBackMaxDistance2;
    private com.android.server.gesture.GestureNavView.IGestureNavBackAnim mGestureNavBackAnim;

    private final class BackHandler extends android.os.Handler {
        public BackHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                com.android.server.gesture.GestureUtils.playHwEffectForBackIfNeed(com.android.server.gesture.GestureNavBackStrategy.this.mContext);
            }
        }
    }

    public GestureNavBackStrategy(int navId, android.content.Context context, android.os.Looper looper, com.android.server.gesture.GestureNavView.IGestureNavBackAnim backAnim) {
        super(navId, context, looper);
        this.mGestureNavBackAnim = backAnim;
        this.mBackHandler = new com.android.server.gesture.GestureNavBackStrategy.BackHandler(looper);
    }

    public void updateConfig(int displayWidth, int displayHeight, android.graphics.Rect r) {
        super.updateConfig(displayWidth, displayHeight, r);
        this.mBackMaxDistance1 = com.android.server.gesture.GestureNavConst.getBackMaxDistance1(this.mContext);
        this.mBackMaxDistance2 = com.android.server.gesture.GestureNavConst.getBackMaxDistance2(this.mContext);
        if (com.android.server.gesture.GestureNavConst.DEBUG_ALL) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("distance1:");
            stringBuilder.append(this.mBackMaxDistance1);
            stringBuilder.append(", distance2:");
            stringBuilder.append(this.mBackMaxDistance2);
            android.util.Log.d("GestureNav_Back", stringBuilder.toString());
        }
    }

    protected void onGestureStarted(float rawX, float rawY) {
        super.onGestureStarted(rawX, rawY);
        boolean z = false;
        this.mAnimPositionSetup = false;
        this.mAnimProcessing = false;
        this.mAnimProcessedOnce = true;
        com.android.server.gesture.GestureNavView.IGestureNavBackAnim iGestureNavBackAnim = this.mGestureNavBackAnim;
        if (this.mNavId == 1) {
            z = true;
        }
        iGestureNavBackAnim.setSide(z);
    }

    protected void onGestureReallyStarted() {
        super.onGestureReallyStarted();
        if (!this.mAnimPositionSetup) {
            this.mAnimPositionSetup = true;
            this.mGestureNavBackAnim.setAnimPosition(this.mTouchDownRawY);
        }
    }

    protected void onGestureSlowProcessStarted(java.util.ArrayList<java.lang.Float> pendingMoveDistance) {
        super.onGestureSlowProcessStarted(pendingMoveDistance);
        if (!this.mAnimProcessing) {
            this.mAnimProcessing = true;
        }
        if (pendingMoveDistance != null) {
            int size = pendingMoveDistance.size();
            int size2 = size;
            if (size > 0) {
                for (size = 0; size < size2; size++) {
                    notifyAnimProcess(((java.lang.Float) pendingMoveDistance.get(size)).floatValue());
                }
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("interpolate ");
                    stringBuilder.append(size2);
                    stringBuilder.append(" pending datas");
                    android.util.Log.d("GestureNav_Back", stringBuilder.toString());
                }
            }
        }
    }

    protected void onGestureSlowProcess(float distance, float offsetX, float offsetY) {
        super.onGestureSlowProcess(distance, offsetX, offsetY);
        notifyAnimProcess(distance);
    }

    protected void onGestureFailed(int reason, boolean failedInEventEnd) {
        super.onGestureFailed(reason, failedInEventEnd);
        if (this.mAnimPositionSetup) {
            android.util.Log.d("GestureNav_Back", "gesture failed, disappear anim");
            this.mGestureNavBackAnim.playDisappearAnim();
        }
        android.util.Flog.bdReport(this.mContext, 854, com.android.server.gesture.GestureNavConst.reportResultStr(false, this.mNavId));
    }

    protected void onGestureSuccessFinished(float distance, long durationTime, float velocity, boolean isFastSlideGesture) {
        super.onGestureSuccessFinished(distance, durationTime, velocity, isFastSlideGesture);
        checkHwHapticsVibrator();
        sendKeyEvent(4);
        if (this.mAnimProcessing) {
            if (this.mAnimProcessedOnce) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    android.util.Log.d("GestureNav_Back", "gesture finished, disappear anim");
                }
                this.mGestureNavBackAnim.playDisappearAnim();
                android.util.Flog.bdReport(this.mContext, 854, com.android.server.gesture.GestureNavConst.reportResultStr(true, this.mNavId));
            }
        }
        if (isFastSlideGesture) {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("gesture finished, play fast anim, velocity=");
                stringBuilder.append(velocity);
                android.util.Log.d("GestureNav_Back", stringBuilder.toString());
            }
            if (!this.mAnimPositionSetup) {
                this.mAnimPositionSetup = true;
                this.mGestureNavBackAnim.setAnimPosition(this.mTouchDownRawY);
            }
            this.mGestureNavBackAnim.playFastSlidingAnim();
        } else {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                android.util.Log.d("GestureNav_Back", "velocity does not meet the threshold, disappear anim");
            }
            this.mGestureNavBackAnim.playDisappearAnim();
        }
        android.util.Flog.bdReport(this.mContext, 854, com.android.server.gesture.GestureNavConst.reportResultStr(true, this.mNavId));
    }

    private void notifyAnimProcess(float distance) {
        float process = getBubberbandProcess(distance);
        boolean success = this.mGestureNavBackAnim.setAnimProcess(process);
        if (!this.mAnimProcessedOnce && success) {
            this.mAnimProcessedOnce = true;
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG_ALL) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("process=");
            stringBuilder.append(process);
            stringBuilder.append(", distance=");
            stringBuilder.append(distance);
            stringBuilder.append(", animOnce=");
            stringBuilder.append(this.mAnimProcessedOnce);
            android.util.Log.d("GestureNav_Back", stringBuilder.toString());
        }
    }

    private float getBubberbandProcess(float distance) {
        if (distance < 0.0f) {
            return 0.0f;
        }
        if (distance < ((float) this.mBackMaxDistance1)) {
            return (distance / ((float) this.mBackMaxDistance1)) * 0.88f;
        }
        return 0.88f + (android.util.MathUtils.constrain((distance - ((float) this.mBackMaxDistance1)) / ((float) (this.mBackMaxDistance2 - this.mBackMaxDistance1)), 0.0f, 1.0f) * 0.120000005f);
    }

    private void checkHwHapticsVibrator() {
        if (!this.mBackHandler.hasMessages(1)) {
            this.mBackHandler.sendEmptyMessage(1);
        }
    }
}
