package com.android.server.gesture;

public class GestureNavBaseStrategy {
    public static final int GESTURE_FAIL_REASON_ANGLE_TOO_LARGE = 2;
    public static final int GESTURE_FAIL_REASON_MULTI_TOUCH = 6;
    public static final int GESTURE_FAIL_REASON_SLIDE_CANCEL = 5;
    public static final int GESTURE_FAIL_REASON_SLIDE_TOO_SHORT = 4;
    public static final int GESTURE_FAIL_REASON_TIMEOUT = 1;
    public static final int GESTURE_FAIL_REASON_UNKNOWN = 0;
    public static final int GESTURE_FAIL_REASON_UP_IN_REGION = 3;
    private static final int MAX_PENDING_DATA_SIZE = 30;
    private static final int MSG_COMPENSATE_MOVE_EVENT = 2;
    private static final int MSG_COMPENSATE_SINGLE_EVENT = 1;
    private static final int MSG_PRECHECK_FAST_SLIDING_TIMEOUT = 4;
    private static final int MSG_SEND_KEY_EVENT = 3;
    private static final int PENDING_DATA_SIZE_TOO_SMALL = 4;
    private final int SLIDE_EXCEED_MAJOR_AXIS_THRESHOLD;
    private final int SLIDE_EXCEED_MINOR_AXIS_THRESHOLD;
    private final int SLIDE_NOT_EXCEED_THRESHOLD;
    private boolean mCheckDistanceY;
    protected android.content.Context mContext;
    private int mDeviceId;
    protected int mDisplayHeight;
    protected int mDisplayWidth;
    protected boolean mFastSlideMajorAxisChecking;
    protected final float mFastVelocityThreshold;
    protected boolean mGestureEnd;
    protected boolean mGestureFailed;
    protected int mGestureFailedReason;
    protected boolean mGestureSlowProcessStarted;
    protected boolean mGestureSuccessFinished;
    protected boolean mGuestureReallyStarted;
    private boolean mHasChangeTimeoutWhenSlideOut;
    private boolean mHasCheckAngle;
    private boolean mHasCheckTimeout;
    protected boolean mHasMultiTouched;
    protected boolean mIsFastSlideGesture;
    protected boolean mKeyguardShowing;
    private float mLastPendingDistance;
    protected android.os.Looper mLooper;
    protected final int mMaximumVelocity;
    private int mMoveOutTimeThreshold;
    private int mMultiTouchThreshold;
    protected int mNavId;
    protected java.util.ArrayList<java.lang.Float> mPendingMoveDistance;
    protected java.util.ArrayList<android.graphics.PointF> mPendingMovePoints;
    protected boolean mPreCheckingFastSlideTimeout;
    private int mSlideOutThresholdMajorAxis;
    private int mSlideOutThresholdMinorAxis;
    private int mSlideUpThreshold;
    private int mSource;
    private android.os.Handler mStrategyHandler;
    protected float mTouchCurrentRawX;
    protected float mTouchCurrentRawY;
    protected float mTouchDownRawX;
    protected float mTouchDownRawY;
    private android.graphics.Rect mTouchDownRegion;
    protected long mTouchDownTime;
    protected long mTouchFailedTime;
    protected float mTouchUpRawX;
    protected float mTouchUpRawY;
    protected long mTouchUpTime;
    private boolean mUseProxyAngleStrategy;
    protected android.view.VelocityTracker mVelocityTracker;
    private float mXOffset;
    private float mYOffset;

    protected static final class PointEvent {
        public int action;
        public int deviceId;
        public long downTime;
        public long durationTime;
        public float endX;
        public float endY;
        public int source;
        public float startX;
        public float startY;

        public PointEvent(float _startX, float _startY, long _downTime, int _action, int _deviceId, int _source) {
            this.startX = _startX;
            this.startY = _startY;
            this.endX = 0.0f;
            this.endY = 0.0f;
            this.downTime = _downTime;
            this.durationTime = 0;
            this.action = _action;
            this.deviceId = _deviceId;
            this.source = _source;
        }

        public PointEvent(float _startX, float _startY, float _endX, float _endY, long _time, int _deviceId, int _source) {
            this.startX = _startX;
            this.startY = _startY;
            this.endX = _endX;
            this.endY = _endY;
            this.downTime = 0;
            this.durationTime = _time;
            this.action = 0;
            this.deviceId = _deviceId;
            this.source = _source;
        }
    }

    private final class StrategyHandler extends android.os.Handler {
        public StrategyHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 1:
                    com.android.server.gesture.GestureNavBaseStrategy.this.compensateSingleEvent((com.android.server.gesture.GestureNavBaseStrategy.PointEvent) msg.obj);
                    return;
                case 2:
                    com.android.server.gesture.GestureNavBaseStrategy.this.checkCompensateEvent((com.android.server.gesture.GestureNavBaseStrategy.PointEvent) msg.obj, null, false);
                    return;
                case 3:
                    com.android.server.gesture.GestureUtils.sendKeyEvent(msg.arg1);
                    return;
                case 4:
                    if (com.android.server.gesture.GestureNavConst.DEBUG) {
                        android.util.Log.i("GestureNav_Strategy", "precheck fast sliding timeout");
                    }
                    com.android.server.gesture.GestureNavBaseStrategy.this.mPreCheckingFastSlideTimeout = true;
                    return;
                default:
                    return;
            }
        }
    }

    public GestureNavBaseStrategy(int navId, android.content.Context context) {
        this(navId, context, android.os.Looper.getMainLooper());
    }

    public GestureNavBaseStrategy(int navId, android.content.Context context, android.os.Looper looper) {
        this.mTouchDownRegion = new android.graphics.Rect();
        boolean z = false;
        this.mDeviceId = 0;
        this.mSource = 4098;
        this.mPendingMoveDistance = new java.util.ArrayList();
        this.mPendingMovePoints = new java.util.ArrayList();
        this.SLIDE_NOT_EXCEED_THRESHOLD = 0;
        this.SLIDE_EXCEED_MAJOR_AXIS_THRESHOLD = 1;
        this.SLIDE_EXCEED_MINOR_AXIS_THRESHOLD = 2;
        this.mNavId = navId;
        this.mContext = context;
        this.mLooper = looper;
        if (this.mNavId == 3) {
            z = true;
        }
        this.mCheckDistanceY = z;
        this.mStrategyHandler = new com.android.server.gesture.GestureNavBaseStrategy.StrategyHandler(looper);
        this.mMaximumVelocity = android.view.ViewConfiguration.get(context).getScaledMaximumFlingVelocity();
        this.mFastVelocityThreshold = 10.0f * ((float) android.view.ViewConfiguration.get(context).getScaledMinimumFlingVelocity());
    }

    protected void sendKeyEvent(int keycode) {
        sendKeyEvent(keycode, false);
    }

    protected void sendKeyEvent(int keycode, boolean async) {
        if (async) {
            this.mStrategyHandler.sendMessage(this.mStrategyHandler.obtainMessage(3, keycode, 0, null));
            return;
        }
        com.android.server.gesture.GestureUtils.sendKeyEvent(keycode);
    }

    public void updateDeviceState(boolean keyguardShowing) {
        this.mKeyguardShowing = keyguardShowing;
    }

    public void onNavCreate(com.android.server.gesture.GestureNavView view) {
    }

    public void onNavUpdate() {
    }

    public void onNavDestroy() {
    }

    public void updateConfig(int displayWidth, int displayHeight, android.graphics.Rect r) {
        this.mDisplayWidth = displayWidth;
        this.mDisplayHeight = displayHeight;
        this.mTouchDownRegion.set(r);
        int windowThreshold = this.mCheckDistanceY ? this.mTouchDownRegion.height() : this.mTouchDownRegion.width();
        this.mSlideOutThresholdMajorAxis = ((int) (((float) windowThreshold) * 1.2f)) + slipOutThresholdOffset();
        this.mSlideOutThresholdMinorAxis = ((int) (((float) windowThreshold) * 1.6f)) + slipOutThresholdOffset();
        this.mSlideUpThreshold = ((int) (((float) windowThreshold) * 2.0f)) + slipOverThresholdOffset();
        this.mMultiTouchThreshold = ((int) (((float) windowThreshold) * 3.0f)) + slipOverThresholdOffset();
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("navId:");
            stringBuilder.append(this.mNavId);
            stringBuilder.append(", width:");
            stringBuilder.append(this.mDisplayWidth);
            stringBuilder.append(", height:");
            stringBuilder.append(this.mDisplayHeight);
            stringBuilder.append(", region:");
            stringBuilder.append(r);
            stringBuilder.append(", slipOutMajor:");
            stringBuilder.append(this.mSlideOutThresholdMajorAxis);
            stringBuilder.append(", slipOutMinor:");
            stringBuilder.append(this.mSlideOutThresholdMinorAxis);
            stringBuilder.append(", slipUp:");
            stringBuilder.append(this.mSlideUpThreshold);
            android.util.Log.d("GestureNav_Strategy", stringBuilder.toString());
        }
    }

    protected android.graphics.Rect getRegion() {
        return this.mTouchDownRegion;
    }

    protected boolean frameContainsPoint(float x, float y) {
        return this.mTouchDownRegion.contains((int) x, (int) y);
    }

    protected int slipOutThresholdOffset() {
        return 0;
    }

    protected int slipOverThresholdOffset() {
        return 0;
    }

    protected int moveOutAngleThreshold() {
        return 70;
    }

    protected int moveOutTimeThreshold(boolean useMinTime) {
        int i = 120;
        if (useMinTime) {
            return 120;
        }
        if (this.mCheckDistanceY) {
            i = 250;
        }
        return i;
    }

    protected int distanceExceedThreshold(float distanceX, float distanceY) {
        float distanceMajor = this.mCheckDistanceY ? distanceY : distanceX;
        float distanceMinor = this.mCheckDistanceY ? distanceX : distanceY;
        if (distanceMajor > ((float) this.mSlideOutThresholdMajorAxis)) {
            return 1;
        }
        if (distanceMinor > ((float) this.mSlideOutThresholdMinorAxis)) {
            return 2;
        }
        return 0;
    }

    protected float fastVelocityTheshold() {
        return this.mCheckDistanceY ? 4500.0f : 6000.0f;
    }

    protected int fastTimeoutTheshold() {
        return this.mCheckDistanceY ? 250 : 200;
    }

    protected void setUseProxyAngleStrategy(boolean useProxyAngleStrategy) {
        this.mUseProxyAngleStrategy = useProxyAngleStrategy;
    }

    protected boolean shouldDropMultiTouch() {
        return false;
    }

    protected boolean isMultiTouchBad(android.view.MotionEvent event) {
        int actionIndex = event.getActionIndex();
        float rawX = event.getX(actionIndex) - this.mXOffset;
        float rawY = event.getY(actionIndex) - this.mYOffset;
        float distance = java.lang.Math.abs(this.mCheckDistanceY ? rawY - this.mTouchCurrentRawY : rawX - this.mTouchCurrentRawX);
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("MultiTouch rawX=");
            stringBuilder.append(rawX);
            stringBuilder.append(", rawY=");
            stringBuilder.append(rawY);
            stringBuilder.append(", distance=");
            stringBuilder.append(distance);
            android.util.Log.d("GestureNav_Strategy", stringBuilder.toString());
        }
        return distance > ((float) this.mMultiTouchThreshold);
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        int action = event.getActionMasked();
        if (action != 5) {
            switch (action) {
                case 0:
                    handleActionDown(event);
                    break;
                case 1:
                case 3:
                    handleActionUp(event, action);
                    break;
                case 2:
                    handleActionMove(event);
                    break;
                default:
                    break;
            }
        }
        handleMultiTouchDown(event);
        return this.mGestureFailed;
    }

    private void handleActionDown(android.view.MotionEvent event) {
        gestureReset();
        this.mTouchDownTime = event.getEventTime();
        this.mTouchDownRawX = event.getRawX();
        this.mTouchDownRawY = event.getRawY();
        this.mXOffset = event.getX() - this.mTouchDownRawX;
        this.mYOffset = event.getY() - this.mTouchDownRawY;
        this.mTouchCurrentRawX = this.mTouchDownRawX;
        this.mTouchCurrentRawY = this.mTouchDownRawY;
        this.mDeviceId = event.getDeviceId();
        this.mSource = event.getSource();
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Down rawX=");
            stringBuilder.append(this.mTouchDownRawX);
            stringBuilder.append(", rawY=");
            stringBuilder.append(this.mTouchDownRawY);
            stringBuilder.append(", rect=");
            stringBuilder.append(getRegion());
            stringBuilder.append(", navId=");
            stringBuilder.append(this.mNavId);
            stringBuilder.append(", xOffset=");
            stringBuilder.append(this.mXOffset);
            stringBuilder.append(", yOffset=");
            stringBuilder.append(this.mYOffset);
            android.util.Log.d("GestureNav_Strategy", stringBuilder.toString());
        }
        this.mVelocityTracker = android.view.VelocityTracker.obtain();
        if (this.mVelocityTracker != null) {
            this.mVelocityTracker.addMovement(event);
        }
        onGestureStarted(this.mTouchDownRawX, this.mTouchDownRawY);
    }

    private void handleMultiTouchDown(android.view.MotionEvent event) {
        if (!this.mHasMultiTouched) {
            this.mHasMultiTouched = true;
        }
        if (!this.mGestureFailed && !this.mGuestureReallyStarted) {
            if (shouldDropMultiTouch() || isMultiTouchBad(event)) {
                int pointerCount = event.getPointerCount();
                int count = pointerCount;
                if (pointerCount > 1) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Multi touch pointer down, count=");
                    stringBuilder.append(count);
                    android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(" ,pointerCount=");
                    stringBuilder2.append(count);
                    gestureFailed(6, false, stringBuilder2.toString(), event.getEventTime());
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:56:0x018f  */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x0280  */
    private void handleActionMove(android.view.MotionEvent r24) {
        /*
        r23 = this;
        r6 = r23;
        r7 = r24;
        r0 = r6.mVelocityTracker;
        if (r0 == 0) goto L_0x000d;
    L_0x0008:
        r0 = r6.mVelocityTracker;
        r0.addMovement(r7);
    L_0x000d:
        r0 = r24.getRawX();
        r6.mTouchCurrentRawX = r0;
        r0 = r24.getRawY();
        r6.mTouchCurrentRawY = r0;
        r0 = r6.mTouchCurrentRawX;
        r1 = r6.mTouchDownRawX;
        r8 = r0 - r1;
        r0 = r6.mTouchCurrentRawY;
        r1 = r6.mTouchDownRawY;
        r9 = r0 - r1;
        r10 = r6.distanceX(r8);
        r11 = r6.distanceY(r9);
        r12 = r6.diff(r10, r11);
        r0 = com.android.server.gesture.GestureNavConst.DEBUG_ALL;
        if (r0 == 0) goto L_0x005f;
    L_0x0035:
        r0 = "GestureNav_Strategy";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "Move rawX=";
        r1.append(r2);
        r2 = r6.mTouchCurrentRawX;
        r1.append(r2);
        r2 = ", rawY=";
        r1.append(r2);
        r2 = r6.mTouchCurrentRawY;
        r1.append(r2);
        r2 = ", distance=";
        r1.append(r2);
        r1.append(r12);
        r1 = r1.toString();
        android.util.Log.d(r0, r1);
    L_0x005f:
        r0 = r6.mGestureFailed;
        if (r0 != 0) goto L_0x006e;
    L_0x0063:
        r0 = r6.mGestureSlowProcessStarted;
        if (r0 != 0) goto L_0x006e;
    L_0x0067:
        r0 = r6.mTouchCurrentRawX;
        r1 = r6.mTouchCurrentRawY;
        r6.recordPendingMoveDatas(r7, r12, r0, r1);
    L_0x006e:
        r0 = r6.mPreCheckingFastSlideTimeout;
        if (r0 == 0) goto L_0x0084;
    L_0x0072:
        r0 = r6.mFastSlideMajorAxisChecking;
        if (r0 == 0) goto L_0x0084;
    L_0x0076:
        r0 = com.android.server.gesture.GestureNavConst.DEBUG;
        if (r0 == 0) goto L_0x0081;
    L_0x007a:
        r0 = "GestureNav_Strategy";
        r1 = "cancel fast check when move arrived after timeout";
        android.util.Log.d(r0, r1);
    L_0x0081:
        r0 = 0;
        r6.mFastSlideMajorAxisChecking = r0;
    L_0x0084:
        r0 = 0;
        r1 = r6.mUseProxyAngleStrategy;
        r13 = 1;
        if (r1 != 0) goto L_0x016b;
    L_0x008a:
        r1 = r6.mGestureFailed;
        if (r1 != 0) goto L_0x016b;
    L_0x008e:
        r1 = r6.mHasCheckAngle;
        if (r1 != 0) goto L_0x016b;
    L_0x0092:
        r1 = r6.distanceExceedThreshold(r10, r11);
        r14 = r1;
        if (r1 != r13) goto L_0x0168;
    L_0x0099:
        r6.mHasCheckAngle = r13;
        r0 = java.lang.Math.abs(r8);
        r1 = java.lang.Math.abs(r9);
        r4 = r6.angle(r0, r1);
        r15 = 0;
        r16 = 0;
        r0 = r23.moveOutAngleThreshold();
        r0 = (double) r0;
        r0 = (r4 > r0 ? 1 : (r4 == r0 ? 0 : -1));
        if (r0 <= 0) goto L_0x00d3;
    L_0x00b3:
        r1 = 2;
        r2 = 0;
        r0 = new java.lang.StringBuilder;
        r0.<init>();
        r3 = ", angle=";
        r0.append(r3);
        r0.append(r4);
        r3 = r0.toString();
        r18 = r24.getEventTime();
        r0 = r6;
        r20 = r4;
        r4 = r18;
        r0.gestureFailed(r1, r2, r3, r4);
        goto L_0x010f;
    L_0x00d3:
        r20 = r4;
        r0 = r6.mHasCheckTimeout;
        if (r0 != 0) goto L_0x010f;
    L_0x00d9:
        r6.mHasCheckTimeout = r13;
        r0 = r6.mVelocityTracker;
        if (r0 == 0) goto L_0x00eb;
    L_0x00df:
        r1 = 1000; // 0x3e8 float:1.401E-42 double:4.94E-321;
        r2 = r6.mMaximumVelocity;
        r2 = (float) r2;
        r0.computeCurrentVelocity(r1, r2);
        r15 = r6.getVelocity(r0);
    L_0x00eb:
        r1 = r23.fastVelocityTheshold();
        r1 = (r15 > r1 ? 1 : (r15 == r1 ? 0 : -1));
        if (r1 <= 0) goto L_0x010f;
    L_0x00f3:
        r1 = r24.getEventTime();
        r3 = r6.mTouchDownTime;
        r1 = r1 - r3;
        r3 = r23.fastTimeoutTheshold();
        r3 = (long) r3;
        r3 = r3 - r1;
        r16 = 0;
        r5 = (r3 > r16 ? 1 : (r3 == r16 ? 0 : -1));
        if (r5 <= 0) goto L_0x0111;
    L_0x0106:
        r6.mFastSlideMajorAxisChecking = r13;
        r5 = r6.mStrategyHandler;
        r13 = 4;
        r5.sendEmptyMessageDelayed(r13, r3);
        goto L_0x0111;
    L_0x010f:
        r3 = r16;
    L_0x0111:
        r0 = "GestureNav_Strategy";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "angle:";
        r1.append(r2);
        r22 = r12;
        r12 = r20;
        r1.append(r12);
        r2 = ", velocity:";
        r1.append(r2);
        r1.append(r15);
        r2 = ", checkTimeout:";
        r1.append(r2);
        r2 = r6.mHasCheckTimeout;
        r1.append(r2);
        r2 = ", fastChecking:";
        r1.append(r2);
        r2 = r6.mFastSlideMajorAxisChecking;
        r1.append(r2);
        r2 = ", delayTime:";
        r1.append(r2);
        r1.append(r3);
        r2 = ", slipOutMode:";
        r1.append(r2);
        r1.append(r14);
        r2 = ", distanceX:";
        r1.append(r2);
        r1.append(r10);
        r2 = ", distanceY:";
        r1.append(r2);
        r1.append(r11);
        r1 = r1.toString();
        android.util.Log.i(r0, r1);
        goto L_0x0179;
    L_0x0168:
        r22 = r12;
        goto L_0x016e;
    L_0x016b:
        r22 = r12;
        r14 = r0;
    L_0x016e:
        r0 = r6.mUseProxyAngleStrategy;
        if (r0 == 0) goto L_0x0179;
    L_0x0172:
        r0 = r6.mHasCheckAngle;
        if (r0 != 0) goto L_0x0179;
    L_0x0176:
        r0 = 1;
        r6.mHasCheckAngle = r0;
    L_0x0179:
        r0 = 0;
        r2 = 2;
        if (r14 != r2) goto L_0x018b;
    L_0x017e:
        r2 = r6.mHasChangeTimeoutWhenSlideOut;
        if (r2 != 0) goto L_0x018b;
    L_0x0182:
        r2 = 1;
        r6.mHasChangeTimeoutWhenSlideOut = r2;
        r3 = r6.moveOutTimeThreshold(r2);
        r6.mMoveOutTimeThreshold = r3;
    L_0x018b:
        r2 = r6.mGestureFailed;
        if (r2 != 0) goto L_0x0264;
    L_0x018f:
        r2 = r6.mHasCheckTimeout;
        if (r2 != 0) goto L_0x0264;
    L_0x0193:
        r2 = r24.getEventTime();
        r4 = r6.mTouchDownTime;
        r2 = r2 - r4;
        r12 = r2;
        r0 = r6.mMoveOutTimeThreshold;
        r0 = (long) r0;
        r0 = (r2 > r0 ? 1 : (r2 == r0 ? 0 : -1));
        if (r0 <= 0) goto L_0x0265;
    L_0x01a2:
        r0 = 1;
        r6.mHasCheckTimeout = r0;
        r15 = 0;
        r0 = r6.mTouchCurrentRawX;
        r1 = r6.mTouchCurrentRawY;
        r0 = r6.frameContainsPoint(r0, r1);
        if (r0 == 0) goto L_0x01e6;
    L_0x01b1:
        r1 = 1;
        r2 = 0;
        r0 = new java.lang.StringBuilder;
        r0.<init>();
        r3 = ", time=";
        r0.append(r3);
        r0.append(r12);
        r3 = "ms, point(";
        r0.append(r3);
        r3 = r6.mTouchCurrentRawX;
        r0.append(r3);
        r3 = ", ";
        r0.append(r3);
        r3 = r6.mTouchCurrentRawY;
        r0.append(r3);
        r3 = ")";
        r0.append(r3);
        r3 = r0.toString();
        r4 = r24.getEventTime();
        r0 = r6;
        r0.gestureFailed(r1, r2, r3, r4);
        goto L_0x0226;
    L_0x01e6:
        r0 = r6.mHasCheckAngle;
        if (r0 != 0) goto L_0x0226;
    L_0x01ea:
        r0 = 1;
        r6.mHasCheckAngle = r0;
        r0 = java.lang.Math.abs(r8);
        r1 = java.lang.Math.abs(r9);
        r4 = r6.angle(r0, r1);
        r0 = r23.moveOutAngleThreshold();
        r0 = (double) r0;
        r0 = (r4 > r0 ? 1 : (r4 == r0 ? 0 : -1));
        if (r0 <= 0) goto L_0x0221;
    L_0x0202:
        r1 = 2;
        r2 = 0;
        r0 = new java.lang.StringBuilder;
        r0.<init>();
        r3 = ", timeout angle=";
        r0.append(r3);
        r0.append(r4);
        r3 = r0.toString();
        r15 = r24.getEventTime();
        r0 = r6;
        r17 = r4;
        r4 = r15;
        r0.gestureFailed(r1, r2, r3, r4);
        goto L_0x0223;
    L_0x0221:
        r17 = r4;
    L_0x0223:
        r0 = r17;
        goto L_0x0227;
    L_0x0226:
        r0 = r15;
    L_0x0227:
        r2 = "GestureNav_Strategy";
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r4 = "move out time:";
        r3.append(r4);
        r3.append(r12);
        r4 = "ms, threshold:";
        r3.append(r4);
        r4 = r6.mMoveOutTimeThreshold;
        r3.append(r4);
        r4 = "ms, point(";
        r3.append(r4);
        r4 = r6.mTouchCurrentRawX;
        r3.append(r4);
        r4 = ", ";
        r3.append(r4);
        r4 = r6.mTouchCurrentRawY;
        r3.append(r4);
        r4 = "), angle:";
        r3.append(r4);
        r3.append(r0);
        r3 = r3.toString();
        android.util.Log.i(r2, r3);
        goto L_0x0265;
    L_0x0264:
        r12 = r0;
    L_0x0265:
        r0 = r6.mGuestureReallyStarted;
        if (r0 != 0) goto L_0x027c;
    L_0x0269:
        r0 = r23.gestureReady();
        if (r0 == 0) goto L_0x027c;
    L_0x026f:
        r0 = "GestureNav_Strategy";
        r1 = "gesture really started";
        android.util.Log.i(r0, r1);
        r0 = 1;
        r6.mGuestureReallyStarted = r0;
        r23.onGestureReallyStarted();
    L_0x027c:
        r0 = r6.mGuestureReallyStarted;
        if (r0 == 0) goto L_0x029d;
    L_0x0280:
        r0 = r6.mFastSlideMajorAxisChecking;
        if (r0 != 0) goto L_0x029d;
    L_0x0284:
        r0 = r6.mGestureSlowProcessStarted;
        if (r0 != 0) goto L_0x0297;
    L_0x0288:
        r0 = "GestureNav_Strategy";
        r1 = "gesture slow process started";
        android.util.Log.i(r0, r1);
        r0 = 1;
        r6.mGestureSlowProcessStarted = r0;
        r0 = r6.mPendingMoveDistance;
        r6.onGestureSlowProcessStarted(r0);
    L_0x0297:
        r0 = r22;
        r6.onGestureSlowProcess(r0, r8, r9);
        goto L_0x029f;
    L_0x029d:
        r0 = r22;
    L_0x029f:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.gesture.GestureNavBaseStrategy.handleActionMove(android.view.MotionEvent):void");
    }

    private void handleActionUp(android.view.MotionEvent event, int action) {
        this.mTouchUpTime = event.getEventTime();
        this.mTouchUpRawX = event.getRawX();
        this.mTouchUpRawY = event.getRawY();
        this.mTouchCurrentRawX = this.mTouchUpRawX;
        this.mTouchCurrentRawY = this.mTouchUpRawY;
        this.mStrategyHandler.removeMessages(4);
        float velocity = 0.0f;
        if (this.mVelocityTracker != null) {
            this.mVelocityTracker.addMovement(event);
            this.mVelocityTracker.computeCurrentVelocity(1000, (float) this.mMaximumVelocity);
            velocity = getVelocity(this.mVelocityTracker);
            this.mVelocityTracker.recycle();
            this.mVelocityTracker = null;
        }
        if (this.mGestureFailed && action == 1 && this.mGestureFailedReason != 6) {
            android.util.Log.i("GestureNav_Strategy", "Receive up after gesture failed");
            onGestureUpArrivedAfterFailed(this.mTouchUpRawX, this.mTouchUpRawY, this.mTouchDownTime);
        }
        if (!(this.mGestureFailed || this.mGuestureReallyStarted || !frameContainsPoint(this.mTouchUpRawX, this.mTouchUpRawY))) {
            gestureFailed(3, true, "", this.mTouchUpTime);
        }
        float distance = diff(this.mTouchDownRawX, this.mTouchDownRawY, this.mTouchUpRawX, this.mTouchUpRawY);
        if (!(this.mGestureFailed || this.mGuestureReallyStarted || distance >= ((float) this.mSlideUpThreshold))) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(", distance:");
            stringBuilder.append(distance);
            gestureFailed(4, true, stringBuilder.toString(), this.mTouchUpTime);
        }
        long durationTime = this.mTouchUpTime - this.mTouchDownTime;
        if (!this.mGestureFailed && this.mGuestureReallyStarted && ((distance < ((float) this.mSlideUpThreshold) && durationTime > 150) || action == 3)) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(", duration:");
            stringBuilder2.append(durationTime);
            stringBuilder2.append("ms, distance:");
            stringBuilder2.append(distance);
            stringBuilder2.append(", action:");
            stringBuilder2.append(action);
            gestureFailed(5, true, stringBuilder2.toString(), this.mTouchUpTime);
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("Up rawX=");
            stringBuilder3.append(this.mTouchUpRawX);
            stringBuilder3.append(", rawY=");
            stringBuilder3.append(this.mTouchUpRawY);
            stringBuilder3.append(", failed=");
            stringBuilder3.append(this.mGestureFailed);
            stringBuilder3.append(", rellayStarted=");
            stringBuilder3.append(this.mGuestureReallyStarted);
            stringBuilder3.append(", velocity=");
            stringBuilder3.append(velocity);
            stringBuilder3.append(", distance=");
            stringBuilder3.append(distance);
            stringBuilder3.append(", duration=");
            stringBuilder3.append(durationTime);
            android.util.Log.d("GestureNav_Strategy", stringBuilder3.toString());
        }
        gestureFinished(distance, durationTime, velocity);
        gestureEnd(action);
    }

    private void gestureReset() {
        this.mGestureFailed = false;
        this.mHasCheckTimeout = false;
        this.mHasCheckAngle = false;
        this.mGuestureReallyStarted = false;
        this.mGestureSlowProcessStarted = false;
        this.mGestureEnd = false;
        this.mGestureSuccessFinished = false;
        this.mGestureFailedReason = 0;
        this.mIsFastSlideGesture = false;
        this.mPreCheckingFastSlideTimeout = false;
        this.mFastSlideMajorAxisChecking = false;
        this.mUseProxyAngleStrategy = false;
        this.mHasChangeTimeoutWhenSlideOut = false;
        this.mHasMultiTouched = false;
        this.mMoveOutTimeThreshold = moveOutTimeThreshold(false);
        this.mStrategyHandler.removeMessages(4);
        this.mLastPendingDistance = 0.0f;
        this.mPendingMoveDistance.clear();
        this.mPendingMovePoints.clear();
    }

    private void gestureFailed(int reason, boolean failedInEventEnd, java.lang.String appendStr, long failedTime) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(translateFailedReason(reason));
        stringBuilder.append(appendStr);
        android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
        this.mGestureFailedReason = reason;
        this.mTouchFailedTime = failedTime;
        this.mGestureFailed = true;
        onGestureFailed(this.mGestureFailedReason, failedInEventEnd);
    }

    protected boolean gestureReady() {
        return !this.mGestureFailed && this.mHasCheckTimeout && this.mHasCheckAngle;
    }

    private void gestureFinished(float distance, long durationTime, float velocity) {
        if (!this.mGestureFailed) {
            if (!this.mGestureSlowProcessStarted && (this.mFastSlideMajorAxisChecking || velocity > 6000.0f)) {
                this.mIsFastSlideGesture = true;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("gesture success, reallyStarted=");
            stringBuilder.append(this.mGuestureReallyStarted);
            stringBuilder.append(", slowStarted=");
            stringBuilder.append(this.mGestureSlowProcessStarted);
            stringBuilder.append(", velocity=");
            stringBuilder.append(velocity);
            stringBuilder.append(", fastChecking=");
            stringBuilder.append(this.mFastSlideMajorAxisChecking);
            stringBuilder.append(", fastGesture=");
            stringBuilder.append(this.mIsFastSlideGesture);
            android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
            this.mGestureSuccessFinished = true;
            onGestureSuccessFinished(distance, durationTime, velocity, this.mIsFastSlideGesture);
        }
    }

    private void gestureEnd(int action) {
        this.mGestureEnd = true;
        this.mPendingMoveDistance.clear();
        this.mPendingMovePoints.clear();
        onGestureEnd(action);
    }

    protected void onGestureStarted(float rawX, float rawY) {
    }

    protected void onGestureReallyStarted() {
    }

    protected void onGestureSlowProcessStarted(java.util.ArrayList<java.lang.Float> arrayList) {
    }

    protected void onGestureSlowProcess(float distance, float offsetX, float offsetY) {
    }

    protected void onGestureFailed(int reason, boolean failedInEventEnd) {
        switch (reason) {
            case 0:
                return;
            case 1:
            case 2:
                compensateBatchDownEvent(this.mTouchDownRawX, this.mTouchDownRawY, this.mPendingMovePoints, this.mTouchDownTime, this.mTouchFailedTime - this.mTouchDownTime, this.mDeviceId, this.mSource);
                return;
            case 3:
            case 4:
                long durationTime = this.mTouchFailedTime - this.mTouchDownTime;
                if (durationTime < 500) {
                    checkCompensateEvent(new com.android.server.gesture.GestureNavBaseStrategy.PointEvent(this.mTouchDownRawX, this.mTouchDownRawY, this.mTouchUpRawX, this.mTouchUpRawY, durationTime, this.mDeviceId, this.mSource), this.mPendingMovePoints, this.mHasMultiTouched);
                    return;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("no need compensate as duration time is too long, duration:");
                stringBuilder.append(durationTime);
                android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
                return;
            case 5:
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    android.util.Log.d("GestureNav_Strategy", "gesture cancel, no need process");
                    return;
                }
                return;
            case 6:
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    android.util.Log.d("GestureNav_Strategy", "multi touch, no need process");
                    return;
                }
                return;
            default:
                return;
        }
    }

    protected void onGestureSuccessFinished(float distance, long durationTime, float velocity, boolean isFastSlideGesture) {
    }

    protected void onGestureEnd(int action) {
    }

    protected void onGestureUpArrivedAfterFailed(float rawX, float rawY, long pointDownTime) {
        this.mStrategyHandler.sendMessage(this.mStrategyHandler.obtainMessage(1, 0, 0, new com.android.server.gesture.GestureNavBaseStrategy.PointEvent(rawX, rawY, pointDownTime, 1, this.mDeviceId, this.mSource)));
    }

    private void compensateSingleEvent(com.android.server.gesture.GestureNavBaseStrategy.PointEvent p) {
        long j;
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("compensateSingleEvent x=");
            stringBuilder.append(p.startX);
            stringBuilder.append(", y=");
            stringBuilder.append(p.startY);
            stringBuilder.append(", action=");
            stringBuilder.append(p.action);
            android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
        }
        if (p.action == 0) {
            j = p.downTime;
        } else {
            j = android.os.SystemClock.uptimeMillis();
        }
        com.android.server.gesture.GestureUtils.injectMotionEvent(p.action, p.downTime, j, p.startX, p.startY, p.deviceId, p.source);
    }

    private void compensateBatchDownEvent(float startX, float startY, java.util.ArrayList<android.graphics.PointF> pendingMovePoints, long downTime, long durationTime, int deviceId, int source) {
        float f;
        float f2;
        long j;
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("compensateBatchDownEvent x=");
            f = startX;
            stringBuilder.append(f);
            stringBuilder.append(", y=");
            f2 = startY;
            stringBuilder.append(f2);
            stringBuilder.append(", durationTime=");
            j = durationTime;
            stringBuilder.append(j);
            android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
        } else {
            f = startX;
            f2 = startY;
            j = durationTime;
        }
        com.android.server.gesture.GestureUtils.injectDownWithBatchMoveEvent(downTime, f, f2, pendingMovePoints, j, deviceId, source);
    }

    private void checkCompensateEvent(com.android.server.gesture.GestureNavBaseStrategy.PointEvent p, java.util.ArrayList<android.graphics.PointF> pendingMovePoints, boolean hasMultiTouched) {
        int distance = distance(p.startX, p.startY, p.endX, p.endY);
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkCompensateEvent distance=");
            stringBuilder.append(distance);
            android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
        }
        if (distance < 15) {
            compensateTapEvent(p);
        } else {
            compensateMoveEvent(p, pendingMovePoints, hasMultiTouched);
        }
    }

    private void compensateTapEvent(com.android.server.gesture.GestureNavBaseStrategy.PointEvent p) {
        com.android.server.gesture.GestureUtils.sendTap(p.startX, p.startY, p.deviceId, p.source);
    }

    private void compensateMoveEvent(com.android.server.gesture.GestureNavBaseStrategy.PointEvent p, java.util.ArrayList<android.graphics.PointF> pendingMovePoints, boolean hasMultiTouched) {
        java.util.ArrayList arrayList;
        boolean canUsePendingPoints = true;
        if (pendingMovePoints == null) {
            canUsePendingPoints = false;
        } else if (pendingMovePoints.size() >= 30 || pendingMovePoints.size() < 4) {
            canUsePendingPoints = false;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("pending points size:");
                stringBuilder.append(pendingMovePoints.size());
                android.util.Log.i("GestureNav_Strategy", stringBuilder.toString());
            }
        }
        float f = p.startX;
        float f2 = p.startY;
        float f3 = p.endX;
        float f4 = p.endY;
        int i = (int) p.durationTime;
        int i2 = p.deviceId;
        int i3 = p.source;
        if (canUsePendingPoints) {
            arrayList = pendingMovePoints;
        } else {
            arrayList = null;
        }
        com.android.server.gesture.GestureUtils.sendSwipe(f, f2, f3, f4, i, i2, i3, arrayList, hasMultiTouched);
    }

    private void recordPendingMoveDatas(android.view.MotionEvent event, float distance, float rawX, float rawY) {
        int dist;
        int h = 0;
        if (this.mPendingMoveDistance.size() < 30) {
            dist = (int) java.lang.Math.abs(distance - this.mLastPendingDistance);
            int dt = 150;
            if (dist > 150) {
                int times = dist / 150;
                if (distance <= this.mLastPendingDistance) {
                    dt = -150;
                }
                for (int i = 0; i < times; i++) {
                    this.mPendingMoveDistance.add(java.lang.Float.valueOf(distance - ((float) ((times - i) * dt))));
                }
            }
            this.mPendingMoveDistance.add(java.lang.Float.valueOf(distance));
            this.mLastPendingDistance = distance;
        }
        if (this.mPendingMovePoints.size() < 30) {
            dist = event.getHistorySize();
            while (h < dist) {
                float rx = event.getHistoricalX(h) - this.mXOffset;
                float ry = event.getHistoricalY(h) - this.mYOffset;
                this.mPendingMovePoints.add(new android.graphics.PointF(rx, ry));
                if (com.android.server.gesture.GestureNavConst.DEBUG_ALL) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("record rx=");
                    stringBuilder.append(rx);
                    stringBuilder.append(", ry=");
                    stringBuilder.append(ry);
                    android.util.Log.d("GestureNav_Strategy", stringBuilder.toString());
                }
                h++;
            }
            this.mPendingMovePoints.add(new android.graphics.PointF(rawX, rawY));
        }
    }

    private static final int distance(float startX, float startY, float endX, float endY) {
        float dx = startX - endX;
        float dy = startY - endY;
        return (int) java.lang.Math.sqrt((double) ((dx * dx) + (dy * dy)));
    }

    private float distanceX(float offsetX) {
        return java.lang.Math.abs(offsetX);
    }

    private float distanceY(float offsetY) {
        return java.lang.Math.abs(offsetY);
    }

    private float diff(float diffX, float diffY) {
        return this.mCheckDistanceY ? diffY : diffX;
    }

    private float diff(float startX, float startY, float endX, float endY) {
        return this.mCheckDistanceY ? distanceY(endY - startY) : distanceX(endX - startX);
    }

    private double angle(float distanceX, float distanceY) {
        return com.android.server.gesture.GestureUtils.angle(distanceX, distanceY, this.mCheckDistanceY);
    }

    private float getVelocity(android.view.VelocityTracker velocityTracker) {
        return java.lang.Math.abs(this.mCheckDistanceY ? velocityTracker.getYVelocity() : velocityTracker.getXVelocity());
    }

    protected java.lang.String translateFailedReason(int reason) {
        switch (reason) {
            case 1:
                return "Gesture failed as move out region timeout";
            case 2:
                return "Gesture failed as move out gesture angle too large";
            case 3:
                return "Gesture failed as up in region(maybe sliping in region)";
            case 4:
                return "Gesture failed as sliding distance too short";
            case 5:
                return "Gesture failed as sliding rollback or canceled";
            case 6:
                return "Gesture failed as multi finger sliding";
            default:
                return "Gesture failed as other";
        }
    }
}
