package com.android.server.gesture;

public class GestureNavBottomStrategy extends com.android.server.gesture.GestureNavBaseStrategy {
    private static final int MSG_HIDE_INPUTMETHOD_IF_NEED = 1;
    private static final int STARTUP_TARGET_HIVISION = 4;
    private static final int STARTUP_TARGET_NONE = 0;
    private static final int STARTUP_TARGET_QUICK_STEP = 3;
    private static final int STARTUP_TARGET_SINGLE_HAND = 1;
    private static final int STARTUP_TARGET_VOICE_ASSIST = 2;
    private android.os.Handler mBottomHandler;
    private boolean mFirstAftTriggered;
    private final java.lang.Runnable mGoHomeRunnable = new java.lang.Runnable() {
        public void run() {
            com.android.server.gesture.GestureNavBottomStrategy.this.sendKeyEvent(3);
        }
    };
    private boolean mInTaskLockMode;
    private android.view.inputmethod.InputMethodManagerInternal mInputMethodManagerInternal;
    private long mLastAftGestureTime;
    private boolean mPreConditionNotReady;
    private com.android.server.gesture.QuickSingleHandController mQuickSingleHandController;
    private com.android.server.gesture.QuickSlideOutController mQuickSlideOutController;
    private com.android.server.gesture.QuickStepController mQuickStepController;
    private boolean mShouldCheckAftForThisGesture;
    private int mStartupTarget = 0;

    private final class BottomHandler extends android.os.Handler {
        public BottomHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                com.android.server.gesture.GestureNavBottomStrategy.this.hideCurrentInputMethod();
            }
        }
    }

    public GestureNavBottomStrategy(int navId, android.content.Context context, android.os.Looper looper) {
        super(navId, context, looper);
        this.mBottomHandler = new com.android.server.gesture.GestureNavBottomStrategy.BottomHandler(looper);
    }

    private void notifyStart() {
        this.mQuickStepController = new com.android.server.gesture.QuickStepController(this.mContext, this.mLooper);
        this.mQuickSingleHandController = new com.android.server.gesture.QuickSingleHandController(this.mContext, this.mLooper);
        this.mQuickSlideOutController = new com.android.server.gesture.QuickSlideOutController(this.mContext, this.mLooper);
    }

    private void notifyStop() {
        this.mQuickStepController = null;
        this.mQuickSingleHandController = null;
        this.mQuickSlideOutController = null;
    }

    private boolean isSidleOutEnabled() {
        return this.mQuickSlideOutController != null && this.mQuickSlideOutController.isSlideOutEnabled();
    }

    private boolean isSupportMultiTouch() {
        return this.mQuickStepController != null && this.mQuickStepController.isSupportMultiTouch();
    }

    private int checkStartupTarget(int rawX, int rawY) {
        if (this.mKeyguardShowing) {
            return 3;
        }
        int width = getRegion().width();
        int singleHandWidth = (int) (com.android.server.gesture.GestureNavConst.BOTTOM_WINDOW_SINGLE_HAND_RATIO * ((float) getRegion().height()));
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkStartupTarget width=");
            stringBuilder.append(width);
            stringBuilder.append(", rawX=");
            stringBuilder.append(rawX);
            stringBuilder.append(", rawY=");
            stringBuilder.append(rawY);
            stringBuilder.append(", singleHandWidth=");
            stringBuilder.append(singleHandWidth);
            android.util.Log.d("GestureNav_Bottom", stringBuilder.toString());
        }
        if (rawX > singleHandWidth) {
            if (rawX < width - singleHandWidth) {
                if (isSidleOutEnabled()) {
                    if (!this.mInTaskLockMode) {
                        if (((float) rawX) < ((float) width) * 0.19999999f) {
                            return 2;
                        }
                        if (((float) rawX) >= ((float) width) * 0.19999999f && ((float) rawX) <= ((float) width) - (((float) width) * 0.19999999f)) {
                            return 3;
                        }
                        if (((float) rawX) > ((float) width) - (((float) width) * 0.19999999f)) {
                            return 4;
                        }
                        return 0;
                    }
                }
                return 3;
            }
        }
        return 1;
    }

    public void updateDeviceState(boolean keyguardShowing) {
        super.updateDeviceState(keyguardShowing);
        if (this.mQuickStepController != null) {
            this.mQuickStepController.updateDeviceState(keyguardShowing);
        }
    }

    public void onNavCreate(com.android.server.gesture.GestureNavView navView) {
        notifyStart();
        this.mQuickStepController.onNavCreate(navView);
        this.mQuickSlideOutController.onNavCreate(navView);
        this.mQuickSingleHandController.onNavCreate(navView);
    }

    public void onNavUpdate() {
        this.mQuickStepController.onNavUpdate();
        this.mQuickSlideOutController.onNavUpdate();
        this.mQuickSingleHandController.onNavUpdate();
    }

    public void onNavDestroy() {
        this.mQuickStepController.onNavDestroy();
        this.mQuickSlideOutController.onNavDestroy();
        this.mQuickSingleHandController.onNavDestroy();
        notifyStop();
    }

    protected boolean shouldDropMultiTouch() {
        if (isSupportMultiTouch()) {
            return false;
        }
        return true;
    }

    protected int moveOutAngleThreshold() {
        if (this.mStartupTarget != 2) {
            if (this.mStartupTarget != 4) {
                return super.moveOutAngleThreshold();
            }
        }
        return 45;
    }

    protected void onGestureStarted(float rawX, float rawY) {
        super.onGestureStarted(rawX, rawY);
        this.mInTaskLockMode = com.android.server.gesture.GestureUtils.isInLockTaskMode();
        this.mPreConditionNotReady = false;
        this.mStartupTarget = checkStartupTarget((int) rawX, (int) rawY);
        boolean z = true;
        if (this.mStartupTarget == 1) {
            this.mShouldCheckAftForThisGesture = false;
        } else {
            if (!this.mInTaskLockMode) {
                if (!shouldCheckAftForThisGesture()) {
                    z = false;
                }
            }
            this.mShouldCheckAftForThisGesture = z;
        }
        long diffTime = 0;
        if (!this.mShouldCheckAftForThisGesture) {
            this.mFirstAftTriggered = false;
        } else if (this.mFirstAftTriggered) {
            long uptimeMillis = android.os.SystemClock.uptimeMillis() - this.mLastAftGestureTime;
            diffTime = uptimeMillis;
            if (uptimeMillis > 2000) {
                this.mFirstAftTriggered = false;
            }
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("StartupTarget=");
            stringBuilder.append(this.mStartupTarget);
            stringBuilder.append(", checkAft=");
            stringBuilder.append(this.mShouldCheckAftForThisGesture);
            stringBuilder.append(", firstAftTriggered=");
            stringBuilder.append(this.mFirstAftTriggered);
            stringBuilder.append(", diffTime=");
            stringBuilder.append(diffTime);
            android.util.Log.d("GestureNav_Bottom", stringBuilder.toString());
        }
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || this.mInTaskLockMode) {
            if (this.mStartupTarget != 2) {
                if (this.mStartupTarget != 4) {
                    if (this.mStartupTarget == 3) {
                        this.mQuickStepController.onGestureStarted();
                    }
                }
            }
            this.mQuickSlideOutController.onGestureStarted();
        }
    }

    protected void onGestureReallyStarted() {
        super.onGestureReallyStarted();
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || this.mInTaskLockMode) {
            this.mBottomHandler.sendEmptyMessage(1);
            if (this.mStartupTarget != 2) {
                if (this.mStartupTarget != 4) {
                    if (this.mStartupTarget == 3) {
                        this.mQuickStepController.onGestureReallyStarted();
                    }
                    return;
                }
            }
            this.mQuickSlideOutController.onGestureReallyStarted();
            return;
        }
        showReTryToast();
    }

    protected void onGestureSlowProcessStarted(java.util.ArrayList<java.lang.Float> pendingMoveDistance) {
        super.onGestureSlowProcessStarted(pendingMoveDistance);
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || this.mInTaskLockMode) {
            if (this.mStartupTarget != 2) {
                if (this.mStartupTarget != 4) {
                    if (this.mStartupTarget == 3) {
                        this.mQuickStepController.onGestureSlowProcessStarted();
                    }
                }
            }
            this.mQuickSlideOutController.onGestureSlowProcessStarted();
        }
    }

    protected void onGestureSlowProcess(float distance, float offsetX, float offsetY) {
        super.onGestureSlowProcess(distance, offsetX, offsetY);
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || !this.mInTaskLockMode) {
        }
    }

    protected void onGestureFailed(int reason, boolean failedInEventEnd) {
        super.onGestureFailed(reason, failedInEventEnd);
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || this.mInTaskLockMode) {
            if (this.mStartupTarget != 2) {
                if (this.mStartupTarget != 4) {
                    if (this.mStartupTarget == 3) {
                        this.mQuickStepController.onGestureFailed();
                    }
                }
            }
            this.mQuickSlideOutController.onGestureFailed();
        }
    }

    protected void onGestureSuccessFinished(float distance, long durationTime, float velocity, boolean isFastSlideGesture) {
        super.onGestureSuccessFinished(distance, durationTime, velocity, isFastSlideGesture);
        if (!this.mShouldCheckAftForThisGesture || this.mFirstAftTriggered || this.mInTaskLockMode) {
            if (this.mStartupTarget != 2) {
                if (this.mStartupTarget != 4) {
                    if (this.mStartupTarget == 3) {
                        this.mQuickStepController.onGestureSuccessFinished(distance, durationTime, velocity, isFastSlideGesture, this.mGoHomeRunnable);
                    }
                }
            }
            this.mQuickSlideOutController.onGestureSuccessFinished(distance, durationTime, velocity, isFastSlideGesture, null);
        }
    }

    protected void onGestureEnd(int action) {
        super.onGestureEnd(action);
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        boolean result = super.onTouchEvent(event);
        boolean firstAftChecking = this.mShouldCheckAftForThisGesture && !this.mFirstAftTriggered;
        if (firstAftChecking) {
            if (this.mGestureEnd && !this.mGestureFailed) {
                this.mFirstAftTriggered = true;
                this.mLastAftGestureTime = android.os.SystemClock.uptimeMillis();
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("gesture end, mLastAftGestureTime=");
                    stringBuilder.append(this.mLastAftGestureTime);
                    android.util.Log.d("GestureNav_Bottom", stringBuilder.toString());
                }
            }
            if (!this.mInTaskLockMode) {
                return result;
            }
        }
        handleTouchEvent(event);
        if (!firstAftChecking && this.mGestureEnd && !this.mGestureFailed && this.mFirstAftTriggered) {
            this.mFirstAftTriggered = false;
            if (this.mInTaskLockMode) {
                exitLockTaskMode();
            }
        }
        return result;
    }

    private void handleTouchEvent(android.view.MotionEvent event) {
        switch (this.mStartupTarget) {
            case 1:
                handleSingleHand(event);
                return;
            case 2:
            case 4:
                handleQuickSlideOut(event);
                return;
            case 3:
                handleQuickStep(event);
                return;
            default:
                return;
        }
    }

    private void handleSingleHand(android.view.MotionEvent event) {
        if (!this.mPreConditionNotReady) {
            int actionMasked = event.getActionMasked();
            if (actionMasked != 3) {
                switch (actionMasked) {
                    case 0:
                        setUseProxyAngleStrategy(true);
                        if (this.mQuickSingleHandController.isPreConditionNotReady(false)) {
                            android.util.Log.i("GestureNav_Bottom", "QuickSingleHand precondition not ready at down");
                            this.mPreConditionNotReady = true;
                            return;
                        }
                        break;
                    case 1:
                        break;
                    default:
                        break;
                }
            }
            setUseProxyAngleStrategy(false);
            this.mQuickSingleHandController.setGestureResultAtUp(this.mGestureFailed ^ 1);
            this.mQuickSingleHandController.handleTouchEvent(event);
        }
    }

    private void handleQuickSlideOut(android.view.MotionEvent event) {
        if (!this.mPreConditionNotReady) {
            int actionMasked = event.getActionMasked();
            if (actionMasked != 3) {
                switch (actionMasked) {
                    case 0:
                        boolean onLeft = this.mStartupTarget == 2;
                        if (!this.mQuickSlideOutController.isPreConditionNotReady(onLeft)) {
                            this.mQuickSlideOutController.setSlidingSide(onLeft);
                            break;
                        }
                        java.lang.String str = "GestureNav_Bottom";
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("QuickSlideOut precondition not ready at ");
                        stringBuilder.append(onLeft ? "left" : "right");
                        stringBuilder.append(" down");
                        android.util.Log.i(str, stringBuilder.toString());
                        this.mPreConditionNotReady = true;
                        return;
                    case 1:
                        break;
                    default:
                        break;
                }
            }
            this.mQuickSlideOutController.setGestureResultAtUp(this.mGestureFailed ^ 1);
            this.mQuickSlideOutController.handleTouchEvent(event);
        }
    }

    private void handleQuickStep(android.view.MotionEvent event) {
        this.mQuickStepController.handleTouchEvent(event);
    }

    private void hideCurrentInputMethod() {
        if (this.mInputMethodManagerInternal == null) {
            this.mInputMethodManagerInternal = (android.view.inputmethod.InputMethodManagerInternal) com.android.server.LocalServices.getService(android.view.inputmethod.InputMethodManagerInternal.class);
        }
        if (this.mInputMethodManagerInternal != null) {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                android.util.Log.d("GestureNav_Bottom", "hide input method if need");
            }
            this.mInputMethodManagerInternal.hideCurrentInputMethod();
        }
    }

    private boolean shouldCheckAftForThisGesture() {
        return com.android.server.wm.HwGestureNavWhiteConfig.getInstance().isEnable();
    }

    private void showReTryToast() {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            android.util.Log.d("GestureNav_Bottom", "showReTryToast");
        }
        this.mBottomHandler.post(new java.lang.Runnable() {
            public void run() {
                android.widget.Toast toast = android.widget.Toast.makeText(com.android.server.gesture.GestureNavBottomStrategy.this.mContext, 33686183, 0);
                toast.getWindowParams().type = 2010;
                android.view.WindowManager.LayoutParams windowParams = toast.getWindowParams();
                windowParams.privateFlags |= 16;
                toast.show();
            }
        });
    }

    private void exitLockTaskMode() {
        android.util.Log.i("GestureNav_Bottom", "start exit lock task mode");
        this.mBottomHandler.post(new java.lang.Runnable() {
            public void run() {
                com.android.server.gesture.GestureUtils.exitLockTaskMode();
            }
        });
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter pw, java.lang.String[] args) {
        pw.print(prefix);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mShouldCheckAftForThisGesture=");
        stringBuilder.append(this.mShouldCheckAftForThisGesture);
        pw.print(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" mFirstAftTriggered=");
        stringBuilder.append(this.mFirstAftTriggered);
        pw.print(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" mLastAftGestureTime=");
        stringBuilder.append(this.mLastAftGestureTime);
        pw.print(stringBuilder.toString());
        pw.println();
        if (this.mQuickSlideOutController != null) {
            this.mQuickSlideOutController.dump(prefix, pw, args);
        }
        if (this.mQuickStepController != null) {
            this.mQuickStepController.dump(prefix, pw, args);
        }
    }
}
