package com.android.server.gesture;

public class GestureNavManager implements com.android.server.gesture.GestureNavView.IGestureEventProxy, com.android.server.Watchdog.Monitor {
    private static final int MSG_CONFIG_CHANGED = 3;
    private static final int MSG_DEVICE_STATE_CHANGED = 4;
    private static final int MSG_FOCUS_CHANGED = 5;
    private static final int MSG_KEYGUARD_STATE_CHANGED = 6;
    private static final int MSG_NOTCH_DISPLAY_CHANGED = 9;
    private static final int MSG_PREFER_CHANGED = 8;
    private static final int MSG_RELOAD_NAV_GLOBAL_STATE = 2;
    private static final int MSG_ROTATION_CHANGED = 7;
    private static final int MSG_UPDATE_NAV_GLOBAL_STATE = 1;
    private static final java.lang.String TAG = "GestureNavManager";
    private com.android.server.gesture.GestureNavBottomStrategy mBottomStrategy;
    private android.content.Context mContext;
    private int mCurrentUserId;
    private com.android.server.gesture.GestureNavManager.DensityObserver mDensityObserver;
    private java.lang.String mDensityStr;
    private final com.android.server.gesture.DeviceStateController.DeviceChangedListener mDeviceChangedCallback = new com.android.server.gesture.DeviceStateController.DeviceChangedListener() {
        public void onDeviceProvisionedChanged(boolean provisioned) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Device provisioned changed, provisioned=");
                    stringBuilder.append(provisioned);
                    android.util.Log.i("GestureNavManager", stringBuilder.toString());
                }
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(4);
            }
        }

        public void onUserSwitched(int newUserId) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("User switched, newUserId=");
                    stringBuilder.append(newUserId);
                    android.util.Log.i("GestureNavManager", stringBuilder.toString());
                }
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(4);
            }
        }

        public void onUserSetupChanged(boolean setup) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("User setup changed, setup=");
                    stringBuilder.append(setup);
                    android.util.Log.i("GestureNavManager", stringBuilder.toString());
                }
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(4);
            }
        }

        public void onPreferredActivityChanged(boolean isPrefer) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Preferred activity changed, isPrefer=");
                    stringBuilder.append(isPrefer);
                    android.util.Log.i("GestureNavManager", stringBuilder.toString());
                }
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(8);
            }
        }
    };
    private boolean mDeviceProvisioned;
    private com.android.server.gesture.DeviceStateController mDeviceStateController;
    private android.graphics.Point mDisplaySize = new android.graphics.Point();
    private int mFocusWinNavOptions;
    private java.lang.String mFocusWindowTitle;
    private boolean mFocusWindowUsingNotch = true;
    private com.android.server.gesture.GestureNavAnimProxy mGestureNavAnimProxy;
    private com.android.server.gesture.GestureNavView mGestureNavBottom;
    private boolean mGestureNavEnabled;
    private com.android.server.gesture.GestureNavView mGestureNavLeft;
    private boolean mGestureNavReady;
    private com.android.server.gesture.GestureNavView mGestureNavRight;
    private boolean mGuideOrOtaAlive;
    private android.os.Handler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private boolean mHasNotch;
    private int mHoleHeight = 0;
    private java.lang.String mHomeWindow;
    private boolean mInKeyguardMainWindow;
    private boolean mKeyguardShowing;
    private boolean mLandscape;
    private com.android.server.gesture.GestureNavManager.LauncherStateChangedReceiver mLauncherStateChangedReceiver;
    private com.android.server.gesture.GestureNavBaseStrategy mLeftBackStrategy;
    private final java.lang.Object mLock = new java.lang.Object();
    private boolean mNavBackEnabled;
    private boolean mNavBottomEnabled;
    private boolean mNavStarted;
    private boolean mNotchDisplayDisabled;
    private com.android.server.gesture.GestureNavManager.NotchObserver mNotchObserver;
    private com.android.server.gesture.GestureNavBaseStrategy mRightBackStrategy;
    private int mRotation = (android.os.SystemProperties.getInt("ro.panel.hw_orientation", 0) / 90);
    private boolean mUserSetuped;
    private android.view.WindowManager mWindowManager;
    private boolean mWindowViewSetuped;

    private final class DensityObserver extends android.database.ContentObserver {
        public DensityObserver(android.os.Handler handler) {
            super(handler);
        }

        public void onChange(boolean selfChange, android.net.Uri uri) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted && com.android.server.gesture.GestureNavManager.this.updateDisplayDensity()) {
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(2);
            }
        }
    }

    private final class GestureHandler extends android.os.Handler {
        public GestureHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("handleMessage before msg=");
                stringBuilder.append(msg.what);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
            boolean z = false;
            com.android.server.gesture.GestureNavManager gestureNavManager;
            switch (msg.what) {
                case 1:
                    com.android.server.gesture.GestureNavManager.this.updateGestureNavGlobalState();
                    break;
                case 2:
                    com.android.server.gesture.GestureNavManager.this.reloadGestureNavGlobalState();
                    break;
                case 3:
                    com.android.server.gesture.GestureNavManager.this.handleConfigChanged();
                    break;
                case 4:
                    com.android.server.gesture.GestureNavManager.this.handleDeviceStateChanged();
                    break;
                case 5:
                    gestureNavManager = com.android.server.gesture.GestureNavManager.this;
                    java.lang.String str = (java.lang.String) msg.obj;
                    if (msg.arg1 == 1) {
                        z = true;
                    }
                    gestureNavManager.handleFocusChanged(str, z, msg.arg2);
                    break;
                case 6:
                    gestureNavManager = com.android.server.gesture.GestureNavManager.this;
                    if (msg.arg1 == 1) {
                        z = true;
                    }
                    gestureNavManager.handleKeygaurdStateChanged(z);
                    break;
                case 7:
                    com.android.server.gesture.GestureNavManager.this.handleRotationChanged(msg.arg1);
                    break;
                case 8:
                    com.android.server.gesture.GestureNavManager.this.handlePreferChanged();
                    break;
                case 9:
                    com.android.server.gesture.GestureNavManager.this.handleNotchDisplayChanged();
                    break;
                default:
                    break;
            }
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("handleMessage after msg=");
                stringBuilder.append(msg.what);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
        }
    }

    private final class LauncherStateChangedReceiver extends android.content.BroadcastReceiver {
        private LauncherStateChangedReceiver() {
        }

        /* synthetic */ LauncherStateChangedReceiver(com.android.server.gesture.GestureNavManager x0, com.android.server.gesture.GestureNavManager.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Launcher state changed, intent=");
                    stringBuilder.append(intent);
                    android.util.Log.i("GestureNavManager", stringBuilder.toString());
                }
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(8);
            }
        }
    }

    private final class NotchObserver extends android.database.ContentObserver {
        public NotchObserver(android.os.Handler handler) {
            super(handler);
        }

        public void onChange(boolean selfChange, android.net.Uri uri) {
            if (com.android.server.gesture.GestureNavManager.this.mNavStarted) {
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(9);
            }
        }
    }

    public GestureNavManager(android.content.Context context) {
        this.mContext = context;
        this.mHandlerThread = new android.os.HandlerThread("GestureNavManager");
        this.mHandlerThread.start();
        this.mHandler = new com.android.server.gesture.GestureNavManager.GestureHandler(this.mHandlerThread.getLooper());
    }

    public void systemReady() {
        this.mWindowManager = (android.view.WindowManager) this.mContext.getSystemService("window");
        com.android.server.gesture.GestureUtils.systemReady();
        this.mHasNotch = com.android.server.gesture.GestureUtils.hasNotch();
        com.android.server.Watchdog.getInstance().addMonitor(this);
        com.android.server.Watchdog.getInstance().addThread(this.mHandler);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("secure_gesture_navigation"), false, new android.database.ContentObserver(new android.os.Handler()) {
            public void onChange(boolean selfChange) {
                android.util.Log.i("GestureNavManager", "gesture nav status change");
                com.android.server.gesture.GestureNavManager.this.mHandler.sendEmptyMessage(1);
            }
        }, -1);
        this.mHandler.sendEmptyMessage(1);
    }

    public void monitor() {
        synchronized (this.mLock) {
        }
    }

    private void updateEnableStateLocked() {
        this.mGestureNavEnabled = com.android.server.gesture.GestureNavConst.isGestureNavEnabled(this.mContext, -2);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mGestureNavEnabled=");
        stringBuilder.append(this.mGestureNavEnabled);
        android.util.Log.i("GestureNavManager", stringBuilder.toString());
    }

    private void updateGestureNavGlobalState() {
        synchronized (this.mLock) {
            updateEnableStateLocked();
            if (this.mGestureNavEnabled) {
                startGestureNavLocked();
            } else {
                stopGestureNavLocked();
            }
        }
    }

    private void reloadGestureNavGlobalState() {
        synchronized (this.mLock) {
            android.util.Log.i("GestureNavManager", "force reloadGestureNavGlobalState");
            this.mGestureNavEnabled = false;
            stopGestureNavLocked();
            updateEnableStateLocked();
            if (this.mGestureNavEnabled) {
                startGestureNavLocked();
            }
        }
    }

    private void startGestureNavLocked() {
        android.util.Log.i("GestureNavManager", "startGestureNavLocked");
        this.mNavStarted = true;
        updateDisplayDensity();
        updateNotchDisplayStateLocked();
        this.mDeviceStateController = com.android.server.gesture.DeviceStateController.getInstance(this.mContext);
        this.mDeviceStateController.addCallback(this.mDeviceChangedCallback);
        updateGestureNavStateLocked();
        android.content.ContentResolver resolver = this.mContext.getContentResolver();
        this.mDensityObserver = new com.android.server.gesture.GestureNavManager.DensityObserver(this.mHandler);
        resolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("display_density_forced"), false, this.mDensityObserver, -1);
        this.mNotchObserver = new com.android.server.gesture.GestureNavManager.NotchObserver(this.mHandler);
        resolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("display_notch_status"), false, this.mNotchObserver, -1);
        this.mLauncherStateChangedReceiver = new com.android.server.gesture.GestureNavManager.LauncherStateChangedReceiver(this, null);
        android.content.IntentFilter filter = new android.content.IntentFilter("android.intent.action.PACKAGE_ADDED");
        filter.addDataScheme("package");
        filter.addDataSchemeSpecificPart("com.huawei.android.launcher", 0);
        filter.addAction("android.intent.action.PACKAGE_CHANGED");
        this.mContext.registerReceiver(this.mLauncherStateChangedReceiver, filter, null, this.mHandler);
    }

    private void stopGestureNavLocked() {
        android.util.Log.i("GestureNavManager", "stopGestureNavLocked");
        if (this.mLauncherStateChangedReceiver != null) {
            this.mContext.unregisterReceiver(this.mLauncherStateChangedReceiver);
            this.mLauncherStateChangedReceiver = null;
        }
        if (this.mDensityObserver != null) {
            this.mContext.getContentResolver().unregisterContentObserver(this.mDensityObserver);
            this.mDensityObserver = null;
        }
        if (this.mNotchObserver != null) {
            this.mContext.getContentResolver().unregisterContentObserver(this.mNotchObserver);
            this.mNotchObserver = null;
        }
        updateGestureNavStateLocked();
        if (this.mDeviceStateController != null) {
            this.mDeviceStateController.removeCallback(this.mDeviceChangedCallback);
            this.mDeviceStateController = null;
        }
        this.mNavStarted = false;
    }

    private void updateGestureNavStateLocked() {
        updateDeviceStateLocked();
        updateConfigLocked();
        updateNavWindowLocked();
        updateNavVisibleLocked();
    }

    public void onUserChanged(int newUserId) {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("User switched then reInit, newUserId=");
            stringBuilder.append(newUserId);
            android.util.Log.i("GestureNavManager", stringBuilder.toString());
        }
        this.mHandler.sendEmptyMessage(1);
    }

    public void onConfigurationChanged() {
        if (this.mNavStarted) {
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                android.util.Log.d("GestureNavManager", "onConfigurationChanged");
            }
            this.mHandler.sendEmptyMessage(3);
        }
    }

    public void onRotationChanged(int rotation) {
        if (this.mNavStarted) {
            this.mHandler.sendMessage(this.mHandler.obtainMessage(7, rotation, 0));
        }
    }

    public void onFocusWindowChanged(com.android.server.policy.WindowManagerPolicy.WindowState lastFocus, com.android.server.policy.WindowManagerPolicy.WindowState newFocus) {
        if (this.mNavStarted && newFocus != null) {
            if (newFocus.getAttrs() != null) {
                java.lang.String focusWindowTitle = newFocus.getAttrs().getTitle().toString();
                this.mHandler.sendMessage(this.mHandler.obtainMessage(5, newFocus.isWindowUsingNotch(), newFocus.getHwGestureNavOptions(), focusWindowTitle));
            }
        }
    }

    public void onKeyguardShowingChanged(boolean showing) {
        if (this.mNavStarted) {
            this.mHandler.sendMessage(this.mHandler.obtainMessage(6, showing, 0));
        }
    }

    private void handleDeviceStateChanged() {
        synchronized (this.mLock) {
            updateDeviceStateLocked();
            updateNavVisibleLocked();
        }
    }

    private void handleConfigChanged() {
        synchronized (this.mLock) {
            if (this.mDeviceStateController != null) {
                this.mDeviceStateController.onConfigurationChanged();
            }
            updateConfigLocked();
            updateNavWindowLocked();
            updateNavVisibleLocked();
        }
    }

    private void handleRotationChanged(int rotation) {
        synchronized (this.mLock) {
            int lastRotation = this.mRotation;
            this.mRotation = rotation;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("lastRotation=");
                stringBuilder.append(lastRotation);
                stringBuilder.append(", currentRotation=");
                stringBuilder.append(rotation);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
            if (isRotationChangedInLand(lastRotation, rotation)) {
                updateConfigLocked();
                updateNavWindowLocked();
                updateNavVisibleLocked();
            }
        }
    }

    /* JADX WARNING: Missing block: B:11:0x0013, code:
            return;
     */
    private void handlePreferChanged() {
        /*
        r2 = this;
        r0 = r2.mLock;
        monitor-enter(r0);
        r1 = r2.mDeviceStateController;	 Catch:{ all -> 0x0014 }
        if (r1 != 0) goto L_0x0009;
    L_0x0007:
        monitor-exit(r0);	 Catch:{ all -> 0x0014 }
        return;
    L_0x0009:
        r1 = r2.updateHomeWindowLocked();	 Catch:{ all -> 0x0014 }
        if (r1 == 0) goto L_0x0012;
    L_0x000f:
        r2.updateNavVisibleLocked();	 Catch:{ all -> 0x0014 }
    L_0x0012:
        monitor-exit(r0);	 Catch:{ all -> 0x0014 }
        return;
    L_0x0014:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0014 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.gesture.GestureNavManager.handlePreferChanged():void");
    }

    private void handleNotchDisplayChanged() {
        synchronized (this.mLock) {
            if (updateNotchDisplayStateLocked()) {
                updateConfigLocked();
                updateNavWindowLocked();
                updateNavVisibleLocked();
            }
        }
    }

    private void handleFocusChanged(java.lang.String focusedWindow, boolean usingNotch, int focusWindowNavOptions) {
        synchronized (this.mLock) {
            this.mFocusWindowTitle = focusedWindow;
            this.mInKeyguardMainWindow = isInKeyguardMainWindowLocked();
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Focus:");
                stringBuilder.append(this.mFocusWindowTitle);
                stringBuilder.append(", UN=");
                stringBuilder.append(usingNotch);
                stringBuilder.append(", LUN=");
                stringBuilder.append(this.mFocusWindowUsingNotch);
                stringBuilder.append(", FNO=");
                stringBuilder.append(focusWindowNavOptions);
                stringBuilder.append(", LFNO=");
                stringBuilder.append(this.mFocusWinNavOptions);
                stringBuilder.append(", IKMW=");
                stringBuilder.append(this.mInKeyguardMainWindow);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
            this.mFocusWinNavOptions = focusWindowNavOptions;
            if (this.mFocusWindowUsingNotch != usingNotch) {
                this.mFocusWindowUsingNotch = usingNotch;
                updateConfigLocked();
                updateNavWindowLocked();
            }
            updateNavVisibleLocked();
        }
    }

    private void handleKeygaurdStateChanged(boolean showing) {
        synchronized (this.mLock) {
            this.mKeyguardShowing = showing;
            this.mInKeyguardMainWindow = isInKeyguardMainWindowLocked();
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("keyguard showing=");
                stringBuilder.append(showing);
                stringBuilder.append(", IKMW=");
                stringBuilder.append(this.mInKeyguardMainWindow);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
            updateNavVisibleLocked();
            if (this.mBottomStrategy != null) {
                this.mBottomStrategy.updateDeviceState(this.mKeyguardShowing);
            }
        }
    }

    private void updateDeviceStateLocked() {
        if (this.mDeviceStateController != null) {
            this.mCurrentUserId = this.mDeviceStateController.getCurrentUser();
            this.mDeviceProvisioned = this.mDeviceStateController.isDeviceProvisioned();
            this.mUserSetuped = this.mDeviceStateController.isCurrentUserSetup();
            this.mKeyguardShowing = this.mDeviceStateController.isKeyguardShowingOrOccluded();
            this.mInKeyguardMainWindow = this.mDeviceStateController.isKeyguardShowingAndNotOccluded();
            updateHomeWindowLocked();
            com.android.server.policy.WindowManagerPolicy.WindowState focusWindowState = this.mDeviceStateController.getFocusWindow();
            if (!(focusWindowState == null || focusWindowState.getAttrs() == null)) {
                this.mFocusWindowTitle = focusWindowState.getAttrs().getTitle().toString();
                this.mFocusWindowUsingNotch = focusWindowState.isWindowUsingNotch();
            }
            if (this.mBottomStrategy != null) {
                this.mBottomStrategy.updateDeviceState(this.mKeyguardShowing);
            }
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Update device state, provisioned:");
                stringBuilder.append(this.mDeviceProvisioned);
                stringBuilder.append(", userSetup:");
                stringBuilder.append(this.mUserSetuped);
                stringBuilder.append(", guideOrOtaAlive:");
                stringBuilder.append(this.mGuideOrOtaAlive);
                stringBuilder.append(", keyguardShowing:");
                stringBuilder.append(this.mKeyguardShowing);
                stringBuilder.append(", IKMW:");
                stringBuilder.append(this.mInKeyguardMainWindow);
                stringBuilder.append(", focus:");
                stringBuilder.append(this.mFocusWindowTitle);
                stringBuilder.append(", usingNotch:");
                stringBuilder.append(this.mFocusWindowUsingNotch);
                stringBuilder.append(", home:");
                stringBuilder.append(this.mHomeWindow);
                android.util.Log.i("GestureNavManager", stringBuilder.toString());
            }
        }
    }

    private void updateConfigLocked() {
        if (this.mGestureNavReady) {
            boolean z = false;
            this.mLandscape = this.mContext.getResources().getConfiguration().orientation == 2;
            this.mWindowManager.getDefaultDisplay().getRealSize(this.mDisplaySize);
            int displayWidth = this.mDisplaySize.x;
            int displayHeight = this.mDisplaySize.y;
            int backWindowHeight = java.lang.Math.round(((float) displayHeight) * 0.75f);
            int backWindowWidth = com.android.server.gesture.GestureNavConst.getBackWindowWidth(this.mContext);
            int bottomWindowHeight = com.android.server.gesture.GestureNavConst.getBottomWindowHeight(this.mContext);
            this.mHoleHeight = com.android.server.gesture.GestureNavConst.getStatusBarHeight(this.mContext);
            boolean usingNotch = true;
            if (this.mHasNotch) {
                if (this.mLandscape) {
                    if (!this.mNotchDisplayDisabled && this.mFocusWindowUsingNotch) {
                        z = true;
                    }
                    usingNotch = z;
                } else {
                    usingNotch = true;
                }
                this.mGestureNavLeft.updateViewNotchState(usingNotch);
                this.mGestureNavRight.updateViewNotchState(usingNotch);
                this.mGestureNavAnimProxy.updateViewNotchState(usingNotch);
            }
            boolean usingNotch2 = usingNotch;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("w=");
                stringBuilder.append(displayWidth);
                stringBuilder.append(", h=");
                stringBuilder.append(displayHeight);
                stringBuilder.append(", backH=");
                stringBuilder.append(backWindowHeight);
                stringBuilder.append(", backW=");
                stringBuilder.append(backWindowWidth);
                stringBuilder.append(", bottomH=");
                stringBuilder.append(bottomWindowHeight);
                stringBuilder.append(", usingNotch=");
                stringBuilder.append(usingNotch2);
                stringBuilder.append(", holeH=");
                stringBuilder.append(this.mHoleHeight);
                android.util.Log.d("GestureNavManager", stringBuilder.toString());
            }
            updateViewConfigLocked(displayWidth, displayHeight, backWindowWidth, backWindowHeight, bottomWindowHeight, usingNotch2);
        }
    }

    private void updateNavWindowLocked() {
        if (this.mGestureNavEnabled) {
            if (this.mWindowViewSetuped) {
                updateNavWindows();
            } else {
                createNavWindows();
            }
        } else if (this.mWindowViewSetuped) {
            destroyNavWindows();
        }
    }

    private void updateNavVisibleLocked() {
        if (this.mWindowViewSetuped) {
            boolean showBack = true;
            boolean showBottom = true;
            if (this.mInKeyguardMainWindow) {
                showBack = false;
                showBottom = false;
            } else {
                if (!this.mDeviceProvisioned || !this.mUserSetuped || this.mGuideOrOtaAlive || isFocusWindowBottomDisabledLocked()) {
                    showBottom = false;
                }
                if (isSpecialWindowLocked(this.mFocusWindowTitle) || isFocusWindowBackDisabledLocked()) {
                    showBack = false;
                }
            }
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateNavVisible showBack:");
                stringBuilder.append(showBack);
                stringBuilder.append(", showBottom:");
                stringBuilder.append(showBottom);
                android.util.Log.i("GestureNavManager", stringBuilder.toString());
            }
            enableBackNavLocked(showBack);
            enableBottomNavLocked(showBottom);
        }
    }

    private void enableBackNavLocked(boolean enable) {
        if (this.mWindowViewSetuped && this.mNavBackEnabled != enable) {
            this.mGestureNavLeft.show(enable);
            this.mGestureNavRight.show(enable);
            this.mNavBackEnabled = enable;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("enableBackNav show:");
                stringBuilder.append(this.mNavBackEnabled);
                android.util.Log.i("GestureNavManager", stringBuilder.toString());
            }
        }
    }

    private void enableBottomNavLocked(boolean enable) {
        if (this.mWindowViewSetuped && this.mNavBottomEnabled != enable) {
            this.mGestureNavBottom.show(enable);
            this.mNavBottomEnabled = enable;
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("enableBottomNav show:");
                stringBuilder.append(this.mNavBottomEnabled);
                android.util.Log.i("GestureNavManager", stringBuilder.toString());
            }
        }
    }

    private void createNavWindows() {
        android.util.Log.i("GestureNavManager", "createNavWindows");
        this.mGestureNavLeft = new com.android.server.gesture.GestureNavView(this.mContext, 1);
        this.mGestureNavRight = new com.android.server.gesture.GestureNavView(this.mContext, 2);
        this.mGestureNavBottom = new com.android.server.gesture.GestureNavView(this.mContext, 3);
        android.os.Looper looper = this.mHandlerThread.getLooper();
        this.mGestureNavAnimProxy = new com.android.server.gesture.GestureNavAnimProxy(this.mContext, looper);
        this.mLeftBackStrategy = new com.android.server.gesture.GestureNavBackStrategy(1, this.mContext, looper, this.mGestureNavAnimProxy);
        this.mRightBackStrategy = new com.android.server.gesture.GestureNavBackStrategy(2, this.mContext, looper, this.mGestureNavAnimProxy);
        this.mBottomStrategy = new com.android.server.gesture.GestureNavBottomStrategy(3, this.mContext, looper);
        this.mGestureNavReady = true;
        android.util.Log.i("GestureNavManager", "gesture nav ready.");
        updateConfigLocked();
        configAndAddNavWindow("GestureNavLeft", this.mGestureNavLeft, this.mLeftBackStrategy);
        configAndAddNavWindow("GestureNavRight", this.mGestureNavRight, this.mRightBackStrategy);
        configAndAddNavWindow("GestureNavBottom", this.mGestureNavBottom, this.mBottomStrategy);
        this.mLeftBackStrategy.onNavCreate(this.mGestureNavBottom);
        this.mRightBackStrategy.onNavCreate(this.mGestureNavBottom);
        this.mBottomStrategy.onNavCreate(this.mGestureNavBottom);
        this.mGestureNavAnimProxy.onNavCreate();
        this.mBottomStrategy.updateDeviceState(this.mKeyguardShowing);
        this.mWindowViewSetuped = true;
        this.mNavBackEnabled = true;
        this.mNavBottomEnabled = true;
    }

    private void updateNavWindows() {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            android.util.Log.d("GestureNavManager", "updateNavWindows");
        }
        reLayoutNavWindow("GestureNavLeft", this.mGestureNavLeft, this.mLeftBackStrategy);
        reLayoutNavWindow("GestureNavRight", this.mGestureNavRight, this.mRightBackStrategy);
        reLayoutNavWindow("GestureNavBottom", this.mGestureNavBottom, this.mBottomStrategy);
        this.mLeftBackStrategy.onNavUpdate();
        this.mRightBackStrategy.onNavUpdate();
        this.mBottomStrategy.onNavUpdate();
        this.mGestureNavAnimProxy.onNavUpdate();
    }

    private void destroyNavWindows() {
        android.util.Log.i("GestureNavManager", "destoryNavWindows");
        this.mGestureNavReady = false;
        this.mWindowViewSetuped = false;
        this.mNavBackEnabled = false;
        this.mNavBottomEnabled = false;
        this.mLeftBackStrategy.onNavDestroy();
        this.mRightBackStrategy.onNavDestroy();
        this.mBottomStrategy.onNavDestroy();
        com.android.server.gesture.GestureUtils.removeWindowView(this.mWindowManager, this.mGestureNavLeft, true);
        com.android.server.gesture.GestureUtils.removeWindowView(this.mWindowManager, this.mGestureNavRight, true);
        com.android.server.gesture.GestureUtils.removeWindowView(this.mWindowManager, this.mGestureNavBottom, true);
        this.mGestureNavAnimProxy.onNavDestroy();
        this.mGestureNavAnimProxy = null;
        this.mLeftBackStrategy = null;
        this.mRightBackStrategy = null;
        this.mBottomStrategy = null;
        this.mGestureNavLeft = null;
        this.mGestureNavRight = null;
        this.mGestureNavBottom = null;
    }

    private android.view.WindowManager.LayoutParams createLayoutParams(java.lang.String title, com.android.server.gesture.GestureNavView.WindowConfig config) {
        android.view.WindowManager.LayoutParams lp = new android.view.WindowManager.LayoutParams(2024, 296);
        if (android.app.ActivityManager.isHighEndGfx()) {
            lp.flags |= 16777216;
        }
        lp.format = -2;
        lp.alpha = 0.0f;
        lp.gravity = 51;
        lp.x = config.startX;
        lp.y = config.startY;
        lp.width = config.width;
        lp.height = config.height;
        lp.windowAnimations = 0;
        lp.softInputMode = 49;
        lp.setTitle(title);
        if (config.usingNotch) {
            lp.hwFlags |= 65536;
        } else {
            lp.hwFlags &= -65537;
        }
        lp.hwFlags |= 131072;
        lp.hwFlags |= 2097152;
        return lp;
    }

    private void configAndAddNavWindow(java.lang.String title, com.android.server.gesture.GestureNavView view, com.android.server.gesture.GestureNavBaseStrategy strategy) {
        com.android.server.gesture.GestureNavView.WindowConfig config = view.getViewConfig();
        android.view.WindowManager.LayoutParams params = createLayoutParams(title, config);
        strategy.updateConfig(config.displayWidth, config.displayHeight, new android.graphics.Rect(config.locationOnScreenX, config.locationOnScreenY, config.locationOnScreenX + config.width, config.locationOnScreenY + config.height));
        view.setGestureEventProxy(this);
        com.android.server.gesture.GestureUtils.addWindowView(this.mWindowManager, view, params);
    }

    private void reLayoutNavWindow(java.lang.String title, com.android.server.gesture.GestureNavView view, com.android.server.gesture.GestureNavBaseStrategy strategy) {
        com.android.server.gesture.GestureNavView.WindowConfig config = view.getViewConfig();
        android.view.WindowManager.LayoutParams params = createLayoutParams(title, config);
        strategy.updateConfig(config.displayWidth, config.displayHeight, new android.graphics.Rect(config.locationOnScreenX, config.locationOnScreenY, config.locationOnScreenX + config.width, config.locationOnScreenY + config.height));
        com.android.server.gesture.GestureUtils.updateViewLayout(this.mWindowManager, view, params);
    }

    private boolean isInKeyguardMainWindowLocked() {
        if (!this.mKeyguardShowing || ((this.mDeviceStateController == null || this.mDeviceStateController.isKeyguardOccluded()) && !"StatusBar".equals(this.mFocusWindowTitle))) {
            return false;
        }
        return true;
    }

    private void updateViewConfigLocked(int displayWidth, int displayHeight, int backWindowWidth, int backWindowHeight, int bottomWindowHeight, boolean usingNotch) {
        int leftViewStartPos = 0;
        int rightViewOffset = 0;
        int viewWidth = displayWidth;
        if (this.mHasNotch && !usingNotch) {
            int i = this.mRotation;
            if (i == 1) {
                leftViewStartPos = this.mHoleHeight;
                viewWidth = displayWidth - this.mHoleHeight;
                rightViewOffset = 0;
            } else if (i == 3) {
                leftViewStartPos = 0;
                viewWidth = displayWidth - this.mHoleHeight;
                rightViewOffset = this.mHoleHeight;
            }
        }
        int leftViewStartPos2 = leftViewStartPos;
        int rightViewOffset2 = rightViewOffset;
        int viewWidth2 = viewWidth;
        viewWidth = displayHeight;
        int i2 = backWindowWidth;
        int i3 = backWindowHeight;
        this.mGestureNavLeft.updateViewConfig(displayWidth, viewWidth, 0, displayHeight - backWindowHeight, i2, i3, leftViewStartPos2, displayHeight - backWindowHeight);
        rightViewOffset = displayWidth;
        this.mGestureNavRight.updateViewConfig(rightViewOffset, viewWidth, (displayWidth - backWindowWidth) - rightViewOffset2, displayHeight - backWindowHeight, i2, i3, (displayWidth - backWindowWidth) - rightViewOffset2, displayHeight - backWindowHeight);
        i2 = viewWidth2;
        int i4 = leftViewStartPos2;
        this.mGestureNavBottom.updateViewConfig(rightViewOffset, viewWidth, 0, displayHeight - bottomWindowHeight, i2, bottomWindowHeight, i4, displayHeight - bottomWindowHeight);
        this.mGestureNavAnimProxy.updateViewConfig(rightViewOffset, viewWidth, 0, 0, i2, displayHeight, i4, 0);
    }

    private boolean updateHomeWindowLocked() {
        java.lang.String homeWindow = this.mDeviceStateController.getCurrentHomeActivity(this.mCurrentUserId);
        if (homeWindow == null || homeWindow.equals(this.mHomeWindow)) {
            return false;
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("newHome=");
            stringBuilder.append(homeWindow);
            stringBuilder.append(", oldHome=");
            stringBuilder.append(this.mHomeWindow);
            android.util.Log.i("GestureNavManager", stringBuilder.toString());
        }
        this.mHomeWindow = homeWindow;
        this.mGuideOrOtaAlive = "com.huawei.hwstartupguide/com.huawei.hwstartupguide.LanguageSelectActivity".equals(this.mHomeWindow);
        return true;
    }

    private boolean isSpecialWindowLocked(java.lang.String windowName) {
        if (this.mHomeWindow == null || !this.mHomeWindow.equals(windowName)) {
            return false;
        }
        return true;
    }

    private boolean isFocusWindowBackDisabledLocked() {
        return (this.mFocusWinNavOptions & 262144) != 0;
    }

    private boolean isFocusWindowBottomDisabledLocked() {
        return (this.mFocusWinNavOptions & 524288) != 0;
    }

    private boolean updateNotchDisplayStateLocked() {
        boolean notchStatus = android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "display_notch_status", 0, -2) == 1;
        if (notchStatus == this.mNotchDisplayDisabled) {
            return false;
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("newNotch=");
            stringBuilder.append(notchStatus);
            stringBuilder.append(", oldNotch=");
            stringBuilder.append(this.mNotchDisplayDisabled);
            android.util.Log.d("GestureNavManager", stringBuilder.toString());
        }
        this.mNotchDisplayDisabled = notchStatus;
        return true;
    }

    private boolean updateDisplayDensity() {
        java.lang.String densityStr = android.provider.Settings.Secure.getStringForUser(this.mContext.getContentResolver(), "display_density_forced", -2);
        if (densityStr == null || densityStr.equals(this.mDensityStr)) {
            return false;
        }
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("newDensity=");
            stringBuilder.append(densityStr);
            stringBuilder.append(", oldDensity=");
            stringBuilder.append(this.mDensityStr);
            android.util.Log.d("GestureNavManager", stringBuilder.toString());
        }
        this.mDensityStr = densityStr;
        return true;
    }

    private boolean isRotationChangedInLand(int lastRotation, int newRotation) {
        if ((lastRotation == 1 && newRotation == 3) || (lastRotation == 3 && newRotation == 1)) {
            return true;
        }
        return false;
    }

    public boolean onTouchEvent(com.android.server.gesture.GestureNavView view, android.view.MotionEvent event) {
        switch (view.getNavId()) {
            case 1:
                if (this.mLeftBackStrategy != null) {
                    this.mLeftBackStrategy.onTouchEvent(event);
                    break;
                }
                break;
            case 2:
                if (this.mRightBackStrategy != null) {
                    this.mRightBackStrategy.onTouchEvent(event);
                    break;
                }
                break;
            case 3:
                if (this.mBottomStrategy != null) {
                    this.mBottomStrategy.onTouchEvent(event);
                    break;
                }
                break;
            default:
                break;
        }
        return true;
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter pw, java.lang.String[] args) {
        if (com.android.server.gesture.GestureNavConst.DEBUG_DUMP && this.mGestureNavEnabled) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(prefix);
            stringBuilder.append("GestureNavManager");
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(prefix);
            stringBuilder.append("  ");
            prefix = stringBuilder.toString();
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mDeviceProvisioned=");
            stringBuilder.append(this.mDeviceProvisioned);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mUserSetuped=");
            stringBuilder.append(this.mUserSetuped);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mGuideOrOtaAlive=");
            stringBuilder.append(this.mGuideOrOtaAlive);
            pw.print(stringBuilder.toString());
            pw.println();
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mKeyguardShowing=");
            stringBuilder.append(this.mKeyguardShowing);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mInKeyguardMainWindow=");
            stringBuilder.append(this.mInKeyguardMainWindow);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mNotchDisplayDisabled=");
            stringBuilder.append(this.mNotchDisplayDisabled);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mFocusWindowUsingNotch=");
            stringBuilder.append(this.mFocusWindowUsingNotch);
            pw.print(stringBuilder.toString());
            pw.println();
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mFocusWindowTitle=");
            stringBuilder.append(this.mFocusWindowTitle);
            pw.println(stringBuilder.toString());
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mHomeWindow=");
            stringBuilder.append(this.mHomeWindow);
            pw.println(stringBuilder.toString());
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mDensityStr=");
            stringBuilder.append(this.mDensityStr);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mFocusWinNavOptions=0x");
            stringBuilder.append(java.lang.Integer.toHexString(this.mFocusWinNavOptions));
            pw.print(stringBuilder.toString());
            pw.println();
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mWindowViewSetuped=");
            stringBuilder.append(this.mWindowViewSetuped);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mNavBackEnabled=");
            stringBuilder.append(this.mNavBackEnabled);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mNavBottomEnabled=");
            stringBuilder.append(this.mNavBottomEnabled);
            pw.print(stringBuilder.toString());
            pw.println();
            pw.print(prefix);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mRotation=");
            stringBuilder.append(this.mRotation);
            pw.print(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mLandscape=");
            stringBuilder.append(this.mLandscape);
            pw.print(stringBuilder.toString());
            if (this.mHasNotch) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(" mHasNotch=");
                stringBuilder.append(this.mHasNotch);
                pw.print(stringBuilder.toString());
            }
            pw.println();
            com.android.internal.util.DumpUtils.dumpAsync(this.mHandler, new com.android.internal.util.DumpUtils.Dump() {
                public void dump(java.io.PrintWriter pw, java.lang.String prefix) {
                    java.lang.StringBuilder stringBuilder;
                    if (com.android.server.gesture.GestureNavManager.this.mGestureNavReady && com.android.server.gesture.GestureNavManager.this.mWindowViewSetuped && com.android.server.gesture.GestureNavManager.this.mGestureNavLeft != null) {
                        pw.print(prefix);
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("GestureNavLeft=");
                        stringBuilder.append(com.android.server.gesture.GestureNavManager.this.mGestureNavLeft.getViewConfig());
                        pw.println(stringBuilder.toString());
                    }
                    if (com.android.server.gesture.GestureNavManager.this.mGestureNavReady && com.android.server.gesture.GestureNavManager.this.mWindowViewSetuped && com.android.server.gesture.GestureNavManager.this.mGestureNavRight != null) {
                        pw.print(prefix);
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("GestureNavRight=");
                        stringBuilder.append(com.android.server.gesture.GestureNavManager.this.mGestureNavRight.getViewConfig());
                        pw.println(stringBuilder.toString());
                    }
                    if (com.android.server.gesture.GestureNavManager.this.mGestureNavReady && com.android.server.gesture.GestureNavManager.this.mWindowViewSetuped && com.android.server.gesture.GestureNavManager.this.mGestureNavBottom != null) {
                        pw.print(prefix);
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("GestureNavBottom=");
                        stringBuilder.append(com.android.server.gesture.GestureNavManager.this.mGestureNavBottom.getViewConfig());
                        pw.println(stringBuilder.toString());
                    }
                    if (com.android.server.gesture.GestureNavManager.this.mGestureNavReady && com.android.server.gesture.GestureNavManager.this.mWindowViewSetuped && com.android.server.gesture.GestureNavManager.this.mBottomStrategy != null) {
                        com.android.server.gesture.GestureNavManager.this.mBottomStrategy.dump(prefix, pw, null);
                    }
                }
            }, pw, prefix, 200);
        }
    }
}
