package com.android.server.gesture;

public class GestureNavView extends android.view.SurfaceView {
    private com.android.server.gesture.GestureNavView.IGestureEventProxy mGestureEventProxy;
    private int mNavId;
    private com.android.server.gesture.GestureNavView.WindowConfig mWindowConfig;

    public interface IGestureEventProxy {
        boolean onTouchEvent(com.android.server.gesture.GestureNavView gestureNavView, android.view.MotionEvent motionEvent);
    }

    public interface IGestureNavBackAnim {
        void onGestureAction(boolean z);

        void playDisappearAnim();

        void playFastSlidingAnim();

        void setAnimPosition(float f);

        boolean setAnimProcess(float f);

        void setSide(boolean z);
    }

    public static final class WindowConfig {
        public int displayHeight;
        public int displayWidth;
        public int height;
        public int locationOnScreenX;
        public int locationOnScreenY;
        public int startX;
        public int startY;
        public boolean usingNotch;
        public int width;

        public WindowConfig() {
            this(-1, -1, 0, 0, -1, -1, 0, 0);
        }

        public WindowConfig(int _displayWidth, int _displayHeight, int _startX, int _startY, int _width, int _height, int _locationOnScreenX, int _locationOnScreenY) {
            this.usingNotch = true;
            set(_displayWidth, _displayHeight, _startX, _startY, _width, _height, _locationOnScreenX, _locationOnScreenY);
        }

        private void set(int _displayWidth, int _displayHeight, int _startX, int _startY, int _width, int _height, int _locationOnScreenX, int _locationOnScreenY) {
            this.displayWidth = _displayWidth;
            this.displayHeight = _displayHeight;
            this.startX = _startX;
            this.startY = _startY;
            this.width = _width;
            this.height = _height;
            this.locationOnScreenX = _locationOnScreenX;
            this.locationOnScreenY = _locationOnScreenY;
        }

        public void update(int _displayWidth, int _displayHeight, int _startX, int _startY, int _width, int _height, int _locationOnScreenX, int _locationOnScreenY) {
            set(_displayWidth, _displayHeight, _startX, _startY, _width, _height, _locationOnScreenX, _locationOnScreenY);
        }

        public void udpateNotch(boolean _usingNotch) {
            this.usingNotch = _usingNotch;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("d.w:");
            stringBuilder.append(this.displayWidth);
            stringBuilder.append(", d.h:");
            stringBuilder.append(this.displayHeight);
            stringBuilder.append(", s.x:");
            stringBuilder.append(this.startX);
            stringBuilder.append(", s.y:");
            stringBuilder.append(this.startY);
            stringBuilder.append(", w:");
            stringBuilder.append(this.width);
            stringBuilder.append(", h:");
            stringBuilder.append(this.height);
            stringBuilder.append(", uN:");
            stringBuilder.append(this.usingNotch);
            stringBuilder.append(", l.x:");
            stringBuilder.append(this.locationOnScreenX);
            stringBuilder.append(", l.y:");
            stringBuilder.append(this.locationOnScreenY);
            return stringBuilder.toString();
        }
    }

    public GestureNavView(android.content.Context context) {
        this(context, 0);
    }

    public GestureNavView(android.content.Context context, int navId) {
        super(context);
        this.mNavId = -1;
        this.mWindowConfig = new com.android.server.gesture.GestureNavView.WindowConfig();
        this.mNavId = navId;
        init();
    }

    public GestureNavView(android.content.Context context, android.util.AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public GestureNavView(android.content.Context context, android.util.AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.mNavId = -1;
        this.mWindowConfig = new com.android.server.gesture.GestureNavView.WindowConfig();
        init();
    }

    private void init() {
        setZOrderOnTop(true);
        getHolder().setFormat(-2);
    }

    public void updateViewConfig(int _displayWidth, int _displayHeight, int _startX, int _startY, int _width, int _height, int _locationOnScreenX, int _locationOnScreenY) {
        this.mWindowConfig.update(_displayWidth, _displayHeight, _startX, _startY, _width, _height, _locationOnScreenX, _locationOnScreenY);
    }

    public void updateViewNotchState(boolean usingNotch) {
        this.mWindowConfig.udpateNotch(usingNotch);
    }

    public com.android.server.gesture.GestureNavView.WindowConfig getViewConfig() {
        return this.mWindowConfig;
    }

    public int getNavId() {
        return this.mNavId;
    }

    public void setGestureEventProxy(com.android.server.gesture.GestureNavView.IGestureEventProxy proxy) {
        this.mGestureEventProxy = proxy;
    }

    public void show(boolean enable) {
        setVisibility(enable ? 0 : 8);
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        if (this.mGestureEventProxy != null) {
            return this.mGestureEventProxy.onTouchEvent(this, event);
        }
        return super.onTouchEvent(event);
    }
}
