package com.android.server.gesture;

public class GestureUtils {
    public static final int DEFAULT_DEVICE_ID = 0;
    private static final int DEFAULT_EDGE_FLAGS = 0;
    private static final int DEFAULT_META_STATE = 0;
    private static final float DEFAULT_PRECISION_X = 1.0f;
    private static final float DEFAULT_PRECISION_Y = 1.0f;
    private static final float DEFAULT_PRESSURE_DOWN = 1.0f;
    private static final float DEFAULT_PRESSURE_UP = 0.0f;
    private static final float DEFAULT_SIZE = 1.0f;
    private static final int MOTION_EVENT_INJECTION_DELAY_MILLIS = 5;
    private static boolean mHasInit = false;
    private static boolean mHasNotch = false;
    private static boolean mSupportEffectVb = false;

    public static void systemReady() {
        if (!mHasInit) {
            mHasNotch = parseHole();
            mSupportEffectVb = com.huawei.android.os.HwVibrator.isSupportHwVibrator("haptic.virtual_navigation.click_back");
            if (com.android.server.gesture.GestureNavConst.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("systemReady hasNotch=");
                stringBuilder.append(mHasNotch);
                stringBuilder.append(", effectVb=");
                stringBuilder.append(mSupportEffectVb);
                android.util.Log.d("GestureNav_Utils", stringBuilder.toString());
            }
            mHasInit = true;
        }
    }

    public static boolean parseHole() {
        java.lang.String[] props = android.os.SystemProperties.get("ro.config.hw_notch_size", "").split(",");
        if (props == null || props.length != 4) {
            return false;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prop hole height:");
        stringBuilder.append(java.lang.Integer.parseInt(props[1]));
        android.util.Log.d("GestureNav_Utils", stringBuilder.toString());
        return true;
    }

    public static boolean hasNotch() {
        return mHasNotch;
    }

    public static boolean isSupportEffectVibrator() {
        return mSupportEffectVb;
    }

    public static int getInputDeviceId(int inputSource) {
        for (int devId : android.view.InputDevice.getDeviceIds()) {
            if (android.view.InputDevice.getDevice(devId).supportsSource(inputSource)) {
                return devId;
            }
        }
        return 0;
    }

    public static void sendKeyEvent(int keycode) {
        int i;
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sendKeyEvent keycode=");
            i = keycode;
            stringBuilder.append(i);
            android.util.Log.i("GestureNav_Utils", stringBuilder.toString());
        } else {
            i = keycode;
        }
        long now = android.os.SystemClock.uptimeMillis();
        int[] actions = new int[]{0, 1};
        int effectFlag = mSupportEffectVb ? 0 : 64;
        int i2 = 0;
        while (true) {
            int i3 = i2;
            if (i3 < actions.length) {
                int i4 = i3;
                int[] actions2 = actions;
                android.hardware.input.InputManager.getInstance().injectInputEvent(new android.view.KeyEvent(now, now, actions[i3], i, 0, 0, -1, 0, 8 | effectFlag, 257), 0);
                i2 = i4 + 1;
                int i5 = 0;
                actions = actions2;
            } else {
                return;
            }
        }
    }

    public static void sendTap(float x, float y, int deviceId, int source) {
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sendTap (");
            stringBuilder.append(x);
            stringBuilder.append(", ");
            stringBuilder.append(y);
            stringBuilder.append(")");
            android.util.Log.d("GestureNav_Utils", stringBuilder.toString());
        }
        long downTime = android.os.SystemClock.uptimeMillis();
        long j = downTime;
        float f = x;
        float f2 = y;
        int i = deviceId;
        int i2 = source;
        injectMotionEvent(0, j, downTime, f, f2, 1.0f, i, i2);
        injectMotionEvent(1, j, android.os.SystemClock.uptimeMillis(), f, f2, 0.0f, i, i2);
    }

    public static void sendSwipe(float x1, float y1, float x2, float y2, int duration, int deviceId, int source, java.util.ArrayList<android.graphics.PointF> pendingMovePoints, boolean hasMultiTouched) {
        long size;
        long size2;
        float f = x1;
        float f2 = y1;
        float f3 = x2;
        float f4 = y2;
        int i = duration;
        java.util.ArrayList<android.graphics.PointF> arrayList = pendingMovePoints;
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sendSwipe (");
            stringBuilder.append(f);
            stringBuilder.append(", ");
            stringBuilder.append(f2);
            stringBuilder.append(") to (");
            stringBuilder.append(f3);
            stringBuilder.append(", ");
            stringBuilder.append(f4);
            stringBuilder.append("), duration:");
            stringBuilder.append(i);
            android.util.Log.d("GestureNav_Utils", stringBuilder.toString());
        }
        if (i < 80) {
            i = 80;
        } else if (i > 500) {
            i = 500;
        }
        int duration2 = i;
        long now = android.os.SystemClock.uptimeMillis();
        long downTime = now;
        injectMotionEvent(0, downTime, now, f, f2, 1.0f, deviceId, source);
        long size3;
        if (hasMultiTouched || arrayList == null) {
            size3 = 0;
        } else {
            long size4 = (long) pendingMovePoints.size();
            size = size4;
            if (size4 > 0) {
                if (com.android.server.gesture.GestureNavConst.DEBUG != null) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("inject ");
                    stringBuilder2.append(size);
                    stringBuilder2.append(" pending move points");
                    android.util.Log.d("GestureNav_Utils", stringBuilder2.toString());
                }
                size2 = null;
                while (true) {
                    int i2 = size2;
                    if (((long) i2) >= size) {
                        break;
                    }
                    float f5 = ((android.graphics.PointF) arrayList.get(i2)).x;
                    float f6 = f5;
                    int i3 = i2;
                    size3 = size;
                    injectMotionEvent(2, downTime, now, f6, ((android.graphics.PointF) arrayList.get(i2)).y, 1.0f, deviceId, source);
                    android.os.SystemClock.sleep(5);
                    now = android.os.SystemClock.uptimeMillis();
                    size2 = i3 + 1;
                    size = size3;
                }
                injectMotionEvent(1, downTime, now, f3, f4, 0.0f, deviceId, source);
            }
        }
        size2 = downTime + ((long) duration2);
        while (true) {
            long endTime = size2;
            if (now >= endTime) {
                break;
            }
            size = now - downTime;
            float alpha = ((float) size) / ((float) duration2);
            injectMotionEvent(2, downTime, now, lerp(f, f3, alpha), lerp(f2, f4, alpha), 1.0f, deviceId, source);
            android.os.SystemClock.sleep(5);
            now = android.os.SystemClock.uptimeMillis();
            long j = 5;
            size2 = endTime;
        }
        injectMotionEvent(1, downTime, now, f3, f4, 0.0f, deviceId, source);
    }

    public static void injectMotionEvent(int action, long downTime, long eventTime, float x, float y, int deviceId, int source) {
        int i = action;
        injectMotionEvent(i, downTime, eventTime, x, y, i == 1 ? 0.0f : 1.0f, deviceId, source);
    }

    public static void injectMotionEvent(int action, long downTime, long eventTime, float x, float y, float pressure, int deviceId, int source) {
        android.view.MotionEvent event = android.view.MotionEvent.obtain(downTime, eventTime, action, x, y, pressure, 1.0f, 0, 1.0f, 1.0f, deviceId, 0);
        event.setSource(source);
        ((android.hardware.input.InputManagerInternal) com.android.server.LocalServices.getService(android.hardware.input.InputManagerInternal.class)).injectInputEvent(event, 0, 0, 524288);
    }

    public static void injectDownWithBatchMoveEvent(long downTime, float downX, float downY, java.util.ArrayList<android.graphics.PointF> batchMovePoints, long durationTime, int deviceId, int source) {
        java.util.ArrayList<android.graphics.PointF> arrayList = batchMovePoints;
        android.view.MotionEvent event = android.view.MotionEvent.obtain(downTime, downTime, 0, downX, downY, 1.0f, 1.0f, 0, 1.0f, 1.0f, deviceId, 0);
        event.setSource(source);
        int appendPolicyFlag = 524288;
        int size;
        if (arrayList != null) {
            int size2 = batchMovePoints.size();
            size = size2;
            if (size2 > 0) {
                int appendPolicyFlag2 = 524288 | 262144;
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("inject down with ");
                    stringBuilder.append(size);
                    stringBuilder.append(" batch move points");
                    android.util.Log.d("GestureNav_Utils", stringBuilder.toString());
                }
                appendPolicyFlag = 0;
                while (true) {
                    int i = appendPolicyFlag;
                    if (i >= size) {
                        break;
                    }
                    event.addBatch(downTime + ((long) (((1.0f * ((float) (i + 1))) / ((float) size)) * ((float) durationTime))), ((android.graphics.PointF) arrayList.get(i)).x, ((android.graphics.PointF) arrayList.get(i)).y, 1.0f, 1.0f, 0);
                    appendPolicyFlag = i + 1;
                }
                appendPolicyFlag = appendPolicyFlag2;
            }
        } else {
            size = 0;
        }
        ((android.hardware.input.InputManagerInternal) com.android.server.LocalServices.getService(android.hardware.input.InputManagerInternal.class)).injectInputEvent(event, 0, 0, appendPolicyFlag);
    }

    private static final float lerp(float a, float b, float alpha) {
        return ((b - a) * alpha) + a;
    }

    public static double angle(float distanceX, float distanceY, boolean divY) {
        if ((divY ? distanceY : distanceX) == 0.0f) {
            return 90.0d;
        }
        return (java.lang.Math.atan((double) (divY ? distanceX / distanceY : distanceY / distanceX)) / 3.141592653589793d) * 180.0d;
    }

    public static void addWindowView(android.view.WindowManager mWindowManager, android.view.View view, android.view.WindowManager.LayoutParams params) {
        if (view != null) {
            try {
                mWindowManager.addView(view, params);
            } catch (java.lang.Exception e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("addWindowView fail.");
                stringBuilder.append(e);
                android.util.Log.e("GestureNav_Utils", stringBuilder.toString());
            }
        }
    }

    public static void updateViewLayout(android.view.WindowManager mWindowManager, android.view.View view, android.view.WindowManager.LayoutParams params) {
        if (view != null) {
            try {
                mWindowManager.updateViewLayout(view, params);
            } catch (java.lang.Exception e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateViewLayout fail.");
                stringBuilder.append(e);
                android.util.Log.e("GestureNav_Utils", stringBuilder.toString());
            }
        }
    }

    public static void removeWindowView(android.view.WindowManager mWindowManager, android.view.View view, boolean immediate) {
        java.lang.StringBuilder stringBuilder;
        if (view != null) {
            if (immediate) {
                try {
                    mWindowManager.removeViewImmediate(view);
                } catch (java.lang.IllegalArgumentException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("removeWindowView fail.");
                    stringBuilder.append(e);
                    android.util.Log.e("GestureNav_Utils", stringBuilder.toString());
                } catch (java.lang.IllegalArgumentException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("removeWindowView fail.");
                    stringBuilder.append(e2);
                    android.util.Log.e("GestureNav_Utils", stringBuilder.toString());
                }
            } else {
                mWindowManager.removeView(view);
            }
        }
    }

    public static boolean isInLockTaskMode() {
        boolean z = false;
        try {
            if (android.app.ActivityManager.getService().getLockTaskModeState() != 0) {
                z = true;
            }
            return z;
        } catch (android.os.RemoteException e) {
            android.util.Log.d("GestureNav_Utils", "Check lock task mode fail.", e);
            return false;
        }
    }

    public static void exitLockTaskMode() {
        try {
            android.app.ActivityManager.getService().stopSystemLockTaskMode();
        } catch (android.os.RemoteException e) {
            android.util.Log.d("GestureNav_Utils", "Exit lock task mode fail.", e);
        }
    }

    public static android.app.ActivityManager.RunningTaskInfo getRunningTask(android.content.Context context) {
        java.util.List<android.app.ActivityManager.RunningTaskInfo> tasks = ((android.app.ActivityManager) context.getSystemService("activity")).getRunningTasks(1);
        if (tasks == null || tasks.isEmpty()) {
            return null;
        }
        return (android.app.ActivityManager.RunningTaskInfo) tasks.get(0);
    }

    public static boolean isSuperPowerSaveMode() {
        return android.os.SystemProperties.getBoolean("sys.super_power_save", false);
    }

    public static boolean playHwEffectForBackIfNeed(android.content.Context context) {
        if (!mSupportEffectVb || !isHapticFedbackEnabled(context)) {
            return false;
        }
        com.huawei.android.os.HwVibrator.setHwVibrator(android.os.Process.myUid(), "android", "haptic.virtual_navigation.click_back");
        return true;
    }

    public static boolean isHapticFedbackEnabled(android.content.Context context) {
        return android.provider.Settings.System.getIntForUser(context.getContentResolver(), "haptic_feedback_enabled", 0, -2) != 0;
    }
}
