package com.android.server.gesture;

public class QuickStepController extends com.android.server.gesture.QuickStartupStub {
    public static final int HIT_TARGET_OVERVIEW = 3;
    private static final java.lang.String TALKBACK_COMPONENT_NAME = "com.google.android.marvin.talkback/com.google.android.marvin.talkback.TalkBackService";
    private boolean mKeyguardShowing;
    private android.os.Looper mLooper;
    private com.android.server.gesture.GestureNavView mNavView;
    private com.android.server.gesture.OverviewProxyService mOverviewEventSender;
    private boolean mQuickStepStarted;
    private com.android.server.gesture.QuickStepController.SettingsObserver mSettingsObserver;
    private boolean mTalkBackOn;
    private final android.graphics.Matrix mTransformGlobalMatrix = new android.graphics.Matrix();
    private final android.graphics.Matrix mTransformLocalMatrix = new android.graphics.Matrix();

    private final class SettingsObserver extends android.database.ContentObserver {
        public SettingsObserver(android.os.Handler handler) {
            super(handler);
        }

        public void onChange(boolean selfChange) {
            com.android.server.gesture.QuickStepController.this.updateSettings();
        }
    }

    public QuickStepController(android.content.Context context, android.os.Looper looper) {
        super(context);
        this.mLooper = looper;
    }

    private com.android.systemui.shared.recents.IOverviewProxy getOverviewProxy() {
        if (this.mOverviewEventSender != null) {
            return this.mOverviewEventSender.getProxy();
        }
        return null;
    }

    public boolean isSupportMultiTouch() {
        return this.mTalkBackOn;
    }

    public void updateDeviceState(boolean keyguardShowing) {
        this.mKeyguardShowing = keyguardShowing;
    }

    public void updateSettings() {
        android.content.ContentResolver resolver = this.mContext.getContentResolver();
        boolean z = false;
        boolean accessibilityEnabled = android.provider.Settings.Secure.getIntForUser(resolver, "accessibility_enabled", 0, -2) == 1;
        java.lang.String enabledSerices = android.provider.Settings.Secure.getStringForUser(resolver, "enabled_accessibility_services", -2);
        boolean isContainsTalkBackService = enabledSerices != null && enabledSerices.contains("com.google.android.marvin.talkback/com.google.android.marvin.talkback.TalkBackService");
        if (accessibilityEnabled && isContainsTalkBackService) {
            z = true;
        }
        this.mTalkBackOn = z;
        if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("accessEnabled:");
            stringBuilder.append(accessibilityEnabled);
            stringBuilder.append(", hasTalkback:");
            stringBuilder.append(isContainsTalkBackService);
            android.util.Log.d("GestureNav_QS", stringBuilder.toString());
        }
    }

    public void onNavCreate(com.android.server.gesture.GestureNavView navView) {
        super.onNavCreate(navView);
        this.mNavView = navView;
        this.mOverviewEventSender = new com.android.server.gesture.OverviewProxyService(this.mContext, this.mLooper);
        this.mOverviewEventSender.notifyStart();
        this.mSettingsObserver = new com.android.server.gesture.QuickStepController.SettingsObserver(new android.os.Handler(this.mLooper));
        android.content.ContentResolver resolver = this.mContext.getContentResolver();
        resolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("accessibility_enabled"), false, this.mSettingsObserver, -1);
        resolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("enabled_accessibility_services"), false, this.mSettingsObserver, -1);
        updateSettings();
    }

    public void onNavUpdate() {
        super.onNavUpdate();
        if (this.mNavView != null) {
            this.mNavView.invalidate();
        }
    }

    public void onNavDestroy() {
        super.onNavDestroy();
        if (this.mSettingsObserver != null) {
            this.mContext.getContentResolver().unregisterContentObserver(this.mSettingsObserver);
            this.mSettingsObserver = null;
        }
        if (this.mOverviewEventSender != null) {
            this.mOverviewEventSender.notifyStop();
            this.mOverviewEventSender = null;
        }
        this.mNavView = null;
    }

    public void onGestureSuccessFinished(float distance, long durationTime, float velocity, boolean isFastSlideGesture, java.lang.Runnable runnable) {
        super.onGestureSuccessFinished(distance, durationTime, velocity, isFastSlideGesture, runnable);
        if (!this.mKeyguardShowing) {
            return;
        }
        if (isGoHomeAllRight(distance, durationTime) && runnable != null) {
            runnable.run();
        } else if (com.android.server.gesture.GestureNavConst.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("keyguard go home fail, distance=");
            stringBuilder.append(distance);
            stringBuilder.append(", durationTime=");
            stringBuilder.append(durationTime);
            android.util.Log.d("GestureNav_QS", stringBuilder.toString());
        }
    }

    public void handleTouchEvent(android.view.MotionEvent event) {
        if (!(com.android.server.gesture.GestureNavConst.USE_ANIM_LEGACY || getOverviewProxy() == null)) {
            if (!this.mKeyguardShowing) {
                int action = event.getActionMasked();
                if (action == 0) {
                    this.mTransformGlobalMatrix.set(android.graphics.Matrix.IDENTITY_MATRIX);
                    this.mTransformLocalMatrix.set(android.graphics.Matrix.IDENTITY_MATRIX);
                    if (this.mNavView != null) {
                        this.mNavView.transformMatrixToGlobal(this.mTransformGlobalMatrix);
                        this.mNavView.transformMatrixToLocal(this.mTransformLocalMatrix);
                    }
                    this.mQuickStepStarted = false;
                    this.mGestureReallyStarted = false;
                } else if (action == 2) {
                    if (!this.mQuickStepStarted) {
                        if (this.mGestureReallyStarted) {
                            startQuickStep(event);
                        }
                    }
                }
                proxyMotionEvents(event);
            }
        }
    }

    private void startQuickStep(android.view.MotionEvent event) {
        this.mQuickStepStarted = true;
        com.android.systemui.shared.recents.IOverviewProxy overviewProxy = getOverviewProxy();
        if (overviewProxy != null) {
            event.transform(this.mTransformGlobalMatrix);
            try {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    android.util.Log.d("GestureNav_QS", "Quick Step Start");
                }
                overviewProxy.onQuickStep(event);
            } catch (android.os.RemoteException e) {
                android.util.Log.e("GestureNav_QS", "Failed to send quick step started.", e);
            } catch (Throwable th) {
                event.transform(this.mTransformLocalMatrix);
            }
            event.transform(this.mTransformLocalMatrix);
        }
    }

    private boolean proxyMotionEvents(android.view.MotionEvent event) {
        com.android.systemui.shared.recents.IOverviewProxy overviewProxy = getOverviewProxy();
        boolean z = false;
        if (overviewProxy == null) {
            return false;
        }
        event.transform(this.mTransformGlobalMatrix);
        try {
            if (event.getActionMasked() == 0) {
                if (com.android.server.gesture.GestureNavConst.DEBUG) {
                    android.util.Log.i("GestureNav_QS", "Send Motion Down Event");
                }
                overviewProxy.onPreMotionEvent(3);
            }
            if (com.android.server.gesture.GestureNavConst.DEBUG_ALL) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Send MotionEvent: ");
                stringBuilder.append(event.toString());
                android.util.Log.d("GestureNav_QS", stringBuilder.toString());
            }
            overviewProxy.onMotionEvent(event);
            z = true;
            return z;
        } catch (android.os.RemoteException e) {
            android.util.Log.e("GestureNav_QS", "Callback failed", e);
            return z;
        } finally {
            event.transform(this.mTransformLocalMatrix);
        }
    }

    private boolean isGoHomeAllRight(float distance, long durationTime) {
        if (distance <= 180.0f || durationTime >= 500) {
            return false;
        }
        return true;
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter pw, java.lang.String[] args) {
        pw.print(prefix);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mTalkBackOn=");
        stringBuilder.append(this.mTalkBackOn);
        pw.println(stringBuilder.toString());
        if (this.mOverviewEventSender != null) {
            this.mOverviewEventSender.dump(prefix, pw, args);
        }
    }
}
