package com.android.server.gesture;

public class SlideOutCircleView extends android.widget.FrameLayout {
    public static final android.view.animation.Interpolator ALPHA_OUT = new android.view.animation.PathInterpolator(0.0f, 0.0f, 0.8f, 1.0f);
    private final android.graphics.Paint mBackgroundPaint;
    private final int mBaseMargin;
    private float mCircleAnimationEndValue;
    private android.animation.ValueAnimator mCircleAnimator;
    private int mCircleCenterStartPos;
    private boolean mCircleHidden;
    private final int mCircleMaxSize;
    private final int mCircleMinSize;
    private final android.graphics.Rect mCircleRect;
    private final int mCircleSideMargin;
    private float mCircleSize;
    private android.animation.ValueAnimator.AnimatorUpdateListener mCircleUpdateListener;
    private android.animation.AnimatorListenerAdapter mClearAnimatorListener;
    private boolean mClipToOutline;
    private final android.view.animation.Interpolator mDisappearInterpolator;
    private boolean mDraggedFarEnough;
    private android.animation.ValueAnimator mFadeOutAnimator;
    private final android.view.animation.Interpolator mFastOutSlowInInterpolator;
    private android.widget.ImageView mLeftLogo;
    private final int mMaxElevation;
    private float mOffset;
    private boolean mOffsetAnimatingIn;
    private android.animation.ValueAnimator mOffsetAnimator;
    private android.animation.ValueAnimator.AnimatorUpdateListener mOffsetUpdateListener;
    private float mOutlineAlpha;
    private android.widget.ImageView mRightLogo;
    private boolean mSlidingOnLeft;
    private final int mStaticOffset;
    private final android.graphics.Rect mStaticRect;

    private static class MyAnimatorListenerAdapter extends android.animation.AnimatorListenerAdapter {
        java.lang.Runnable mRunnable;

        public MyAnimatorListenerAdapter(java.lang.Runnable runnable) {
            this.mRunnable = runnable;
        }

        public void onAnimationEnd(android.animation.Animator animation) {
            if (this.mRunnable != null) {
                this.mRunnable.run();
            }
        }
    }

    public SlideOutCircleView(android.content.Context context) {
        this(context, null);
    }

    public SlideOutCircleView(android.content.Context context, android.util.AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public SlideOutCircleView(android.content.Context context, android.util.AttributeSet attrs, int defStyleAttr) {
        this(context, attrs, defStyleAttr, 0);
    }

    public SlideOutCircleView(android.content.Context context, android.util.AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.mBackgroundPaint = new android.graphics.Paint();
        this.mCircleRect = new android.graphics.Rect();
        this.mStaticRect = new android.graphics.Rect();
        this.mSlidingOnLeft = true;
        this.mCircleUpdateListener = new android.animation.ValueAnimator.AnimatorUpdateListener() {
            public void onAnimationUpdate(android.animation.ValueAnimator animation) {
                com.android.server.gesture.SlideOutCircleView.this.applyCircleSize(((java.lang.Float) animation.getAnimatedValue()).floatValue());
                com.android.server.gesture.SlideOutCircleView.this.updateElevation();
            }
        };
        this.mClearAnimatorListener = new android.animation.AnimatorListenerAdapter() {
            public void onAnimationEnd(android.animation.Animator animation) {
                com.android.server.gesture.SlideOutCircleView.this.mCircleAnimator = null;
            }
        };
        this.mOffsetUpdateListener = new android.animation.ValueAnimator.AnimatorUpdateListener() {
            public void onAnimationUpdate(android.animation.ValueAnimator animation) {
                com.android.server.gesture.SlideOutCircleView.this.setOffset(((java.lang.Float) animation.getAnimatedValue()).floatValue());
            }
        };
        setOutlineProvider(new android.view.ViewOutlineProvider() {
            public void getOutline(android.view.View view, android.graphics.Outline outline) {
                if (com.android.server.gesture.SlideOutCircleView.this.mCircleSize > 0.0f) {
                    outline.setOval(com.android.server.gesture.SlideOutCircleView.this.mCircleRect);
                } else {
                    outline.setEmpty();
                }
                outline.setAlpha(com.android.server.gesture.SlideOutCircleView.this.mOutlineAlpha);
            }
        });
        setWillNotDraw(false);
        this.mCircleSideMargin = context.getResources().getDimensionPixelSize(34472401);
        this.mCircleMinSize = context.getResources().getDimensionPixelSize(34472400);
        this.mCircleMaxSize = context.getResources().getDimensionPixelSize(34472399);
        this.mCircleCenterStartPos = context.getResources().getDimensionPixelSize(34472398);
        this.mBaseMargin = context.getResources().getDimensionPixelSize(34472397);
        this.mStaticOffset = context.getResources().getDimensionPixelSize(34472403);
        this.mMaxElevation = context.getResources().getDimensionPixelSize(34472146);
        this.mFastOutSlowInInterpolator = android.view.animation.AnimationUtils.loadInterpolator(this.mContext, 17563661);
        this.mDisappearInterpolator = android.view.animation.AnimationUtils.loadInterpolator(this.mContext, 17563663);
        this.mBackgroundPaint.setAntiAlias(true);
        this.mBackgroundPaint.setColor(getResources().getColor(33882315));
    }

    protected void onDraw(android.graphics.Canvas canvas) {
        super.onDraw(canvas);
        drawBackground(canvas);
    }

    private void drawBackground(android.graphics.Canvas canvas) {
        canvas.drawCircle((float) this.mCircleRect.centerX(), (float) this.mCircleRect.centerY(), this.mCircleSize / 2.0f, this.mBackgroundPaint);
    }

    protected void onFinishInflate() {
        super.onFinishInflate();
        this.mLeftLogo = (android.widget.ImageView) findViewById(34603223);
        this.mRightLogo = (android.widget.ImageView) findViewById(34603249);
    }

    protected void onLayout(boolean changed, int l, int t, int r, int b) {
        super.onLayout(changed, l, t, r, b);
        this.mLeftLogo.layout(0, 0, this.mLeftLogo.getMeasuredWidth(), this.mLeftLogo.getMeasuredHeight());
        this.mRightLogo.layout(0, 0, this.mRightLogo.getMeasuredWidth(), this.mRightLogo.getMeasuredHeight());
        if (changed) {
            updateCircleRect(this.mStaticRect, (float) this.mStaticOffset, true);
        }
    }

    public void setSlidingSide(boolean onLeft) {
        this.mSlidingOnLeft = onLeft;
        if (this.mSlidingOnLeft) {
            this.mLeftLogo.setVisibility(0);
            this.mRightLogo.setVisibility(4);
        } else {
            this.mLeftLogo.setVisibility(4);
            this.mRightLogo.setVisibility(0);
        }
        updateCircleRect(this.mStaticRect, (float) this.mStaticOffset, true);
    }

    public android.widget.ImageView getLogo() {
        return this.mSlidingOnLeft ? this.mLeftLogo : this.mRightLogo;
    }

    public void setCircleSize(float circleSize) {
        setCircleSize(circleSize, false, null, 0, null);
    }

    public void setCircleSize(float circleSize, boolean animated, java.lang.Runnable endRunnable, int startDelay, android.view.animation.Interpolator interpolator) {
        boolean isAnimating = this.mCircleAnimator != null;
        boolean animationPending = isAnimating && !this.mCircleAnimator.isRunning();
        boolean animatingOut = isAnimating && this.mCircleAnimationEndValue == 0.0f;
        if (!(animated || animationPending)) {
            if (!animatingOut) {
                if (isAnimating) {
                    float diff = circleSize - this.mCircleAnimationEndValue;
                    this.mCircleAnimator.getValues()[0].setFloatValues(new float[]{diff, circleSize});
                    this.mCircleAnimator.setCurrentPlayTime(this.mCircleAnimator.getCurrentPlayTime());
                    this.mCircleAnimationEndValue = circleSize;
                    return;
                }
                applyCircleSize(circleSize);
                updateElevation();
                return;
            }
        }
        if (isAnimating) {
            this.mCircleAnimator.cancel();
        }
        this.mCircleAnimator = android.animation.ValueAnimator.ofFloat(new float[]{this.mCircleSize, circleSize});
        this.mCircleAnimator.addUpdateListener(this.mCircleUpdateListener);
        this.mCircleAnimator.addListener(this.mClearAnimatorListener);
        this.mCircleAnimator.addListener(new com.android.server.gesture.SlideOutCircleView.MyAnimatorListenerAdapter(endRunnable));
        this.mCircleAnimator.setInterpolator(interpolator != null ? interpolator : this.mDisappearInterpolator);
        this.mCircleAnimator.setDuration(300);
        this.mCircleAnimator.setStartDelay((long) startDelay);
        this.mCircleAnimator.start();
        this.mCircleAnimationEndValue = circleSize;
    }

    private void applyCircleSize(float circleSize) {
        this.mCircleSize = circleSize;
        updateLayout();
    }

    private void updateElevation() {
        float t = (((float) this.mStaticOffset) - this.mOffset) / ((float) this.mStaticOffset);
        float f = 0.0f;
        if (1.0f - t > 0.0f) {
            f = t;
        }
        setElevation(((float) this.mMaxElevation) * f);
    }

    public void setOffset(float offset) {
        setOffset(offset, false, 0, null, null);
    }

    private void setOffset(float offset, boolean animate, int startDelay, android.view.animation.Interpolator interpolator, final java.lang.Runnable endRunnable) {
        if (animate) {
            if (this.mOffsetAnimator != null) {
                this.mOffsetAnimator.removeAllListeners();
                this.mOffsetAnimator.cancel();
            }
            float[] fArr = new float[2];
            fArr[0] = this.mOffset;
            boolean z = true;
            fArr[1] = offset;
            this.mOffsetAnimator = android.animation.ValueAnimator.ofFloat(fArr);
            this.mOffsetAnimator.addUpdateListener(this.mOffsetUpdateListener);
            this.mOffsetAnimator.addListener(new android.animation.AnimatorListenerAdapter() {
                public void onAnimationEnd(android.animation.Animator animation) {
                    com.android.server.gesture.SlideOutCircleView.this.mOffsetAnimator = null;
                    if (endRunnable != null) {
                        endRunnable.run();
                    }
                }
            });
            this.mOffsetAnimator.setInterpolator(interpolator != null ? interpolator : this.mDisappearInterpolator);
            this.mOffsetAnimator.setStartDelay((long) startDelay);
            this.mOffsetAnimator.setDuration(300);
            this.mOffsetAnimator.start();
            if (offset == 0.0f) {
                z = false;
            }
            this.mOffsetAnimatingIn = z;
            return;
        }
        this.mOffset = offset;
        updateLayout();
        if (endRunnable != null) {
            endRunnable.run();
        }
    }

    private void updateLayout() {
        updateCircleRect();
        updateLogo();
        invalidateOutline();
        invalidate();
        updateClipping();
    }

    private void updateClipping() {
        boolean clip = this.mCircleSize < ((float) this.mCircleMinSize);
        if (clip != this.mClipToOutline) {
            setClipToOutline(clip);
            this.mClipToOutline = clip;
        }
    }

    private void updateLogo() {
        android.widget.ImageView mLogo = getLogo();
        boolean exitAnimationRunning = this.mFadeOutAnimator != null;
        android.graphics.Rect rect = exitAnimationRunning ? this.mCircleRect : this.mStaticRect;
        float translationX = (((float) (rect.left + rect.right)) / 2.0f) - (((float) mLogo.getWidth()) / 2.0f);
        float translationY = (((float) (rect.top + rect.bottom)) / 2.0f) - (((float) mLogo.getHeight()) / 2.0f);
        float t = (((float) this.mStaticOffset) - this.mOffset) / ((float) this.mStaticOffset);
        if (exitAnimationRunning) {
            translationY += (this.mOffset - ((float) this.mStaticOffset)) / 2.0f;
        } else {
            translationY += (((float) this.mStaticOffset) * t) * 0.3f;
            float alphaTmp = ((1.0f - t) - 0.5f) * 2.0f;
            float alpha = 0.0f;
            if (alphaTmp > 0.0f) {
                alpha = alphaTmp;
            }
            mLogo.setAlpha(alpha);
        }
        mLogo.setTranslationX(translationX);
        mLogo.setTranslationY(translationY);
    }

    private void updateCircleRect() {
        updateCircleRect(this.mCircleRect, this.mOffset, false);
    }

    private void updateCircleRect(android.graphics.Rect rect, float offset, boolean useStaticSize) {
        int left;
        int top;
        float circleSize = useStaticSize ? (float) this.mCircleMinSize : this.mCircleSize;
        if (this.mSlidingOnLeft) {
            left = (int) (((float) (this.mCircleSideMargin + this.mCircleCenterStartPos)) - (circleSize / 2.0f));
            top = (int) (((((float) getHeight()) - (circleSize / 2.0f)) - ((float) this.mBaseMargin)) - offset);
        } else {
            left = (int) (((float) ((getWidth() - this.mCircleSideMargin) - this.mCircleCenterStartPos)) - (circleSize / 2.0f));
            top = (int) (((((float) getHeight()) - (circleSize / 2.0f)) - ((float) this.mBaseMargin)) - offset);
        }
        rect.set(left, top, (int) (((float) left) + circleSize), (int) (((float) top) + circleSize));
    }

    public void setDragDistance(float distance) {
        if (!this.mCircleHidden || this.mDraggedFarEnough) {
            float circleSize = ((float) this.mCircleMinSize) + rubberband(distance);
            if (circleSize > ((float) this.mCircleMaxSize)) {
                circleSize = (float) this.mCircleMaxSize;
            }
            setCircleSize(circleSize);
        }
    }

    private float rubberband(float diff) {
        return (float) java.lang.Math.pow((double) java.lang.Math.abs(diff), 0.6000000238418579d);
    }

    public void startAbortAnimation(java.lang.Runnable endRunnable, boolean animAlpha) {
        setCircleSize(0.0f, true, null, 0, null);
        setOffset(0.0f, true, 0, null, endRunnable);
        if (animAlpha) {
            animate().alpha(0.0f).setDuration(300).setStartDelay(0).setInterpolator(ALPHA_OUT).start();
        } else {
            setAlpha(0.0f);
        }
        this.mCircleHidden = true;
    }

    public void startEnterAnimation() {
        setAlpha(1.0f);
        applyCircleSize(0.0f);
        setOffset(0.0f);
        setCircleSize((float) this.mCircleMinSize, true, null, 50, null);
        setOffset((float) this.mStaticOffset, true, 50, null, null);
        this.mCircleHidden = false;
    }

    public void startExitAnimation(java.lang.Runnable endRunnable, boolean isFastSlide) {
        setOffset((((float) getHeight()) / 2.0f) - ((float) this.mBaseMargin), true, 50, this.mFastOutSlowInInterpolator, null);
        setCircleSize((float) java.lang.Math.ceil(java.lang.Math.hypot((double) (((float) getWidth()) / 2.0f), (double) (((float) getHeight()) / 2.0f)) * 2.0d), true, null, 50, this.mFastOutSlowInInterpolator);
        performExitFadeOutAnimation(50, 300, endRunnable);
    }

    private void performExitFadeOutAnimation(int startDelay, int duration, final java.lang.Runnable endRunnable) {
        this.mFadeOutAnimator = android.animation.ValueAnimator.ofFloat(new float[]{((float) this.mBackgroundPaint.getAlpha()) / 255.0f, 0.0f});
        this.mFadeOutAnimator.setInterpolator(new android.view.animation.LinearInterpolator());
        this.mFadeOutAnimator.addUpdateListener(new android.animation.ValueAnimator.AnimatorUpdateListener() {
            public void onAnimationUpdate(android.animation.ValueAnimator animation) {
                float backgroundValue;
                float animatedFraction = animation.getAnimatedFraction();
                float logoValue = com.android.server.gesture.SlideOutCircleView.ALPHA_OUT.getInterpolation(1.0f - (animatedFraction > 0.5f ? 1.0f : animatedFraction / 0.5f));
                if (animatedFraction < 0.2f) {
                    backgroundValue = 0.0f;
                } else {
                    backgroundValue = com.android.server.gesture.SlideOutCircleView.ALPHA_OUT.getInterpolation((animatedFraction - 0.2f) / 0.8f);
                }
                float backgroundValue2 = 1.0f - backgroundValue;
                com.android.server.gesture.SlideOutCircleView.this.mBackgroundPaint.setAlpha((int) (255.0f * backgroundValue2));
                com.android.server.gesture.SlideOutCircleView.this.mOutlineAlpha = backgroundValue2;
                com.android.server.gesture.SlideOutCircleView.this.getLogo().setAlpha(logoValue);
                com.android.server.gesture.SlideOutCircleView.this.invalidateOutline();
                com.android.server.gesture.SlideOutCircleView.this.invalidate();
            }
        });
        this.mFadeOutAnimator.addListener(new android.animation.AnimatorListenerAdapter() {
            public void onAnimationEnd(android.animation.Animator animation) {
                if (endRunnable != null) {
                    endRunnable.run();
                }
                com.android.server.gesture.SlideOutCircleView.this.getLogo().setAlpha(1.0f);
                com.android.server.gesture.SlideOutCircleView.this.mBackgroundPaint.setAlpha(255);
                com.android.server.gesture.SlideOutCircleView.this.mOutlineAlpha = 1.0f;
                com.android.server.gesture.SlideOutCircleView.this.mFadeOutAnimator = null;
            }
        });
        this.mFadeOutAnimator.setStartDelay((long) startDelay);
        this.mFadeOutAnimator.setDuration((long) duration);
        this.mFadeOutAnimator.start();
    }

    public void setDraggedFarEnough(boolean farEnough) {
        if (farEnough != this.mDraggedFarEnough) {
            if (!farEnough) {
                startAbortAnimation(null, false);
            } else if (this.mCircleHidden) {
                startEnterAnimation();
            }
            this.mDraggedFarEnough = farEnough;
        }
    }

    public void reset() {
        this.mDraggedFarEnough = false;
        this.mCircleHidden = true;
        this.mClipToOutline = false;
        if (this.mFadeOutAnimator != null) {
            this.mFadeOutAnimator.cancel();
        }
        this.mBackgroundPaint.setAlpha(255);
        this.mOutlineAlpha = 1.0f;
    }

    public boolean isAnimationRunning(boolean enterAnimation) {
        return this.mOffsetAnimator != null && enterAnimation == this.mOffsetAnimatingIn;
    }

    public void performOnAnimationFinished(java.lang.Runnable runnable) {
        if (this.mOffsetAnimator != null) {
            this.mOffsetAnimator.addListener(new com.android.server.gesture.SlideOutCircleView.MyAnimatorListenerAdapter(runnable));
        } else if (runnable != null) {
            runnable.run();
        }
    }

    public boolean hasOverlappingRendering() {
        return false;
    }
}
