package com.android.server.gesture;

public class SlideOutContainer extends android.widget.FrameLayout {
    private static final long EXIT_START_DELAY = 150;
    private boolean mAnimatingOut;
    private final java.lang.Runnable mHideImmediatelyRunnable;
    private final java.lang.Runnable mHideRunnable;
    private com.android.server.gesture.anim.HwGestureSideLayout mOrb;
    private com.android.server.gesture.SlideOutCircleView mOrbLegacy;
    private android.view.View mScrim;

    public SlideOutContainer(android.content.Context context) {
        this(context, null);
    }

    public SlideOutContainer(android.content.Context context, android.util.AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public SlideOutContainer(android.content.Context context, android.util.AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.mHideImmediatelyRunnable = new java.lang.Runnable() {
            public void run() {
                com.android.server.gesture.SlideOutContainer.this.show(false, false);
            }
        };
        this.mHideRunnable = new java.lang.Runnable() {
            public void run() {
                com.android.server.gesture.SlideOutContainer.this.show(false, true);
            }
        };
    }

    protected void onFinishInflate() {
        super.onFinishInflate();
        this.mScrim = findViewById(34603264);
        this.mOrb = (com.android.server.gesture.anim.HwGestureSideLayout) findViewById(34603261);
        this.mOrbLegacy = (com.android.server.gesture.SlideOutCircleView) findViewById(34603262);
        if (com.android.server.gesture.GestureNavConst.USE_ANIM_LEGACY && this.mOrbLegacy != null && this.mOrb != null) {
            this.mOrbLegacy.setVisibility(0);
            this.mOrb.setVisibility(8);
            this.mOrb = null;
        } else if (this.mOrbLegacy != null && this.mOrb != null) {
            this.mOrb.setVisibility(0);
            this.mOrbLegacy.setVisibility(8);
            this.mOrbLegacy = null;
        }
    }

    public void show(boolean show) {
        setVisibility(show ? 0 : 4);
    }

    public void show(boolean show, boolean animate) {
        if (show) {
            if (getVisibility() != 0) {
                setVisibility(0);
                if (animate) {
                    startEnterAnimation();
                } else {
                    reset();
                }
            }
        } else if (animate) {
            startExitAnimation(new java.lang.Runnable() {
                public void run() {
                    com.android.server.gesture.SlideOutContainer.this.mAnimatingOut = false;
                    com.android.server.gesture.SlideOutContainer.this.setVisibility(8);
                }
            }, false, false);
        } else {
            setVisibility(8);
        }
    }

    public void hide(boolean animate) {
        if (animate) {
            startAbortAnimation();
        } else {
            setVisibility(4);
        }
    }

    public void reset() {
        this.mAnimatingOut = false;
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.reset();
        }
        this.mScrim.setAlpha(1.0f);
    }

    public void startEnterAnimation() {
        if (!this.mAnimatingOut) {
            if (this.mOrb != null) {
                this.mOrb.startEnterAnimation();
            }
            if (this.mOrbLegacy != null) {
                this.mOrbLegacy.startEnterAnimation();
            }
            this.mScrim.setAlpha(0.0f);
            post(new java.lang.Runnable() {
                public void run() {
                    com.android.server.gesture.SlideOutContainer.this.mScrim.animate().alpha(1.0f).setDuration(300).setStartDelay(0).setInterpolator(new android.view.animation.PathInterpolator(0.0f, 0.0f, 0.2f, 1.0f));
                }
            });
        }
    }

    public void startExitAnimation(boolean isFastSlide, boolean startMaskAnimation) {
        startExitAnimation(this.mHideRunnable, isFastSlide, startMaskAnimation);
    }

    public void startExitAnimation(java.lang.Runnable endRunnable, boolean isFastSlide, boolean startMaskAnimation) {
        if (this.mAnimatingOut) {
            if (endRunnable != null) {
                endRunnable.run();
            }
            return;
        }
        this.mAnimatingOut = true;
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.startExitAnimation(this.mHideImmediatelyRunnable, isFastSlide);
        }
        if (this.mOrb != null) {
            this.mOrb.startExitAnimation(this.mHideImmediatelyRunnable, isFastSlide, startMaskAnimation);
        }
        this.mScrim.animate().alpha(0.0f).setDuration(250).setStartDelay(150).setInterpolator(new android.view.animation.PathInterpolator(0.4f, 0.0f, 0.2f, 1.0f));
    }

    public void startAbortAnimation() {
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.startAbortAnimation(this.mHideImmediatelyRunnable, true);
        }
        if (this.mOrb != null) {
            this.mOrb.startExitAnimation(this.mHideImmediatelyRunnable, false, false);
            setVisibility(8);
        }
        this.mScrim.setAlpha(0.0f);
    }

    public void performOnAnimationFinished(java.lang.Runnable runnable) {
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.performOnAnimationFinished(runnable);
        }
        if (this.mOrb != null && runnable != null) {
            runnable.run();
        }
    }

    public boolean isAnimationRunning() {
        if (this.mOrbLegacy != null) {
            return this.mOrbLegacy.isAnimationRunning(true);
        }
        return false;
    }

    public void setSlideOverThreshold(boolean over) {
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.setDraggedFarEnough(over);
        }
    }

    public void setSlideDistance(float distance, float ratio) {
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.setDragDistance(distance);
        }
        if (this.mOrb != null) {
            this.mOrb.setSlidingProcess(ratio);
        }
    }

    public void setSlidingSide(boolean onLeft) {
        if (this.mOrbLegacy != null) {
            this.mOrbLegacy.setSlidingSide(onLeft);
        }
        if (this.mOrb != null) {
            this.mOrb.setSlidingSide(onLeft);
        }
    }

    public boolean isShowing() {
        return getVisibility() == 0 && !this.mAnimatingOut;
    }

    public boolean isVisible() {
        return getVisibility() == 0;
    }

    public android.widget.ImageView getMaybeSwapLogo() {
        if (this.mOrbLegacy != null) {
            return this.mOrbLegacy.getLogo();
        }
        if (this.mOrb != null) {
            return this.mOrb.getLogo();
        }
        return null;
    }
}
