package com.android.server.gesture.anim;

public class GLHelper {
    private static final java.lang.String TAG = "GLHelper";

    private static int compileShader(int type, java.lang.String shaderCode) {
        int shaderObjectId = android.opengl.GLES30.glCreateShader(type);
        while (true) {
            int glGetError = android.opengl.GLES30.glGetError();
            int error = glGetError;
            if (glGetError == 0) {
                break;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error ");
            stringBuilder.append(error);
            com.android.server.gesture.anim.GLLogUtils.logE("GLHelper", stringBuilder.toString());
        }
        if (shaderObjectId == 0) {
            com.android.server.gesture.anim.GLLogUtils.logW("GLHelper", "Could not create new shader.");
            return 0;
        }
        android.opengl.GLES30.glShaderSource(shaderObjectId, shaderCode);
        android.opengl.GLES30.glCompileShader(shaderObjectId);
        int[] compileStatus = new int[1];
        android.opengl.GLES30.glGetShaderiv(shaderObjectId, 35713, compileStatus, 0);
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("Results of compiling source:\n");
        stringBuilder2.append(shaderCode);
        stringBuilder2.append("\n:");
        stringBuilder2.append(android.opengl.GLES30.glGetShaderInfoLog(shaderObjectId));
        com.android.server.gesture.anim.GLLogUtils.logD("GLHelper", stringBuilder2.toString());
        if (compileStatus[0] != 0) {
            return shaderObjectId;
        }
        android.opengl.GLES30.glDeleteShader(shaderObjectId);
        com.android.server.gesture.anim.GLLogUtils.logW("GLHelper", "Compilation of shader failed.");
        return 0;
    }

    private static int linkProgram(int vertexShaderId, int fragmentShaderId) {
        int programObjectId = android.opengl.GLES30.glCreateProgram();
        if (programObjectId == 0) {
            com.android.server.gesture.anim.GLLogUtils.logW("GLHelper", "Could not create new program");
            return 0;
        }
        android.opengl.GLES30.glAttachShader(programObjectId, vertexShaderId);
        android.opengl.GLES30.glAttachShader(programObjectId, fragmentShaderId);
        android.opengl.GLES30.glLinkProgram(programObjectId);
        int[] linkStatus = new int[1];
        android.opengl.GLES30.glGetProgramiv(programObjectId, 35714, linkStatus, 0);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Results of linking program:\n");
        stringBuilder.append(android.opengl.GLES30.glGetProgramInfoLog(programObjectId));
        com.android.server.gesture.anim.GLLogUtils.logV("GLHelper", stringBuilder.toString());
        if (linkStatus[0] != 0) {
            return programObjectId;
        }
        android.opengl.GLES30.glDeleteProgram(programObjectId);
        com.android.server.gesture.anim.GLLogUtils.logW("GLHelper", "Linking of program failed.");
        return 0;
    }

    private static void validateProgram(int programObjectId) {
        android.opengl.GLES30.glValidateProgram(programObjectId);
        int[] validateStatus = new int[1];
        android.opengl.GLES30.glGetProgramiv(programObjectId, 35715, validateStatus, 0);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Results of validating program: ");
        stringBuilder.append(validateStatus[0]);
        stringBuilder.append("\nLog:");
        stringBuilder.append(android.opengl.GLES30.glGetProgramInfoLog(programObjectId));
        com.android.server.gesture.anim.GLLogUtils.logV("GLHelper", stringBuilder.toString());
    }

    public static int buildProgram(java.lang.String vertexShaderSource, java.lang.String fragmentShaderSource) {
        int program = linkProgram(compileShader(35633, vertexShaderSource), compileShader(35632, fragmentShaderSource));
        validateProgram(program);
        return program;
    }
}
