package com.android.server.gesture.anim.models;

public class GestureBackMetaball implements com.android.server.gesture.anim.models.GLModel {
    private static final java.lang.String FRAGMENT_SHADER_CODE = "#version 300 es\nprecision mediump float;\n\n// Calculating parameters\nuniform float energyR;\nuniform float wallOffset;\nuniform float energyThreshold;\nuniform float ballCenterMaxDis;\nuniform float processOffset;\nuniform float uAntiAliasingDelta;\n\nuniform bool isLeft;\nuniform float animProcess;\nuniform float uBallCenterY;\n\n// Render point\nin vec2 v_Position;\n\n// Result color of render point\nout vec4 o_FragColor;\n\n\nfloat energy_to_ball(vec2 point, vec2 ball) {\n    float denomination = distance(point, ball) * distance(point, ball);\n    float energy = energyR * energyR / denomination;\n    return energy;\n}\n\nfloat energy_to_wall(vec2 point) {\n    return point.x * point.x - wallOffset;\n}\n\nvoid main() {\n\n    vec2 point = v_Position.xy;\n    float ballCenterDistance = (ballCenterMaxDis + processOffset) * animProcess;\n\n    // Calculate side to 1(right) and -1(left).\n    float sideRatio = isLeft ? -1.0 : 1.0;\n    vec2 ballCenter = vec2(sideRatio * (1.0 + processOffset - ballCenterDistance), uBallCenterY);\n\n    // draw energy area\n    float energy = energy_to_wall(point) + energy_to_ball(point, ballCenter);\n    if (energy >= energyThreshold + uAntiAliasingDelta) {\n        o_FragColor = vec4(0, 0, 0, 0.8);\n    } else if (energy >= energyThreshold) {\n        float alphaRatio = (energy - energyThreshold) / uAntiAliasingDelta;\n        o_FragColor = vec4(0, 0, 0, 0.8 * alphaRatio);\n    } else {\n        // draw white side\n        float sideWRatio = 0.97;\n        float sideX = sideRatio * (1.0 - (1.0 - sideRatio * v_Position.x) * sideWRatio);        vec2 pointS = vec2(sideX, v_Position.y * sideWRatio);\n\n        vec2 ballCenterS = vec2(sideRatio * (1.0 + processOffset - ballCenterDistance), uBallCenterY * sideWRatio);\n\n        // draw energy area\n        float energyS = energy_to_wall(pointS) + energy_to_ball(pointS, ballCenterS);\n        float alphaRatioUx = 1.0 - pointS.x * sideRatio;        if (energyS >= energyThreshold + uAntiAliasingDelta) {\n            o_FragColor = vec4(1, 1, 1, 0.8 * alphaRatioUx);\n        } else if (energyS >= energyThreshold) {\n            float alphaRatio = (energyS - energyThreshold) / uAntiAliasingDelta;\n            o_FragColor = vec4(1, 1, 1, 0.8 * alphaRatio * alphaRatioUx);\n        }\n    }}";
    private static final float MAX_WALL_OFFSET = 0.15f;
    private static final float MIN_WALL_OFFSET = 0.05f;
    private static final int POINT_DESCRIBE_SIZE = 2;
    private static final java.lang.String TAG = "GestureBackMetaball";
    private static final java.lang.String VERTEX_SHADER_CODE = "#version 300 es\n\nlayout (location = 0) in vec4 a_Position;\n\nuniform float uHWRatio;\n\nout vec2 v_Position;\n\nvoid main() {\n    gl_Position = a_Position;\n    v_Position = vec2(a_Position.x, a_Position.y * uHWRatio);\n}";
    private float mAnimProcess;
    private int mAnimProcessLoc;
    private float mAntiAliasingDelta;
    private int mAntiAliasingDeltaLoc;
    private int mAttrVertexLoc;
    private float mBallCenter;
    private float mBallCenterMaxDis;
    private int mBallCenterMaxDisLoc;
    private int mBallCenterYLoc;
    private boolean mDraw;
    private float mEnergyR;
    private int mEnergyRLoc;
    private float mEnergyThreshold;
    private int mEnergyThresholdLoc;
    private int mHWRatioLoc;
    private int mHeight;
    private boolean mIsLeft;
    private int mIsLeftLoc;
    private float mProcessOffset;
    private int mProcessOffsetLoc;
    private int mProgram;
    private java.nio.FloatBuffer mRectBuffer;
    private final float[] mRectData = new float[]{-1.0f, 1.0f, 1.0f, 1.0f, -1.0f, -1.0f, 1.0f, -1.0f};
    private float mWallOffset;
    private int mWallOffsetLoc;
    private int mWidth;

    public GestureBackMetaball() {
        com.android.server.gesture.anim.GLLogUtils.logD("GestureBackMetaball", "create");
        this.mDraw = true;
        this.mEnergyR = 0.1f;
        this.mWallOffset = 0.05f;
        this.mEnergyThreshold = 1.0f;
        this.mBallCenterMaxDis = 0.15f;
        this.mProcessOffset = 0.35f;
        this.mAntiAliasingDelta = 0.015f;
        this.mIsLeft = true;
        this.mAnimProcess = 0.0f;
        this.mBallCenter = 0.0f;
    }

    public void prepare() {
        this.mProgram = com.android.server.gesture.anim.GLHelper.buildProgram("#version 300 es\n\nlayout (location = 0) in vec4 a_Position;\n\nuniform float uHWRatio;\n\nout vec2 v_Position;\n\nvoid main() {\n    gl_Position = a_Position;\n    v_Position = vec2(a_Position.x, a_Position.y * uHWRatio);\n}", "#version 300 es\nprecision mediump float;\n\n// Calculating parameters\nuniform float energyR;\nuniform float wallOffset;\nuniform float energyThreshold;\nuniform float ballCenterMaxDis;\nuniform float processOffset;\nuniform float uAntiAliasingDelta;\n\nuniform bool isLeft;\nuniform float animProcess;\nuniform float uBallCenterY;\n\n// Render point\nin vec2 v_Position;\n\n// Result color of render point\nout vec4 o_FragColor;\n\n\nfloat energy_to_ball(vec2 point, vec2 ball) {\n    float denomination = distance(point, ball) * distance(point, ball);\n    float energy = energyR * energyR / denomination;\n    return energy;\n}\n\nfloat energy_to_wall(vec2 point) {\n    return point.x * point.x - wallOffset;\n}\n\nvoid main() {\n\n    vec2 point = v_Position.xy;\n    float ballCenterDistance = (ballCenterMaxDis + processOffset) * animProcess;\n\n    // Calculate side to 1(right) and -1(left).\n    float sideRatio = isLeft ? -1.0 : 1.0;\n    vec2 ballCenter = vec2(sideRatio * (1.0 + processOffset - ballCenterDistance), uBallCenterY);\n\n    // draw energy area\n    float energy = energy_to_wall(point) + energy_to_ball(point, ballCenter);\n    if (energy >= energyThreshold + uAntiAliasingDelta) {\n        o_FragColor = vec4(0, 0, 0, 0.8);\n    } else if (energy >= energyThreshold) {\n        float alphaRatio = (energy - energyThreshold) / uAntiAliasingDelta;\n        o_FragColor = vec4(0, 0, 0, 0.8 * alphaRatio);\n    } else {\n        // draw white side\n        float sideWRatio = 0.97;\n        float sideX = sideRatio * (1.0 - (1.0 - sideRatio * v_Position.x) * sideWRatio);        vec2 pointS = vec2(sideX, v_Position.y * sideWRatio);\n\n        vec2 ballCenterS = vec2(sideRatio * (1.0 + processOffset - ballCenterDistance), uBallCenterY * sideWRatio);\n\n        // draw energy area\n        float energyS = energy_to_wall(pointS) + energy_to_ball(pointS, ballCenterS);\n        float alphaRatioUx = 1.0 - pointS.x * sideRatio;        if (energyS >= energyThreshold + uAntiAliasingDelta) {\n            o_FragColor = vec4(1, 1, 1, 0.8 * alphaRatioUx);\n        } else if (energyS >= energyThreshold) {\n            float alphaRatio = (energyS - energyThreshold) / uAntiAliasingDelta;\n            o_FragColor = vec4(1, 1, 1, 0.8 * alphaRatio * alphaRatioUx);\n        }\n    }}");
        this.mRectBuffer = java.nio.ByteBuffer.allocateDirect(this.mRectData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mRectData);
        this.mAttrVertexLoc = android.opengl.GLES30.glGetAttribLocation(this.mProgram, "a_Position");
        this.mEnergyRLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "energyR");
        this.mWallOffsetLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "wallOffset");
        this.mEnergyThresholdLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "energyThreshold");
        this.mBallCenterMaxDisLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "ballCenterMaxDis");
        this.mProcessOffsetLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "processOffset");
        this.mAntiAliasingDeltaLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "uAntiAliasingDelta");
        this.mIsLeftLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "isLeft");
        this.mAnimProcessLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "animProcess");
        this.mBallCenterYLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "uBallCenterY");
        this.mHWRatioLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "uHWRatio");
    }

    public void onSurfaceViewChanged(int width, int height) {
        android.opengl.GLES30.glViewport(0, 0, width, height);
        this.mWidth = width;
        this.mHeight = height;
    }

    public void drawSelf() {
        if (this.mDraw) {
            float hwRatio;
            if (this.mWidth < this.mHeight) {
                android.opengl.GLES30.glViewport(0, 0, this.mWidth, this.mHeight);
                hwRatio = ((float) this.mHeight) / ((float) this.mWidth);
            } else if (this.mIsLeft) {
                android.opengl.GLES30.glViewport(0, 0, this.mHeight, this.mHeight);
                hwRatio = 1.0f;
            } else {
                android.opengl.GLES30.glViewport(this.mWidth - this.mHeight, 0, this.mHeight, this.mHeight);
                hwRatio = 1.0f;
                android.opengl.GLES30.glUseProgram(this.mProgram);
                android.opengl.GLES30.glUniform1f(this.mEnergyRLoc, this.mEnergyR);
                android.opengl.GLES30.glUniform1f(this.mWallOffsetLoc, this.mWallOffset);
                android.opengl.GLES30.glUniform1f(this.mEnergyThresholdLoc, this.mEnergyThreshold);
                android.opengl.GLES30.glUniform1f(this.mBallCenterMaxDisLoc, this.mBallCenterMaxDis);
                android.opengl.GLES30.glUniform1f(this.mProcessOffsetLoc, this.mProcessOffset);
                android.opengl.GLES30.glUniform1f(this.mAntiAliasingDeltaLoc, this.mAntiAliasingDelta);
                android.opengl.GLES30.glUniform1i(this.mIsLeftLoc, this.mIsLeft);
                android.opengl.GLES30.glUniform1f(this.mAnimProcessLoc, this.mAnimProcess);
                android.opengl.GLES30.glUniform1f(this.mBallCenterYLoc, changeBallCenterToGL(this.mBallCenter, hwRatio));
                android.opengl.GLES30.glUniform1f(this.mHWRatioLoc, hwRatio);
                this.mRectBuffer.flip();
                android.opengl.GLES30.glEnableVertexAttribArray(this.mAttrVertexLoc);
                android.opengl.GLES30.glVertexAttribPointer(this.mAttrVertexLoc, 2, 5126, false, 8, this.mRectBuffer);
                android.opengl.GLES30.glDrawArrays(5, 0, this.mRectData.length / 2);
            }
            android.opengl.GLES30.glUseProgram(this.mProgram);
            android.opengl.GLES30.glUniform1f(this.mEnergyRLoc, this.mEnergyR);
            android.opengl.GLES30.glUniform1f(this.mWallOffsetLoc, this.mWallOffset);
            android.opengl.GLES30.glUniform1f(this.mEnergyThresholdLoc, this.mEnergyThreshold);
            android.opengl.GLES30.glUniform1f(this.mBallCenterMaxDisLoc, this.mBallCenterMaxDis);
            android.opengl.GLES30.glUniform1f(this.mProcessOffsetLoc, this.mProcessOffset);
            android.opengl.GLES30.glUniform1f(this.mAntiAliasingDeltaLoc, this.mAntiAliasingDelta);
            android.opengl.GLES30.glUniform1i(this.mIsLeftLoc, this.mIsLeft);
            android.opengl.GLES30.glUniform1f(this.mAnimProcessLoc, this.mAnimProcess);
            android.opengl.GLES30.glUniform1f(this.mBallCenterYLoc, changeBallCenterToGL(this.mBallCenter, hwRatio));
            android.opengl.GLES30.glUniform1f(this.mHWRatioLoc, hwRatio);
            this.mRectBuffer.flip();
            android.opengl.GLES30.glEnableVertexAttribArray(this.mAttrVertexLoc);
            android.opengl.GLES30.glVertexAttribPointer(this.mAttrVertexLoc, 2, 5126, false, 8, this.mRectBuffer);
            android.opengl.GLES30.glDrawArrays(5, 0, this.mRectData.length / 2);
        }
    }

    private float changeBallCenterToGL(float y, float hwRatio) {
        return ((-2.0f * (y / ((float) this.mHeight))) + 1.0f) * hwRatio;
    }

    public float getProcess() {
        return this.mAnimProcess;
    }

    public void setProcess(float process) {
        this.mAnimProcess = process;
        if (this.mAnimProcess <= 0.55f) {
            this.mWallOffset = 0.05f;
        } else {
            this.mWallOffset = 0.05f + ((0.10000001f * (process - 0.55f)) / 0.45f);
        }
    }

    public void setSide(boolean isLeft) {
        this.mIsLeft = isLeft;
    }

    public void setCenter(float y) {
        this.mBallCenter = y;
    }

    public void setDraw(boolean draw) {
        this.mDraw = draw;
    }
}
