package com.android.server.gesture.anim.models;

public class GestureBackTexture implements com.android.server.gesture.anim.models.GLModel {
    private static final int BASE_VIEW_HEIGHT = 2340;
    private static final int BASE_VIEW_WIDTH = 1080;
    private static final java.lang.String FRAGMENT_SHADER_CODE = "#version 300 es\nprecision mediump float;\n\nuniform float uAlpha;\nuniform sampler2D uTexture;\n\nin vec2 vTexCoord;\n\nout vec4 oFragColor;\n\nvoid main() {\n    vec4 vt = texture(uTexture, vTexCoord);\n    oFragColor = vec4(vt.rgb, vt.a * uAlpha);\n}";
    private static final int POINT_DESCRIBE_SIZE = 2;
    private static final java.lang.String TAG = "GestureBackTexture";
    private static final int TEXTURE_H = 62;
    private static final int TEXTURE_W = 38;
    private static final java.lang.String VERTEX_SHADER_CODE = "#version 300 es\n\nlayout (location = 0) in vec4 aPosition;\nlayout (location = 1) in vec2 aTexCoordinate;\n\nout vec2 vTexCoord;\n\nvoid main() {\n    gl_Position = aPosition;\n    vTexCoord = aTexCoordinate;\n}";
    private int mAlphaLoc;
    private float mAnimProcess;
    private int mAttrTextureLoc;
    private int mAttrVertexLoc;
    private int mCenterY;
    private android.content.Context mContext;
    private boolean mDraw;
    private int mHeight;
    private boolean mIsLeft;
    private float mMaxTextureOffset;
    private int mProgram;
    private java.nio.FloatBuffer mRectBuffer;
    private float[] mRectData = new float[]{-1.0f, 1.0f, 1.0f, 1.0f, -1.0f, -1.0f, 1.0f, -1.0f};
    private float mTextureAlpha;
    private java.nio.FloatBuffer mTextureBuffer;
    private final float[] mTextureData = new float[]{0.0f, 0.0f, 1.0f, 0.0f, 0.0f, 1.0f, 1.0f, 1.0f};
    private int mTextureLoc;
    private int mWidth;

    public GestureBackTexture(android.content.Context context) {
        this.mContext = context;
        this.mDraw = true;
        this.mMaxTextureOffset = 0.15f;
        this.mAnimProcess = 0.0f;
        this.mIsLeft = true;
        this.mTextureAlpha = 0.0f;
        this.mCenterY = 0;
    }

    public void prepare() {
        this.mProgram = com.android.server.gesture.anim.GLHelper.buildProgram("#version 300 es\n\nlayout (location = 0) in vec4 aPosition;\nlayout (location = 1) in vec2 aTexCoordinate;\n\nout vec2 vTexCoord;\n\nvoid main() {\n    gl_Position = aPosition;\n    vTexCoord = aTexCoordinate;\n}", "#version 300 es\nprecision mediump float;\n\nuniform float uAlpha;\nuniform sampler2D uTexture;\n\nin vec2 vTexCoord;\n\nout vec4 oFragColor;\n\nvoid main() {\n    vec4 vt = texture(uTexture, vTexCoord);\n    oFragColor = vec4(vt.rgb, vt.a * uAlpha);\n}");
        this.mRectBuffer = java.nio.ByteBuffer.allocateDirect(this.mRectData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mRectData);
        this.mTextureBuffer = java.nio.ByteBuffer.allocateDirect(this.mTextureData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mTextureData);
        createTexture(this.mContext, 33751938);
        this.mAttrVertexLoc = android.opengl.GLES30.glGetAttribLocation(this.mProgram, "aPosition");
        this.mAttrTextureLoc = android.opengl.GLES30.glGetAttribLocation(this.mProgram, "aTexCoordinate");
        this.mAlphaLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "uAlpha");
        this.mTextureLoc = android.opengl.GLES30.glGetUniformLocation(this.mProgram, "uTexture");
    }

    public void onSurfaceViewChanged(int width, int height) {
        android.opengl.GLES30.glViewport(0, 0, width, height);
        this.mWidth = width;
        this.mHeight = height;
        if (this.mCenterY == 0) {
            this.mCenterY = height / 2;
        }
    }

    public void drawSelf() {
        if (this.mDraw) {
            int centerY = changeCenterToGL(this.mCenterY);
            float viewRatio;
            if (this.mWidth < this.mHeight) {
                viewRatio = ((float) this.mWidth) / 1080.0f;
                android.opengl.GLES30.glViewport(0, centerY - ((int) ((62.0f * viewRatio) / 2.0f)), this.mWidth, (int) (62.0f * viewRatio));
                refreshVertexLoc((float) this.mWidth, viewRatio);
            } else if (this.mIsLeft) {
                viewRatio = ((float) this.mHeight) / 1080.0f;
                android.opengl.GLES30.glViewport(0, centerY - ((int) ((62.0f * viewRatio) / 2.0f)), this.mHeight, (int) (62.0f * viewRatio));
                refreshVertexLoc((float) this.mHeight, viewRatio);
            } else {
                viewRatio = ((float) this.mHeight) / 1080.0f;
                android.opengl.GLES30.glViewport(this.mWidth - this.mHeight, centerY - ((int) ((62.0f * viewRatio) / 2.0f)), this.mHeight, (int) (62.0f * viewRatio));
                refreshVertexLoc((float) this.mHeight, viewRatio);
            }
            android.opengl.GLES30.glUseProgram(this.mProgram);
            android.opengl.GLES30.glUniform1f(this.mAlphaLoc, this.mTextureAlpha);
            android.opengl.GLES30.glUniform1i(this.mTextureLoc, 0);
            this.mRectBuffer.flip();
            android.opengl.GLES30.glEnableVertexAttribArray(this.mAttrVertexLoc);
            android.opengl.GLES30.glVertexAttribPointer(this.mAttrVertexLoc, 2, 5126, false, 8, this.mRectBuffer);
            this.mTextureBuffer.flip();
            android.opengl.GLES30.glEnableVertexAttribArray(this.mAttrTextureLoc);
            android.opengl.GLES30.glVertexAttribPointer(this.mAttrTextureLoc, 2, 5126, false, 8, this.mTextureBuffer);
            android.opengl.GLES30.glDrawArrays(5, 0, this.mRectData.length / 2);
        }
    }

    private int changeCenterToGL(int y) {
        return this.mHeight - y;
    }

    private void refreshVertexLoc(float drawWidth, float viewRatio) {
        float startOffset = 2.0f * ((38.0f * viewRatio) / drawWidth);
        float textureCenterX = (-1.0f - startOffset) + ((this.mMaxTextureOffset + startOffset) * this.mAnimProcess);
        if (!this.mIsLeft) {
            textureCenterX *= -1.0f;
        }
        this.mRectData = new float[]{textureCenterX - textureW, 1.0f, textureCenterX + textureW, 1.0f, textureCenterX - textureW, -1.0f, textureCenterX + textureW, -1.0f};
        this.mRectBuffer = java.nio.ByteBuffer.allocateDirect(this.mRectData.length * 4).order(java.nio.ByteOrder.nativeOrder()).asFloatBuffer().put(this.mRectData);
    }

    private static void createTexture(android.content.Context context, int resourceId) {
        android.graphics.BitmapFactory.Options options = new android.graphics.BitmapFactory.Options();
        options.inScaled = false;
        android.graphics.Bitmap bitmap = android.graphics.BitmapFactory.decodeResource(context.getResources(), resourceId, options);
        if (bitmap == null) {
            com.android.server.gesture.anim.GLLogUtils.logD("GestureBackTexture", ">> load bitmap fail");
            return;
        }
        int[] texture = new int[1];
        android.opengl.GLES30.glGenTextures(1, texture, 0);
        if (texture[0] == 0) {
            com.android.server.gesture.anim.GLLogUtils.logD("GestureBackTexture", ">> create texture fail");
            return;
        }
        android.opengl.GLES30.glActiveTexture(33984);
        android.opengl.GLES30.glBindTexture(3553, texture[0]);
        android.opengl.GLES30.glTexParameterf(3553, 10241, 9728.0f);
        android.opengl.GLES30.glTexParameterf(3553, 10240, 9729.0f);
        android.opengl.GLUtils.texImage2D(3553, 0, 6408, bitmap, 5121, 0);
        bitmap.recycle();
        android.opengl.GLES30.glGenerateMipmap(3553);
    }

    private void setAlpha(float alpha) {
        this.mTextureAlpha = alpha;
    }

    public void setProcess(float process) {
        this.mAnimProcess = process;
        if (this.mAnimProcess >= 0.55f) {
            setAlpha(1.0f);
        } else if (this.mAnimProcess < 0.275f) {
            setAlpha(0.0f);
        } else {
            setAlpha((this.mAnimProcess - 0.275f) / (0.55f - 0.275f));
        }
    }

    public void setSide(boolean isLeft) {
        this.mIsLeft = isLeft;
    }

    public void setCenter(int y) {
        this.mCenterY = y;
    }

    public void setDraw(boolean draw) {
        this.mDraw = draw;
    }
}
