package com.android.server.hidata.arbitration;

public class HwArbitrationCommonUtils {
    private static final java.lang.String KEY_HiCure_Show = "ro.config.hw_hicure_test";
    public static final boolean MAINLAND_REGION = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    public static final java.lang.String TAG = "HiData_HwArbitrationCommonUtils";

    public static void logD(java.lang.String tag, java.lang.String log) {
        android.util.Log.d(tag, log);
    }

    public static void logI(java.lang.String tag, java.lang.String log) {
        android.util.Log.i(tag, log);
    }

    public static void logE(java.lang.String tag, java.lang.String log) {
        android.util.Log.e(tag, log);
    }

    public static int getActiveConnectType(android.content.Context mContext) {
        if (mContext == null) {
            logE("HiData_HwArbitrationCommonUtils", "getActiveConnectType: mContext is null");
            return 802;
        }
        android.net.NetworkInfo activeNetInfo = ((android.net.ConnectivityManager) mContext.getSystemService("connectivity")).getActiveNetworkInfo();
        if (activeNetInfo != null && activeNetInfo.getType() == 1 && activeNetInfo.isConnected()) {
            logD("HiData_HwArbitrationCommonUtils", "TYPE_WIFI is active");
            return 800;
        } else if (activeNetInfo != null && activeNetInfo.getType() == 0 && activeNetInfo.isConnected()) {
            logD("HiData_HwArbitrationCommonUtils", "TYPE_MOBILE is active");
            return 801;
        } else {
            logD("HiData_HwArbitrationCommonUtils", "ACTIVE_TYPE is none");
            return 802;
        }
    }

    public static boolean isWifiEnabled(android.content.Context mContext) {
        return android.provider.Settings.Global.getInt(mContext.getContentResolver(), "wifi_on", 0) != 0;
    }

    public static boolean isCellConnected(android.content.Context mContext) {
        android.net.NetworkInfo cellNetInfo = ((android.net.ConnectivityManager) mContext.getSystemService("connectivity")).getNetworkInfo(0);
        if (cellNetInfo == null || cellNetInfo.getState() != android.net.NetworkInfo.State.CONNECTED) {
            return false;
        }
        return true;
    }

    public static boolean isWifiConnected(android.content.Context mContext) {
        android.net.NetworkInfo wifiNetInfo = ((android.net.ConnectivityManager) mContext.getSystemService("connectivity")).getNetworkInfo(1);
        if (wifiNetInfo == null || wifiNetInfo.getState() != android.net.NetworkInfo.State.CONNECTED) {
            return false;
        }
        return true;
    }

    public static boolean isCellEnable(android.content.Context mContext) {
        return android.provider.Settings.Global.getInt(mContext.getContentResolver(), "mobile_data", 0) != 0;
    }

    public static boolean isDataRoamingEnable(android.content.Context mContext) {
        boolean z = false;
        if (android.provider.Settings.Global.getInt(mContext.getContentResolver(), "data_roaming", 0) != 0) {
            z = true;
        }
        boolean result = z;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("DataRoamingStateEnable:");
        stringBuilder.append(result);
        logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
        return result;
    }

    public static boolean hasSimCard(android.content.Context mContext) {
        if (((android.telephony.TelephonyManager) mContext.getSystemService("phone")).getSimState() != 5) {
            return false;
        }
        return true;
    }

    public static boolean isScreenOn(android.content.Context mContext) {
        android.view.Display[] displays = ((android.hardware.display.DisplayManager) mContext.getSystemService("display")).getDisplays();
        int length = displays.length;
        int i = 0;
        while (i < length) {
            android.view.Display display = displays[i];
            if (display.getState() != 2) {
                if (display.getState() != 0) {
                    i++;
                }
            }
            logD("HiData_HwArbitrationCommonUtils", "display STATE is ON");
            return true;
        }
        return false;
    }

    public static boolean isVicePhoneCalling(android.content.Context context) {
        boolean isCalling = false;
        android.telephony.TelephonyManager telephonyManager = (android.telephony.TelephonyManager) context.getSystemService("phone");
        int viceSubId = 0;
        if (telephonyManager == null) {
            logE("HiData_HwArbitrationCommonUtils", "isVicePhoneCalling: telephonyManager is null, return!");
            return false;
        }
        if (2 == telephonyManager.getPhoneCount()) {
            if (android.telephony.SubscriptionManager.getDefaultSubId() == 0) {
                viceSubId = 1;
            }
            if (5 == telephonyManager.getSimState(viceSubId) && (2 == telephonyManager.getCallState(viceSubId) || 1 == telephonyManager.getCallState(viceSubId))) {
                isCalling = true;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isViceSIMCalling:");
        stringBuilder.append(isCalling);
        logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
        return isCalling;
    }

    public static boolean isDefaultPhoneCSCalling(android.content.Context context) {
        boolean isCSCalling = false;
        android.telephony.TelephonyManager telephonyManager = (android.telephony.TelephonyManager) context.getSystemService("phone");
        java.lang.StringBuilder stringBuilder;
        if (telephonyManager == null) {
            logE("HiData_HwArbitrationCommonUtils", "isDefaultPhoneCSCalling: telephonyManager is null, return!");
            return false;
        } else if (telephonyManager.isVolteAvailable()) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isVolteAvailable:");
            stringBuilder.append(telephonyManager.isVolteAvailable());
            logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
            return false;
        } else {
            int mDefaultSubId = android.telephony.SubscriptionManager.getDefaultSubId();
            if (5 == telephonyManager.getSimState(mDefaultSubId) && (2 == telephonyManager.getCallState(mDefaultSubId) || 1 == telephonyManager.getCallState(mDefaultSubId))) {
                isCSCalling = true;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isDefaultSIMCSCalling:");
            stringBuilder.append(isCSCalling);
            logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
            return isCSCalling;
        }
    }

    public static boolean isSlotIdValid(int slotId) {
        return slotId >= 0 && 2 > slotId;
    }

    public static boolean isDataConnected(android.content.Context context) {
        return 2 == ((android.telephony.TelephonyManager) context.getSystemService("phone")).getDataState();
    }

    public static java.lang.String getTopActivityPackageName(android.content.Context context) {
        try {
            java.util.List<android.app.ActivityManager.RunningTaskInfo> tasks = ((android.app.ActivityManager) context.getSystemService("activity")).getRunningTasks(1);
            if (tasks != null) {
                if (!tasks.isEmpty()) {
                    android.content.ComponentName topActivity = ((android.app.ActivityManager.RunningTaskInfo) tasks.get(0)).topActivity;
                    if (topActivity == null) {
                        return null;
                    }
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Top_Activity, pgName:");
                    stringBuilder.append(topActivity.getPackageName());
                    logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Top_Activity, className:");
                    stringBuilder.append(topActivity.getClassName());
                    logD("HiData_HwArbitrationCommonUtils", stringBuilder.toString());
                    return topActivity.getPackageName();
                }
            }
            logD("HiData_HwArbitrationCommonUtils", "Top_Activity,Null");
            return null;
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("Debug_Top_Activity:Failure to get topActivity PackageName ");
            stringBuilder2.append(e);
            logD("HiData_HwArbitrationCommonUtils", stringBuilder2.toString());
        }
    }

    public static int getForegroundAppUid(android.content.Context context) {
        if (context == null) {
            return -1;
        }
        java.util.List<android.app.ActivityManager.RunningAppProcessInfo> lr = ((android.app.ActivityManager) context.getSystemService("activity")).getRunningAppProcesses();
        if (lr == null) {
            return -1;
        }
        for (android.app.ActivityManager.RunningAppProcessInfo ra : lr) {
            if (ra.importance != 200) {
                if (ra.importance == 100) {
                }
            }
            return ra.uid;
        }
        return -1;
    }

    public static boolean isDataRoamingEnabled(android.content.Context context, int subId) {
        boolean z = false;
        if (subId >= 0) {
            if (subId <= 1) {
                java.lang.String ROAMING_SIM = "data_roaming";
                if (1 == subId) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(ROAMING_SIM);
                    stringBuilder.append("_sim2");
                    ROAMING_SIM = stringBuilder.toString();
                }
                if (android.provider.Settings.Global.getInt(context.getContentResolver(), ROAMING_SIM, 0) != 0) {
                    z = true;
                }
                return z;
            }
        }
        logD("HiData_HwArbitrationCommonUtils", "unvalid SubId");
        return false;
    }

    public static java.lang.String getAppNameUid(android.content.Context context, int uid) {
        android.app.ActivityManager activityManager = (android.app.ActivityManager) context.getSystemService("activity");
        java.lang.String processName = "";
        if (activityManager == null) {
            return processName;
        }
        java.util.List<android.app.ActivityManager.RunningAppProcessInfo> appProcessList = activityManager.getRunningAppProcesses();
        if (appProcessList != null) {
            if (appProcessList.size() != 0) {
                for (android.app.ActivityManager.RunningAppProcessInfo appProcess : appProcessList) {
                    if (appProcess.uid == uid) {
                        return appProcess.processName;
                    }
                }
                return processName;
            }
        }
        return processName;
    }

    public static boolean isHiCureShow() {
        return android.os.SystemProperties.getBoolean("ro.config.hw_hicure_test", false);
    }
}
