package com.android.server.hidata.arbitration;

public class HwArbitrationDisplay {
    private static final java.lang.String ACTION_WIFI_PLUS_ACTIVITY = "android.settings.WIFI_PLUS_SETTINGS";
    private static final int HiData_High_NOTIFICATION_ID = 288223;
    private static final int HiData_Low_NOTIFICATION_ID = 288224;
    private static final java.lang.String NotificationHighChannelTAG = "hidata_brain_high_tag";
    private static final java.lang.String NotificationLowChannelTAG = "hidata_brain_low_tag";
    private static final java.lang.String TAG;
    private static com.android.server.hidata.arbitration.HwArbitrationDisplay instance;
    private android.content.Context mContext;
    private android.os.Handler mHBDHandler;
    private android.app.NotificationManager mNotificationManager;
    private long mRO_StartRxBytes;
    private long mRO_StartTxBytes;
    private boolean mplinkEnableState = false;
    private boolean noNotify25MB;
    private boolean noNotify50MB;
    private boolean noSetHighChanel;
    private boolean noSetLowChanel;
    private boolean smartmpEnableState = false;
    private boolean startMonitorDataFlow;

    static {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HiData_");
        stringBuilder.append(com.android.server.hidata.arbitration.HwArbitrationDisplay.class.getSimpleName());
        TAG = stringBuilder.toString();
    }

    private HwArbitrationDisplay(android.content.Context mContext) {
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "init HwArbitrationDisplay");
        this.mContext = mContext;
        resetState();
        initHBDHandler();
        this.mNotificationManager = (android.app.NotificationManager) mContext.getSystemService("notification");
    }

    public static synchronized com.android.server.hidata.arbitration.HwArbitrationDisplay getInstance(android.content.Context context) {
        com.android.server.hidata.arbitration.HwArbitrationDisplay hwArbitrationDisplay;
        synchronized (com.android.server.hidata.arbitration.HwArbitrationDisplay.class) {
            if (instance == null) {
                instance = new com.android.server.hidata.arbitration.HwArbitrationDisplay(context);
            }
            hwArbitrationDisplay = instance;
        }
        return hwArbitrationDisplay;
    }

    private void resetState() {
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "resetState Notification State");
        this.noNotify25MB = true;
        this.noNotify50MB = true;
        this.noSetLowChanel = true;
        this.noSetHighChanel = true;
        this.mRO_StartRxBytes = 0;
        this.mRO_StartTxBytes = 0;
        this.startMonitorDataFlow = true;
    }

    public void requestDataMonitor(boolean enable, int id) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("enable = ");
        stringBuilder.append(enable);
        stringBuilder.append(", id = ");
        stringBuilder.append(id);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str, stringBuilder.toString());
        if (!(!enable || this.mplinkEnableState || this.smartmpEnableState)) {
            this.mHBDHandler.sendEmptyMessage(3002);
        }
        if (1 == id) {
            this.mplinkEnableState = enable;
        }
        if (2 == id) {
            this.smartmpEnableState = enable;
        }
        if (!enable && !this.mplinkEnableState && !this.smartmpEnableState) {
            this.mHBDHandler.sendEmptyMessage(3003);
        }
    }

    private void periodCheckHighDataFlow() {
        if (this.startMonitorDataFlow) {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "start Hidata_Notification monitor");
            this.mRO_StartRxBytes = android.net.TrafficStats.getMobileRxBytes();
            this.mRO_StartTxBytes = android.net.TrafficStats.getMobileTxBytes();
            if (this.mRO_StartTxBytes < 0 || this.mRO_StartRxBytes < 0) {
                this.mRO_StartRxBytes = 0;
                this.mRO_StartTxBytes = 0;
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "read rx tx error");
            }
            this.startMonitorDataFlow = false;
            return;
        }
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        long rxBytes = android.net.TrafficStats.getMobileRxBytes();
        long txBytes = android.net.TrafficStats.getMobileTxBytes();
        if (rxBytes < 0 || txBytes < 0) {
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("read rx tx error, rx=");
            stringBuilder.append(rxBytes);
            stringBuilder.append(", tx=");
            stringBuilder.append(txBytes);
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str, stringBuilder.toString());
        }
        str = TAG;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("rxBytes: ");
        stringBuilder.append(rxBytes);
        stringBuilder.append(", txBytes: ");
        stringBuilder.append(txBytes);
        stringBuilder.append(", mRO_StartRxBytes: ");
        stringBuilder.append(this.mRO_StartRxBytes);
        stringBuilder.append(", mRO_StartTxBytes: ");
        stringBuilder.append(this.mRO_StartTxBytes);
        stringBuilder.append(", CostBytes: ");
        stringBuilder.append((((rxBytes - this.mRO_StartRxBytes) + txBytes) - this.mRO_StartTxBytes) / 1048576);
        stringBuilder.append("MB");
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str, stringBuilder.toString());
        if (rxBytes >= this.mRO_StartRxBytes && txBytes >= this.mRO_StartTxBytes) {
            long totalCostBytes = (rxBytes - this.mRO_StartRxBytes) + (txBytes - this.mRO_StartTxBytes);
            if (totalCostBytes > 52428800 && this.noNotify50MB) {
                this.noNotify25MB = false;
                this.noNotify50MB = false;
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "show Hidata_Notification: 50MB");
                showHiDataHighNotification(((int) totalCostBytes) / 1048576);
            } else if (totalCostBytes > 26214400 && this.noNotify25MB) {
                this.noNotify25MB = false;
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "show Hidata_Notification: 25MB");
                showHiDataHighNotification(((int) totalCostBytes) / 1048576);
            } else if (totalCostBytes > 52428800) {
                int notifyInt = ((int) totalCostBytes) / 1048576;
                java.lang.String str2 = TAG;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("show Hidata_Notification: ");
                stringBuilder2.append(notifyInt);
                stringBuilder2.append("MB");
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str2, stringBuilder2.toString());
                getInstance(this.mContext).showHiDataLowNotification(notifyInt);
            }
        }
    }

    private android.app.Notification getNotification(int mobileDateSize, boolean isHigh) {
        android.app.Notification.Builder b;
        int i = mobileDateSize;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("showHiDataNotification: ");
        stringBuilder.append(i);
        stringBuilder.append("MB");
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str, stringBuilder.toString());
        str = this.mContext.getResources().getString(33686080);
        java.lang.String content = this.mContext.getResources().getString(33686079);
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("");
        stringBuilder2.append(i);
        java.lang.String title = str.replace("%d", stringBuilder2.toString());
        java.lang.String suitch = this.mContext.getResources().getString(33686078);
        android.app.PendingIntent roveInPendingIntent = android.app.PendingIntent.getBroadcastAsUser(this.mContext, 0, new android.content.Intent("com.huawei.hidata.arbitration.notification.accept").setPackage(this.mContext.getPackageName()), 268435456, android.os.UserHandle.ALL);
        android.app.PendingIntent activityPendingIntent = android.app.PendingIntent.getActivity(this.mContext, 1, new android.content.Intent("android.settings.WIFI_PLUS_SETTINGS"), 268435456);
        android.app.Notification.Action action = new android.app.Notification.Action.Builder(33751955, suitch, roveInPendingIntent).build();
        if (isHigh) {
            b = new android.app.Notification.Builder(this.mContext, "hidata_brain_high_tag");
        } else {
            b = new android.app.Notification.Builder(this.mContext, "hidata_brain_low_tag");
        }
        b.setContentIntent(activityPendingIntent);
        b.setAutoCancel(true);
        b.setUsesChronometer(true);
        b.setContentTitle(title);
        b.setContentText(content);
        b.setVisibility(1);
        b.setTicker("");
        b.setShowWhen(true);
        b.setUsesChronometer(false);
        b.setSmallIcon(33751955);
        b.addAction(action);
        b.setOngoing(true);
        return b.build();
    }

    private void showHiDataHighNotification(int mobileDateSize) {
        if (this.mNotificationManager == null) {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE(TAG, "High NotificationManager is null!");
            return;
        }
        if (this.noSetHighChanel) {
            this.noSetHighChanel = false;
            this.mNotificationManager.deleteNotificationChannel("hidata_brain_low_tag");
            android.app.NotificationChannel highNotificationChannel = new android.app.NotificationChannel("hidata_brain_high_tag", this.mContext.getResources().getString(33686075), 4);
            highNotificationChannel.setSound(android.provider.Settings.System.DEFAULT_NOTIFICATION_URI, android.app.Notification.AUDIO_ATTRIBUTES_DEFAULT);
            highNotificationChannel.enableLights(true);
            highNotificationChannel.enableVibration(true);
            this.mNotificationManager.createNotificationChannel(highNotificationChannel);
        }
        this.mNotificationManager.notify(288223, getNotification(mobileDateSize, true));
    }

    private void cancelHiDataHighNotification() {
        if (this.mNotificationManager == null) {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE(TAG, "mNotificationManager is null!");
            return;
        }
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "cancel the High notification!");
        this.mNotificationManager.cancel(288223);
    }

    private void showHiDataLowNotification(int mobileDateSize) {
        if (this.mNotificationManager == null) {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE(TAG, "High NotificationManager is null!");
            return;
        }
        if (this.noSetLowChanel) {
            this.noSetLowChanel = false;
            cancelHiDataHighNotification();
            this.mNotificationManager.deleteNotificationChannel("hidata_brain_high_tag");
            this.mNotificationManager.createNotificationChannel(new android.app.NotificationChannel("hidata_brain_low_tag", this.mContext.getResources().getString(33686075), 2));
        }
        this.mNotificationManager.notify(288224, getNotification(mobileDateSize, false));
    }

    private void cancelHiDataLowNotification() {
        if (this.mNotificationManager == null) {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE(TAG, "mNotificationManager is null!");
            return;
        }
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "cancel the Low notification!");
        this.mNotificationManager.cancel(288224);
    }

    private void initHBDHandler() {
        android.os.HandlerThread handlerThread = new android.os.HandlerThread("hidata_brain_display_handler");
        handlerThread.start();
        this.mHBDHandler = new android.os.Handler(handlerThread.getLooper()) {
            public void handleMessage(android.os.Message msg) {
                switch (msg.what) {
                    case 3002:
                        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(com.android.server.hidata.arbitration.HwArbitrationDisplay.TAG, "MSG_Display_Start_Monitor_Network");
                        com.android.server.hidata.arbitration.HwArbitrationDisplay.this.periodCheckHighDataFlow();
                        sendEmptyMessageDelayed(3002, 3000);
                        return;
                    case 3003:
                        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(com.android.server.hidata.arbitration.HwArbitrationDisplay.TAG, "MSG_Display_stop_Monotor_network");
                        removeMessages(3002);
                        com.android.server.hidata.arbitration.HwArbitrationDisplay.this.cancelHiDataHighNotification();
                        com.android.server.hidata.arbitration.HwArbitrationDisplay.this.cancelHiDataLowNotification();
                        com.android.server.hidata.arbitration.HwArbitrationDisplay.this.resetState();
                        return;
                    default:
                        return;
                }
            }
        };
    }

    public static void setToast(android.content.Context mContext, java.lang.String info) {
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(TAG, "show HiData_Toast");
        android.widget.Toast.makeText(mContext, info, 1).show();
    }
}
