package com.android.server.hidata.arbitration;

public class HwArbitrationFunction {
    private static final java.lang.String COUNTRY_CODE_CHINA = "460";
    private static final java.lang.String TAG;
    private static int mCurrentDataTech = 0;
    private static int mCurrentServiceState = 1;
    private static boolean mDataRoamingState = false;
    private static boolean mDataTechSuitable = false;
    private static boolean mIsPvpScene = false;
    private static boolean mIsScreenOn = true;

    static {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HiData_");
        stringBuilder.append(com.android.server.hidata.arbitration.HwArbitrationFunction.class.getSimpleName());
        TAG = stringBuilder.toString();
    }

    public static boolean isAllowMpLink(android.content.Context context, int uid) {
        if (!com.android.server.hidata.arbitration.HwArbitrationCommonUtils.MAINLAND_REGION) {
            android.util.Log.d(TAG, "region is not CN");
            return false;
        } else if (!com.android.server.hidata.arbitration.HwArbitrationCommonUtils.hasSimCard(context)) {
            android.util.Log.d(TAG, "No Sim");
            return false;
        } else if (isInAirplaneMode(context)) {
            android.util.Log.d(TAG, "cell in AirplaneMode");
            return false;
        } else if (!isStateInService()) {
            android.util.Log.d(TAG, "SIM not in service");
            return false;
        } else if (!isChina()) {
            android.util.Log.d(TAG, "not China operator");
            return false;
        } else if (!com.android.server.hidata.arbitration.HwArbitrationCommonUtils.isCellEnable(context)) {
            android.util.Log.d(TAG, "Cell is not enabled");
            return false;
        } else if (isInVPNMode(context)) {
            android.util.Log.d(TAG, "cell in VPNMode");
            return false;
        } else if (!huawei.android.net.hwmplink.MpLinkCommonUtils.isMpLinkEnabled(context)) {
            android.util.Log.d(TAG, "WLAN+ off");
            return false;
        } else if (!isCell4Gor3G(context)) {
            android.util.Log.d(TAG, "not 4G or 3G");
            return false;
        } else if (isDataRoaming()) {
            android.util.Log.d(TAG, "celluar data is roaming");
            return false;
        } else if (Integer.MIN_VALUE != uid && isUidPolicyNotAllowCell(uid)) {
            android.util.Log.d(TAG, "uid policy is not allow cellar");
            return false;
        } else if (com.android.server.hidata.arbitration.HwArbitrationCommonUtils.isDefaultPhoneCSCalling(context)) {
            android.util.Log.d(TAG, "Default Sim is CS calling");
            return false;
        } else if (com.android.server.hidata.arbitration.HwArbitrationCommonUtils.isVicePhoneCalling(context)) {
            android.util.Log.d(TAG, "Vice Sim is calling");
            return false;
        } else if (!isVSimEnabled()) {
            return true;
        } else {
            android.util.Log.d(TAG, "skyTone VSim is Enabled");
            return false;
        }
    }

    private static boolean isChina() {
        java.lang.String operator = android.telephony.TelephonyManager.getDefault().getNetworkOperator();
        return (operator == null || operator.length() == 0 || !operator.startsWith("460")) ? false : true;
    }

    private static boolean isInAirplaneMode(android.content.Context context) {
        boolean z = false;
        try {
            if (android.provider.Settings.Global.getInt(context.getContentResolver(), "airplane_mode_on") == 1) {
                z = true;
            }
            return z;
        } catch (android.provider.Settings.SettingNotFoundException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("AirplaneMode error is: ");
            stringBuilder.append(e.toString());
            android.util.Log.e(str, stringBuilder.toString());
            return false;
        }
    }

    public static boolean isInVPNMode(android.content.Context context) {
        try {
            return getSettingsSystemBoolean(context.getContentResolver(), "wifipro_network_vpn_state", false);
        } catch (java.lang.Exception e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("VPN Mode error is: ");
            stringBuilder.append(e.toString());
            android.util.Log.e(str, stringBuilder.toString());
            return false;
        }
    }

    private static boolean getSettingsSystemBoolean(android.content.ContentResolver cr, java.lang.String name, boolean def) {
        return android.provider.Settings.System.getInt(cr, name, def) == 1;
    }

    public static int getCurrentNetwork(android.content.Context context, int UID) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getCurrentNetwork,UID =");
        stringBuilder.append(UID);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str, stringBuilder.toString());
        if (com.android.server.hidata.arbitration.HwArbitrationStateMachine.getInstance(context) != null) {
            return com.android.server.hidata.arbitration.HwArbitrationStateMachine.getInstance(context).getCurrentNetwork(context, UID);
        }
        return com.android.server.hidata.arbitration.HwArbitrationCommonUtils.getActiveConnectType(context);
    }

    public static int getNetworkID(android.content.Context mContext, int network) {
        int networkType = -1;
        if (network == 800) {
            networkType = getWifiNetwork(mContext);
        }
        if (network == 801) {
            networkType = getCellNetwork(mContext);
        }
        android.net.ConnectivityManager mConnectivityManager = (android.net.ConnectivityManager) mContext.getSystemService("connectivity");
        if (!(mConnectivityManager == null || mConnectivityManager.getAllNetworks() == null)) {
            android.net.Network[] networks = mConnectivityManager.getAllNetworks();
            int length = networks.length;
            for (int i = 0; i < length; i++) {
                android.net.NetworkInfo netInfo = mConnectivityManager.getNetworkInfo(networks[i]);
                if (netInfo != null && netInfo.getType() == networkType) {
                    android.net.Network myNetwork = networks[i];
                    if (myNetwork != null) {
                        return myNetwork.netId;
                    }
                }
            }
        }
        return -1;
    }

    public static int getNetwork(android.content.Context mContext, int netId) {
        int result = -1;
        android.net.ConnectivityManager mConnectivityManager = (android.net.ConnectivityManager) mContext.getSystemService("connectivity");
        if (!(mConnectivityManager == null || mConnectivityManager.getAllNetworks() == null)) {
            android.net.Network[] networks = mConnectivityManager.getAllNetworks();
            int length = networks.length;
            for (int i = 0; i < length; i++) {
                android.net.NetworkInfo netInfo = mConnectivityManager.getNetworkInfo(networks[i]);
                android.net.Network myNetwork = networks[i];
                if (!(myNetwork == null || myNetwork.netId != netId || netInfo == null)) {
                    result = netInfo.getType();
                }
            }
        }
        if (getWifiNetwork(mContext) == result) {
            return 800;
        }
        if (getCellNetwork(mContext) == result) {
            return 801;
        }
        return 802;
    }

    public static int getWifiNetwork(android.content.Context mContext) {
        mContext.getSystemService("connectivity");
        return 1;
    }

    public static int getCellNetwork(android.content.Context mContext) {
        mContext.getSystemService("connectivity");
        return 0;
    }

    private static boolean isCell4Gor3G(android.content.Context mContext) {
        int networkClass = android.telephony.TelephonyManager.getNetworkClass(((android.telephony.TelephonyManager) mContext.getSystemService("phone")).getNetworkType());
        if (networkClass != 2) {
            if (networkClass != 3) {
                return false;
            }
        }
        return true;
    }

    public static boolean isInLTE(android.content.Context mContext) {
        int networkType = ((android.telephony.TelephonyManager) mContext.getSystemService("phone")).getNetworkType();
        if (networkType == 13 || networkType == 19) {
            return true;
        }
        return false;
    }

    private static boolean isUidPolicyNotAllowCell(int uid) {
        boolean out;
        java.io.IOException e3;
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        org.xmlpull.v1.XmlPullParser parser = android.util.Xml.newPullParser();
        if (parser == null) {
            android.util.Log.e(TAG, "parser is null!!!");
            return false;
        }
        out = false;
        java.io.InputStream inStream = null;
        try {
            inStream = new java.io.FileInputStream(new java.io.File("/data/system/hwnetpolicy.xml"));
            parser.setInput(inStream, "UTF-8");
            for (int eventType = parser.getEventType(); eventType != 1; eventType = parser.next()) {
                if (eventType != 0) {
                    if (eventType == 2) {
                        java.lang.String name = parser.getName();
                        if (name != null && name.equalsIgnoreCase("uid-policy")) {
                            int xmlUid = java.lang.Integer.parseInt(parser.getAttributeValue(null, "uid"));
                            int xmlPolicy = java.lang.Integer.parseInt(parser.getAttributeValue(null, "policy"));
                            if (xmlUid == uid && (xmlPolicy == 1 || xmlPolicy == 2 || xmlPolicy == 3)) {
                                java.lang.String str2 = TAG;
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("uid: ");
                                stringBuilder2.append(xmlUid);
                                stringBuilder2.append(", policy: ");
                                stringBuilder2.append(xmlPolicy);
                                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD(str2, stringBuilder2.toString());
                                out = true;
                            }
                        }
                    }
                }
            }
            try {
                inStream.close();
            } catch (java.io.IOException e) {
                e3 = e;
                str = TAG;
                stringBuilder = new java.lang.StringBuilder();
            }
        } catch (java.lang.RuntimeException e2) {
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RuntimeException: ");
            stringBuilder.append(e2.toString());
            android.util.Log.e(str, stringBuilder.toString());
            if (inStream != null) {
                try {
                    inStream.close();
                } catch (java.io.IOException e4) {
                    e3 = e4;
                    str = TAG;
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (java.lang.Exception e5) {
            str = TAG;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Exception: ");
            stringBuilder.append(e5.toString());
            android.util.Log.e(str, stringBuilder.toString());
            if (inStream != null) {
                try {
                    inStream.close();
                } catch (java.io.IOException e6) {
                    e3 = e6;
                    str = TAG;
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (Throwable th) {
            if (inStream != null) {
                try {
                    inStream.close();
                } catch (java.io.IOException e32) {
                    java.lang.String str3 = TAG;
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("IOException: ");
                    stringBuilder3.append(e32.toString());
                    android.util.Log.e(str3, stringBuilder3.toString());
                }
            }
        }
        return out;
        stringBuilder.append("IOException: ");
        stringBuilder.append(e3.toString());
        android.util.Log.e(str, stringBuilder.toString());
        return out;
    }

    public static boolean isStreamingScene(com.android.server.hidata.appqoe.HwAPPStateInfo appInfo) {
        if (appInfo == null) {
            return false;
        }
        if (!(appInfo.mScenceId == 100501 || appInfo.mScenceId == 100106)) {
            if (appInfo.mScenceId != 100105) {
                return false;
            }
        }
        return true;
    }

    public static void setPvpScene(boolean isPvpScene) {
        mIsPvpScene = isPvpScene;
    }

    public static boolean isPvpScene() {
        return mIsPvpScene;
    }

    public static void setScreenState(boolean isScreenOn) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mIsScreenOn:");
        stringBuilder.append(isScreenOn);
        android.util.Log.d(str, stringBuilder.toString());
        mIsScreenOn = isScreenOn;
    }

    public static boolean isScreenOn() {
        return mIsScreenOn;
    }

    public static void setDataRoamingState(boolean isDataRoaming) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mDataRoamingState:");
        stringBuilder.append(isDataRoaming);
        android.util.Log.d(str, stringBuilder.toString());
        mDataRoamingState = isDataRoaming;
    }

    public static boolean isDataRoaming() {
        return mDataRoamingState;
    }

    public static void setDataTechSuitable(boolean dataTechSuitable) {
        mDataTechSuitable = dataTechSuitable;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mDataTechSuitable:");
        stringBuilder.append(mDataTechSuitable);
        android.util.Log.d(str, stringBuilder.toString());
    }

    public static boolean isDataTechSuitable() {
        return mDataTechSuitable;
    }

    public static void setServiceState(int currentServiceState) {
        mCurrentServiceState = currentServiceState;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mCurrentServiceState:");
        stringBuilder.append(mCurrentServiceState);
        android.util.Log.d(str, stringBuilder.toString());
    }

    public static boolean isStateInService() {
        return mCurrentServiceState == 0;
    }

    public static void setDataTech(int dataTech) {
        mCurrentDataTech = dataTech;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mCurrentDataTech:");
        stringBuilder.append(mCurrentDataTech);
        android.util.Log.d(str, stringBuilder.toString());
    }

    public static int getDataTech() {
        return mCurrentDataTech;
    }

    private static boolean isVSimEnabled() {
        return android.telephony.HwTelephonyManager.getDefault().isVSimEnabled();
    }

    public static boolean isInMPLink(android.content.Context context, int uid) {
        boolean result = false;
        if (com.android.server.hidata.arbitration.HwArbitrationStateMachine.getInstance(context) != null) {
            result = com.android.server.hidata.arbitration.HwArbitrationStateMachine.getInstance(context).isInMPLink(uid);
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isInMPLink:");
        stringBuilder.append(result);
        android.util.Log.d(str, stringBuilder.toString());
        return result;
    }
}
