package com.android.server.hidata.arbitration;

public class HwArbitrationManager {
    private static final boolean HiStreamEnabled = android.os.SystemProperties.getBoolean("ro.config.hw_histream.enabled", true);
    private static final java.lang.String TAG = "HiData_HwArbitrationManager";
    private static com.android.server.hidata.arbitration.HwArbitrationManager mHwArbitrationManager;
    private com.android.server.hidata.appqoe.HwAPPQoEManager mAPPQoEManager = null;
    private android.content.Context mContext;
    private com.android.server.hidata.arbitration.IHiDataCHRCallBack mHiDataCHRCallBack;
    private com.android.server.hidata.arbitration.HwArbitrationChrImpl mHwArbitrationChrImpl;
    private com.android.server.hidata.arbitration.HwArbitrationStateMachine mHwArbitrationStateMachine;
    private com.android.server.hidata.arbitration.HwArbitrationCallbackImpl mHwArbitrtionCallbackImpl = null;
    private com.android.server.hidata.histream.HwHiStreamManager mHwHiStreamManager = null;
    private com.android.server.hidata.wavemapping.HwWaveMappingManager mHwWaveMappingManager = null;
    private com.android.server.hidata.mplink.HwMplinkManager mMplinkManager = null;
    private com.android.server.hidata.arbitration.HwArbitrationStateMonitor mStateMonitor = null;

    public static com.android.server.hidata.arbitration.HwArbitrationManager createInstance(android.content.Context context, com.android.server.hidata.arbitration.IHiDataCHRCallBack chrcallBack) {
        if (mHwArbitrationManager == null) {
            mHwArbitrationManager = new com.android.server.hidata.arbitration.HwArbitrationManager(context, chrcallBack);
        }
        return mHwArbitrationManager;
    }

    public static com.android.server.hidata.arbitration.HwArbitrationManager getInstance() {
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logI("HiData_HwArbitrationManager", "HwArbitrationManager getInstance");
        return mHwArbitrationManager;
    }

    private HwArbitrationManager(android.content.Context context, com.android.server.hidata.arbitration.IHiDataCHRCallBack chrcallBack) {
        this.mContext = context;
        this.mHwArbitrationStateMachine = com.android.server.hidata.arbitration.HwArbitrationStateMachine.getInstance(this.mContext);
        this.mHwArbitrtionCallbackImpl = com.android.server.hidata.arbitration.HwArbitrationCallbackImpl.getInstance(this.mContext);
        this.mHiDataCHRCallBack = chrcallBack;
        this.mHwArbitrationChrImpl = com.android.server.hidata.arbitration.HwArbitrationChrImpl.createInstance();
        this.mHwArbitrationChrImpl.registArbitationChrCallBack(chrcallBack);
        modelInit(context);
        this.mStateMonitor = com.android.server.hidata.arbitration.HwArbitrationStateMonitor.createHwArbitrationStateMonitor(this.mContext, this.mHwArbitrationStateMachine.getHandler());
        this.mStateMonitor.startMonitor();
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logI("HiData_HwArbitrationManager", "init HwArbitration completed!");
    }

    private void modelInit(android.content.Context context) {
        this.mMplinkManager = com.android.server.hidata.mplink.HwMplinkManager.createInstance(context);
        this.mMplinkManager.registMpLinkCallback(this.mHwArbitrtionCallbackImpl);
        this.mMplinkManager.registCHRCallback(this.mHiDataCHRCallBack);
        this.mAPPQoEManager = com.android.server.hidata.appqoe.HwAPPQoEManager.createHwAPPQoEManager(context);
        this.mAPPQoEManager.registerAppQoECallback(this.mHwArbitrtionCallbackImpl, true);
        com.android.server.hidata.channelqoe.HwChannelQoEManager.createInstance(context);
        this.mHwWaveMappingManager = com.android.server.hidata.wavemapping.HwWaveMappingManager.getInstance(context);
        this.mHwWaveMappingManager.registerWaveMappingCallback(this.mHwArbitrtionCallbackImpl);
        if (true == HiStreamEnabled) {
            this.mHwHiStreamManager = com.android.server.hidata.histream.HwHiStreamManager.createInstance(this.mContext);
            this.mHwHiStreamManager.registCHRCallback(this.mHiDataCHRCallBack);
            this.mHwHiStreamManager.registerHistreamQoeCallback(this.mHwArbitrtionCallbackImpl);
        }
    }

    public boolean getWifiPlusFlagFromHiData() {
        if (this.mHwArbitrtionCallbackImpl == null) {
            return isSmartMpEnable();
        }
        boolean z;
        if (!this.mHwArbitrtionCallbackImpl.getWifiPlusFlagFromHiData()) {
            if (!isSmartMpEnable()) {
                z = false;
                return z;
            }
        }
        z = true;
        return z;
    }

    private boolean isSmartMpEnable() {
        return android.emcom.EmcomManager.getInstance().isSmartMpEnable();
    }
}
