package com.android.server.hidata.hiradio;

public class HwHiRadioBoost {
    private static final java.lang.String BASTET_SERVICE = "BastetService";
    public static final int BSR_ACCELERATE_ENABLED = 2;
    public static final int DATA_ACCELERATE_ENABLED = 1;
    public static final int HIREADIO_BOOST_ACTION_BG_OR_FG = 512;
    public static final int HIREADIO_BOOST_ACTION_ENABLE = 256;
    public static final int NO_ACTION_ENABLED = 0;
    private static final java.lang.String TAG = "HwHiRadioBoost";
    private static com.android.server.hidata.hiradio.HwHiRadioBoost mHwHiRadioBoost;
    private android.os.IBinder mBastetService;
    private android.os.IBinder.DeathRecipient mDeathRecipient = new android.os.IBinder.DeathRecipient() {
        public void binderDied() {
            com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", "Bastet service has died!");
            synchronized (com.android.server.hidata.hiradio.HwHiRadioBoost.this) {
                if (com.android.server.hidata.hiradio.HwHiRadioBoost.this.mBastetService != null) {
                    com.android.server.hidata.hiradio.HwHiRadioBoost.this.mBastetService.unlinkToDeath(this, 0);
                    com.android.server.hidata.hiradio.HwHiRadioBoost.this.mBastetService = null;
                    com.android.server.hidata.hiradio.HwHiRadioBoost.this.mIBastetManager = null;
                }
            }
        }
    };
    private com.huawei.android.bastet.IBastetManager mIBastetManager;

    public static com.android.server.hidata.hiradio.HwHiRadioBoost createInstance() {
        if (mHwHiRadioBoost == null) {
            mHwHiRadioBoost = new com.android.server.hidata.hiradio.HwHiRadioBoost();
        }
        return mHwHiRadioBoost;
    }

    private HwHiRadioBoost() {
        boolean isConnected = getBastetService();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("init mHwHiRadioBoost completed, isConnected = ");
        stringBuilder.append(isConnected);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD("HwHiRadioBoost", stringBuilder.toString());
    }

    private boolean getBastetService() {
        synchronized (this) {
            if (this.mBastetService == null) {
                this.mBastetService = android.os.ServiceManager.getService("BastetService");
                if (this.mBastetService == null) {
                    com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", "Failed to get bastet service!");
                    return false;
                }
                try {
                    this.mBastetService.linkToDeath(this.mDeathRecipient, 0);
                    this.mIBastetManager = com.huawei.android.bastet.IBastetManager.Stub.asInterface(this.mBastetService);
                } catch (android.os.RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
        return true;
    }

    private boolean isDataAccelerateEnabled(int actions) {
        return (actions & 1) == 1;
    }

    private boolean isBSRAccelerateEnabled(int actions) {
        return (actions & 2) == 2;
    }

    public void startOptimizeActionsForApp(com.android.server.hidata.appqoe.HwAPPStateInfo AppInfo, int actions) {
        java.lang.StringBuilder stringBuilder;
        if (AppInfo != null) {
            if (actions > 0) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("startOptimizeActionsForApp Enter: AppInfo.uid is ");
                stringBuilder.append(AppInfo.mAppUID);
                stringBuilder.append("AppInfo.mAppState is ");
                stringBuilder.append(AppInfo.mAppState);
                stringBuilder.append("actions is ");
                stringBuilder.append(actions);
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", stringBuilder.toString());
                if (isDataAccelerateEnabled(actions) || isBSRAccelerateEnabled(actions)) {
                    configDataAccelerate(AppInfo.mAppUID, true, true, (actions & 1) | (actions & 2));
                }
                return;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Enter startOptimizeActionsForApp: AppInfo is null, actions is ");
        stringBuilder.append(actions);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", stringBuilder.toString());
    }

    public void stopOptimizedActionsForApp(com.android.server.hidata.appqoe.HwAPPStateInfo AppInfo, boolean fgBgState, int actions) {
        java.lang.StringBuilder stringBuilder;
        if (AppInfo != null) {
            if (actions >= 0) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("stopOptimizedActionsForApp Enter: AppInfo.uid is ");
                stringBuilder.append(AppInfo.mAppUID);
                stringBuilder.append("AppInfo.mAppState is ");
                stringBuilder.append(AppInfo.mAppState);
                stringBuilder.append("actions is ");
                stringBuilder.append(actions);
                com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", stringBuilder.toString());
                if (isDataAccelerateEnabled(actions) || isBSRAccelerateEnabled(actions)) {
                    configDataAccelerate(AppInfo.mAppUID, fgBgState, false, (actions & 1) | (actions & 2));
                }
                return;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Enter stopOptimizedActionsForApp: AppInfo is null, actions is ");
        stringBuilder.append(actions);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", stringBuilder.toString());
    }

    private void configDataAccelerate(int uid, boolean fgBgState, boolean enable, int action) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("configDataAccelerate Enter, uid is ");
        stringBuilder.append(uid);
        stringBuilder.append("action is ");
        stringBuilder.append(action);
        com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logE("HwHiRadioBoost", stringBuilder.toString());
        if (enable) {
            action += 256;
        }
        if (!fgBgState) {
            action += 512;
        }
        try {
            getBastetService();
            synchronized (this) {
                if (this.mIBastetManager != null && this.mIBastetManager.configDataAccelerate(uid, action) == 0) {
                    com.android.server.hidata.arbitration.HwArbitrationCommonUtils.logD("HwHiRadioBoost", "configDataAccelerate success");
                }
            }
        } catch (android.os.RemoteException e) {
            e.printStackTrace();
        }
    }
}
