package com.android.server.hidata.histream;

class HwHiStreamNetworkMonitor {
    public static final int EVENT_CONNECTIVITY_CHANGE = 3;
    public static final int EVENT_MOBILE_DATA_DISABLED = 2;
    public static final int EVENT_WIFI_DISABLED = 1;
    private static com.android.server.hidata.histream.HwHiStreamNetworkMonitor mHwHiStreamNetworkMonitor;
    private android.content.BroadcastReceiver mBroadcastReceiver;
    private android.content.Context mContext;
    private java.lang.String mCurrBSSID = null;
    private android.os.Handler mHandler;
    private android.content.IntentFilter mIntentFilter;
    public long mLastCellDisableTime = 0;
    public long mLastHandoverTime = 0;
    public long mLastWifiDisabledTime = 0;
    public long mLastWifiEnabledTime = 0;
    private com.huawei.lcagent.client.LogCollectManager mLogCollectManager;
    private android.net.NetworkInfo mNetworkInfo;
    private android.content.ContentResolver mResolver;
    private android.telephony.TelephonyManager mTelephonyManager;
    private com.android.server.hidata.histream.HwHiStreamNetworkMonitor.UserDataEnableObserver mUserDataEnableObserver;
    private android.net.wifi.WifiInfo mWifiInfo;
    private android.net.wifi.WifiManager mWifiManager;

    private class UserDataEnableObserver extends android.database.ContentObserver {
        public UserDataEnableObserver(android.os.Handler handler) {
            super(handler);
            com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mResolver = com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mContext.getContentResolver();
        }

        public void register() {
            com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mResolver.registerContentObserver(android.provider.Settings.Global.getUriFor("mobile_data"), false, this);
        }

        public void unregister() {
            com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mResolver.unregisterContentObserver(this);
        }

        public void onChange(boolean selfChange) {
            if (!com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.isUserDataEnabled()) {
                com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mLastCellDisableTime = java.lang.System.currentTimeMillis();
                android.os.Bundle bundle = new android.os.Bundle();
                bundle.putInt("event", 2);
                com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.sendMessage(com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.obtainMessage(3, bundle));
            }
        }
    }

    private HwHiStreamNetworkMonitor(android.content.Context context, android.os.Handler handler) {
        this.mContext = context;
        this.mHandler = handler;
        registerBroadcastReceiver();
        this.mUserDataEnableObserver = new com.android.server.hidata.histream.HwHiStreamNetworkMonitor.UserDataEnableObserver(this.mHandler);
        this.mUserDataEnableObserver.register();
        this.mWifiManager = (android.net.wifi.WifiManager) this.mContext.getSystemService("wifi");
        this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        this.mLogCollectManager = new com.huawei.lcagent.client.LogCollectManager(this.mContext);
    }

    public static com.android.server.hidata.histream.HwHiStreamNetworkMonitor createInstance(android.content.Context context, android.os.Handler handler) {
        if (mHwHiStreamNetworkMonitor == null) {
            mHwHiStreamNetworkMonitor = new com.android.server.hidata.histream.HwHiStreamNetworkMonitor(context, handler);
        }
        return mHwHiStreamNetworkMonitor;
    }

    public static com.android.server.hidata.histream.HwHiStreamNetworkMonitor getInstance() {
        return mHwHiStreamNetworkMonitor;
    }

    public int getCurrNetworkType(int uid) {
        return com.android.server.hidata.arbitration.HwArbitrationFunction.getCurrentNetwork(this.mContext, uid);
    }

    public java.lang.String getCurBSSID() {
        if (this.mCurrBSSID == null) {
            this.mWifiInfo = this.mWifiManager.getConnectionInfo();
            if (this.mWifiInfo != null) {
                this.mCurrBSSID = this.mWifiInfo.getBSSID();
            }
        }
        return this.mCurrBSSID;
    }

    private void handleWifiConnected() {
        this.mWifiInfo = this.mWifiManager.getConnectionInfo();
        if (this.mWifiInfo != null) {
            this.mCurrBSSID = this.mWifiInfo.getBSSID();
        }
    }

    public boolean getMoblieDateSettings() {
        return getSettingsGlobalBoolean(this.mContext.getContentResolver(), "mobile_data", false);
    }

    private boolean getSettingsGlobalBoolean(android.content.ContentResolver cr, java.lang.String name, boolean def) {
        return android.provider.Settings.Global.getInt(cr, name, def) == 1;
    }

    private void registerBroadcastReceiver() {
        this.mBroadcastReceiver = new android.content.BroadcastReceiver() {
            public void onReceive(android.content.Context context, android.content.Intent intent) {
                java.lang.String action = intent.getAction();
                if ("android.net.wifi.STATE_CHANGE".equals(action)) {
                    com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mNetworkInfo = (android.net.NetworkInfo) intent.getParcelableExtra("networkInfo");
                    if (com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mNetworkInfo != null && com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mNetworkInfo.getState() == android.net.NetworkInfo.State.CONNECTED) {
                        com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.handleWifiConnected();
                    }
                } else if ("android.net.conn.CONNECTIVITY_CHANGE".equals(action)) {
                    android.os.Bundle bundle = new android.os.Bundle();
                    bundle.putInt("event", 3);
                    com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.sendMessageDelayed(com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.obtainMessage(3, bundle), 500);
                } else if ("android.net.wifi.WIFI_STATE_CHANGED".equals(action)) {
                    int wifistatue = intent.getIntExtra("wifi_state", 4);
                    if (1 == wifistatue) {
                        com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mLastWifiDisabledTime = java.lang.System.currentTimeMillis();
                        android.os.Bundle bundle2 = new android.os.Bundle();
                        bundle2.putInt("event", 1);
                        com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.sendMessage(com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mHandler.obtainMessage(3, bundle2));
                    } else if (3 == wifistatue) {
                        com.android.server.hidata.histream.HwHiStreamUtils.logD("+++++++WIFI enabled ++++++");
                        com.android.server.hidata.histream.HwHiStreamNetworkMonitor.this.mLastWifiEnabledTime = java.lang.System.currentTimeMillis();
                    }
                }
            }
        };
        this.mIntentFilter = new android.content.IntentFilter();
        this.mIntentFilter.addAction("android.net.wifi.STATE_CHANGE");
        this.mIntentFilter.addAction("android.net.wifi.RSSI_CHANGED");
        this.mIntentFilter.addAction("android.net.wifi.WIFI_STATE_CHANGED");
        this.mIntentFilter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
        this.mIntentFilter.addAction("com.android.server.hidata.arbitration.HwArbitrationStateMachine");
        this.mContext.registerReceiver(this.mBroadcastReceiver, this.mIntentFilter);
    }

    public java.lang.String getCurrentDefaultDataImsi() {
        java.lang.String mCurrentDefaultDataImsi = this.mTelephonyManager.getSubscriberId(android.telephony.SubscriptionManager.getDefaultDataSubscriptionId());
        if (this.mLogCollectManager == null || mCurrentDefaultDataImsi == null) {
            return mCurrentDefaultDataImsi;
        }
        try {
            return this.mLogCollectManager.doEncrypt(mCurrentDefaultDataImsi);
        } catch (android.os.RemoteException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getCurrentDefaultDataImsi doEncrypt error:");
            stringBuilder.append(e);
            com.android.server.hidata.histream.HwHiStreamUtils.logE(stringBuilder.toString());
            return null;
        }
    }

    public boolean isUserDataEnabled() {
        return android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "mobile_data", 0) != 0;
    }
}
