package com.android.server.input;

public class HwGuiShou {
    private static final java.lang.String FINGERPRINT_SLIDE_SWITCH = "fingerprint_slide_switch";
    private static boolean GUISHOU_ENABLED = false;
    private static final int SIM_SUB1 = 0;
    private static final int SIM_SUB2 = 1;
    private static final java.lang.String TAG = "HwGuiShou";
    private android.content.Context mContext;
    private com.android.server.input.FingerprintNavigation mFingerprintNavigationFilter;
    private com.android.server.input.HwGuiShou.FpSlideSwitchSettingsObserver mFpSlideSwitchSettingsObserver;
    private android.os.Handler mHandler;
    private com.android.server.input.HwInputManagerService mHwInputManagerService;
    private int mInCallCount = 0;
    private boolean mIsPhoneStateListenerNotRegister = true;
    private android.os.Looper mLooper;
    private android.telephony.TelephonyManager mPhoneManager;
    private android.content.ContentResolver mResolver;
    private int mTempSlideSwitch = 0;

    class FpSlideSwitchSettingsObserver extends android.database.ContentObserver {
        public boolean mmForceUpdateChange = false;

        FpSlideSwitchSettingsObserver(android.os.Handler handler) {
            super(handler);
        }

        public void registerContentObserver(int userId) {
            com.android.server.input.HwGuiShou.this.mResolver.registerContentObserver(android.provider.Settings.Secure.getUriFor("fingerprint_slide_switch"), false, this, userId);
        }

        public void onChange(boolean selfChange) {
            int i = 1;
            boolean injectSlide = android.provider.Settings.Secure.getIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", 0, android.app.ActivityManager.getCurrentUser()) != 0;
            if (this.mmForceUpdateChange || com.android.server.input.HwGuiShou.this.mInCallCount <= 0 || injectSlide) {
                this.mmForceUpdateChange = false;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("open fingerprint nav=");
                stringBuilder.append(injectSlide);
                android.util.Log.d("HwGuiShou", stringBuilder.toString());
                android.content.ContentResolver access$100 = com.android.server.input.HwGuiShou.this.mResolver;
                java.lang.String str = "fingerprint_slide_switch";
                if (!injectSlide) {
                    i = 0;
                }
                android.provider.Settings.System.putInt(access$100, str, i);
                return;
            }
            android.provider.Settings.Secure.putIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", 1, android.app.ActivityManager.getCurrentUser());
        }
    }

    static {
        boolean z = false;
        GUISHOU_ENABLED = false;
        boolean isStopAlarmDisabled = android.os.SystemProperties.getBoolean("ro.config.fp_rm_alarm", false);
        boolean isGallerySlideEnabled = android.os.SystemProperties.getBoolean("ro.config.fp_navigation", true);
        boolean isNotificationSlideEnabledByAdd = android.os.SystemProperties.getBoolean("ro.config.fp_add_notification", true);
        boolean isNotificationSlideDisabledByRm = android.os.SystemProperties.getBoolean("ro.config.fp_rm_notification", false);
        if (!(isStopAlarmDisabled || isGallerySlideEnabled || (isNotificationSlideEnabledByAdd && !isNotificationSlideDisabledByRm))) {
            z = true;
        }
        GUISHOU_ENABLED = z;
    }

    public HwGuiShou(com.android.server.input.HwInputManagerService inputService, android.content.Context context, android.os.Handler handler, com.android.server.input.FingerprintNavigation fn) {
        this.mContext = context;
        this.mHandler = handler;
        this.mHwInputManagerService = inputService;
        this.mFingerprintNavigationFilter = fn;
        if (context != null) {
            this.mResolver = context.getContentResolver();
        }
    }

    public static boolean isGuiShouEnabled() {
        return GUISHOU_ENABLED;
    }

    public static boolean isFPNavigationInThreeAppsEnabled(boolean injectCamera, boolean answerCall, boolean stopAlarm) {
        boolean z = true;
        if (isGuiShouEnabled()) {
            return true;
        }
        if (injectCamera || answerCall || stopAlarm) {
            z = false;
        }
        return z;
    }

    private boolean isDefaultSlideSwitchOn() {
        if (this.mHwInputManagerService != null) {
            return this.mHwInputManagerService.isDefaultSlideSwitchOn();
        }
        return true;
    }

    private void registerPhoneStateListenerBySub(int sub) {
        this.mTempSlideSwitch = isDefaultSlideSwitchOn();
        android.telephony.PhoneStateListener listener = new android.telephony.PhoneStateListener(java.lang.Integer.valueOf(sub), this.mLooper) {
            public void onCallStateChanged(int state, java.lang.String incomingNumber) {
                switch (state) {
                    case 0:
                        android.util.Slog.i("HwGuiShou", "call state: idle");
                        com.android.server.input.HwGuiShou.this.mInCallCount = com.android.server.input.HwGuiShou.this.mInCallCount - 1;
                        if (com.android.server.input.HwGuiShou.this.mInCallCount == 0) {
                            android.provider.Settings.Secure.putIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", com.android.server.input.HwGuiShou.this.mTempSlideSwitch, android.app.ActivityManager.getCurrentUser());
                            return;
                        } else if (com.android.server.input.HwGuiShou.this.mInCallCount < 0) {
                            com.android.server.input.HwGuiShou.this.mInCallCount = 0;
                            return;
                        } else {
                            return;
                        }
                    case 1:
                        android.util.Slog.i("HwGuiShou", "call state: ringing");
                        if (com.android.server.input.HwGuiShou.this.mInCallCount == 0) {
                            if (com.android.server.input.HwGuiShou.this.mFingerprintNavigationFilter.isAlarm()) {
                                com.android.server.input.HwGuiShou.this.mTempSlideSwitch = com.android.server.input.HwGuiShou.this.isDefaultSlideSwitchOn();
                            } else {
                                com.android.server.input.HwGuiShou.this.mTempSlideSwitch = android.provider.Settings.Secure.getIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", 0, android.app.ActivityManager.getCurrentUser());
                            }
                        }
                        com.android.server.input.HwGuiShou.this.mInCallCount = com.android.server.input.HwGuiShou.this.mInCallCount + 1;
                        android.provider.Settings.Secure.putIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", 1, android.app.ActivityManager.getCurrentUser());
                        return;
                    case 2:
                        android.util.Slog.i("HwGuiShou", "call state: offhook");
                        com.android.server.input.HwGuiShou.this.mTempSlideSwitch = com.android.server.input.HwGuiShou.this.isDefaultSlideSwitchOn();
                        com.android.server.input.HwGuiShou.this.mFpSlideSwitchSettingsObserver.mmForceUpdateChange = true;
                        android.provider.Settings.Secure.putIntForUser(com.android.server.input.HwGuiShou.this.mResolver, "fingerprint_slide_switch", com.android.server.input.HwGuiShou.this.mTempSlideSwitch, android.app.ActivityManager.getCurrentUser());
                        return;
                    default:
                        return;
                }
            }
        };
        if (this.mPhoneManager != null) {
            this.mPhoneManager.listen(listener, 481);
        }
    }

    public void registerPhoneStateListener() {
        if (isGuiShouEnabled()) {
            this.mLooper = android.os.Looper.myLooper();
            this.mPhoneManager = android.telephony.TelephonyManager.from(this.mContext);
            if (this.mPhoneManager != null && this.mIsPhoneStateListenerNotRegister) {
                registerPhoneStateListenerBySub(0);
                registerPhoneStateListenerBySub(1);
                this.mIsPhoneStateListenerNotRegister = false;
            }
        }
    }

    public void registerFpSlideSwitchSettingsObserver() {
        if (isGuiShouEnabled()) {
            this.mFpSlideSwitchSettingsObserver = new com.android.server.input.HwGuiShou.FpSlideSwitchSettingsObserver(this.mHandler);
            this.mFpSlideSwitchSettingsObserver.registerContentObserver(android.os.UserHandle.myUserId());
        }
    }

    public void registerFpSlideSwitchSettingsObserver(int newUserId) {
        if (isGuiShouEnabled()) {
            this.mFpSlideSwitchSettingsObserver = new com.android.server.input.HwGuiShou.FpSlideSwitchSettingsObserver(this.mHandler);
            this.mFpSlideSwitchSettingsObserver.registerContentObserver(newUserId);
        }
    }

    public void setFingerprintSlideSwitchValue(boolean value) {
        if (isGuiShouEnabled()) {
            android.provider.Settings.Secure.putIntForUser(this.mResolver, "fingerprint_slide_switch", value, android.app.ActivityManager.getCurrentUser());
        }
    }
}
