package com.android.server.lights;

public class HwLightsService extends com.android.server.lights.LightsService {
    private static boolean DEBUG = false;
    private static final int MAX_BRIGHTNESS = 10000;
    private static java.lang.String MAX_BRIGHTNESS_NODE = "/sys/class/leds/lcd_backlight0/max_brightness";
    private static final int MIN_BRIGHTNESS = 156;
    private static final int MSG_UPDATE_BRIGHTNESS = 0;
    private static final int NORMALIZED_DEFAULT_MAX_BRIGHTNESS = 255;
    private static final int NORMALIZED_DEFAULT_MIN_BRIGHTNESS = 4;
    private static final int NORMALIZED_MAX_BRIGHTNESS = 10000;
    private static java.lang.String PANEL_INFO_NODE = "/sys/class/graphics/fb0/panel_info";
    private static final int REFRESH_FRAMES_CMD = 1;
    private static final int SRE_REFRESH_FRAMES_CMD = 1;
    static final java.lang.String TAG = "HwLightsService";
    private boolean mAutoBrightnessEnabled = false;
    private com.android.server.lights.HwLightsService.BackLightLevelLogPrinter mBackLightLevelPrinter = null;
    private android.content.ContentResolver mContentResolver = getContext().getContentResolver();
    private int mCurrentUserId = 0;
    private int mDeviceActualBrightnessNit = 0;
    private int mDeviceBrightnessLevel = 0;
    private int mDeviceStandardBrightnessNit = 0;
    private com.huawei.displayengine.DisplayEngineManager mDisplayEngineManager;
    private int mNormalizedMaxBrightness = -1;
    private int mNormalizedMinBrightness = -1;
    private final android.content.BroadcastReceiver mReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            if (action != null && "android.intent.action.ACTION_SHUTDOWN".equals(action)) {
                android.util.Log.i("HwLightsService", "handle ACTION_SHUTDOWN broadcast");
                com.android.server.lights.LightsService.mHasShutDown = true;
            }
        }
    };
    private android.os.Handler mRefreshFramesHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            com.android.server.lights.HwLightsService.this.mRefreshFramesHandler.removeMessages(1);
            com.android.server.lights.LightsService.refreshFrames_native();
            com.android.server.lights.HwLightsService.this.mSBLFrameCount = com.android.server.lights.HwLightsService.this.mSBLFrameCount - 1;
            if (com.android.server.lights.HwLightsService.this.mSBLFrameCount > 0) {
                com.android.server.lights.HwLightsService.this.mRefreshFramesHandler.sendEmptyMessageDelayed(1, 16);
            } else if (com.android.server.lights.HwLightsService.this.mSBLSetAfterRefresh) {
                com.android.server.lights.HwLightsService.this.sendSmartBackLightWithRefreshFramesImpl(com.android.server.lights.HwLightsService.this.mSBLId, com.android.server.lights.HwLightsService.this.mSBLEnable, com.android.server.lights.HwLightsService.this.mSBLLevel, com.android.server.lights.HwLightsService.this.mSBLValue, 0, false, 0, 0);
                com.android.server.lights.HwLightsService.this.mSBLSetAfterRefresh = false;
            }
        }
    };
    private int mSBLEnable;
    private int mSBLFrameCount;
    private int mSBLId;
    private int mSBLLevel;
    private boolean mSBLSetAfterRefresh;
    private int mSBLValue;
    private int mSREFrameCount;
    private int mSREId;
    private android.os.Handler mSRERefreshFramesHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            com.android.server.lights.HwLightsService.this.mSRERefreshFramesHandler.removeMessages(1);
            com.android.server.lights.LightsService.refreshFrames_native();
            com.android.server.lights.HwLightsService.this.mSREFrameCount = com.android.server.lights.HwLightsService.this.mSREFrameCount - 1;
            if (com.android.server.lights.HwLightsService.this.mSREFrameCount > 0) {
                com.android.server.lights.HwLightsService.this.mSRERefreshFramesHandler.sendEmptyMessageDelayed(1, 16);
            } else if (com.android.server.lights.HwLightsService.this.mSRESetAfterRefresh) {
                com.android.server.lights.LightsService.setLight_native(com.android.server.lights.HwLightsService.this.mSREId, com.android.server.lights.HwLightsService.this.mSREValue, 0, 0, 0, 0);
                com.android.server.lights.HwLightsService.this.mSRESetAfterRefresh = false;
            }
        }
    };
    private boolean mSRESetAfterRefresh;
    private int mSREValue;
    private int mSupportAmoled = 0;
    private boolean mSupportAmoled_isloaded = false;
    private int mSupportGammaFix = 0;
    private boolean mSupportGammaFix_isloaded = false;
    private int mSupportRGLed = 0;
    private boolean mSupportRGLed_isloaded = false;
    private int mSupportXCC = 0;
    private boolean mSupportXCC_isloaded = false;
    private android.os.Handler mUpdateBrightnessHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            if (msg.what == 0) {
                int brightnessOut = (int) java.lang.Math.ceil((double) ((((float) (65535 & com.android.server.lights.HwLightsService.this.getLcdBrightnessMode())) * 255.0f) / 10000.0f));
                android.provider.Settings.System.putIntForUser(com.android.server.lights.HwLightsService.this.mContentResolver, "screen_auto_brightness", brightnessOut, com.android.server.lights.HwLightsService.this.mCurrentUserId);
                if (brightnessOut != 0) {
                    android.provider.Settings.System.putIntForUser(com.android.server.lights.HwLightsService.this.mContentResolver, "screen_brightness", brightnessOut, com.android.server.lights.HwLightsService.this.mCurrentUserId);
                }
            }
        }
    };

    private static class BackLightLevelLogPrinter {
        private java.lang.String mLogTag = null;
        private int mPrintedLevel = 0;
        private float mThresholdPercent = 0.1f;

        public BackLightLevelLogPrinter(java.lang.String logTag, float thresholdPercent) {
            this.mThresholdPercent = thresholdPercent;
            this.mLogTag = logTag;
        }

        public void printLevel(int level) {
            if (!com.android.server.lights.HwLightsService.DEBUG) {
                return;
            }
            if ((level != 0 || this.mPrintedLevel == 0) && (level == 0 || this.mPrintedLevel != 0)) {
                int threshold = (int) (((float) this.mPrintedLevel) * this.mThresholdPercent);
                int i = 2;
                if (threshold >= 2) {
                    i = threshold;
                }
                threshold = i;
                i = level - this.mPrintedLevel;
                if ((i < 0 ? -i : i) > threshold) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(this.mLogTag);
                    stringBuilder.append(" = ");
                    stringBuilder.append(level);
                    android.util.Slog.i("HwLightsService", stringBuilder.toString());
                    this.mPrintedLevel = level;
                }
                return;
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(this.mLogTag);
            stringBuilder2.append(" = ");
            stringBuilder2.append(level);
            android.util.Slog.i("HwLightsService", stringBuilder2.toString());
            this.mPrintedLevel = level;
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwLightsService", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwLightsService(android.content.Context context) {
        super(context);
        boolean z = false;
        getNormalizedBrightnessRangeFromKernel();
        if (this.mNormalizedMaxBrightness > 255) {
            z = true;
        }
        this.mIsHighPrecision = z;
        setBackLightMaxLevel_native(this.mNormalizedMaxBrightness);
        this.mDisplayEngineManager = new com.huawei.displayengine.DisplayEngineManager();
    }

    public void onBootPhase(int phase) {
        super.onBootPhase(phase);
        if (phase == 1000) {
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("android.intent.action.ACTION_SHUTDOWN");
            getContext().registerReceiver(this.mReceiver, filter);
        }
    }

    private void refreshSmartBackLightFrames(int id, int count, boolean setAfterRefresh, int enable, int level, int value) {
        this.mSBLId = id;
        this.mSBLFrameCount = count;
        this.mSBLSetAfterRefresh = setAfterRefresh;
        this.mSBLEnable = enable;
        this.mSBLLevel = level;
        this.mSBLValue = value;
        if (count > 0) {
            this.mRefreshFramesHandler.sendEmptyMessage(1);
        }
    }

    public void sendSmartBackLightWithRefreshFramesImpl(int id, int enable, int level, int value, int frames, boolean setAfterRefresh, int enable2, int value2) {
        int i = id;
        if (i != 257) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("id = ");
            stringBuilder.append(i);
            stringBuilder.append(", error! this mothod only used for SBL!");
            android.util.Slog.e("HwLightsService", stringBuilder.toString());
            return;
        }
        synchronized (this) {
            int i2 = value;
            int i3 = level;
            setLight_native(i, (65535 & (i2 > 65535 ? 65535 : i2)) | (((enable & 1) << 24) | ((i3 & 255) << 16)), 0, 0, 0, 0);
            refreshSmartBackLightFrames(i, frames, setAfterRefresh, enable2, i3, value2);
        }
    }

    private void refreshSREFrames(int id, int count, boolean setAfterRefresh, int value) {
        this.mSREId = id;
        this.mSREFrameCount = count;
        this.mSRESetAfterRefresh = setAfterRefresh;
        this.mSREValue = value;
        if (count > 0) {
            this.mSRERefreshFramesHandler.sendEmptyMessage(1);
        }
    }

    public void sendSREWithRefreshFramesImpl(int id, int enable, int ambientLightThreshold, int ambientLight, int frames, boolean setAfterRefresh, int enable2, int ambientLight2) {
        java.lang.Throwable th;
        synchronized (this) {
            int ambientLightThresholdMin = 4095;
            int i = ambientLightThreshold;
            if (i <= 4095) {
                ambientLightThresholdMin = i;
            }
            int i2 = ambientLight;
            int ambientLightMin = i2 > 65535 ? 65535 : i2;
            int sreValue2 = (65535 & ambientLightMin) | (((enable2 & 1) << 28) | ((ambientLightThresholdMin & 4095) << 16));
            try {
                setLight_native(id, (((enable & 1) << 28) | ((ambientLightThresholdMin & 4095) << 16)) | (ambientLightMin & 65535), 0, 0, 0, 0);
                refreshSREFrames(id, frames, setAfterRefresh, sreValue2);
            } catch (Throwable th2) {
                th = th2;
                throw th;
            }
        }
    }

    protected void sendUpdateaAutoBrightnessDbMsg() {
        if (this.mWriteAutoBrightnessDbEnable && this.mAutoBrightnessEnabled && this.mUpdateBrightnessHandler != null) {
            if (this.mUpdateBrightnessHandler.hasMessages(0)) {
                this.mUpdateBrightnessHandler.removeMessages(0);
            }
            this.mUpdateBrightnessHandler.sendEmptyMessage(0);
        }
    }

    protected void updateBrightnessMode(boolean mode) {
        this.mAutoBrightnessEnabled = mode;
    }

    protected void updateCurrentUserId(int userId) {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("user change from  ");
            stringBuilder.append(this.mCurrentUserId);
            stringBuilder.append(" into ");
            stringBuilder.append(userId);
            android.util.Slog.d("HwLightsService", stringBuilder.toString());
        }
        this.mCurrentUserId = userId;
    }

    private boolean getBrightnessRangeFromPanelInfo() {
        java.io.File file = new java.io.File(PANEL_INFO_NODE);
        if (file.exists()) {
            java.io.BufferedReader reader = null;
            java.io.FileInputStream fis = null;
            java.lang.StringBuilder stringBuilder;
            try {
                fis = new java.io.FileInputStream(file);
                reader = new java.io.BufferedReader(new java.io.InputStreamReader(fis, "UTF-8"));
                java.lang.String readLine = reader.readLine();
                java.lang.String tempString = readLine;
                if (readLine != null) {
                    if (DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("getBrightnessRangeFromPanelInfo String = ");
                        stringBuilder.append(tempString);
                        android.util.Slog.i("HwLightsService", stringBuilder.toString());
                    }
                    if (tempString.length() == 0) {
                        android.util.Slog.e("HwLightsService", "getBrightnessRangeFromPanelInfo error! String is null");
                        reader.close();
                        close(reader, fis);
                        return false;
                    }
                    java.lang.String[] stringSplited = tempString.split(",");
                    if (stringSplited.length < 2) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("split failed! String = ");
                        stringBuilder2.append(tempString);
                        android.util.Slog.e("HwLightsService", stringBuilder2.toString());
                        reader.close();
                        close(reader, fis);
                        return false;
                    } else if (parsePanelInfo(stringSplited)) {
                        reader.close();
                        close(reader, fis);
                        return true;
                    }
                }
            } catch (java.io.FileNotFoundException e) {
                android.util.Slog.e("HwLightsService", "getBrightnessRangeFromPanelInfo error! FileNotFoundException");
            } catch (java.io.IOException e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getBrightnessRangeFromPanelInfo error! IOException ");
                stringBuilder.append(e2);
                android.util.Slog.e("HwLightsService", stringBuilder.toString());
            } catch (java.lang.Exception e3) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getBrightnessRangeFromPanelInfo error! Exception ");
                stringBuilder.append(e3);
                android.util.Slog.e("HwLightsService", stringBuilder.toString());
            } catch (Throwable th) {
                close(reader, fis);
            }
            close(reader, fis);
            return false;
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("getBrightnessRangeFromPanelInfo PANEL_INFO_NODE:");
            stringBuilder3.append(PANEL_INFO_NODE);
            stringBuilder3.append(" isn't exist");
            android.util.Slog.w("HwLightsService", stringBuilder3.toString());
        }
        return false;
    }

    private boolean parsePanelInfo(java.lang.String[] stringSplited) {
        if (stringSplited == null) {
            return false;
        }
        java.lang.String key = null;
        int index = -1;
        int standardMaxNit = 0;
        int actualMaxNit = 0;
        int deviceLevel = 0;
        int min = -1;
        int max = -1;
        int i = 0;
        while (i < stringSplited.length) {
            try {
                key = "blmax:";
                index = stringSplited[i].indexOf(key);
                if (index != -1) {
                    max = java.lang.Integer.parseInt(stringSplited[i].substring(key.length() + index));
                } else {
                    key = "blmin:";
                    index = stringSplited[i].indexOf(key);
                    if (index != -1) {
                        min = java.lang.Integer.parseInt(stringSplited[i].substring(key.length() + index));
                    } else {
                        key = "bldevicelevel:";
                        index = stringSplited[i].indexOf(key);
                        if (index != -1) {
                            deviceLevel = java.lang.Integer.parseInt(stringSplited[i].substring(key.length() + index));
                        } else {
                            key = "blmax_nit_actual:";
                            index = stringSplited[i].indexOf(key);
                            if (index != -1) {
                                actualMaxNit = java.lang.Integer.parseInt(stringSplited[i].substring(key.length() + index));
                            } else {
                                key = "blmax_nit_standard:";
                                index = stringSplited[i].indexOf(key);
                                if (index != -1) {
                                    standardMaxNit = java.lang.Integer.parseInt(stringSplited[i].substring(key.length() + index));
                                }
                            }
                        }
                    }
                }
                i++;
            } catch (java.lang.NumberFormatException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("parsePanelInfo() error! ");
                stringBuilder.append(key);
                stringBuilder.append(e);
                android.util.Slog.e("HwLightsService", stringBuilder.toString());
                return false;
            }
        }
        if (max == -1 || min == -1) {
            return false;
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("getBrightnessRangeFromPanelInfo success! min = ");
            stringBuilder2.append(min);
            stringBuilder2.append(", max = ");
            stringBuilder2.append(max);
            stringBuilder2.append(", deviceLevel = ");
            stringBuilder2.append(deviceLevel);
            stringBuilder2.append(",actualMaxNit=");
            stringBuilder2.append(actualMaxNit);
            stringBuilder2.append(",standardMaxNit=");
            stringBuilder2.append(standardMaxNit);
            android.util.Slog.i("HwLightsService", stringBuilder2.toString());
        }
        this.mNormalizedMaxBrightness = max;
        this.mNormalizedMinBrightness = min;
        this.mDeviceBrightnessLevel = deviceLevel;
        this.mDeviceActualBrightnessNit = actualMaxNit;
        this.mDeviceStandardBrightnessNit = standardMaxNit;
        return true;
    }

    private boolean getBrightnessRangeFromMaxBrightness() {
        java.io.File file = new java.io.File(MAX_BRIGHTNESS_NODE);
        if (file.exists()) {
            java.io.BufferedReader reader = null;
            java.io.FileInputStream fis = null;
            try {
                fis = new java.io.FileInputStream(file);
                reader = new java.io.BufferedReader(new java.io.InputStreamReader(fis, "UTF-8"));
                java.lang.String readLine = reader.readLine();
                java.lang.String tempString = readLine;
                if (readLine != null) {
                    this.mNormalizedMaxBrightness = java.lang.Integer.parseInt(tempString);
                    this.mNormalizedMinBrightness = (this.mNormalizedMaxBrightness * 4) / 255;
                    if (DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("getBrightnessRangeFromMaxBrightness success! min = ");
                        stringBuilder.append(this.mNormalizedMinBrightness);
                        stringBuilder.append(", max = ");
                        stringBuilder.append(this.mNormalizedMaxBrightness);
                        android.util.Slog.i("HwLightsService", stringBuilder.toString());
                    }
                    reader.close();
                    close(reader, fis);
                    return true;
                }
            } catch (java.io.FileNotFoundException e) {
                e.printStackTrace();
            } catch (java.io.IOException e2) {
                e2.printStackTrace();
            } catch (java.lang.Exception e3) {
                e3.printStackTrace();
            } catch (Throwable th) {
                close(null, null);
            }
            close(reader, fis);
            return false;
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("getBrightnessRangeFromMaxBrightness MAX_BRIGHTNESS_NODE:");
            stringBuilder2.append(MAX_BRIGHTNESS_NODE);
            stringBuilder2.append(" isn't exist");
            android.util.Slog.w("HwLightsService", stringBuilder2.toString());
        }
        return false;
    }

    private void checkNormalizedBrightnessRange() {
        java.lang.StringBuilder stringBuilder;
        if (this.mNormalizedMinBrightness < 0 || this.mNormalizedMinBrightness >= this.mNormalizedMaxBrightness || this.mNormalizedMaxBrightness > 10000) {
            this.mNormalizedMinBrightness = 4;
            this.mNormalizedMaxBrightness = 255;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkNormalizedBrightnessRange failed! load default brightness range: min = ");
            stringBuilder.append(this.mNormalizedMinBrightness);
            stringBuilder.append(", max = ");
            stringBuilder.append(this.mNormalizedMaxBrightness);
            android.util.Slog.e("HwLightsService", stringBuilder.toString());
            return;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("checkNormalizedBrightnessRange success! range: min = ");
        stringBuilder.append(this.mNormalizedMinBrightness);
        stringBuilder.append(", max = ");
        stringBuilder.append(this.mNormalizedMaxBrightness);
        android.util.Slog.i("HwLightsService", stringBuilder.toString());
    }

    protected void getNormalizedBrightnessRangeFromKernel() {
        try {
            if (getBrightnessRangeFromPanelInfo()) {
                checkNormalizedBrightnessRange();
                return;
            }
            if (DEBUG) {
                android.util.Slog.w("HwLightsService", "getBrightnessRangeFromPanelInfo failed");
            }
            if (getBrightnessRangeFromMaxBrightness()) {
                checkNormalizedBrightnessRange();
                return;
            }
            if (DEBUG) {
                android.util.Slog.w("HwLightsService", "getBrightnessRangeFromMaxBrightness failed");
            }
            checkNormalizedBrightnessRange();
        } catch (java.lang.Exception e) {
            e.printStackTrace();
        }
    }

    private int mapIntoRealBacklightLevelIfNeedXNit(int level) {
        java.lang.StringBuilder stringBuilder;
        int brightnessvalue = level;
        if (!this.mSupportXCC_isloaded) {
            this.mSupportXCC = this.mDisplayEngineManager.getSupported(16);
            this.mSupportXCC_isloaded = true;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportXCC  = ");
            stringBuilder.append(this.mSupportXCC);
            android.util.Slog.i("HwLightsService", stringBuilder.toString());
        }
        if (this.mSupportXCC == 1) {
            android.os.PersistableBundle bundle = new android.os.PersistableBundle();
            bundle.putInt("MinBrightness", this.mNormalizedMinBrightness);
            bundle.putInt("MaxBrightness", this.mNormalizedMaxBrightness);
            bundle.putInt("brightnesslevel", brightnessvalue);
            brightnessvalue = this.mDisplayEngineManager.setData(6, bundle);
            if (brightnessvalue <= 0) {
                brightnessvalue = this.mNormalizedMinBrightness + (((level - 156) * (this.mNormalizedMaxBrightness - this.mNormalizedMinBrightness)) / 9844);
            }
        } else {
            brightnessvalue = this.mNormalizedMinBrightness + (((level - 156) * (this.mNormalizedMaxBrightness - this.mNormalizedMinBrightness)) / 9844);
        }
        if (!this.mSupportAmoled_isloaded) {
            this.mSupportAmoled = this.mDisplayEngineManager.getSupported(25);
            this.mSupportAmoled_isloaded = true;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportAmoled  = ");
            stringBuilder.append(this.mSupportAmoled);
            android.util.Slog.i("HwLightsService", stringBuilder.toString());
        }
        if (!this.mSupportGammaFix_isloaded) {
            java.lang.StringBuilder stringBuilder2;
            byte[] status = new byte[1];
            if (this.mDisplayEngineManager.getEffect(7, 0, status, 1) == 0) {
                this.mSupportGammaFix = status[0];
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("[effect] getEffect(DE_FEATURE_GAMMA):");
                stringBuilder2.append(this.mSupportGammaFix);
                android.util.Slog.i("HwLightsService", stringBuilder2.toString());
            }
            this.mSupportGammaFix_isloaded = true;
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("mSupportGammaFix  = ");
            stringBuilder2.append(this.mSupportGammaFix);
            android.util.Slog.i("HwLightsService", stringBuilder2.toString());
        }
        if (!this.mSupportRGLed_isloaded) {
            this.mSupportRGLed = this.mDisplayEngineManager.getSupported(19);
            this.mSupportRGLed_isloaded = true;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSupportRGLed  = ");
            stringBuilder.append(this.mSupportRGLed);
            android.util.Slog.i("HwLightsService", stringBuilder.toString());
        }
        if (this.mSupportAmoled == 1 || this.mSupportGammaFix == 1 || this.mSupportRGLed == 1) {
            this.mDisplayEngineManager.setScene(26, (level << 16) | brightnessvalue);
        }
        return brightnessvalue;
    }

    protected int mapIntoRealBacklightLevel(int level) {
        if (this.mBackLightLevelPrinter != null) {
            this.mBackLightLevelPrinter.printLevel(level);
        } else {
            this.mBackLightLevelPrinter = new com.android.server.lights.HwLightsService.BackLightLevelLogPrinter("back light level before map", 0.1f);
        }
        if (level == 0) {
            return 0;
        }
        if (level < 156) {
            return this.mNormalizedMinBrightness;
        }
        if (level > 10000) {
            return this.mNormalizedMaxBrightness;
        }
        return mapIntoRealBacklightLevelIfNeedXNit(level);
    }

    public int getDeviceActualBrightnessLevelImpl() {
        return this.mDeviceBrightnessLevel;
    }

    public int getDeviceActualBrightnessNitImpl() {
        return this.mDeviceActualBrightnessNit;
    }

    public int getDeviceStandardBrightnessNitImpl() {
        return this.mDeviceStandardBrightnessNit;
    }

    protected int getNormalizedMaxBrightness() {
        return this.mNormalizedMaxBrightness;
    }

    private void close(java.io.BufferedReader reader, java.io.FileInputStream fis) {
        if (reader != null || fis != null) {
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e) {
                    e.printStackTrace();
                }
            }
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e2) {
                    e2.printStackTrace();
                }
            }
        }
    }
}
