package com.android.server.location;

public class HwCmccGpsFeature implements com.android.server.location.IHwCmccGpsFeature {
    private static final int AGPS_ROAMING_ENABLED = 1;
    private static final int AGPS_ROAMING_UNENABLED = 0;
    private static final java.lang.String AGPS_SERVICE_IP_DEFAULT = "supl.google.com";
    private static final int AGPS_SERVICE_PORT_DEFAULT = 7275;
    private static final int COLD_MODE = 2;
    private static final int GPS_POSITION_MODE_MS_ASSISTED = 2;
    private static final int GPS_POSITION_MODE_MS_BASED = 1;
    private static final int GPS_POSITION_MODE_STANDALONE = 0;
    private static final int HOT_MODE = 0;
    private static final java.lang.String KEY_AGPS_ROAMING_ENABLED = "assisted_gps_roaming_enabled";
    private static final java.lang.String KEY_AGPS_SERVICE_ADDRESS = "assisted_gps_service_IP";
    private static final java.lang.String KEY_AGPS_SERVICE_PORT = "assisted_gps_service_port";
    private static final java.lang.String KEY_AGPS_SETTINGS = "assisted_gps_mode";
    private static final java.lang.String TAG = "HwCmccGpsFeature";
    private static final java.lang.String TIME_SYNCHRONIZATION = "time_synchronization";
    private static final int TIME_SYNCHRONIZTION_OFF = 0;
    private static final int TIME_SYNCHRONIZTION_ON = 1;
    private static final int WARM_MODE = 1;
    private boolean mAgpsSwitchOn = android.os.SystemProperties.getBoolean("ro.config.agps_server_setting", false);
    private android.content.Context mContext;
    private com.android.server.location.GnssLocationProvider mGnssLocationProvider;
    private boolean mIsRoaming = false;
    private int mNeedSyncTime;
    private boolean mSyncedTimeFlag = true;
    private com.android.server.location.GpsLocationProviderUtils utils;

    public HwCmccGpsFeature(android.content.Context context, com.android.server.location.GnssLocationProvider gnssLocationProvider) {
        this.mContext = context;
        this.mGnssLocationProvider = gnssLocationProvider;
        this.utils = (com.android.server.location.GpsLocationProviderUtils) com.huawei.utils.reflect.EasyInvokeFactory.getInvokeUtils(com.android.server.location.GpsLocationProviderUtils.class);
    }

    public void setRoaming(boolean flag) {
        this.mIsRoaming = flag;
    }

    public boolean checkSuplInit() {
        if (!this.mAgpsSwitchOn) {
            return false;
        }
        if (android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "assisted_gps_enabled", 1) == 0) {
            return true;
        }
        setAgpsServer();
        return false;
    }

    private void setAgpsServer() {
        java.lang.String strSuplServerHost = android.provider.SettingsEx.Systemex.getString(this.mContext.getContentResolver(), "assisted_gps_service_IP");
        int iSuplServerPort = android.provider.SettingsEx.Systemex.getInt(this.mContext.getContentResolver(), "assisted_gps_service_port", 7275);
        if (strSuplServerHost == null) {
            strSuplServerHost = "supl.google.com";
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setAgpsServer SuplServerHost:");
        stringBuilder.append(strSuplServerHost);
        stringBuilder.append(" SuplServerPort:");
        stringBuilder.append(iSuplServerPort);
        android.util.Log.d("HwCmccGpsFeature", stringBuilder.toString());
        this.utils.setSuplHostPort(this.mGnssLocationProvider, strSuplServerHost, java.lang.String.valueOf(iSuplServerPort));
    }

    private int setPostionMode() {
        int positionMode = android.provider.SettingsEx.Systemex.getInt(this.mContext.getContentResolver(), "assisted_gps_mode", 1);
        if (!(positionMode == 0 || 1 == positionMode || 2 == positionMode)) {
            positionMode = 1;
        }
        if (1 != android.provider.SettingsEx.Systemex.getInt(this.mContext.getContentResolver(), "assisted_gps_roaming_enabled", 0) && this.mIsRoaming) {
            positionMode = 0;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setPostionMode positionMode:");
        stringBuilder.append(positionMode);
        android.util.Log.d("HwCmccGpsFeature", stringBuilder.toString());
        return positionMode;
    }

    public int setPostionModeAndAgpsServer(int oldPositionMode, boolean agpsEnabled) {
        if (this.mAgpsSwitchOn) {
            if (agpsEnabled) {
                int positionMode = setPostionMode();
                if (positionMode != 0) {
                    setAgpsServer();
                }
                this.mSyncedTimeFlag = true;
                this.mNeedSyncTime = android.provider.SettingsEx.Systemex.getInt(this.mContext.getContentResolver(), "time_synchronization", 0);
                return positionMode;
            }
        }
        return oldPositionMode;
    }

    public void syncTime(long timestamp) {
        if (1 == this.mNeedSyncTime && this.mSyncedTimeFlag && this.mAgpsSwitchOn) {
            android.util.Log.i("HwCmccGpsFeature", "syncing gps time");
            this.mSyncedTimeFlag = false;
            android.os.SystemClock.setCurrentTimeMillis(timestamp);
        }
    }

    public void setDelAidData() {
        int mode = android.provider.SettingsEx.Systemex.getInt(this.mContext.getContentResolver(), "gps_start_mode", 0);
        android.os.Bundle extras = new android.os.Bundle();
        switch (mode) {
            case 0:
                android.util.Log.d("HwCmccGpsFeature", "HOT_MODE");
                return;
            case 1:
                android.util.Log.d("HwCmccGpsFeature", "WARM_MODE");
                extras.putBoolean("ephemeris", true);
                this.mGnssLocationProvider.sendExtraCommand("delete_aiding_data", extras);
                return;
            case 2:
                android.util.Log.d("HwCmccGpsFeature", "COLD_MODE");
                extras.putBoolean("ephemeris", true);
                extras.putBoolean("position", true);
                extras.putBoolean("time", true);
                this.mGnssLocationProvider.sendExtraCommand("delete_aiding_data", extras);
                return;
            default:
                return;
        }
    }
}
