package com.android.server.location;

public abstract class HwGeoFencerBase {
    private static final java.lang.String TAG = "HwGeoFencerBase";
    private java.util.HashMap<android.app.PendingIntent, android.location.GeoFenceParams> mGeoFences = new java.util.HashMap();

    protected abstract boolean start(android.location.GeoFenceParams geoFenceParams);

    protected abstract boolean stop(android.app.PendingIntent pendingIntent);

    public void add(double latitude, double longitude, float radius, long expiration, android.app.PendingIntent intent, java.lang.String packageName) {
        add(new android.location.GeoFenceParams(latitude, longitude, radius, expiration, intent, packageName));
    }

    public void add(android.location.GeoFenceParams geoFence) {
        synchronized (this.mGeoFences) {
            this.mGeoFences.put(geoFence.mIntent, geoFence);
        }
        if (!start(geoFence)) {
            synchronized (this.mGeoFences) {
                this.mGeoFences.remove(geoFence.mIntent);
            }
        }
    }

    public void remove(android.app.PendingIntent intent) {
        remove(intent, false);
    }

    public void remove(android.app.PendingIntent intent, boolean localOnly) {
        android.location.GeoFenceParams geoFence;
        synchronized (this.mGeoFences) {
            geoFence = (android.location.GeoFenceParams) this.mGeoFences.remove(intent);
        }
        if (geoFence != null && !localOnly && !stop(intent)) {
            synchronized (this.mGeoFences) {
                this.mGeoFences.put(geoFence.mIntent, geoFence);
            }
        }
    }

    public int getNumbOfGeoFences() {
        return this.mGeoFences.size();
    }

    public java.util.Collection<android.location.GeoFenceParams> getAllGeoFences() {
        return this.mGeoFences.values();
    }

    public android.location.GeoFenceParams getGeoFence(android.app.PendingIntent intent) {
        return (android.location.GeoFenceParams) this.mGeoFences.get(intent);
    }

    public boolean hasCaller(int uid) {
        for (android.location.GeoFenceParams alert : this.mGeoFences.values()) {
            if (alert.mUid == uid) {
                return true;
            }
        }
        return false;
    }

    public void removeCaller(int uid) {
        java.util.ArrayList<android.app.PendingIntent> removedFences = null;
        for (android.location.GeoFenceParams alert : this.mGeoFences.values()) {
            if (alert.mUid == uid) {
                if (removedFences == null) {
                    removedFences = new java.util.ArrayList();
                }
                removedFences.add(alert.mIntent);
            }
        }
        if (removedFences != null) {
            for (int i = removedFences.size() - 1; i >= 0; i--) {
                this.mGeoFences.remove(removedFences.get(i));
            }
        }
    }

    public void transferService(com.android.server.location.HwGeoFencerBase geofencer) {
        for (android.location.GeoFenceParams alert : geofencer.mGeoFences.values()) {
            geofencer.stop(alert.mIntent);
            add(alert);
        }
    }

    public void dump(java.io.PrintWriter pw, java.lang.String prefix) {
        if (this.mGeoFences.size() > 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(prefix);
            stringBuilder.append("  GeoFences:");
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(prefix);
            stringBuilder.append("    ");
            prefix = stringBuilder.toString();
            for (java.util.Map.Entry<android.app.PendingIntent, android.location.GeoFenceParams> i : this.mGeoFences.entrySet()) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append(prefix);
                stringBuilder2.append(i.getKey());
                stringBuilder2.append(":");
                pw.println(stringBuilder2.toString());
                ((android.location.GeoFenceParams) i.getValue()).dump(pw, prefix);
            }
        }
    }
}
