package com.android.server.location;

public class HwGeoFencerProxy extends com.android.server.location.HwGeoFencerBase {
    private static final boolean LOGV_ENABLED = true;
    private static final java.lang.String TAG = "HwGeoFencerProxy";
    private static com.android.server.location.HwGeoFencerProxy mGeoFencerProxy;
    private final android.content.Context mContext;
    private android.location.IGeoFencer mGeoFencer;
    private final android.content.Intent mIntent;
    private final android.location.IGeoFenceListener.Stub mListener = new android.location.IGeoFenceListener.Stub() {
        public void geoFenceExpired(android.app.PendingIntent intent) throws android.os.RemoteException {
            com.android.server.location.HwGeoFencerProxy hwGeoFencerProxy = com.android.server.location.HwGeoFencerProxy.this;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("geoFenceExpired - ");
            stringBuilder.append(intent);
            hwGeoFencerProxy.logv(stringBuilder.toString());
            com.android.server.location.HwGeoFencerProxy.this.remove(intent, true);
        }
    };
    private final android.content.ServiceConnection mServiceConnection = new android.content.ServiceConnection() {
        public void onServiceConnected(android.content.ComponentName className, android.os.IBinder service) {
            synchronized (this) {
                com.android.server.location.HwGeoFencerProxy.this.mGeoFencer = android.location.IGeoFencer.Stub.asInterface(service);
                notifyAll();
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onServiceConnected: mGeoFencer - ");
            stringBuilder.append(com.android.server.location.HwGeoFencerProxy.this.mGeoFencer);
            android.util.Log.v("HwGeoFencerProxy", stringBuilder.toString());
        }

        public void onServiceDisconnected(android.content.ComponentName className) {
            synchronized (this) {
                com.android.server.location.HwGeoFencerProxy.this.mGeoFencer = null;
            }
            android.util.Log.v("HwGeoFencerProxy", "onServiceDisconnected");
        }
    };

    public static com.android.server.location.HwGeoFencerProxy getGeoFencerProxy(android.content.Context context, java.lang.String serviceName) {
        if (mGeoFencerProxy == null) {
            mGeoFencerProxy = new com.android.server.location.HwGeoFencerProxy(context, serviceName);
        }
        return mGeoFencerProxy;
    }

    private HwGeoFencerProxy(android.content.Context context, java.lang.String serviceName) {
        this.mContext = context;
        this.mIntent = new android.content.Intent();
        this.mIntent.setPackage(serviceName);
        this.mContext.bindService(this.mIntent, this.mServiceConnection, 21);
    }

    public void removeCaller(int uid) {
        super.removeCaller(uid);
        if (this.mGeoFencer != null) {
            try {
                this.mGeoFencer.clearGeoFenceUser(uid);
            } catch (android.os.RemoteException e) {
            }
        } else {
            android.util.Log.e("HwGeoFencerProxy", "removeCaller - mGeoFencer is null");
        }
    }

    private boolean ensureGeoFencer() {
        if (this.mGeoFencer == null) {
            try {
                synchronized (this.mServiceConnection) {
                    logv("waiting...");
                    this.mServiceConnection.wait(60000);
                    logv("woke up!!!");
                }
                if (this.mGeoFencer == null) {
                    android.util.Log.w("HwGeoFencerProxy", "Timed out. No GeoFencer connection");
                    return false;
                }
            } catch (java.lang.InterruptedException e) {
                android.util.Log.w("HwGeoFencerProxy", "Interrupted while waiting for GeoFencer");
                return false;
            }
        }
        return true;
    }

    protected boolean start(android.location.GeoFenceParams geofence) {
        if (ensureGeoFencer()) {
            try {
                return this.mGeoFencer.setGeoFence(this.mListener, geofence);
            } catch (android.os.RemoteException e) {
            }
        }
        return false;
    }

    protected boolean stop(android.app.PendingIntent intent) {
        if (ensureGeoFencer()) {
            try {
                this.mGeoFencer.clearGeoFence(this.mListener, intent);
                return true;
            } catch (android.os.RemoteException e) {
            }
        }
        return false;
    }

    private void logv(java.lang.String s) {
        android.util.Log.v("HwGeoFencerProxy", s);
    }
}
