package com.android.server.location;

public class HwGnssLocationProvider extends com.android.server.location.GnssLocationProvider {
    private static final int AGPS_TYPE_SUPL = 1;
    private static final java.lang.String GNSS_NAVIGATING_FLAG = "hw_higeo_gnss_Navigating";
    private static final int GNSS_REQ_CHANGE_START = 1;
    private static final int GNSS_REQ_CHANGE_STOP = 2;
    private static final java.lang.String LOCATION_MAP_BAIDU_PACKAGE = "com.baidu.BaiduMap";
    private static final java.lang.String LOCATION_MAP_FLP_PACKAGE = "com.amap.android.ams";
    private static final java.lang.String LOCATION_MAP_GAODE_PACKAGE = "com.autonavi.minimap";
    private static final java.lang.String LOCATION_MAP_GOOGLE_PACKAGE = "com.google.android.apps.maps";
    private static final java.lang.String LOCATION_MAP_WAZE_PACKAGE = "com.waze";
    private static final java.lang.String MAPS_LOCATION_FLAG = "hw_higeo_maps_location";
    private static final java.lang.String TAG = "HwGnssLocationProvider";
    private boolean AUTO_ACC_Enable = android.os.SystemProperties.getBoolean("ro.config.hw_auto_acc_enable", false);
    private int isLastExistMapLocation;
    private java.lang.String isLocalDBEnabled;
    private com.android.server.location.HwGnssLocationProvider.BroadcastHelper mBroadcastHelper = new com.android.server.location.HwGnssLocationProvider.BroadcastHelper();
    private android.content.Context mContext;
    com.android.server.location.HwCustGpsLocationProvider mCust = ((com.android.server.location.HwCustGpsLocationProvider) com.huawei.cust.HwCustUtils.createObj(com.android.server.location.HwCustGpsLocationProvider.class, new java.lang.Object[]{this}));
    private android.os.IDeviceIdleController mDeviceIdleController;
    private java.util.Properties mHwProperties;
    private int mPreferAccuracy;
    private com.android.server.location.GpsLocationProviderUtils utils = ((com.android.server.location.GpsLocationProviderUtils) com.huawei.utils.reflect.EasyInvokeFactory.getInvokeUtils(com.android.server.location.GpsLocationProviderUtils.class));

    private class BroadcastHelper {
        android.content.BroadcastReceiver innerBroadcastReciever;

        public BroadcastHelper() {
            this.innerBroadcastReciever = new android.content.BroadcastReceiver(com.android.server.location.HwGnssLocationProvider.this) {
                public void onReceive(android.content.Context context, android.content.Intent intent) {
                    if (context != null) {
                        if (intent != null) {
                            if ("android.intent.action.SIM_STATE_CHANGED".equals(intent.getAction())) {
                                java.lang.String state = intent.getStringExtra("ss");
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append(" onReceive action state = ");
                                stringBuilder.append(state);
                                android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
                                if ("LOADED".equals(state)) {
                                    com.android.server.location.HwGnssLocationProvider.BroadcastHelper.this.checkAndSetAGpsParameter();
                                }
                            }
                            return;
                        }
                    }
                    android.util.Log.d("HwGnssLocationProvider", "context or intent is null,return.");
                }
            };
        }

        public void init() {
            android.content.IntentFilter intentFilter = new android.content.IntentFilter();
            intentFilter.addAction("android.intent.action.SIM_STATE_CHANGED");
            com.android.server.location.HwGnssLocationProvider.this.mContext.registerReceiver(this.innerBroadcastReciever, intentFilter);
        }

        private void checkAndSetAGpsParameter() {
            java.util.Map agpsConfigMap = com.huawei.cust.HwCfgFilePolicy.getFileConfig("xml/agps_config.xml");
            java.lang.String supl_port = "";
            java.lang.String supl_host = "";
            if (agpsConfigMap != null) {
                java.lang.StringBuilder stringBuilder;
                try {
                    java.util.Map portHostMap = (java.util.Map) agpsConfigMap.get("portHostKey");
                    if (portHostMap != null) {
                        supl_port = (java.lang.String) portHostMap.get("supl_port");
                        supl_host = (java.lang.String) portHostMap.get("supl_host");
                    }
                    if (!(android.text.TextUtils.isEmpty(supl_port) || android.text.TextUtils.isEmpty(supl_host))) {
                        com.android.server.location.HwGnssLocationProvider.this.utils.setSuplServerHost(com.android.server.location.HwGnssLocationProvider.this, supl_host);
                        com.android.server.location.HwGnssLocationProvider.this.utils.setSuplServerPort(com.android.server.location.HwGnssLocationProvider.this, java.lang.Integer.parseInt(supl_port));
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("checkAGpsServer mSuplServerHost = ");
                        stringBuilder.append(com.android.server.location.HwGnssLocationProvider.this.utils.getSuplServerHost(com.android.server.location.HwGnssLocationProvider.this));
                        stringBuilder.append(" mSuplServerPort = ");
                        stringBuilder.append(com.android.server.location.HwGnssLocationProvider.this.utils.getSuplServerPort(com.android.server.location.HwGnssLocationProvider.this));
                        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
                        com.android.server.location.HwGnssLocationProvider.this.utils.native_set_agps_server(com.android.server.location.HwGnssLocationProvider.this, 1, supl_host, com.android.server.location.HwGnssLocationProvider.this.utils.getSuplServerPort(com.android.server.location.HwGnssLocationProvider.this));
                    }
                } catch (java.lang.ClassCastException e) {
                    android.util.Log.e("HwGnssLocationProvider", "ClassCastException occured", e);
                } catch (java.lang.NumberFormatException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Unable to parse supl_port: ");
                    stringBuilder.append(supl_port);
                    android.util.Log.e("HwGnssLocationProvider", stringBuilder.toString(), e2);
                }
            }
        }
    }

    enum MapNavigatingType {
        NOT_MAP,
        WHITE_MAP,
        BLACK_MAP
    }

    public HwGnssLocationProvider(android.content.Context context, android.location.ILocationManager ilocationManager, android.os.Looper looper) {
        super(context, ilocationManager, looper);
        this.mContext = context;
        this.mBroadcastHelper.init();
        this.mHwProperties = this.utils.getProperties(this);
        if (this.mHwProperties != null) {
            this.isLocalDBEnabled = this.mHwProperties.getProperty("LOCAL_DB");
            if (this.isLocalDBEnabled == null) {
                this.isLocalDBEnabled = "true";
            }
        }
        this.mDeviceIdleController = android.os.IDeviceIdleController.Stub.asInterface(android.os.ServiceManager.getService("deviceidle"));
    }

    public boolean isLocalDBEnabled() {
        return "true".equals(this.isLocalDBEnabled);
    }

    public void initDefaultApnObserver(android.os.Handler handler) {
        this.utils.setDefaultApnObserver(this, new android.database.ContentObserver(handler) {
            public void onChange(boolean selfChange) {
                com.android.server.location.HwGnssLocationProvider.this.utils.setDefaultApn(com.android.server.location.HwGnssLocationProvider.this, com.android.server.location.HwGnssLocationProvider.this.utils.getDefaultApn(com.android.server.location.HwGnssLocationProvider.this));
            }
        });
    }

    public void reportContextStatus(int status) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("reportContextStatus status = ");
        stringBuilder.append(status);
        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
        android.content.Intent intent = new android.content.Intent("huawei.android.location.DRIVER_STATUS");
        intent.putExtra("status", status);
        this.mContext.sendBroadcast(intent);
    }

    public int getPreferred_accuracy() {
        if (!this.AUTO_ACC_Enable) {
            return 0;
        }
        int accuracy_set = 0;
        if (existLocationMap()) {
            accuracy_set = 200;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getPreferred_accuracy:");
        stringBuilder.append(accuracy_set);
        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
        this.mPreferAccuracy = accuracy_set;
        return accuracy_set;
    }

    public boolean shouldReStartNavi() {
        if (!this.AUTO_ACC_Enable) {
            return false;
        }
        if ((this.mPreferAccuracy == 200 || !existLocationMap()) && (this.mPreferAccuracy != 200 || existLocationMap())) {
            return false;
        }
        return true;
    }

    private boolean existLocationMap() {
        android.os.WorkSource workSource = getWorkSource();
        if (workSource != null) {
            int num_uName = workSource.size();
            int i = 0;
            while (i < num_uName) {
                if (!(workSource.getName(i).equals("com.autonavi.minimap") || workSource.getName(i).equals("com.amap.android.ams"))) {
                    if (!workSource.getName(i).equals("com.baidu.BaiduMap")) {
                        i++;
                    }
                }
                android.util.Log.d("HwGnssLocationProvider", "existLocationMap:true");
                return true;
            }
        }
        android.util.Log.d("HwGnssLocationProvider", "existLocationMap:false");
        return false;
    }

    public void handleGnssRequirementsChange(int reson) {
        if (reson == 1) {
            handleMapLocation(existLocationMapsForHigeo());
        } else if (reson == 2) {
            handleMapLocation(com.android.server.location.HwGnssLocationProvider.MapNavigatingType.NOT_MAP.ordinal());
        }
    }

    private void handleMapLocation(int mapNavigatingType) {
        int new_state = mapNavigatingType;
        java.lang.StringBuilder stringBuilder;
        if (this.isLastExistMapLocation != new_state) {
            this.isLastExistMapLocation = new_state;
            android.provider.Settings.Secure.putInt(this.mContext.getContentResolver(), "hw_higeo_maps_location", new_state);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("handleGnssRequirementsChange,existLocationMap = ");
            stringBuilder.append(new_state);
            android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
            return;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("existLocationMap state is not change,ignor! isLastExistMapLocation:");
        stringBuilder.append(this.isLastExistMapLocation);
        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
    }

    public void handleGnssNavigatingStateChange(boolean start) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("handleGnssNavigateState,start : ");
        stringBuilder.append(start);
        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
    }

    public void startNavigatingPreparedHook() {
        if (this.mCust != null) {
            this.utils.setPositionMode(this, this.mCust.setPostionMode(this.utils.getPositionMode(this)));
        }
    }

    public boolean sendExtraCommandHook(java.lang.String command, boolean result) {
        boolean hwResult = result;
        if (this.mCust == null) {
            return hwResult;
        }
        hwResult = this.mCust.sendPostionModeCommand(result, command);
        this.utils.setPositionMode(this, this.mCust.setPostionMode(this.utils.getPositionMode(this)));
        return hwResult;
    }

    public void handleUpdateNetworkStateHook(android.net.NetworkInfo info) {
        boolean isRoaming = false;
        if (info != null) {
            isRoaming = info.isRoaming();
        }
        if (this.mCust != null) {
            this.mCust.setRoaming(isRoaming);
        }
    }

    private int existLocationMapsForHigeo() {
        android.os.WorkSource workSource = getWorkSource();
        if (workSource != null) {
            int num_uName = workSource.size();
            int i = 0;
            while (i < num_uName) {
                if ("com.google.android.apps.maps".equals(workSource.getName(i))) {
                    android.util.Log.d("HwGnssLocationProvider", "existLocationMapsForHigeo: black map");
                    return com.android.server.location.HwGnssLocationProvider.MapNavigatingType.BLACK_MAP.ordinal();
                }
                if (!("com.autonavi.minimap".equals(workSource.getName(i)) || "com.amap.android.ams".equals(workSource.getName(i)) || "com.waze".equals(workSource.getName(i)))) {
                    if (!"com.baidu.BaiduMap".equals(workSource.getName(i))) {
                        i++;
                    }
                }
                android.util.Log.d("HwGnssLocationProvider", "existLocationMapsForHigeo: white map");
                return com.android.server.location.HwGnssLocationProvider.MapNavigatingType.WHITE_MAP.ordinal();
            }
        }
        return com.android.server.location.HwGnssLocationProvider.MapNavigatingType.NOT_MAP.ordinal();
    }

    protected java.lang.String getSvType(int svidWithFlag) {
        java.lang.String result = "unknown";
        switch ((svidWithFlag >> 4) & 15) {
            case 1:
                result = "gps";
                break;
            case 2:
                result = "sbas";
                break;
            case 3:
                result = "glonass";
                break;
            case 4:
                result = "qzss";
                break;
            case 5:
                result = "beidou";
                break;
            case 6:
                result = "galileo";
                break;
            default:
                break;
        }
        return java.lang.String.format("%-7s", new java.lang.Object[]{result});
    }

    protected void hwLoadPropertiesFromResource(android.content.Context context, java.util.Properties properties) {
        boolean z = false;
        for (java.lang.String item : context.getResources().getStringArray(17236011)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("hwLoadPropertiesFromResource: ");
            stringBuilder.append(item);
            android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
            int index = item.indexOf("=");
            if (index <= 0 || index + 1 >= item.length()) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("malformed contents: ");
                stringBuilder2.append(item);
                android.util.Log.w("HwGnssLocationProvider", stringBuilder2.toString());
            } else {
                java.lang.String key = item.substring(0, index);
                java.lang.String value = item.substring(index + 1);
                if ("SUPL_ES".equals(key)) {
                    properties.setProperty(key.trim().toUpperCase(), value);
                    break;
                }
            }
        }
        java.lang.String suplESProperty = properties.getProperty("SUPL_ES");
        if (suplESProperty != null) {
            try {
                com.android.server.location.GpsLocationProviderUtils gpsLocationProviderUtils = this.utils;
                if (java.lang.Integer.parseInt(suplESProperty) == 1) {
                    z = true;
                }
                gpsLocationProviderUtils.setSuplEsEnabled(this, z);
            } catch (java.lang.NumberFormatException e) {
                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("unable to parse SUPL_ES when sim changed ");
                stringBuilder3.append(suplESProperty);
                android.util.Log.e("HwGnssLocationProvider", stringBuilder3.toString());
            }
        }
    }

    protected boolean hwCheckLowPowerMode(boolean isDeviceIdle) {
        boolean isGnssStarted = this.utils.getGnssStarted(this);
        if (!isDeviceIdle) {
            return true;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwCheckLowPowerMode isGnssStarted ");
        stringBuilder.append(isGnssStarted);
        android.util.Log.d("HwGnssLocationProvider", stringBuilder.toString());
        if (isGnssStarted) {
            try {
                if (this.mDeviceIdleController != null) {
                    this.mDeviceIdleController.exitIdle("gps interaction");
                }
            } catch (android.os.RemoteException e) {
                android.util.Log.e("HwGnssLocationProvider", "exitIdle fail!");
            }
        }
        return isGnssStarted ^ 1;
    }
}
