package com.android.server.location;

public class HwGpsActionReporter implements com.android.server.location.IHwGpsActionReporter {
    private static final int ACTION_LOC_REMOVE = 0;
    private static final int ACTION_LOC_REQUEST = 1;
    private static final java.lang.String GPS_INJECT_LOCATION_PERMISSION = "com.huawei.android.permission.INJECT_LOCATION";
    private static final int GPS_POSITION_MODE_MS_BASED = 1;
    private static final int GPS_POSITION_MODE_STANDALONE = 0;
    private static final int GPS_START = 1;
    private static final int GPS_STOP = 0;
    private static final int GPS_SWITCH_OFF = 0;
    private static final int GPS_SWITCH_ON = 1;
    protected static final boolean HWFLOW;
    protected static final boolean HWLOGW_E = true;
    private static final int LOCATION_ACTION_REMOVE = 1;
    private static final int LOCATION_ACTION_REQUEST = 0;
    private static final int LOCATION_CHANGE_THRESHOLD_VALUE = 5000;
    private static final long LOCATION_INTERVAL = 0;
    private static final float LOCATION_MIN_DISTANCE = 0.0f;
    private static final int LOCATION_REPORT_GPSSETTING = 65002;
    private static final int LOCATION_REPORT_GPSSWITCH = 65001;
    private static final int LOCATION_REPORT_GPS_ACTION = 65004;
    private static final int LOCATION_REPORT_GPS_DISABLE = 0;
    private static final int LOCATION_REPORT_GPS_ENABLE = 1;
    private static final int LOCATION_REPORT_GPS_START = 1;
    private static final int LOCATION_REPORT_GPS_STOP = 0;
    private static final int LOCATION_REPORT_LOCATION_ACTION = 65003;
    private static final int LOCATION_REPORT_LOCATION_CHANGE = 65005;
    private static final int NO_FIX_TIMEOUT = 60000;
    private static final java.lang.String TAG = "HwGpsActionReporter";
    private static final int VALID_DISTANCE_RANGE = android.os.SystemProperties.getInt("ro.config.invalid_distance", 10000);
    private static final int VALID_TIME_RANGE = android.os.SystemProperties.getInt("ro.config.invalid_time", 120000);
    private static final java.lang.Object mLock = new java.lang.Object();
    private static volatile com.android.server.location.HwGpsActionReporter mSingleInstance = null;
    private int mCellID = -1;
    private android.net.ConnectivityManager mConnectivityManager = null;
    private android.content.Context mContext = null;
    private int mCurrentUserId = 0;
    private java.util.ArrayList<android.location.Location> mErrorNetworkLocations = new java.util.ArrayList();
    private android.location.Location mFirstLocation = null;
    private android.location.Location mGpsLastLocation = null;
    private int mGpsStatus = 0;
    private com.android.server.location.HwGpsActionReporter.GpsStatusListenerTransport mGpsStatusListener = null;
    private android.location.ILocationManager mILocationManager;
    private android.location.Location mInjectLocation = null;
    private final android.content.BroadcastReceiver mInjectedLocationReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent == null) {
                android.util.Log.e("HwGpsActionReporter", "intent is null");
                return;
            }
            java.lang.String action = intent.getAction();
            if (action == null) {
                android.util.Log.e("HwGpsActionReporter", "action is null");
                return;
            }
            if (action.equals("action_inject_location")) {
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    android.util.Log.i("HwGpsActionReporter", "receive inject location broadcast");
                }
                com.android.server.location.HwGpsActionReporter.this.processLocInjectInfo((android.location.Location) intent.getParcelableExtra("key_location"));
            } else if (action.equals("android.intent.action.USER_SWITCHED")) {
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    android.util.Log.i("HwGpsActionReporter", "receive switch user broadcast");
                }
                com.android.server.location.HwGpsActionReporter.this.switchUser(intent.getIntExtra("android.intent.extra.user_handle", 0));
            }
        }
    };
    private int mLastGpsSwitchStatus;
    private android.location.Location mLastLocation = null;
    private android.location.LocationManager mLocationManager;
    private java.lang.String mMccMnc = "";
    private boolean mNetworkAvailable = false;
    private int mNetworkLocCorrCnt = 0;
    private int mNetworkLocErrCnt = 0;
    private int mNetworkType = 0;
    private com.android.server.location.HwGpsActionReporter.PassiveLocationListener mPassiveLocationListener = null;
    private java.lang.String mProvider = null;
    private com.android.server.location.HwReportTool mReportTool = null;
    private java.lang.String mTableID = null;
    private android.telephony.TelephonyManager mTelephonyManager = null;
    private java.util.ArrayList<android.location.Location> mUncheckdNetworkLocations = new java.util.ArrayList();

    private class GpsStatusListenerTransport extends android.location.IGnssStatusListener.Stub {
        private double mDeltaDis;
        private int mSvCount;
        private int mTimeToFirstFix;

        private GpsStatusListenerTransport() {
            this.mTimeToFirstFix = 0;
            this.mSvCount = 0;
            this.mDeltaDis = -1.0d;
        }

        /* synthetic */ GpsStatusListenerTransport(com.android.server.location.HwGpsActionReporter x0, com.android.server.location.HwGpsActionReporter.AnonymousClass1 x1) {
            this();
        }

        public void onGnssStarted() {
            int positionMode;
            if (android.provider.Settings.Global.getInt(com.android.server.location.HwGpsActionReporter.this.mContext.getContentResolver(), "assisted_gps_enabled", 1) != 0) {
                positionMode = 1;
            } else {
                positionMode = 0;
            }
            com.android.server.location.HwGpsActionReporter.this.reportGpsStarted(positionMode);
            com.android.server.location.HwGpsActionReporter.this.setGpsStatus(1);
        }

        public void onGnssStopped() {
            if (com.android.server.location.HwGpsActionReporter.this.mInjectLocation == null) {
                this.mDeltaDis = -1.0d;
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    android.util.Log.i("HwGpsActionReporter", "mInjectLocation is null.");
                }
            } else if (com.android.server.location.HwGpsActionReporter.this.mFirstLocation != null) {
                this.mDeltaDis = (double) com.android.server.location.HwGpsActionReporter.this.mInjectLocation.distanceTo(com.android.server.location.HwGpsActionReporter.this.mFirstLocation);
            } else {
                this.mDeltaDis = -1.0d;
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    android.util.Log.i("HwGpsActionReporter", "mFirstLocation is null.");
                }
            }
            com.android.server.location.HwGpsActionReporter.this.reportGpsStopped(this.mTimeToFirstFix, this.mSvCount, this.mDeltaDis);
            this.mTimeToFirstFix = 0;
            this.mSvCount = 0;
            com.android.server.location.HwGpsActionReporter.this.clearStateInfo();
            com.android.server.location.HwGpsActionReporter.this.setGpsStatus(0);
        }

        public void onFirstFix(int ttff) {
            this.mTimeToFirstFix = ttff;
        }

        public void onSvStatusChanged(int svCount, int[] prnWithFlags, float[] cn0s, float[] elevations, float[] azimuths, float[] carrierFreqs) {
            this.mSvCount = svCount;
        }

        public void onNmeaReceived(long timestamp, java.lang.String nmea) {
        }
    }

    private class PassiveLocationListener implements android.location.LocationListener {
        private PassiveLocationListener() {
        }

        /* synthetic */ PassiveLocationListener(com.android.server.location.HwGpsActionReporter x0, com.android.server.location.HwGpsActionReporter.AnonymousClass1 x1) {
            this();
        }

        public void onLocationChanged(android.location.Location location) {
            if (location == null) {
                android.util.Log.e("HwGpsActionReporter", "location is null");
                return;
            }
            java.lang.StringBuilder stringBuilder;
            boolean isGpsProvider = "gps".equals(location.getProvider());
            boolean isNetworkProvider = "network".equals(location.getProvider());
            boolean isFusedProvider = "fused".equals(location.getProvider());
            if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("provider:");
                stringBuilder.append(location.getProvider());
                stringBuilder.append(",acc is ");
                stringBuilder.append(location.getAccuracy());
                android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
            }
            if (isGpsProvider) {
                if (com.android.server.location.HwGpsActionReporter.this.mFirstLocation == null) {
                    com.android.server.location.HwGpsActionReporter.this.mFirstLocation = location;
                }
                com.android.server.location.HwGpsActionReporter.this.mGpsLastLocation = location;
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    android.util.Log.i("HwGpsActionReporter", "refresh mGpsLastLocation");
                }
            }
            if (isNetworkProvider) {
                com.android.server.location.HwGpsActionReporter.this.mUncheckdNetworkLocations.add(location);
                if (com.android.server.location.HwGpsActionReporter.HWFLOW) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("add:");
                    stringBuilder.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(location)));
                    android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
                }
            }
            if (isGpsProvider || isNetworkProvider) {
                com.android.server.location.HwGpsActionReporter.this.removeExpiredNetworkLocations();
                com.android.server.location.HwGpsActionReporter.this.checkErrorNetworkLocations();
                com.android.server.location.HwGpsActionReporter.this.reportErrorNetworkLocations();
            }
            if (isGpsProvider || isNetworkProvider || isFusedProvider) {
                com.android.server.location.HwGpsActionReporter.this.reportLocationChange(location);
            }
        }

        public void onStatusChanged(java.lang.String provider, int status, android.os.Bundle extras) {
        }

        public void onProviderEnabled(java.lang.String provider) {
        }

        public void onProviderDisabled(java.lang.String provider) {
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwGpsActionReporter", 4)) {
                z = false;
                HWFLOW = z;
            }
        }
        z = true;
        HWFLOW = z;
    }

    public static com.android.server.location.HwGpsActionReporter getInstance(android.content.Context context, android.location.ILocationManager iLocationManager) {
        if (mSingleInstance == null) {
            synchronized (mLock) {
                if (mSingleInstance == null) {
                    mSingleInstance = new com.android.server.location.HwGpsActionReporter(context, iLocationManager);
                }
            }
        }
        return mSingleInstance;
    }

    private HwGpsActionReporter(android.content.Context context, android.location.ILocationManager iLocationManager) {
        this.mContext = context;
        this.mILocationManager = iLocationManager;
        this.mReportTool = com.android.server.location.HwReportTool.getInstance(context);
        this.mGpsStatusListener = new com.android.server.location.HwGpsActionReporter.GpsStatusListenerTransport(this, null);
        this.mPassiveLocationListener = new com.android.server.location.HwGpsActionReporter.PassiveLocationListener(this, null);
        this.mLastGpsSwitchStatus = isGpsProviderSettingOn(this.mCurrentUserId);
        android.content.IntentFilter intentFilter = new android.content.IntentFilter();
        intentFilter.addAction("action_inject_location");
        intentFilter.addAction("android.intent.action.USER_SWITCHED");
        this.mContext.registerReceiver(this.mInjectedLocationReceiver, intentFilter, "com.huawei.android.permission.INJECT_LOCATION", null);
        try {
            if (!this.mILocationManager.registerGnssStatusCallback(this.mGpsStatusListener, this.mContext.getPackageName())) {
                android.util.Log.e("HwGpsActionReporter", "addGpsStatusListener failed");
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwGpsActionReporter", "addGpsStatusListener catch RemoteException", e);
        }
        this.mLocationManager = (android.location.LocationManager) this.mContext.getSystemService("location");
        this.mLocationManager.requestLocationUpdates("passive", 0, 0.0f, this.mPassiveLocationListener);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("location_providers_allowed"), true, new android.database.ContentObserver(null) {
            public void onChange(boolean selfChange) {
                java.lang.String providersSetting = com.android.server.location.HwGpsActionReporter.this.getProvidersSettingAllowed(com.android.server.location.HwGpsActionReporter.this.mCurrentUserId);
                int gpsSwitchStatus = com.android.server.location.HwGpsActionReporter.this.isGpsProviderSettingOn(com.android.server.location.HwGpsActionReporter.this.mCurrentUserId);
                if (gpsSwitchStatus != com.android.server.location.HwGpsActionReporter.this.mLastGpsSwitchStatus) {
                    com.android.server.location.HwGpsActionReporter.this.reportGpsSwitch(gpsSwitchStatus);
                    com.android.server.location.HwGpsActionReporter.this.mLastGpsSwitchStatus = gpsSwitchStatus;
                }
                com.android.server.location.HwGpsActionReporter.this.reportProvidersSetting(providersSetting);
            }
        }, -1);
    }

    public boolean uploadLocationAction(int actionType, java.lang.String actionMsg) {
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("uploadLocationAction:actionType:");
            stringBuilder.append(actionType);
            stringBuilder.append("actionMsg:");
            stringBuilder.append(actionMsg);
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        if (actionMsg == null) {
            return false;
        }
        boolean reportRst;
        switch (actionType) {
            case 0:
                strBuilder.append("{RT:0");
                strBuilder.append(actionMsg);
                strBuilder.append("}");
                reportRst = report(65003, strBuilder.toString());
                break;
            case 1:
                strBuilder.append("{RT:1");
                strBuilder.append(actionMsg);
                strBuilder.append("}");
                reportRst = report(65003, strBuilder.toString());
                break;
            default:
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("unexpected action type:");
                stringBuilder2.append(actionType);
                android.util.Log.e("HwGpsActionReporter", stringBuilder2.toString());
                return false;
        }
        return reportRst;
    }

    private void reportGpsSwitch(int gpsSwitchStatus) {
        boolean checkResult = isGpsProviderSettingOn(this.mCurrentUserId) == gpsSwitchStatus;
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
        strBuilder.append("{ACT:");
        strBuilder.append(gpsSwitchStatus);
        strBuilder.append(",RT:");
        strBuilder.append(checkResult);
        strBuilder.append("}");
        java.lang.String reportString = strBuilder.toString();
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("reportGpsSwitch: ");
            stringBuilder.append(reportString);
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        report(65001, reportString);
    }

    private void reportProvidersSetting(java.lang.String itemValue) {
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
        strBuilder.append("{Mod:[");
        strBuilder.append(itemValue);
        strBuilder.append("]}");
        java.lang.String reportString = strBuilder.toString();
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("reportProvidersSetting: ");
            stringBuilder.append(reportString);
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        report(65002, reportString);
    }

    private void reportGpsStarted(int positionMode) {
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
        strBuilder.append("{GA:");
        strBuilder.append(1);
        strBuilder.append(",PAR1:");
        strBuilder.append(positionMode);
        strBuilder.append(",PAR2:");
        strBuilder.append(60000);
        strBuilder.append("}");
        java.lang.String reportString = strBuilder.toString();
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("reportGpsStarted: ");
            stringBuilder.append(reportString);
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        report(65004, reportString);
    }

    private void reportGpsStopped(int ttff, int svCount, double deltaDistance) {
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
        strBuilder.append("{GA:");
        strBuilder.append(0);
        strBuilder.append(",PAR1:");
        strBuilder.append(ttff);
        strBuilder.append(",PAR2:");
        strBuilder.append(svCount);
        strBuilder.append(",PAR3:");
        strBuilder.append(this.mProvider);
        strBuilder.append(",PAR4:");
        strBuilder.append(this.mTableID);
        strBuilder.append(",PAR5:");
        strBuilder.append(deltaDistance);
        strBuilder.append("}");
        java.lang.String reportString = strBuilder.toString();
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("reportGpsStopped: ");
            stringBuilder.append(reportString);
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        report(65004, reportString);
    }

    private void reportLocationChange(android.location.Location location) {
        if (location != null && isLocationChange(location)) {
            refreshNetworkStatus();
            refreshCellStatus();
            java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
            strBuilder.append("{CID:");
            strBuilder.append(this.mCellID);
            strBuilder.append(",MCCMNC:");
            strBuilder.append(this.mMccMnc);
            strBuilder.append(",LAT:");
            strBuilder.append(location.getLatitude());
            strBuilder.append(",LON:");
            strBuilder.append(location.getLongitude());
            strBuilder.append(",NA:");
            strBuilder.append(this.mNetworkAvailable);
            strBuilder.append(",NT:");
            strBuilder.append(this.mNetworkType);
            strBuilder.append("}");
            java.lang.String reportString = strBuilder.toString();
            if (HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("reportLocationChange:");
                stringBuilder.append(location);
                android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
            }
            report(65005, reportString);
        }
    }

    private void reportErrorNetworkLocations() {
        if (!this.mErrorNetworkLocations.isEmpty()) {
            refreshNetworkStatus();
            refreshCellStatus();
            if (HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mErrorNetworkLocations's size is: ");
                stringBuilder.append(this.mErrorNetworkLocations.size());
                android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
            }
            java.util.Iterator<android.location.Location> unReportedLocations = this.mErrorNetworkLocations.iterator();
            while (unReportedLocations.hasNext()) {
                android.location.Location location = (android.location.Location) unReportedLocations.next();
                this.mNetworkLocErrCnt++;
                float corrRate = ((float) this.mNetworkLocCorrCnt) / ((float) (this.mNetworkLocErrCnt + this.mNetworkLocCorrCnt));
                java.lang.StringBuilder strBuilder = new java.lang.StringBuilder("");
                strBuilder.append("{CID:");
                strBuilder.append(this.mCellID);
                strBuilder.append(",MCCMNC:");
                strBuilder.append(this.mMccMnc);
                strBuilder.append(",LAT:");
                strBuilder.append(location.getLatitude());
                strBuilder.append(",LON:");
                strBuilder.append(location.getLongitude());
                strBuilder.append(",NA:");
                strBuilder.append(this.mNetworkAvailable);
                strBuilder.append(",NT:");
                strBuilder.append(this.mNetworkType);
                strBuilder.append(",RATE:");
                strBuilder.append(corrRate);
                strBuilder.append("}");
                java.lang.String reportString = strBuilder.toString();
                if (HWFLOW) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("corrRate:");
                    stringBuilder2.append(corrRate);
                    android.util.Log.i("HwGpsActionReporter", stringBuilder2.toString());
                }
                report(65005, reportString);
                unReportedLocations.remove();
            }
        }
    }

    private void checkErrorNetworkLocations() {
        if (!this.mUncheckdNetworkLocations.isEmpty() && isReferenceLocationAvailable()) {
            if (HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("checkErrorNetworkLocations mUncheckdNetworkLocations's size is: ");
                stringBuilder.append(this.mUncheckdNetworkLocations.size());
                android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
            }
            java.util.Iterator<android.location.Location> uncheckedLocations = this.mUncheckdNetworkLocations.iterator();
            while (uncheckedLocations.hasNext()) {
                android.location.Location networkLocation = (android.location.Location) uncheckedLocations.next();
                if (networkLocation == null) {
                    android.util.Log.e("HwGpsActionReporter", "removeExpiredNetworkLocations networkLocation is null");
                } else if (this.mGpsLastLocation.getAccuracy() - networkLocation.getAccuracy() <= 0.0f) {
                    float distance = this.mGpsLastLocation.distanceTo(networkLocation);
                    if (distance > ((float) VALID_DISTANCE_RANGE)) {
                        this.mErrorNetworkLocations.add(networkLocation);
                    } else {
                        this.mNetworkLocCorrCnt++;
                    }
                    uncheckedLocations.remove();
                    if (HWFLOW) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("remove: ");
                        stringBuilder2.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(networkLocation)));
                        stringBuilder2.append(", reason: checked: ");
                        stringBuilder2.append(distance);
                        stringBuilder2.append(" meters");
                        android.util.Log.i("HwGpsActionReporter", stringBuilder2.toString());
                    }
                } else if (HWFLOW) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("input gpsLocation is less accuracy,");
                    stringBuilder3.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(networkLocation)));
                    android.util.Log.i("HwGpsActionReporter", stringBuilder3.toString());
                }
            }
        }
    }

    private void removeExpiredNetworkLocations() {
        if (!this.mUncheckdNetworkLocations.isEmpty()) {
            long referenceTime = java.lang.System.currentTimeMillis();
            if (HWFLOW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("removeExpiredNetworkLocations mUncheckdNetworkLocations's size is: ");
                stringBuilder.append(this.mUncheckdNetworkLocations.size());
                android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
            }
            java.util.Iterator<android.location.Location> uncheckedLocations = this.mUncheckdNetworkLocations.iterator();
            while (uncheckedLocations.hasNext()) {
                android.location.Location location = (android.location.Location) uncheckedLocations.next();
                if (location == null) {
                    android.util.Log.e("HwGpsActionReporter", "removeExpiredNetworkLocations network location is null");
                } else {
                    long diffTime = referenceTime - location.getTime();
                    if (diffTime > ((long) VALID_TIME_RANGE)) {
                        if (HWFLOW) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("remove: ");
                            stringBuilder2.append(java.lang.Integer.toHexString(java.lang.System.identityHashCode(location)));
                            stringBuilder2.append(", reason: expired: ");
                            stringBuilder2.append(diffTime);
                            stringBuilder2.append("ms");
                            android.util.Log.i("HwGpsActionReporter", stringBuilder2.toString());
                        }
                        uncheckedLocations.remove();
                    }
                }
            }
        }
    }

    private boolean isReferenceLocationAvailable() {
        if (this.mGpsLastLocation == null) {
            if (HWFLOW) {
                android.util.Log.i("HwGpsActionReporter", "mGpsLastLocation is null");
            }
            return false;
        }
        long diffTime = java.lang.System.currentTimeMillis() - this.mGpsLastLocation.getTime();
        if (diffTime <= ((long) VALID_TIME_RANGE)) {
            return true;
        }
        if (HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("gpslocation is expired:");
            stringBuilder.append(diffTime);
            stringBuilder.append("ms");
            android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
        }
        return false;
    }

    private boolean isLocationChange(android.location.Location location) {
        boolean isChange = false;
        if (location == null) {
            android.util.Log.e("HwGpsActionReporter", "location is null");
            return false;
        } else if (this.mLastLocation == null) {
            this.mLastLocation = location;
            return true;
        } else {
            float dis1 = location.distanceTo(this.mLastLocation);
            float dis2 = location.getAccuracy();
            if (5000.0f <= (dis1 > dis2 ? dis1 : dis2)) {
                isChange = true;
            }
            if (isChange) {
                this.mLastLocation = location;
            }
            return isChange;
        }
    }

    @android.annotation.SuppressLint({"NewApi"})
    private void refreshCellStatus() {
        java.lang.StringBuilder stringBuilder;
        if (this.mTelephonyManager == null) {
            this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        }
        if (this.mTelephonyManager != null) {
            this.mMccMnc = this.mTelephonyManager.getSimOperator();
            int type = this.mTelephonyManager.getCurrentPhoneType();
            android.telephony.CellLocation location = this.mTelephonyManager.getCellLocation();
            switch (type) {
                case 1:
                    if (location instanceof android.telephony.gsm.GsmCellLocation) {
                        try {
                            this.mCellID = ((android.telephony.gsm.GsmCellLocation) location).getCid();
                        } catch (java.lang.Exception e) {
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("GsmCellLocation Type Cast Exception :");
                            stringBuilder.append(e.getMessage());
                            android.util.Log.e("HwGpsActionReporter", stringBuilder.toString());
                        }
                        break;
                    }
                    break;
                case 2:
                    if (location instanceof android.telephony.cdma.CdmaCellLocation) {
                        try {
                            this.mCellID = ((android.telephony.cdma.CdmaCellLocation) location).getBaseStationId();
                        } catch (java.lang.Exception e2) {
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("CdmaCellLocation Type Cast Exception :");
                            stringBuilder.append(e2.getMessage());
                            android.util.Log.e("HwGpsActionReporter", stringBuilder.toString());
                        }
                        break;
                    }
                    break;
                default:
                    this.mCellID = -1;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("unexpected phone type:");
                    stringBuilder2.append(type);
                    android.util.Log.e("HwGpsActionReporter", stringBuilder2.toString());
                    break;
            }
            return;
        }
        android.util.Log.e("HwGpsActionReporter", "mTelephonyManager is null");
    }

    private void refreshNetworkStatus() {
        if (this.mConnectivityManager == null) {
            this.mConnectivityManager = (android.net.ConnectivityManager) this.mContext.getSystemService("connectivity");
        }
        android.net.NetworkInfo networkInfo = null;
        if (this.mConnectivityManager != null) {
            networkInfo = this.mConnectivityManager.getActiveNetworkInfo();
        }
        if (networkInfo != null) {
            this.mNetworkAvailable = networkInfo.isAvailable();
            this.mNetworkType = networkInfo.getSubtype();
        }
    }

    private void processLocInjectInfo(android.location.Location location) {
        if (location == null) {
            if (HWFLOW) {
                android.util.Log.i("HwGpsActionReporter", "processLocInjectInfo: location is null");
            }
        } else if (this.mGpsStatus == 0) {
            if (HWFLOW) {
                android.util.Log.i("HwGpsActionReporter", "processLocInjectInfo: gps does not start");
            }
        } else if (this.mFirstLocation != null) {
            if (HWFLOW) {
                android.util.Log.i("HwGpsActionReporter", "processLocInjectInfo: gps has already fixed");
            }
        } else {
            this.mInjectLocation = location;
            android.os.Bundle b = location.getExtras();
            if (b != null) {
                this.mProvider = b.getString("key_loc_source");
                this.mTableID = b.getString("key_loc_tableID");
            }
        }
    }

    private boolean report(int actionID, java.lang.String actionMsg) {
        if (this.mReportTool != null) {
            return this.mReportTool.report(actionID, actionMsg);
        }
        return false;
    }

    void setGpsStatus(int gpsStatus) {
        if (1 != gpsStatus) {
            if (gpsStatus != 0) {
                if (HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("unexpceted gpsStatus:");
                    stringBuilder.append(gpsStatus);
                    android.util.Log.i("HwGpsActionReporter", stringBuilder.toString());
                    return;
                }
                return;
            }
        }
        this.mGpsStatus = gpsStatus;
    }

    void clearStateInfo() {
        this.mInjectLocation = null;
        this.mFirstLocation = null;
        this.mTableID = null;
        this.mProvider = null;
    }

    void switchUser(int userId) {
        if (this.mCurrentUserId != userId) {
            this.mCurrentUserId = userId;
            this.mLastGpsSwitchStatus = isGpsProviderSettingOn(userId);
        }
    }

    boolean isGpsProviderSettingOn(int userId) {
        try {
            return android.provider.Settings.Secure.isLocationProviderEnabledForUser(this.mContext.getContentResolver(), "gps", userId);
        } catch (java.lang.IllegalArgumentException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("illegal userId for isLocationProviderEnabledForUser:");
            stringBuilder.append(userId);
            android.util.Log.e("HwGpsActionReporter", stringBuilder.toString());
            return false;
        }
    }

    boolean isNetworkProviderSettingOn(int userId) {
        try {
            return android.provider.Settings.Secure.isLocationProviderEnabledForUser(this.mContext.getContentResolver(), "network", userId);
        } catch (java.lang.IllegalArgumentException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("illegal userId for isLocationProviderEnabledForUser:");
            stringBuilder.append(userId);
            android.util.Log.e("HwGpsActionReporter", stringBuilder.toString());
            return false;
        }
    }

    java.lang.String getProvidersSettingAllowed(int userId) {
        java.lang.String allowedProviders = android.provider.Settings.Secure.getStringForUser(this.mContext.getContentResolver(), "location_providers_allowed", userId);
        if (allowedProviders != null) {
            return allowedProviders.replace("0,", "").replace("0", "");
        }
        return "";
    }
}
