package com.android.server.location;

public class HwGpsLogServices implements com.android.server.location.IHwGpsLogServices {
    private static final int BUF_MIXSIZE = 10;
    private static final boolean DEBUG = android.util.Log.isLoggable("HwGnssLogServices", 3);
    private static final int DOMAIN_GNSS = 0;
    private static final long NETWORK_POS_TIMEOUT_SECOND = 11000;
    private static final java.lang.String TAG = "HwGnssLogServices";
    private static final boolean VERBOSE = android.util.Log.isLoggable("HwGnssLogServices", 2);
    static com.android.server.location.HwGpsLogServices mHwGpsLogServices;
    com.huawei.ncdft.HwNcDftConnManager hwNcDftConnManager;
    private android.content.Context mContext;
    private com.android.server.LocationManagerServiceUtil mLocationManagerServiceUtil;
    private boolean mNetWorkFixPending = false;
    private java.util.Timer mNlpTimer = null;
    private java.util.TimerTask mNlpTimerTask = null;
    private android.os.HandlerThread mThread;

    private HwGpsLogServices(android.content.Context context) {
        this.mContext = context;
        android.util.Log.d("HwGnssLogServices", "enter HwGpsLogServices");
        this.mThread = new android.os.HandlerThread("HwGpsLogServices");
        this.mThread.start();
        this.hwNcDftConnManager = new com.huawei.ncdft.HwNcDftConnManager(this.mContext);
    }

    public static synchronized com.android.server.location.HwGpsLogServices getInstance(android.content.Context context) {
        com.android.server.location.HwGpsLogServices hwGpsLogServices;
        synchronized (com.android.server.location.HwGpsLogServices.class) {
            if (mHwGpsLogServices == null) {
                mHwGpsLogServices = new com.android.server.location.HwGpsLogServices(context);
            }
            hwGpsLogServices = mHwGpsLogServices;
        }
        return hwGpsLogServices;
    }

    public static synchronized com.android.server.location.HwGpsLogServices getGpsLogService() {
        com.android.server.location.HwGpsLogServices hwGpsLogServices;
        synchronized (com.android.server.location.HwGpsLogServices.class) {
            hwGpsLogServices = mHwGpsLogServices;
        }
        return hwGpsLogServices;
    }

    private int sendToDft(int event, java.util.List<java.lang.String> list) {
        if (this.hwNcDftConnManager != null) {
            this.hwNcDftConnManager.reportToDft(0, event, list);
            return 0;
        }
        android.util.Log.d("HwGnssLogServices", "hwNcDftConnManager is null, ignore!");
        return 1;
    }

    public void netWorkLocation(java.lang.String provider, com.android.internal.location.ProviderRequest providerRequest) {
        if (provider.equalsIgnoreCase("network")) {
            boolean isNeedUpdate = true;
            if (providerRequest.locationRequests.size() == 0) {
                isNeedUpdate = false;
            } else {
                for (android.location.LocationRequest request : providerRequest.locationRequests) {
                    if (request.getNumUpdates() <= 0) {
                        isNeedUpdate = false;
                    }
                }
            }
            if (this.hwNcDftConnManager != null && isNeedUpdate) {
                java.lang.String requestInterval = java.lang.String.valueOf(providerRequest.interval);
                java.util.List<java.lang.String> list = new java.util.ArrayList();
                list.add(requestInterval);
                list.add(provider);
                sendToDft(0, list);
            }
            if (this.mNetWorkFixPending) {
                android.util.Log.e("HwGnssLogServices", "Network pos is already runing.");
                return;
            }
            this.mNetWorkFixPending = true;
            startNlpTimer();
        }
    }

    private void startNlpTimer() {
        if (this.mNlpTimer == null) {
            this.mNlpTimer = new java.util.Timer();
        }
        if (this.mNlpTimerTask != null) {
            this.mNlpTimerTask.cancel();
            this.mNlpTimerTask = null;
        }
        this.mNlpTimerTask = new java.util.TimerTask() {
            public void run() {
                com.android.server.location.HwGpsLogServices.this.mLocationManagerServiceUtil = com.android.server.LocationManagerServiceUtil.getDefault();
                if (com.android.server.location.HwGpsLogServices.this.mLocationManagerServiceUtil == null) {
                    android.util.Log.d("HwGnssLogServices", " mLocationManagerServiceUtil == null ");
                    com.android.server.location.HwGpsLogServices.this.mNetWorkFixPending = false;
                    return;
                }
                com.android.server.location.LocationProviderInterface p = (com.android.server.location.LocationProviderInterface) com.android.server.location.HwGpsLogServices.this.mLocationManagerServiceUtil.getRealProviders().get("network");
                if (p == null) {
                    android.util.Log.d("HwGnssLogServices", " LocationProviderInterface p is null ");
                    com.android.server.location.HwGpsLogServices.this.mNetWorkFixPending = false;
                    return;
                }
                android.os.Bundle extras = new android.os.Bundle();
                int status = p.getStatus(extras);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("  network position over 11s,  NLP status:  ");
                stringBuilder.append(status);
                android.util.Log.d("HwGnssLogServices", stringBuilder.toString());
                if (status > 2) {
                    com.android.server.location.HwGpsLogServices.this.updateNLPStatusRecord(status);
                }
                java.util.ArrayList<java.lang.Integer> statusList = extras.getIntegerArrayList("status");
                if (statusList != null) {
                    int i = 10;
                    if (statusList.size() < 10) {
                        i = statusList.size();
                    }
                    int list_size = i;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(" list network position over 11s,  list_size:  ");
                    stringBuilder2.append(list_size);
                    android.util.Log.d("HwGnssLogServices", stringBuilder2.toString());
                    for (i = 0; i < list_size; i++) {
                        com.android.server.location.HwGpsLogServices.this.updateNLPStatusRecord(((java.lang.Integer) statusList.get(i)).intValue());
                    }
                }
                com.android.server.location.HwGpsLogServices.this.mNetWorkFixPending = false;
            }
        };
        try {
            this.mNlpTimer.schedule(this.mNlpTimerTask, 11000);
        } catch (java.lang.IllegalStateException e) {
            android.util.Log.e("HwGnssLogServices", " TimerTask is scheduled failed.");
        }
    }

    private void stopNlpTimer() {
        this.mNetWorkFixPending = false;
        android.util.Log.d("HwGnssLogServices", "stopNlpTimer ");
        if (this.mNlpTimer != null) {
            this.mNlpTimer.cancel();
            this.mNlpTimer.purge();
            this.mNlpTimer = null;
        }
        if (this.mNlpTimerTask != null) {
            this.mNlpTimerTask.cancel();
            this.mNlpTimerTask = null;
        }
    }

    public void openGpsSwitchFail(int open) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(open));
        sendToDft(14, list);
    }

    public void initGps(boolean isEnable, byte EngineCapabilities) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(isEnable));
        list.add(java.lang.Integer.toString(EngineCapabilities));
        sendToDft(1, list);
    }

    public void updateXtraDloadStatus(boolean status) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(status));
        sendToDft(10, list);
    }

    public void updateNtpDloadStatus(boolean status) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(status));
        sendToDft(11, list);
    }

    public void updateSetPosMode(boolean status, int interval) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(status));
        list.add(java.lang.Integer.toString(interval));
        sendToDft(12, list);
    }

    public void updateSetPosMode(boolean status) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateSetPosMode = ");
        stringBuilder.append(status);
        android.util.Log.i("HwGnssLogServices", stringBuilder.toString());
    }

    public void updateApkName(java.lang.String provider, java.lang.String hashCode, java.lang.String name, java.lang.String apkRunMode, java.lang.String apkTimeStamp) {
        if (this.hwNcDftConnManager == null) {
            return;
        }
        if (provider.equalsIgnoreCase("gps") || provider.equalsIgnoreCase("network") || provider.equalsIgnoreCase("APKSTOPPROVIDER")) {
            java.util.List<java.lang.String> list = new java.util.ArrayList();
            list.add(java.lang.String.valueOf(provider));
            list.add(java.lang.String.valueOf(hashCode));
            list.add(java.lang.String.valueOf(name));
            list.add(java.lang.String.valueOf(apkRunMode));
            list.add(java.lang.String.valueOf(apkTimeStamp));
            sendToDft(31, list);
        }
    }

    public void updateNLPStatus(int status) {
        stopNlpTimer();
        updateNLPStatusRecord(status);
    }

    public void updateNLPStatusRecord(int status) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(status));
        sendToDft(29, list);
    }

    public void startGps(boolean isEnable, int PositionMode) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(isEnable));
        list.add(java.lang.Integer.toString(PositionMode));
        sendToDft(2, list);
    }

    public void updateNetworkState(android.net.NetworkInfo info) {
        if (this.hwNcDftConnManager != null) {
            this.hwNcDftConnManager.reportNetworkInfo(0, 3, info);
        }
    }

    public void updateAgpsState(int type, int state) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(type));
        list.add(java.lang.Integer.toString(state));
        sendToDft(4, list);
    }

    public void stopGps(boolean status) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(status));
        sendToDft(5, list);
    }

    public void permissionErr(java.lang.String packageName) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(packageName);
        sendToDft(13, list);
    }

    public void addGeofenceStatus() {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add("0");
        sendToDft(15, list);
    }

    public void addBatchingStatus() {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add("0");
        sendToDft(16, list);
    }

    public void updateGpsRunState(int status) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(status));
        sendToDft(6, list);
    }

    public void updateLocation(android.location.Location location, long time, java.lang.String provider) {
        if (this.hwNcDftConnManager != null) {
            this.hwNcDftConnManager.reportGnssLocation(0, 8, location, time, provider);
        }
    }

    public void updateSvStatus(int svCount, int[] svs, float[] snrs, float[] svElevations, float[] svAzimuths) {
        if (this.hwNcDftConnManager != null) {
            this.hwNcDftConnManager.reportGnssSvStatus(0, 9, svCount, svs, snrs, svElevations, svAzimuths);
        }
    }

    public void reportErrorNtpTime(long currentNtpTime, long realTime) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.String.valueOf(currentNtpTime));
        list.add(java.lang.String.valueOf(realTime));
        sendToDft(19, list);
    }

    public void reportBinderError() {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add("0");
        sendToDft(20, list);
    }

    public void processGnssHalDriverEvent(java.lang.String strJsonExceptionBody) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("driver err is ");
        stringBuilder.append(strJsonExceptionBody);
        android.util.Log.d("HwGnssLogServices", stringBuilder.toString());
    }

    public void updateModemData(byte aPosMode, byte aAidingDataStatus, byte aAidingDataReqFlg, byte[] aCurNetStatus, byte aAGPSResult, byte aSUPLStatus, byte aTimeFlg, byte aAddrFlg, byte[] aServerAdder, long aSUPLStatusCode, long aAgpsStartTime, long aAtlOpenTime, long aConnSvrTime, long aAgpsEndTime, short aServerIpPort) {
    }

    public void updateNtpServerInfo(java.lang.String address) {
        if (address != null) {
            java.util.List<java.lang.String> list = new java.util.ArrayList();
            list.clear();
            list.add(address);
            sendToDft(23, list);
        }
    }

    public void injectExtraParam(java.lang.String extraParam) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(extraParam);
        sendToDft(24, list);
    }

    public void injectTimeParam(int timeSource, long ntpTime, int uncertainty) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(timeSource));
        list.add(java.lang.String.valueOf(ntpTime));
        list.add(java.lang.Integer.toString(uncertainty));
        sendToDft(27, list);
    }

    public int logEvent(int type, int event, java.lang.String parameter) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(type));
        list.add(java.lang.Integer.toString(event));
        list.add(parameter);
        int result = sendToDft(25, list);
        if (result != 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("send Higeo CHR msg error:");
            stringBuilder.append(type);
            stringBuilder.append(",");
            stringBuilder.append(event);
            stringBuilder.append(",");
            stringBuilder.append(parameter);
            android.util.Log.d("HwGnssLogServices", stringBuilder.toString());
        }
        return result;
    }

    public void LocationSettingsOffErr(java.lang.String provider) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.add(provider);
        sendToDft(28, list);
    }

    public void setQuickGpsParam(int id, java.lang.String param) {
        java.util.List<java.lang.String> list = new java.util.ArrayList();
        list.clear();
        list.add(java.lang.Integer.toString(id));
        list.add(param);
        sendToDft(30, list);
    }
}
