package com.android.server.location;

public class HwGpsPowerTracker {
    private static final long CHECK_TIME_INTERVEL = 120000;
    private static final int CMD_CHECK_HIGH_POWER = 2001;
    private static final boolean DBG = true;
    public static final java.lang.String DEL_PKG = "pkg";
    private static final int EVENT_LOCATION_BEGIN = 1000;
    private static final int EVENT_LOCATION_END = 1001;
    public static final int EVENT_REMOVE_PACKAGE_LOCATION = 3001;
    private static final java.lang.String TAG = "HwGpsPowerTracker";
    private static final boolean mEnableGpsPowerTrack = android.os.SystemProperties.getBoolean("ro.config.hw_gps_power_track", true);
    private java.util.HashMap<java.lang.String, com.android.server.location.HwGpsPowerTracker.GpsAppTracker> mAppTrackers;
    private android.content.Context mContext;
    private com.android.server.LocationManagerServiceUtil mLocationManagerServiceUtil;
    private android.content.BroadcastReceiver mPackegeChangeReceiver = new android.content.BroadcastReceiver() {
        private java.lang.String getPackageName(android.content.Intent intent) {
            android.net.Uri uri = intent.getData();
            return uri != null ? uri.getSchemeSpecificPart() : null;
        }

        private boolean explicitlyStopped(java.lang.String pkg) {
            android.content.pm.PackageManager pm = com.android.server.location.HwGpsPowerTracker.this.mContext.getPackageManager();
            if (pm == null) {
                return false;
            }
            try {
                android.content.pm.ApplicationInfo ai = pm.getApplicationInfo(pkg, 0);
                if (ai == null || (ai.flags & 2097152) == 0) {
                    return false;
                }
                return true;
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("package info not found:");
                stringBuilder.append(pkg);
                android.util.Log.w("HwGpsPowerTracker", stringBuilder.toString());
                return false;
            }
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                java.lang.String action = intent.getAction();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("LocalReceiver receives:");
                stringBuilder.append(action);
                android.util.Log.d("HwGpsPowerTracker", stringBuilder.toString());
                if ("android.intent.action.PACKAGE_DATA_CLEARED".equals(action) || "android.intent.action.PACKAGE_RESTARTED".equals(action)) {
                    java.lang.String pkg = getPackageName(intent);
                    if (explicitlyStopped(pkg)) {
                        com.android.server.location.HwGpsPowerTracker.this.removeGpsLocation(pkg);
                    }
                }
            }
        }
    };
    private com.android.server.location.HwGpsPowerTracker.PowerHandler mPowerHandler;
    private android.os.Handler mRemoveLocationHandler;
    private android.os.HandlerThread mThread;

    private class GpsAppTracker {
        private java.util.ArrayList<com.android.server.location.HwGpsPowerTracker.NavigateRecord> mCurrentLocationList = new java.util.ArrayList();
        private final java.lang.String mPkgName;

        public GpsAppTracker(java.lang.String appName, boolean isIntent) {
            this.mPkgName = appName;
            recordStart(isIntent);
        }

        public java.lang.String toString() {
            int list_size = this.mCurrentLocationList.size();
            java.lang.StringBuffer result = new java.lang.StringBuffer("  Gps history of ");
            result.append(this.mPkgName);
            result.append("\n");
            for (int i = 0; i < list_size; i++) {
                result.append(((com.android.server.location.HwGpsPowerTracker.NavigateRecord) this.mCurrentLocationList.get(i)).toString());
            }
            return result.toString();
        }

        public boolean noNeedToTrack() {
            return this.mCurrentLocationList.isEmpty();
        }

        public void removeLocation() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("stop ");
            stringBuilder.append(this.mPkgName);
            stringBuilder.append(" location");
            android.util.Log.w("HwGpsPowerTracker", stringBuilder.toString());
            android.os.Message msg = new android.os.Message();
            msg.what = 3001;
            android.os.Bundle data = new android.os.Bundle();
            data.putString("pkg", this.mPkgName);
            msg.setData(data);
            com.android.server.location.HwGpsPowerTracker.this.mRemoveLocationHandler.sendMessage(msg);
        }

        public void checkHighPower() {
            if (!noPidRunning()) {
                return;
            }
            if (isIntentLocation()) {
                android.util.Log.w("HwGpsPowerTracker", "no Process running, stop it");
                removeLocation();
            } else if (!this.mCurrentLocationList.isEmpty()) {
                android.util.Log.e("HwGpsPowerTracker", "impossible here");
                removeLocation();
            }
        }

        private boolean noPidRunning() {
            java.util.List<android.app.ActivityManager.RunningAppProcessInfo> appProcessList = ((android.app.ActivityManager) com.android.server.location.HwGpsPowerTracker.this.mContext.getSystemService("activity")).getRunningAppProcesses();
            if (appProcessList == null) {
                android.util.Log.w("HwGpsPowerTracker", "no Process find");
                return false;
            }
            for (android.app.ActivityManager.RunningAppProcessInfo appProcess : appProcessList) {
                if (appProcess.processName.equals(this.mPkgName)) {
                    return false;
                }
            }
            return true;
        }

        private boolean isIntentLocation() {
            int list_size = this.mCurrentLocationList.size();
            com.android.server.location.HwGpsPowerTracker.NavigateRecord navigateRecord = null;
            for (int i = 0; i < list_size; i++) {
                if (((com.android.server.location.HwGpsPowerTracker.NavigateRecord) this.mCurrentLocationList.get(i)).mIsIntent) {
                    return true;
                }
            }
            return false;
        }

        public void recordEnd() {
            if (!this.mCurrentLocationList.isEmpty()) {
                this.mCurrentLocationList.remove(0);
            }
        }

        public void recordStart(boolean isIntent) {
            this.mCurrentLocationList.add(new com.android.server.location.HwGpsPowerTracker.NavigateRecord(isIntent));
        }

        public boolean isGpsLocationRunning() {
            return this.mCurrentLocationList.isEmpty() ^ 1;
        }
    }

    private static class NavigateRecord {
        private boolean mIsIntent;
        private long mStartTime = java.lang.System.currentTimeMillis();

        public NavigateRecord(boolean isIntent) {
            this.mIsIntent = isIntent;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("      Record [Start=");
            stringBuilder.append(this.mStartTime);
            stringBuilder.append("]\n");
            return stringBuilder.toString();
        }

        public long getStartTime() {
            return this.mStartTime;
        }
    }

    private class PowerHandler extends android.os.Handler {
        PowerHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PowerHandler msg.what:");
            stringBuilder.append(msg.what);
            android.util.Log.d("HwGpsPowerTracker", stringBuilder.toString());
            int i = msg.what;
            if (i != 2001) {
                switch (i) {
                    case 1000:
                        if (!hasMessages(2001)) {
                            android.util.Log.d("HwGpsPowerTracker", "send CMD_CHECK_HIGH_POWER");
                            sendEmptyMessageDelayed(2001, 120000);
                            return;
                        }
                        return;
                    case 1001:
                        synchronized (com.android.server.location.HwGpsPowerTracker.this.mAppTrackers) {
                            if (com.android.server.location.HwGpsPowerTracker.this.noLocationRunCheck()) {
                                removeMessages(2001);
                            }
                            com.android.server.location.HwGpsPowerTracker.this.clearAppTrackerData();
                        }
                        return;
                    default:
                        return;
                }
            }
            synchronized (com.android.server.location.HwGpsPowerTracker.this.mAppTrackers) {
                com.android.server.location.HwGpsPowerTracker.this.checkHighPower();
                if (!com.android.server.location.HwGpsPowerTracker.this.noLocationRunCheck()) {
                    android.util.Log.d("HwGpsPowerTracker", "send CMD_CHECK_HIGH_POWER");
                    sendEmptyMessageDelayed(2001, 120000);
                }
            }
        }
    }

    private class RemoveLocationHandler extends android.os.Handler {
        RemoveLocationHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (3001 == msg.what) {
                java.lang.String pkg = msg.getData().getString("pkg");
                if (pkg != null) {
                    com.android.server.location.HwGpsPowerTracker.this.mLocationManagerServiceUtil.clearPackageLocation(pkg);
                }
            }
            super.handleMessage(msg);
        }
    }

    public HwGpsPowerTracker(android.content.Context context) {
        if (mEnableGpsPowerTrack) {
            this.mThread = new android.os.HandlerThread("LocationManagerPowerTracker");
            this.mThread.start();
            this.mPowerHandler = new com.android.server.location.HwGpsPowerTracker.PowerHandler(this.mThread.getLooper());
            this.mAppTrackers = new java.util.HashMap();
            this.mContext = context;
            android.content.IntentFilter packageFilter = new android.content.IntentFilter();
            packageFilter.addAction("android.intent.action.PACKAGE_DATA_CLEARED");
            packageFilter.addAction("android.intent.action.PACKAGE_RESTARTED");
            packageFilter.addDataScheme("package");
            this.mContext.registerReceiverAsUser(this.mPackegeChangeReceiver, android.os.UserHandle.OWNER, packageFilter, null, null);
            this.mRemoveLocationHandler = new com.android.server.location.HwGpsPowerTracker.RemoveLocationHandler(com.android.internal.os.BackgroundThread.get().getLooper());
            this.mLocationManagerServiceUtil = com.android.server.LocationManagerServiceUtil.getDefault();
        }
    }

    private void removeGpsLocation(java.lang.String pkg) {
        synchronized (this.mAppTrackers) {
            com.android.server.location.HwGpsPowerTracker.GpsAppTracker appTracker = (com.android.server.location.HwGpsPowerTracker.GpsAppTracker) this.mAppTrackers.get(pkg);
            if (appTracker == null) {
                return;
            }
            appTracker.removeLocation();
        }
    }

    private void clearAppTrackerData() {
        synchronized (this.mAppTrackers) {
            if (this.mAppTrackers.size() != 0) {
                java.util.ArrayList<java.lang.String> couldClearApps = new java.util.ArrayList();
                for (java.util.Map.Entry entry : this.mAppTrackers.entrySet()) {
                    com.android.server.location.HwGpsPowerTracker.GpsAppTracker appTracker = (com.android.server.location.HwGpsPowerTracker.GpsAppTracker) entry.getValue();
                    if (appTracker.noNeedToTrack()) {
                        couldClearApps.add(appTracker.mPkgName);
                    }
                }
                int appSize = couldClearApps.size();
                if (appSize > 0) {
                    for (int i = 0; i < appSize; i++) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("clearAppTrackerData AppName:");
                        stringBuilder.append((java.lang.String) couldClearApps.get(i));
                        android.util.Log.d("HwGpsPowerTracker", stringBuilder.toString());
                        this.mAppTrackers.remove(couldClearApps.get(i));
                    }
                }
            }
        }
    }

    public void recordRequest(java.lang.String pkgName, int quality, boolean isIntent) {
        if (mEnableGpsPowerTrack) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("recordRequest AppName:");
            stringBuilder.append(pkgName);
            stringBuilder.append(" quality:");
            stringBuilder.append(quality);
            android.util.Log.d("HwGpsPowerTracker", stringBuilder.toString());
            if (quality == 100) {
                synchronized (this.mAppTrackers) {
                    if (this.mAppTrackers.containsKey(pkgName)) {
                        ((com.android.server.location.HwGpsPowerTracker.GpsAppTracker) this.mAppTrackers.get(pkgName)).recordStart(isIntent);
                    } else {
                        this.mAppTrackers.put(pkgName, new com.android.server.location.HwGpsPowerTracker.GpsAppTracker(pkgName, isIntent));
                    }
                }
                this.mPowerHandler.sendEmptyMessage(1000);
            }
        }
    }

    public void removeRequest(java.lang.String pkgName) {
        if (mEnableGpsPowerTrack) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("removeRequest:");
            stringBuilder.append(pkgName);
            android.util.Log.d("HwGpsPowerTracker", stringBuilder.toString());
            synchronized (this.mAppTrackers) {
                if (this.mAppTrackers.containsKey(pkgName)) {
                    ((com.android.server.location.HwGpsPowerTracker.GpsAppTracker) this.mAppTrackers.get(pkgName)).recordEnd();
                    this.mPowerHandler.sendEmptyMessage(1001);
                    return;
                }
            }
        }
    }

    private void checkHighPower() {
        synchronized (this.mAppTrackers) {
            if (this.mAppTrackers.size() != 0) {
                for (java.util.Map.Entry entry : this.mAppTrackers.entrySet()) {
                    ((com.android.server.location.HwGpsPowerTracker.GpsAppTracker) entry.getValue()).checkHighPower();
                }
            }
        }
    }

    /* JADX WARNING: Missing block: B:16:0x0033, code:
            return true;
     */
    private boolean noLocationRunCheck() {
        /*
        r5 = this;
        r0 = r5.mAppTrackers;
        monitor-enter(r0);
        r1 = r5.mAppTrackers;	 Catch:{ all -> 0x0034 }
        r1 = r1.size();	 Catch:{ all -> 0x0034 }
        if (r1 == 0) goto L_0x0031;
    L_0x000b:
        r1 = r5.mAppTrackers;	 Catch:{ all -> 0x0034 }
        r1 = r1.entrySet();	 Catch:{ all -> 0x0034 }
        r1 = r1.iterator();	 Catch:{ all -> 0x0034 }
    L_0x0015:
        r2 = r1.hasNext();	 Catch:{ all -> 0x0034 }
        if (r2 == 0) goto L_0x0031;
    L_0x001b:
        r2 = r1.next();	 Catch:{ all -> 0x0034 }
        r2 = (java.util.Map.Entry) r2;	 Catch:{ all -> 0x0034 }
        r3 = r2.getValue();	 Catch:{ all -> 0x0034 }
        r3 = (com.android.server.location.HwGpsPowerTracker.GpsAppTracker) r3;	 Catch:{ all -> 0x0034 }
        r4 = r3.isGpsLocationRunning();	 Catch:{ all -> 0x0034 }
        if (r4 == 0) goto L_0x0030;
    L_0x002d:
        r4 = 0;
        monitor-exit(r0);	 Catch:{ all -> 0x0034 }
        return r4;
    L_0x0030:
        goto L_0x0015;
    L_0x0031:
        monitor-exit(r0);	 Catch:{ all -> 0x0034 }
        r0 = 1;
        return r0;
    L_0x0034:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0034 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.location.HwGpsPowerTracker.noLocationRunCheck():boolean");
    }

    public void dump(java.io.PrintWriter pw) {
        if (mEnableGpsPowerTrack) {
            pw.println("  LocationPowerTracker:");
            synchronized (this.mAppTrackers) {
                for (java.util.Map.Entry entry : this.mAppTrackers.entrySet()) {
                    com.android.server.location.HwGpsPowerTracker.GpsAppTracker appTracker = (com.android.server.location.HwGpsPowerTracker.GpsAppTracker) entry.getValue();
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("  ");
                    stringBuilder.append(appTracker.toString());
                    pw.println(stringBuilder.toString());
                }
            }
        }
    }
}
