package com.android.server.location;

public class HwLbsLogger implements com.android.server.location.IHwLbsLogger {
    private static final java.lang.String BUNDLE_PARAMETER_LOCATION = "location";
    private static final java.lang.String BUNDLE_PARAMETER_LOCATION_RECEIVERS = "receivers";
    private static final java.lang.String BUNDLE_PARAMETER_SESSION_ACTION = "action";
    private static final java.lang.String BUNDLE_PARAMETER_SESSION_INTERVAL = "interval";
    private static final java.lang.String BUNDLE_PARAMETER_SESSION_PACKAGE_NAME = "pkgName";
    private static final java.lang.String BUNDLE_PARAMETER_SESSION_PROVIDER = "provider";
    private static final java.lang.String BUNDLE_PARAMETER_SESSION_RECEIVER = "receiver";
    private static final java.lang.String BUNDLE_PARAMETER_TIMESTAMP = "timestamp";
    private static final boolean DEBUG = android.util.Log.isLoggable("HwLbsLogger", 3);
    private static final java.lang.String SESSION_START = "start";
    private static final java.lang.String SESSION_STOP = "stop";
    private static final java.lang.String TAG = "HwLbsLogger";
    private static final boolean VERBOSE = android.util.Log.isLoggable("HwLbsLogger", 2);
    private static com.android.server.location.HwLbsLogger mHwLbsLogger;
    private final com.android.server.location.HwLbsLogger.HwLbsLoggerHandler mHandler;
    private com.android.server.location.HwLogRecordManager mHwLogManager = com.android.server.location.HwLogRecordManager.getInstance();
    private android.os.HandlerThread mThread = new android.os.HandlerThread("HwLbsLogger");

    private final class HwLbsLoggerHandler extends android.os.Handler {
        public HwLbsLoggerHandler(android.os.Looper looper) {
            super(looper, null, true);
        }

        public void handleMessage(android.os.Message msg) {
            android.os.Bundle sessionBundle;
            switch (msg.what) {
                case 100:
                case 102:
                case 103:
                case 104:
                case 105:
                case 106:
                case 107:
                case 108:
                case 109:
                case 110:
                    break;
                case 101:
                    sessionBundle = msg.obj;
                    if (sessionBundle != null) {
                        com.android.server.location.HwLbsLogger.SessionRecord sessionRecord = null;
                        java.lang.String action = sessionBundle.getString("action");
                        if (action.equals("start")) {
                            sessionRecord = new com.android.server.location.HwLbsLogger.SessionRecord(sessionBundle.getLong("timestamp"), action, sessionBundle.getString("pkgName"), sessionBundle.getString("provider"), sessionBundle.getInt("interval"), sessionBundle.getInt("receiver"));
                        } else if (action.equals("stop")) {
                            sessionRecord = new com.android.server.location.HwLbsLogger.SessionRecord(sessionBundle.getLong("timestamp"), action, sessionBundle.getString("pkgName"), sessionBundle.getInt("receiver"));
                        }
                        com.android.server.location.HwLbsLogger.this.saveSessionRecord(sessionRecord);
                        break;
                    }
                    android.util.Log.d("HwLbsLogger", "LOCATION_SESSION_ACTION Parameter bundle is null");
                    return;
                case 111:
                    sessionBundle = msg.obj;
                    if (sessionBundle != null) {
                        com.android.server.location.HwLbsLogger.this.saveLocationResultRecord(new com.android.server.location.HwLbsLogger.LocationResultRecord((android.location.Location) sessionBundle.getParcelable("location"), sessionBundle.getLong("timestamp"), sessionBundle.getIntegerArrayList("receivers")));
                        break;
                    }
                    android.util.Log.d("HwLbsLogger", "LOCATION_POS_REPORT Parameter bundle is null");
                    return;
                case 112:
                    break;
                default:
                    return;
            }
        }
    }

    public static class LocationEventRecord {
        private int mEventId = 0;
        private int mParameter = 0;
        private int mReceiver = 0;
        private long mTimestamp = 0;

        public LocationEventRecord(long timestamp, int eventId, int parameter, int receiver) {
            this.mTimestamp = timestamp;
            this.mEventId = eventId;
            this.mParameter = parameter;
            this.mReceiver = receiver;
        }

        public long getTimestamp() {
            return this.mTimestamp;
        }

        public int getEventId() {
            return this.mEventId;
        }

        public int getParameter() {
            return this.mParameter;
        }

        public int getReceiver() {
            return this.mReceiver;
        }
    }

    public static class LocationResultRecord {
        private android.location.Location mLocation;
        private java.util.List<java.lang.Integer> mReceivers = new java.util.ArrayList();
        private long mTimestamp;

        public LocationResultRecord(android.location.Location location, long timestamp, java.util.List<java.lang.Integer> receivers) {
            this.mLocation = location;
            this.mTimestamp = timestamp;
            if (receivers != null) {
                int size = receivers.size();
                for (int i = 0; i < size; i++) {
                    this.mReceivers.add((java.lang.Integer) receivers.get(i));
                }
            }
        }

        public android.location.Location getLocation() {
            return this.mLocation;
        }

        public long getTimestamp() {
            return this.mTimestamp;
        }

        public java.util.List<java.lang.Integer> getReceivers() {
            return this.mReceivers;
        }
    }

    public static class SessionRecord {
        private java.lang.String mAction;
        private int mInterval;
        private java.lang.String mPkgName;
        private java.lang.String mProvider;
        private int mReceiver;
        private long mTimestamp;

        public SessionRecord(long timestamp, java.lang.String action, java.lang.String pkgName, java.lang.String provider, int interval, int receiver) {
            this.mTimestamp = timestamp;
            this.mAction = action;
            this.mPkgName = pkgName;
            this.mProvider = provider;
            this.mInterval = interval;
            this.mReceiver = receiver;
        }

        public SessionRecord(long timestamp, java.lang.String action, java.lang.String pkgName, int receiver) {
            this.mTimestamp = timestamp;
            this.mAction = action;
            this.mPkgName = pkgName;
            this.mReceiver = receiver;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder sb = new java.lang.StringBuilder();
            sb.append("SessionRecord: ");
            sb.append("mTimestamp ");
            sb.append(this.mTimestamp);
            sb.append(", mAction ");
            sb.append(this.mAction);
            sb.append(", mPkgName ");
            sb.append(this.mPkgName);
            sb.append(", mProvider ");
            sb.append(this.mProvider);
            sb.append(", mInterval ");
            sb.append(this.mInterval);
            sb.append(", mReceiver ");
            sb.append(this.mReceiver);
            return sb.toString();
        }

        public long getTimestamp() {
            return this.mTimestamp;
        }

        public java.lang.String getAction() {
            return this.mAction;
        }

        public java.lang.String getPackageName() {
            return this.mPkgName;
        }

        public java.lang.String getProvider() {
            return this.mProvider;
        }

        public long getInterval() {
            return (long) this.mInterval;
        }

        public int getReceiver() {
            return this.mReceiver;
        }
    }

    private HwLbsLogger(android.content.Context context) {
        android.util.Log.d("HwLbsLogger", "enter HwLbsLogger");
        this.mThread.start();
        this.mHandler = new com.android.server.location.HwLbsLogger.HwLbsLoggerHandler(this.mThread.getLooper());
    }

    public static synchronized com.android.server.location.HwLbsLogger getInstance(android.content.Context context) {
        com.android.server.location.HwLbsLogger hwLbsLogger;
        synchronized (com.android.server.location.HwLbsLogger.class) {
            if (mHwLbsLogger == null) {
                mHwLbsLogger = new com.android.server.location.HwLbsLogger(context);
            }
            hwLbsLogger = mHwLbsLogger;
        }
        return hwLbsLogger;
    }

    public static synchronized com.android.server.location.HwLbsLogger getHwLbsLogger() {
        com.android.server.location.HwLbsLogger hwLbsLogger;
        synchronized (com.android.server.location.HwLbsLogger.class) {
            hwLbsLogger = mHwLbsLogger;
        }
        return hwLbsLogger;
    }

    private void saveSessionRecord(com.android.server.location.HwLbsLogger.SessionRecord sr) {
        if (this.mHwLogManager != null) {
            if (sr != null) {
                this.mHwLogManager.writeSession(sr);
                return;
            }
        }
        android.util.Log.d("HwLbsLogger", "save sesstion record failed");
    }

    private void saveLocationResultRecord(com.android.server.location.HwLbsLogger.LocationResultRecord locationRecord) {
        if (this.mHwLogManager != null) {
            if (locationRecord != null) {
                this.mHwLogManager.writePosition(locationRecord);
                return;
            }
        }
        android.util.Log.d("HwLbsLogger", "save location result record failed.");
    }

    public void loggerEvent(int eventId, android.os.Bundle parameter) {
        android.os.Message msg = android.os.Message.obtain();
        msg.what = eventId;
        msg.obj = parameter;
        this.mHandler.sendMessage(msg);
    }
}
