package com.android.server.location;

public class HwLogRecordManager {
    public static final java.lang.String COMMA_SEPARATE = ",";
    public static final java.lang.String EMPTY = "";
    private static final java.lang.String LOG_VERSION_DOMESTIC = "3";
    private static final java.lang.String MASTER_PASSWORD = com.android.server.location.HwLocalLocationManager.MASTER_PASSWORD;
    public static final java.lang.String NA = "NA";
    private static final java.lang.String SESSION_START = "start";
    private static final java.lang.String SESSION_STOP = "stop";
    private static final java.lang.String TAG = "HwLogRecordManager";
    public static final java.lang.String VERTICAL_ESC_SEPARATE = "\\|";
    public static final java.lang.String VERTICAL_SEPARATE = "|";
    private static final java.lang.Object mLock = new java.lang.Object();
    private static volatile com.android.server.location.HwLogRecordManager mLogManager;

    private HwLogRecordManager() {
        if (isBetaUser()) {
            android.util.Log.d("HwLogRecordManager", "begin start Log file");
            startLogFile();
        }
    }

    public static com.android.server.location.HwLogRecordManager getInstance() {
        if (mLogManager == null) {
            synchronized (mLock) {
                if (mLogManager == null) {
                    android.util.Log.d("HwLogRecordManager", "mLogManager create.");
                    mLogManager = new com.android.server.location.HwLogRecordManager();
                }
            }
        }
        return mLogManager;
    }

    private void startLogFile() {
        com.android.server.location.HwXmlLogParse.createXmlSerializer();
    }

    private boolean isBetaUser() {
        if (android.os.SystemProperties.get("ro.logsystem.usertype", "0").equals("3")) {
            return true;
        }
        return false;
    }

    public void writePosition(com.android.server.location.HwLbsLogger.LocationResultRecord locationResult) {
        if (locationResult != null) {
            android.location.Location location = locationResult.getLocation();
            long timestamp = locationResult.getTimestamp();
            java.util.List<java.lang.Integer> receivers = locationResult.getReceivers();
            if (location != null) {
                if (receivers != null) {
                    java.lang.String hashReceiver = "unknown";
                    int hashNumber = 0;
                    int receiverSize = receivers.size();
                    if (receiverSize > 0) {
                        hashNumber = receiverSize;
                        java.lang.StringBuilder builder = new java.lang.StringBuilder();
                        for (int i = 0; i < receiverSize; i++) {
                            builder.append(receivers.get(i));
                            if (i < receiverSize - 1) {
                                builder.append("; ");
                            }
                        }
                        hashReceiver = builder.toString();
                    }
                    java.lang.String encryptedLong = java.lang.String.valueOf(location.getLongitude());
                    java.lang.String encryptedLat = java.lang.String.valueOf(location.getLatitude());
                    try {
                        java.lang.String str = MASTER_PASSWORD;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(location.getLongitude());
                        stringBuilder.append("");
                        encryptedLong = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(str, stringBuilder.toString());
                        str = MASTER_PASSWORD;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(location.getLatitude());
                        stringBuilder.append("");
                        encryptedLat = com.android.server.location.HwCryptoUtility.AESLocalDbCrypto.encrypt(str, stringBuilder.toString());
                    } catch (java.lang.Exception e) {
                        android.util.Log.d("HwLogRecordManager", "exception occured when encrypt longitude and latitude");
                    }
                    java.lang.StringBuffer dataBuffer = new java.lang.StringBuffer();
                    dataBuffer.append(formatTimestamp(timestamp));
                    dataBuffer.append("|");
                    dataBuffer.append(formatTimestamp(location.getTime()));
                    dataBuffer.append(",");
                    dataBuffer.append(encryptedLat);
                    dataBuffer.append(",");
                    dataBuffer.append(encryptedLong);
                    dataBuffer.append(",");
                    if (location.hasAltitude()) {
                        dataBuffer.append(location.getAltitude());
                        dataBuffer.append(",");
                    } else {
                        dataBuffer.append("NA");
                        dataBuffer.append(",");
                    }
                    if (location.hasAccuracy()) {
                        dataBuffer.append(location.getAccuracy());
                        dataBuffer.append(",");
                    } else {
                        dataBuffer.append("NA");
                        dataBuffer.append(",");
                    }
                    if (location.hasSpeed()) {
                        dataBuffer.append(location.getSpeed());
                        dataBuffer.append(",");
                    } else {
                        dataBuffer.append("NA");
                        dataBuffer.append(",");
                    }
                    if (location.hasBearing()) {
                        dataBuffer.append(location.getBearing());
                        dataBuffer.append(",");
                    } else {
                        dataBuffer.append("NA");
                        dataBuffer.append(",");
                    }
                    java.lang.String provider = location.getProvider();
                    if (provider != null) {
                        dataBuffer.append(provider);
                        dataBuffer.append("|");
                    } else {
                        dataBuffer.append("NA");
                        dataBuffer.append("|");
                    }
                    dataBuffer.append(hashNumber);
                    dataBuffer.append(",");
                    dataBuffer.append(hashReceiver);
                    com.android.server.location.HwXmlLogParse.positionTag(dataBuffer.toString());
                }
            }
        }
    }

    public void writeEvent(com.android.server.location.HwLbsLogger.LocationEventRecord eventRecord) {
        if (eventRecord == null) {
            android.util.Log.d("HwLogRecordManager", "invalid evenet datas.");
        }
    }

    public void writeSession(com.android.server.location.HwLbsLogger.SessionRecord sessionRecord) {
        if (sessionRecord == null) {
            android.util.Log.d("HwLogRecordManager", "invalid session datas.");
            return;
        }
        java.lang.StringBuffer dataBuffer = new java.lang.StringBuffer();
        java.lang.String action = sessionRecord.getAction();
        java.lang.String type = "";
        if (action.equals("start")) {
            dataBuffer.append(formatTimestamp(sessionRecord.getTimestamp()));
            dataBuffer.append("|");
            dataBuffer.append(sessionRecord.getAction());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getPackageName());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getProvider());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getInterval());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getReceiver());
            type = "start";
        } else if (action.equals("stop")) {
            dataBuffer.append(formatTimestamp(sessionRecord.getTimestamp()));
            dataBuffer.append("|");
            dataBuffer.append(sessionRecord.getAction());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getPackageName());
            dataBuffer.append(",");
            dataBuffer.append(sessionRecord.getReceiver());
            type = "stop";
        }
        if (!dataBuffer.toString().equals("")) {
            com.android.server.location.HwXmlLogParse.sessionTag(dataBuffer.toString(), type);
        }
    }

    private java.lang.String formatTimestamp(long timestamp) {
        return new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss SSS", java.util.Locale.US).format(new java.util.Date(timestamp));
    }
}
