package com.android.server.location;

public class HwMultiNlpPolicy {
    public static final int NLP_AB = 2;
    public static final int NLP_GOOGLE = 1;
    public static final int NLP_NONE = 0;
    private static final java.lang.String PROPERTY_GLOBAL_OPERATOR_NUMERIC = "ril.operator.numeric";
    private static final java.lang.String TAG = "HwMultiNlpPolicy";
    private static volatile com.android.server.location.HwMultiNlpPolicy instance;
    private boolean isChineseSimCard = false;
    private boolean isRegistedInChineseNetwork = false;
    private boolean isSimCardReady = false;
    private boolean isVSimEnabled = false;
    private boolean isWifiNetworkConnected = false;
    private final android.content.BroadcastReceiver mBroadcastReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("receive broadcast intent, action: ");
            stringBuilder.append(action);
            android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
            if ("android.net.conn.CONNECTIVITY_CHANGE".equals(action)) {
                android.net.NetworkInfo info = (android.net.NetworkInfo) intent.getParcelableExtra("networkInfo");
                if (info != null && info.getType() == 1) {
                    info = ((android.net.ConnectivityManager) com.android.server.location.HwMultiNlpPolicy.this.mContext.getSystemService("connectivity")).getNetworkInfo(info.getType());
                    if (info != null) {
                        com.android.server.location.HwMultiNlpPolicy.this.isWifiNetworkConnected = info.isConnected();
                    }
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("isWifiNetworkConnected: ");
                    stringBuilder2.append(com.android.server.location.HwMultiNlpPolicy.this.isWifiNetworkConnected);
                    android.util.Slog.d("HwMultiNlpPolicy", stringBuilder2.toString());
                }
            } else if ("android.intent.action.SIM_STATE_CHANGED".equals(action)) {
                com.android.server.location.HwMultiNlpPolicy.this.setOrUpdateChineseSimCard(com.android.server.location.HwMultiNlpPolicy.this.mDataSub);
            } else if ("android.intent.action.ACTION_DEFAULT_DATA_SUBSCRIPTION_CHANGED".equals(action)) {
                com.android.server.location.HwMultiNlpPolicy.this.mDataSub = intent.getIntExtra("subscription", -1);
                com.android.server.location.HwMultiNlpPolicy.this.setOrUpdateChineseSimCard(com.android.server.location.HwMultiNlpPolicy.this.mDataSub);
            }
        }
    };
    private android.content.Context mContext;
    private int mDataSub = -1;
    private int mLastChoiceNlp = 0;
    private android.telephony.PhoneStateListener[] mPhoneStateListener;
    private android.telephony.TelephonyManager mTelephonyManager;

    public static com.android.server.location.HwMultiNlpPolicy getDefault(android.content.Context context) {
        if (instance == null) {
            instance = new com.android.server.location.HwMultiNlpPolicy(context);
        }
        return instance;
    }

    public static com.android.server.location.HwMultiNlpPolicy getDefault() {
        return instance;
    }

    public HwMultiNlpPolicy(android.content.Context context) {
        this.mContext = context;
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
        filter.addCategory("android.net.conn.CONNECTIVITY_CHANGE@hwBrExpand@ConnectStatus=WIFIDATACON|ConnectStatus=WIFIDATADSCON");
        filter.addAction("android.intent.action.SIM_STATE_CHANGED");
        filter.addAction("android.intent.action.ACTION_DEFAULT_DATA_SUBSCRIPTION_CHANGED");
        this.mContext.registerReceiver(this.mBroadcastReceiver, filter);
        registerPhoneStateListener();
        getDataSubscription();
    }

    private void registerPhoneStateListener() {
        this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        this.mPhoneStateListener = new android.telephony.PhoneStateListener[3];
        for (int i = 0; i < 3; i++) {
            this.mPhoneStateListener[i] = getPhoneStateListener(i);
            this.mTelephonyManager.listen(this.mPhoneStateListener[i], 1);
        }
    }

    private android.telephony.PhoneStateListener getPhoneStateListener(int subId) {
        return new android.telephony.PhoneStateListener(java.lang.Integer.valueOf(subId)) {
            public void onServiceStateChanged(android.telephony.ServiceState state) {
                if (state != null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("PhoneStateListener ");
                    stringBuilder.append(this.mSubId);
                    stringBuilder.append(", mDataSub ");
                    stringBuilder.append(com.android.server.location.HwMultiNlpPolicy.this.mDataSub);
                    android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
                    if (this.mSubId.intValue() == com.android.server.location.HwMultiNlpPolicy.this.mDataSub && com.android.server.location.HwMultiNlpPolicy.this.mDataSub != -1) {
                        com.android.server.location.HwMultiNlpPolicy.this.setSimCardState(state.getDataRegState());
                        com.android.server.location.HwMultiNlpPolicy.this.setRegistedNetwork(state.getOperatorNumeric());
                    } else if (this.mSubId.intValue() == 2) {
                        com.android.server.location.HwMultiNlpPolicy.this.isVSimEnabled = android.telephony.HwTelephonyManager.getDefault().isVSimEnabled();
                    }
                }
            }
        };
    }

    public boolean shouldUseGoogleNLP(boolean update) {
        return 1 == choiceNLP(update);
    }

    public boolean shouldBeRecheck() {
        return this.mLastChoiceNlp != choiceNLP(false);
    }

    public int shouldUseNLP() {
        return choiceNLP(false);
    }

    private int choiceNLP(boolean update) {
        int result;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("choiceNLP isSimCardReady: ");
        stringBuilder.append(this.isSimCardReady);
        stringBuilder.append(" isWifiNetworkConnected: ");
        stringBuilder.append(this.isWifiNetworkConnected);
        stringBuilder.append(" isRegistedInChineseNetwork: ");
        stringBuilder.append(this.isRegistedInChineseNetwork);
        stringBuilder.append(" isVSimEnabled: ");
        stringBuilder.append(this.isVSimEnabled);
        stringBuilder.append(" isChineseSimCard: ");
        stringBuilder.append(this.isChineseSimCard);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        if (this.isSimCardReady) {
            if (this.isWifiNetworkConnected) {
                if (this.isRegistedInChineseNetwork) {
                    result = 2;
                } else {
                    result = 1;
                }
            } else if (this.isVSimEnabled) {
                if (isVsimRegistedInChineseNetwork()) {
                    result = 2;
                } else {
                    result = 1;
                }
            } else if (this.isChineseSimCard) {
                result = 2;
            } else {
                result = 1;
            }
        } else if (this.isVSimEnabled) {
            if (isVsimRegistedInChineseNetwork()) {
                result = 2;
            } else {
                result = 1;
            }
        } else if (isRegistedInChineseNetworkWithoutSimCard()) {
            result = 2;
        } else if (isRegistedInForeginNetworkWithoutSimCard()) {
            result = 1;
        } else if (isChineseVersion()) {
            result = 2;
        } else {
            result = 1;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("choiceNLP ");
        stringBuilder.append(result);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        if (update) {
            this.mLastChoiceNlp = result;
        }
        return result;
    }

    public static boolean isChineseVersion() {
        return "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    }

    private void getDataSubscription() {
        this.mDataSub = android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "multi_sim_data_call", 0);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getDataSubscription mDataSub: ");
        stringBuilder.append(this.mDataSub);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
    }

    public int getPreferredDataSubscription() {
        return android.telephony.SubscriptionManager.getDefaultDataSubscriptionId();
    }

    private void setSimCardState(int simState) {
        this.isSimCardReady = simState == 0;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setSimCardReady ");
        stringBuilder.append(simState);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
    }

    private void setOrUpdateChineseSimCard(int dataSub) {
        if (dataSub != -1) {
            java.lang.String simCountry = android.telephony.TelephonyManager.getDefault().getSimCountryIso(dataSub);
            boolean isCtSimCard = android.telephony.HwTelephonyManager.getDefault().isCTSimCard(dataSub);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isChineseSimCard datasub ");
            stringBuilder.append(dataSub);
            stringBuilder.append(", ");
            stringBuilder.append(simCountry);
            android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
            if ((simCountry == null || !simCountry.equalsIgnoreCase("CN")) && !isCtSimCard) {
                this.isChineseSimCard = false;
            } else {
                this.isChineseSimCard = true;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("isChineseSimCard ");
        stringBuilder2.append(this.isChineseSimCard);
        stringBuilder2.append(" , dataSub ");
        stringBuilder2.append(dataSub);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder2.toString());
    }

    private void setRegistedNetwork(java.lang.String numeric) {
        if (numeric == null || numeric.length() < 5 || !numeric.substring(0, 5).equals("99999")) {
            if (numeric != null && numeric.length() >= 3 && numeric.substring(0, 3).equals("460")) {
                this.isRegistedInChineseNetwork = true;
            } else if (!(numeric == null || numeric.equals(""))) {
                this.isRegistedInChineseNetwork = false;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setRegistedNetwork ");
        stringBuilder.append(numeric);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
    }

    private boolean isVsimRegistedInChineseNetwork() {
        boolean ret = false;
        java.lang.String networkCountry = android.os.SystemProperties.get("gsm.operator.iso-country.vsim");
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isVsimRegistedInChineseNetwork ");
        stringBuilder.append(networkCountry);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        if (networkCountry != null && networkCountry.equalsIgnoreCase("CN")) {
            ret = true;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isVsimRegistedInChineseNetwork ");
        stringBuilder.append(ret);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        return ret;
    }

    private boolean isRegistedInChineseNetworkWithoutSimCard() {
        boolean ret = false;
        java.lang.String rplmns = android.os.SystemProperties.get("ril.operator.numeric", "");
        if (rplmns != null && rplmns.length() > 3 && rplmns.substring(0, 3).equals("460")) {
            ret = true;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isRegistedInChineseNetworkWithoutSimCard rplmns ");
        stringBuilder.append(rplmns);
        stringBuilder.append(", ret ");
        stringBuilder.append(ret);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        return ret;
    }

    private boolean isRegistedInForeginNetworkWithoutSimCard() {
        boolean ret = false;
        java.lang.String rplmns = android.os.SystemProperties.get("ril.operator.numeric", "");
        if (!(rplmns == null || rplmns.length() <= 3 || rplmns.substring(0, 3).equals("460"))) {
            ret = true;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isRegistedInForeginNetworkWithoutSimCard rplmns ");
        stringBuilder.append(rplmns);
        stringBuilder.append(", ret ");
        stringBuilder.append(ret);
        android.util.Slog.d("HwMultiNlpPolicy", stringBuilder.toString());
        return ret;
    }
}
