package com.android.server.location;

public class HwReportTool {
    private static final boolean DEBUG = huawei.android.debug.HwDBGSwitchController.getDBGSwitch();
    private static final java.lang.String REPORTERINTERFACE_LIB_PATH = "/system/framework/com.huawei.report.jar";
    private static final java.lang.String REPORT_CLS = "com.huawei.report.ReporterInterface";
    private static final java.lang.String REPORT_METHOD_E = "e";
    private static final java.lang.String TAG = "HwReportTool";
    private static volatile com.android.server.location.HwReportTool sSingleInstance = null;
    private com.huawei.lcagent.client.LogCollectManager mClient = null;
    private android.content.Context mContext = null;
    private java.lang.reflect.Method sReportMethod = null;
    private java.lang.Class<?> sReporterClazz = null;

    public static com.android.server.location.HwReportTool getInstance(android.content.Context context) {
        if (sSingleInstance == null) {
            sSingleInstance = new com.android.server.location.HwReportTool(context.getApplicationContext());
        }
        return sSingleInstance;
    }

    private HwReportTool(android.content.Context context) {
        initReporter(context);
    }

    private void initReporter(android.content.Context context) {
        try {
            this.sReporterClazz = new dalvik.system.PathClassLoader("/system/framework/com.huawei.report.jar", context.getClassLoader()).loadClass("com.huawei.report.ReporterInterface");
            this.sReportMethod = this.sReporterClazz.getDeclaredMethod("e", new java.lang.Class[]{android.content.Context.class, java.lang.Integer.TYPE, java.lang.String.class});
            this.mClient = new com.huawei.lcagent.client.LogCollectManager(context);
            this.mContext = context;
        } catch (java.lang.ClassNotFoundException e) {
            android.util.Log.e("HwReportTool", "Can't find sReporterClazz");
            this.sReporterClazz = null;
        } catch (java.lang.NoSuchMethodException e2) {
            android.util.Log.e("HwReportTool", "Can't find sReportMethod");
            this.sReportMethod = null;
        } catch (java.lang.NullPointerException e3) {
            e3.printStackTrace();
        }
    }

    public boolean report(int eventID, java.lang.String eventMsg) {
        if (!isBetaUser()) {
            android.util.Log.e("HwReportTool", "This is not beta user build");
        } else if (!(this.sReportMethod == null || this.sReporterClazz == null)) {
            try {
                return ((java.lang.Boolean) this.sReportMethod.invoke(this.sReporterClazz, new java.lang.Object[]{this.mContext, java.lang.Integer.valueOf(eventID), eventMsg})).booleanValue();
            } catch (java.lang.Exception e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("got exception");
                stringBuilder.append(e.getMessage());
                android.util.Log.e("HwReportTool", stringBuilder.toString(), e);
            }
        }
        return false;
    }

    private boolean isBetaUser() {
        return 3 == getUserType();
    }

    private int getUserType() {
        int userType = -1;
        if (this.mClient == null) {
            return -1;
        }
        try {
            userType = this.mClient.getUserType();
        } catch (android.os.RemoteException e) {
            e.printStackTrace();
        } catch (java.lang.NullPointerException e2) {
            e2.printStackTrace();
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("userType is: ");
            stringBuilder.append(userType);
            android.util.Log.d("HwReportTool", stringBuilder.toString());
        }
        return userType;
    }
}
