package com.android.server.mtm.iaware.appmng;

public class AwareProcessInfo {
    private boolean isFas = false;
    private boolean isFreeze = false;
    private boolean isRare = false;
    private boolean isStandBy = false;
    private android.util.ArrayMap<java.lang.String, com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy> mBrPolicys = new android.util.ArrayMap();
    public int mClassRate;
    public com.android.server.mtm.taskstatus.ProcessCleaner.CleanType mCleanType;
    public java.util.Map<java.lang.String, java.lang.Integer> mDetailedReason;
    public boolean mHasShownUi;
    public int mImportance;
    public int mMemGroup;
    public int mPid;
    public com.android.server.mtm.taskstatus.ProcessInfo mProcInfo;
    public java.lang.String mReason;
    public boolean mRestartFlag = false;
    private int mState = 10;
    public int mSubClassRate;
    public int mTaskId = -1;
    public com.android.server.mtm.iaware.appmng.AwareProcessInfo.XmlConfig mXmlConfig;

    public static class XmlConfig {
        public int mCfgDefaultGroup;
        public boolean mFrequentlyUsed;
        public boolean mResCleanAllow;
        public boolean mRestartFlag;

        public XmlConfig(int groupId, boolean frequentUsed, boolean allowCleanRes, boolean restartFlag) {
            this.mCfgDefaultGroup = groupId;
            this.mFrequentlyUsed = frequentUsed;
            this.mResCleanAllow = allowCleanRes;
            this.mRestartFlag = restartFlag;
        }
    }

    public boolean getRestartFlag() {
        if (this.mRestartFlag) {
            return true;
        }
        if (this.mXmlConfig == null) {
            return false;
        }
        return this.mXmlConfig.mRestartFlag;
    }

    public AwareProcessInfo(int pid, int memGroup, int importance, int classRate, com.android.server.mtm.taskstatus.ProcessInfo procInfo) {
        this.mPid = pid;
        this.mMemGroup = memGroup;
        this.mImportance = importance;
        this.mClassRate = classRate;
        this.mSubClassRate = 0;
        this.mProcInfo = procInfo;
    }

    public AwareProcessInfo(int pid, com.android.server.mtm.taskstatus.ProcessInfo procInfo) {
        this.mPid = pid;
        this.mProcInfo = procInfo;
    }

    public java.lang.String getProcessStatus() {
        if (this.mDetailedReason == null) {
            return null;
        }
        com.android.server.mtm.utils.AppStatusUtils.Status[] values = com.android.server.mtm.utils.AppStatusUtils.Status.values();
        java.lang.Integer statType = (java.lang.Integer) this.mDetailedReason.get(com.android.server.mtm.iaware.appmng.rule.RuleParserUtil.AppMngTag.STATUS.getDesc());
        if (statType == null || values.length <= statType.intValue() || statType.intValue() < 0) {
            return null;
        }
        return values[statType.intValue()].description();
    }

    public boolean isForegroundApp() {
        if (this.mDetailedReason == null) {
            return false;
        }
        java.lang.Integer statType = (java.lang.Integer) this.mDetailedReason.get(com.android.server.mtm.iaware.appmng.rule.RuleParserUtil.AppMngTag.STATUS.getDesc());
        if (statType == null) {
            return false;
        }
        if (com.android.server.mtm.utils.AppStatusUtils.Status.TOP_ACTIVITY.ordinal() == statType.intValue() || com.android.server.mtm.utils.AppStatusUtils.Status.FOREGROUND_APP.ordinal() == statType.intValue()) {
            return true;
        }
        return false;
    }

    public boolean isVisibleApp(int visibleAppAdj) {
        if (!(this.mDetailedReason == null || this.mProcInfo == null)) {
            if (this.mProcInfo.mCurAdj == visibleAppAdj) {
                java.lang.Integer statType = (java.lang.Integer) this.mDetailedReason.get(com.android.server.mtm.iaware.appmng.rule.RuleParserUtil.AppMngTag.STATUS.getDesc());
                if (statType != null && com.android.server.mtm.utils.AppStatusUtils.Status.VISIBLE_APP.ordinal() == statType.intValue()) {
                    return true;
                }
                return false;
            }
        }
        return false;
    }

    public boolean isAwareProtected() {
        if (android.text.TextUtils.isEmpty(this.mReason)) {
            return false;
        }
        return android.app.mtm.iaware.appmng.AppMngConstant.CleanReason.LIST.getCode().equals(this.mReason);
    }

    public java.lang.String getStatisticsInfo() {
        java.lang.StringBuilder build = new java.lang.StringBuilder();
        build.append("proc info pid:");
        build.append(this.mPid);
        build.append(",classRate:");
        build.append(this.mClassRate);
        build.append(",");
        build.append(getClassRateStr());
        build.append(",importance:");
        build.append(this.mImportance);
        if (this.mProcInfo != null) {
            if (this.mProcInfo.mPackageName != null) {
                build.append(",packageName:");
                int size = this.mProcInfo.mPackageName.size();
                for (int i = 0; i < size; i++) {
                    java.lang.String pkg = (java.lang.String) this.mProcInfo.mPackageName.get(i);
                    build.append(" ");
                    build.append(pkg);
                }
            }
            build.append(",procName:");
            build.append(this.mProcInfo.mProcessName);
            build.append(",adj:");
            build.append(this.mProcInfo.mCurAdj);
        }
        return build.toString();
    }

    public java.lang.String getClassRateStr() {
        return com.android.server.mtm.iaware.appmng.AwareAppMngSort.getClassRateStr(this.mClassRate);
    }

    public static java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcInfosList() {
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> awareProcList = new java.util.ArrayList();
        com.android.server.mtm.taskstatus.ProcessInfoCollector processInfoCollector = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance();
        if (processInfoCollector == null) {
            return awareProcList;
        }
        java.util.List<com.android.server.mtm.taskstatus.ProcessInfo> procList = processInfoCollector.getProcessInfoList();
        if (procList.isEmpty()) {
            return awareProcList;
        }
        int size = procList.size();
        for (int i = 0; i < size; i++) {
            com.android.server.mtm.taskstatus.ProcessInfo procInfo = (com.android.server.mtm.taskstatus.ProcessInfo) procList.get(i);
            awareProcList.add(new com.android.server.mtm.iaware.appmng.AwareProcessInfo(procInfo.mPid, 0, 0, com.android.server.mtm.iaware.appmng.AwareAppMngSort.ClassRate.NORMAL.ordinal(), procInfo));
        }
        return awareProcList;
    }

    public static java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcInfosFromPackage(java.lang.String packageName, int userId) {
        java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> awareProcList = new java.util.ArrayList();
        if (packageName != null) {
            if (userId >= 0) {
                if (packageName.equals("")) {
                    return awareProcList;
                }
                com.android.server.mtm.taskstatus.ProcessInfoCollector processInfoCollector = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance();
                if (processInfoCollector == null) {
                    return awareProcList;
                }
                java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList = processInfoCollector.getProcessInfosFromPackage(packageName, userId);
                if (procList.isEmpty()) {
                    return awareProcList;
                }
                int size = procList.size();
                for (int i = 0; i < size; i++) {
                    com.android.server.mtm.taskstatus.ProcessInfo procInfo = (com.android.server.mtm.taskstatus.ProcessInfo) procList.get(i);
                    awareProcList.add(new com.android.server.mtm.iaware.appmng.AwareProcessInfo(procInfo.mPid, 0, 0, com.android.server.mtm.iaware.appmng.AwareAppMngSort.ClassRate.NORMAL.ordinal(), procInfo));
                }
                return awareProcList;
            }
        }
        return awareProcList;
    }

    public static java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcInfosFromPackageList(java.util.List<java.lang.String> packlist, java.util.List<java.lang.Integer> uidList) {
        java.util.List<java.lang.String> list = packlist;
        java.util.List<java.lang.Integer> list2 = uidList;
        java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> awareProcList = new java.util.ArrayList();
        if (list != null) {
            if (list2 != null) {
                if (packlist.size() != uidList.size()) {
                    return awareProcList;
                }
                com.android.server.mtm.taskstatus.ProcessInfoCollector processInfoCollector = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance();
                if (processInfoCollector == null) {
                    return awareProcList;
                }
                android.util.ArrayMap<java.lang.String, java.lang.Integer> packMap = new android.util.ArrayMap();
                int listSize = packlist.size();
                for (int i = 0; i < listSize; i++) {
                    packMap.put((java.lang.String) list.get(i), (java.lang.Integer) list2.get(i));
                }
                java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList = processInfoCollector.getProcessInfosFromPackageMap(packMap);
                if (procList.isEmpty()) {
                    return awareProcList;
                }
                int size = procList.size();
                for (int i2 = 0; i2 < size; i2++) {
                    com.android.server.mtm.taskstatus.ProcessInfo procInfo = (com.android.server.mtm.taskstatus.ProcessInfo) procList.get(i2);
                    awareProcList.add(new com.android.server.mtm.iaware.appmng.AwareProcessInfo(procInfo.mPid, 0, 0, com.android.server.mtm.iaware.appmng.AwareAppMngSort.ClassRate.NORMAL.ordinal(), procInfo));
                }
                return awareProcList;
            }
        }
        return awareProcList;
    }

    public static java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcInfosFromTask(int taskId, int userId) {
        java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> awareProcList = new java.util.ArrayList();
        if (taskId >= 0) {
            if (userId >= 0) {
                com.android.server.mtm.taskstatus.ProcessInfoCollector processInfoCollector = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance();
                if (processInfoCollector == null) {
                    return awareProcList;
                }
                java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList = processInfoCollector.getProcessInfosFromTask(taskId, userId);
                if (procList.isEmpty()) {
                    return awareProcList;
                }
                int size = procList.size();
                for (int i = 0; i < size; i++) {
                    com.android.server.mtm.taskstatus.ProcessInfo procInfo = (com.android.server.mtm.taskstatus.ProcessInfo) procList.get(i);
                    com.android.server.mtm.iaware.appmng.AwareProcessInfo awareProcInfo = new com.android.server.mtm.iaware.appmng.AwareProcessInfo(procInfo.mPid, 0, 0, com.android.server.mtm.iaware.appmng.AwareAppMngSort.ClassRate.NORMAL.ordinal(), procInfo);
                    awareProcInfo.mTaskId = taskId;
                    awareProcList.add(awareProcInfo);
                }
                return awareProcList;
            }
        }
        return awareProcList;
    }

    public static java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcInfosFromTaskList(java.util.List<java.lang.Integer> taskIdList, java.util.List<java.lang.Integer> userIdList) {
        if (!(taskIdList == null || userIdList == null)) {
            if (taskIdList.size() == userIdList.size()) {
                java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> awareProcList = new java.util.ArrayList();
                int listSize = taskIdList.size();
                for (int i = 0; i < listSize; i++) {
                    awareProcList.addAll(getAwareProcInfosFromTask(((java.lang.Integer) taskIdList.get(i)).intValue(), ((java.lang.Integer) userIdList.get(i)).intValue()));
                }
                return awareProcList;
            }
        }
        return null;
    }

    public int getState() {
        if (this.mState == 1) {
            return this.mState;
        }
        if (this.mProcInfo == null || (!this.mProcInfo.mForegroundActivities && !this.mProcInfo.mForegroundServices && !this.mProcInfo.mForceToForeground)) {
            return this.mState;
        }
        return 9;
    }

    public void setState(int state) {
        switch (state) {
            case 1:
                this.isFreeze = true;
                break;
            case 2:
                this.isFreeze = false;
                break;
            case 3:
                this.isStandBy = true;
                break;
            case 4:
                this.isStandBy = false;
                break;
            case 5:
                this.isRare = true;
                break;
            case 6:
                this.isRare = false;
                break;
            case 7:
                this.isFas = true;
                break;
            case 8:
                this.isFas = false;
                break;
            default:
                break;
        }
        resetState();
    }

    private void resetState() {
        if (this.isFreeze) {
            this.mState = 1;
        } else if (this.isFas) {
            this.mState = 7;
        } else if (this.isRare) {
            this.mState = 5;
        } else if (this.isStandBy) {
            this.mState = 3;
        } else {
            this.mState = 10;
        }
    }

    public void updateProcessInfo(com.android.server.mtm.taskstatus.ProcessInfo procInfo) {
        this.mProcInfo = procInfo;
    }

    public void updateBrPolicy() {
        com.android.server.mtm.iaware.appmng.rule.BroadcastMngRule brRule = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getBroadcastMngRule(android.app.mtm.iaware.appmng.AppMngConstant.BroadcastSource.BROADCAST_FILTER);
        if (brRule != null) {
            android.util.ArrayMap<java.lang.String, com.android.server.mtm.iaware.appmng.rule.RuleNode> rules = brRule.getBrRules();
            synchronized (this.mBrPolicys) {
                for (java.util.Map.Entry<java.lang.String, com.android.server.mtm.iaware.appmng.rule.RuleNode> ent : rules.entrySet()) {
                    java.lang.String action = (java.lang.String) ent.getKey();
                    com.android.server.mtm.iaware.appmng.rule.RuleNode node = (com.android.server.mtm.iaware.appmng.rule.RuleNode) ent.getValue();
                    com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy brPolicy = (com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy) this.mBrPolicys.get(action);
                    java.lang.String id = (java.lang.String) this.mProcInfo.mPackageName.get(0);
                    android.content.Intent intent = new android.content.Intent(action);
                    if (brPolicy == null) {
                        brPolicy = new com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy(id, 0, getState());
                        this.mBrPolicys.put(action, brPolicy);
                    }
                    com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy brPolicy2 = brPolicy;
                    brPolicy2.setPolicy(brRule.updateApply(android.app.mtm.iaware.appmng.AppMngConstant.BroadcastSource.BROADCAST_FILTER, id, intent, this, node));
                    brPolicy2.setStae(getState());
                }
            }
        }
    }

    public com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy getBrPolicy(android.content.Intent intent) {
        synchronized (this.mBrPolicys) {
            if (intent == null) {
                try {
                    return null;
                } catch (Throwable th) {
                }
            } else {
                com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy brFilterPolicy = (com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy) this.mBrPolicys.get(intent.getAction());
                return brFilterPolicy;
            }
        }
    }

    public android.util.ArrayMap<java.lang.String, com.android.server.mtm.iaware.appmng.policy.BrFilterPolicy> getBrFilterPolicyMap() {
        android.util.ArrayMap arrayMap;
        synchronized (this.mBrPolicys) {
            arrayMap = new android.util.ArrayMap(this.mBrPolicys);
        }
        return arrayMap;
    }
}
