package com.android.server.mtm.iaware.appmng.appstart.datamgr;

class HsmDataCache {
    private static final java.lang.String BOOTCACHE_KEY_BLIND = "blind";
    private static final java.lang.String BOOTCACHE_KEY_SEPARATOR = ":";
    private static final java.lang.String BOOTCACHE_KEY_WIDGET = "widget";
    public static final long INVALID_ELAPSETIME = -1;
    private static final java.lang.String STARTUP_SETTING_SEPARATOR = "_";
    private static final java.lang.String TAG = "HsmDataCache";
    private java.util.Set<java.lang.String> mBlindPkgs = new android.util.ArraySet();
    private com.android.server.mtm.iaware.appmng.appstart.datamgr.CacheFileRW mCachedBootListFile;
    private com.android.server.mtm.iaware.appmng.appstart.datamgr.CacheFileRW mSettingListFile;
    private java.util.Map<java.lang.String, android.app.mtm.iaware.HwAppStartupSetting> mStartupSetting = new android.util.ArrayMap();
    private java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> mWidgetPkgs = new android.util.ArrayMap();

    private static class WidgetUpdateInfo {
        public long mUpdateElapse;

        public WidgetUpdateInfo(long updateElapse) {
            this.mUpdateElapse = updateElapse;
        }
    }

    public HsmDataCache() {
        java.io.File file = new java.io.File(new java.io.File(android.os.Environment.getDataDirectory(), "system"), "appstart");
        if (!(file.exists() || file.mkdirs())) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Fail to make dir ");
            stringBuilder.append(file.getPath());
            android.rms.iaware.AwareLog.w("HsmDataCache", stringBuilder.toString());
        }
        this.mCachedBootListFile = new com.android.server.mtm.iaware.appmng.appstart.datamgr.CacheFileRW(new java.io.File(file, "appstart_cached_boot.list"));
        java.io.File settingListFile = new java.io.File(file, "appstart_cached_setting.list");
        this.mSettingListFile = new com.android.server.mtm.iaware.appmng.appstart.datamgr.CacheFileRW(settingListFile);
        if (!settingListFile.exists()) {
            android.os.SystemProperties.set("persist.sys.appstart.sync", "true");
            android.rms.iaware.AwareLog.w("HsmDataCache", "HSM need sync since the list file is not exist");
        }
    }

    public android.app.mtm.iaware.HwAppStartupSetting getAppStartupSetting(java.lang.String pkgName) {
        synchronized (this.mStartupSetting) {
            android.app.mtm.iaware.HwAppStartupSetting setting = (android.app.mtm.iaware.HwAppStartupSetting) this.mStartupSetting.get(pkgName);
            if (checkAppStartupSetting(setting)) {
                android.app.mtm.iaware.HwAppStartupSetting hwAppStartupSetting = new android.app.mtm.iaware.HwAppStartupSetting(setting);
                return hwAppStartupSetting;
            }
            return null;
        }
    }

    public java.util.List<android.app.mtm.iaware.HwAppStartupSetting> retrieveStartupSettings(java.util.List<java.lang.String> pkgList, android.app.mtm.iaware.HwAppStartupSettingFilter filter) {
        int[] policy = null;
        int[] show = null;
        int[] modifier = null;
        if (filter != null) {
            policy = filter.getPolicy();
            modifier = filter.getModifier();
            show = filter.getShow();
        }
        java.util.List<android.app.mtm.iaware.HwAppStartupSetting> settingList = new java.util.ArrayList();
        synchronized (this.mStartupSetting) {
            android.app.mtm.iaware.HwAppStartupSetting setting;
            if (pkgList == null) {
                try {
                    for (java.util.Map.Entry<java.lang.String, android.app.mtm.iaware.HwAppStartupSetting> entry : this.mStartupSetting.entrySet()) {
                        setting = (android.app.mtm.iaware.HwAppStartupSetting) entry.getValue();
                        if (filterAppStartupSetting(setting, policy, modifier, show)) {
                            settingList.add(new android.app.mtm.iaware.HwAppStartupSetting(setting));
                        }
                    }
                } catch (Throwable th) {
                }
            } else {
                for (java.lang.String pkg : pkgList) {
                    setting = (android.app.mtm.iaware.HwAppStartupSetting) this.mStartupSetting.get(pkg);
                    if (filterAppStartupSetting(setting, policy, modifier, show)) {
                        settingList.add(new android.app.mtm.iaware.HwAppStartupSetting(setting));
                    }
                }
            }
        }
        return settingList;
    }

    public boolean updateStartupSettings(java.util.List<android.app.mtm.iaware.HwAppStartupSetting> settingList, boolean clearFirst) {
        if (settingList != null) {
            if (settingList.size() != 0) {
                boolean success = false;
                if (clearFirst) {
                    clearStartupSettingCache();
                }
                for (android.app.mtm.iaware.HwAppStartupSetting item : settingList) {
                    if (updateSingleSetting(item)) {
                        success = true;
                    }
                }
                return success;
            }
        }
        return false;
    }

    public boolean removeStartupSetting(java.lang.String pkgName) {
        boolean z;
        synchronized (this.mStartupSetting) {
            z = this.mStartupSetting.remove(pkgName) != null;
        }
        return z;
    }

    public void loadStartupSettingCache() {
        loadDiskStartupSetting();
    }

    public void loadBootCache() {
        java.util.List<java.lang.String> cachedList = new java.util.ArrayList();
        loadDiskCachedBootLocked(cachedList);
        java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> widgetPkgs = new android.util.ArrayMap();
        java.util.Set<java.lang.String> blindPkgs = new android.util.ArraySet();
        long curTime = android.os.SystemClock.elapsedRealtime();
        for (java.lang.String bootCached : cachedList) {
            if (bootCached != null) {
                java.lang.String[] bootPkgList = bootCached.split(":");
                if (bootPkgList.length > 1) {
                    java.lang.String keyString = bootPkgList[null];
                    java.lang.String valueString = bootPkgList[1];
                    if ("widget".equals(keyString)) {
                        widgetPkgs.put(valueString, new com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo(curTime));
                    } else if ("blind".equals(keyString)) {
                        blindPkgs.add(valueString);
                    }
                }
            }
        }
        this.mWidgetPkgs = widgetPkgs;
        this.mBlindPkgs = blindPkgs;
    }

    public void clearStartupSettingCache() {
        synchronized (this.mStartupSetting) {
            this.mStartupSetting.clear();
        }
    }

    private boolean checkAppStartupSetting(android.app.mtm.iaware.HwAppStartupSetting setting) {
        return setting != null && setting.valid();
    }

    private boolean filterAppStartupSetting(android.app.mtm.iaware.HwAppStartupSetting setting, int[] policy, int[] modifier, int[] show) {
        if (!checkAppStartupSetting(setting)) {
            return false;
        }
        int i;
        if (policy != null) {
            i = 0;
            while (i < policy.length) {
                if (policy[i] != -1 && policy[i] != setting.getPolicy(i)) {
                    return false;
                }
                i++;
            }
        }
        if (show != null) {
            i = 0;
            while (i < show.length) {
                if (show[i] != -1 && show[i] != setting.getShow(i)) {
                    return false;
                }
                i++;
            }
        }
        if (modifier != null) {
            i = 0;
            while (i < modifier.length) {
                if (modifier[i] != -1 && modifier[i] != setting.getModifier(i)) {
                    return false;
                }
                i++;
            }
        }
        return true;
    }

    /* JADX WARNING: Missing block: B:17:0x0047, code:
            return true;
     */
    private boolean updateSingleSetting(android.app.mtm.iaware.HwAppStartupSetting r7) {
        /*
        r6 = this;
        if (r7 == 0) goto L_0x0007;
    L_0x0002:
        r0 = r7.getPackageName();
        goto L_0x0009;
    L_0x0007:
        r0 = "";
    L_0x0009:
        r1 = r6.mStartupSetting;
        monitor-enter(r1);
        r2 = r6.mStartupSetting;	 Catch:{ all -> 0x0048 }
        r2 = r2.get(r0);	 Catch:{ all -> 0x0048 }
        r2 = (android.app.mtm.iaware.HwAppStartupSetting) r2;	 Catch:{ all -> 0x0048 }
        if (r2 != 0) goto L_0x003c;
    L_0x0016:
        r3 = r6.checkAppStartupSetting(r7);	 Catch:{ all -> 0x0048 }
        if (r3 == 0) goto L_0x0022;
    L_0x001c:
        r3 = r6.mStartupSetting;	 Catch:{ all -> 0x0048 }
        r3.put(r0, r7);	 Catch:{ all -> 0x0048 }
        goto L_0x0045;
    L_0x0022:
        r3 = "HsmDataCache";
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0048 }
        r4.<init>();	 Catch:{ all -> 0x0048 }
        r5 = "updateSingleSetting invalid setting: ";
        r4.append(r5);	 Catch:{ all -> 0x0048 }
        r4.append(r7);	 Catch:{ all -> 0x0048 }
        r4 = r4.toString();	 Catch:{ all -> 0x0048 }
        android.rms.iaware.AwareLog.w(r3, r4);	 Catch:{ all -> 0x0048 }
        r3 = 0;
        monitor-exit(r1);	 Catch:{ all -> 0x0048 }
        return r3;
    L_0x003c:
        r3 = r6.mStartupSetting;	 Catch:{ all -> 0x0048 }
        r4 = r2.copyValidInfo(r7);	 Catch:{ all -> 0x0048 }
        r3.put(r0, r4);	 Catch:{ all -> 0x0048 }
    L_0x0045:
        monitor-exit(r1);	 Catch:{ all -> 0x0048 }
        r1 = 1;
        return r1;
    L_0x0048:
        r2 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x0048 }
        throw r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.updateSingleSetting(android.app.mtm.iaware.HwAppStartupSetting):boolean");
    }

    public void updateWidgetPkgList(java.util.Set<java.lang.String> pkgList) {
        java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> cachedPkgs = new android.util.ArrayMap();
        java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> cachedPkgsOld = this.mWidgetPkgs;
        for (java.lang.String pkg : pkgList) {
            com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo updateInfo = (com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo) cachedPkgsOld.get(pkg);
            if (updateInfo == null) {
                updateInfo = new com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo(android.os.SystemClock.elapsedRealtime());
            }
            cachedPkgs.put(pkg, updateInfo);
        }
        this.mWidgetPkgs = cachedPkgs;
    }

    public void updateWidgetUpdateTime(java.lang.String pkgName) {
        com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo updateInfo = (com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo) this.mWidgetPkgs.get(pkgName);
        if (updateInfo != null) {
            updateInfo.mUpdateElapse = android.os.SystemClock.elapsedRealtime();
        }
    }

    public boolean isWidgetExistPkg(java.lang.String pkgName) {
        return this.mWidgetPkgs.containsKey(pkgName);
    }

    public int getWidgetExistPkgCnt() {
        return this.mWidgetPkgs.size();
    }

    public long getWidgetExistPkgUpdateTime(java.lang.String pkgName) {
        com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo updateInfo = (com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo) this.mWidgetPkgs.get(pkgName);
        if (updateInfo == null) {
            return -1;
        }
        return updateInfo.mUpdateElapse;
    }

    public void updateBlindPkg(java.util.Set<java.lang.String> pkgSet) {
        java.util.Set<java.lang.String> cachedPkgs = new android.util.ArraySet();
        cachedPkgs.addAll(pkgSet);
        this.mBlindPkgs = cachedPkgs;
    }

    public boolean isBlindAssistPkg(java.lang.String pkgName) {
        return this.mBlindPkgs.contains(pkgName);
    }

    public void flushStartupSettingToDisk() {
        writeDiskStartupSetting();
    }

    public void flushBootCacheDataToDisk() {
        writeDiskCachedBootLocked();
    }

    private void loadDiskStartupSetting() {
        synchronized (this.mSettingListFile) {
            java.util.List<java.lang.String> lines = this.mSettingListFile.readFileLines();
        }
        synchronized (this.mStartupSetting) {
            for (java.lang.String line : lines) {
                fromStringLine(line);
            }
        }
    }

    private void loadDiskCachedBootLocked(java.util.List<java.lang.String> pkgList) {
        java.util.List<java.lang.String> lines;
        synchronized (this.mCachedBootListFile) {
            lines = this.mCachedBootListFile.readFileLines();
        }
        pkgList.addAll(lines);
    }

    private void appendCachedBootToList(java.lang.String key, java.util.List<java.lang.String> cachedList, java.util.Set<java.lang.String> pkgs) {
        for (java.lang.String pkg : pkgs) {
            if (pkg != null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(key);
                stringBuilder.append(":");
                stringBuilder.append(pkg);
                cachedList.add(stringBuilder.toString());
            }
        }
    }

    private void writeDiskCachedBootLocked() {
        java.util.List<java.lang.String> cachedList = new java.util.ArrayList();
        java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> widgetPkgs = this.mWidgetPkgs;
        java.util.Set<java.lang.String> blindPkgs = this.mBlindPkgs;
        appendCachedBootToList("widget", cachedList, widgetPkgs.keySet());
        appendCachedBootToList("blind", cachedList, blindPkgs);
        synchronized (this.mCachedBootListFile) {
            this.mCachedBootListFile.writeFileLines(cachedList);
        }
    }

    private void writeDiskStartupSetting() {
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        synchronized (this.mStartupSetting) {
            for (java.util.Map.Entry<java.lang.String, android.app.mtm.iaware.HwAppStartupSetting> entry : this.mStartupSetting.entrySet()) {
                result.add(toStringLine(entry));
            }
        }
        synchronized (this.mSettingListFile) {
            this.mSettingListFile.writeFileLines(result);
        }
    }

    private void fromStringLine(java.lang.String line) {
        if (!android.text.TextUtils.isEmpty(line)) {
            try {
                int[] config = new int[12];
                java.lang.String pkgName = line;
                for (int i = 0; i < config.length; i++) {
                    config[i] = -1;
                    int lastIndex = pkgName.lastIndexOf("_");
                    if (lastIndex >= 0 && lastIndex == pkgName.length() - 2) {
                        config[i] = java.lang.Integer.parseInt(pkgName.substring(lastIndex + 1));
                        pkgName = pkgName.substring(0, lastIndex);
                    }
                }
                android.app.mtm.iaware.HwAppStartupSetting item = new android.app.mtm.iaware.HwAppStartupSetting(pkgName, new int[]{config[11], config[10], config[9], config[8]}, new int[]{config[7], config[6], config[5], config[4]}, new int[]{config[3], config[2], config[1], config[0]});
                if (item.valid()) {
                    this.mStartupSetting.put(pkgName, item);
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("fromStringLine invalid record line: ");
                    stringBuilder.append(line);
                    android.rms.iaware.AwareLog.e("HsmDataCache", stringBuilder.toString());
                }
            } catch (java.lang.NumberFormatException e) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("fromStringLine invalid record line: ");
                stringBuilder2.append(line);
                android.rms.iaware.AwareLog.e("HsmDataCache", stringBuilder2.toString());
            }
        }
    }

    private java.lang.String toStringLine(java.util.Map.Entry<java.lang.String, android.app.mtm.iaware.HwAppStartupSetting> entry) {
        int i;
        android.app.mtm.iaware.HwAppStartupSetting item = (android.app.mtm.iaware.HwAppStartupSetting) entry.getValue();
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append(item.getPackageName());
        sb.append("_");
        int i2 = 0;
        for (i = 0; i < 4; i++) {
            sb.append(item.getPolicy(i));
            sb.append("_");
        }
        for (i = 0; i < 4; i++) {
            sb.append(item.getModifier(i));
            sb.append("_");
        }
        while (i2 < 4) {
            sb.append(item.getShow(i2));
            if (i2 < 3) {
                sb.append("_");
            }
            i2++;
        }
        return sb.toString();
    }

    public java.lang.String toString() {
        java.lang.StringBuilder cacheStr = new java.lang.StringBuilder();
        if (com.android.server.rms.iaware.srms.AppStartupFeature.isAppStartupEnabled()) {
            java.util.Map<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> widgetPkgs = this.mWidgetPkgs;
            java.util.Set<java.lang.String> blindPkgs = this.mBlindPkgs;
            cacheStr.append("Widgets(");
            cacheStr.append(widgetPkgs.keySet().size());
            cacheStr.append("):");
            for (java.util.Map.Entry<java.lang.String, com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo> m : widgetPkgs.entrySet()) {
                cacheStr.append("\n  ");
                cacheStr.append((java.lang.String) m.getKey());
                cacheStr.append("  sec:");
                cacheStr.append((android.os.SystemClock.elapsedRealtime() - ((com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache.WidgetUpdateInfo) m.getValue()).mUpdateElapse) / 1000);
            }
            cacheStr.append("\nBlind(");
            cacheStr.append(blindPkgs.size());
            cacheStr.append("):");
            for (java.lang.String blindPkg : blindPkgs) {
                cacheStr.append("\n  ");
                cacheStr.append(blindPkg);
            }
        }
        synchronized (this.mStartupSetting) {
            cacheStr.append("\nStartupSetting(");
            cacheStr.append(this.mStartupSetting.size());
            cacheStr.append("):");
            for (java.util.Map.Entry<java.lang.String, android.app.mtm.iaware.HwAppStartupSetting> entry : this.mStartupSetting.entrySet()) {
                cacheStr.append("\n  ");
                cacheStr.append((android.app.mtm.iaware.HwAppStartupSetting) entry.getValue());
            }
        }
        return cacheStr.toString();
    }
}
