package com.android.server.mtm.iaware.brjob.controller;

public class BarStatusController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_NAME = "BarStatus";
    private static final java.lang.String EXTRA_VISIBLE = "visible";
    private static final java.lang.String INTENT_STATUSBAR_VISIBLE_CHANGE = "com.android.systemui.statusbar.visible.change";
    private static final java.lang.String TAG = "BarStatusController";
    private static com.android.server.mtm.iaware.brjob.controller.BarStatusController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    private android.content.BroadcastReceiver mBarStatusReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if ("com.android.systemui.statusbar.visible.change".equals(intent.getAction())) {
                    com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.updateBarVisible(intent);
                    synchronized (com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.mLock) {
                        boolean changeToSatisfied = false;
                        java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> changedJobs = new java.util.ArrayList();
                        java.util.Iterator it = com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.mTrackedJobs.iterator();
                        while (it.hasNext()) {
                            com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) it.next();
                            java.lang.String value = job.getActionFilterValue("BarStatus");
                            if (com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.mIsVisible.equals(value) && !job.isSatisfied("BarStatus")) {
                                job.setSatisfied("BarStatus", true);
                                changeToSatisfied = true;
                                changedJobs.add(job);
                            } else if (!com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.mIsVisible.equals(value) && job.isSatisfied("BarStatus")) {
                                job.setSatisfied("BarStatus", false);
                            }
                        }
                        if (changeToSatisfied) {
                            if (com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.DEBUG) {
                                android.rms.iaware.AwareLog.i("BarStatusController", "iaware_brjob onControllerStateChanged");
                            }
                            com.android.server.mtm.iaware.brjob.controller.BarStatusController.this.mStateChangedListener.onControllerStateChanged(changedJobs);
                        }
                    }
                }
            }
        }
    };
    private java.lang.String mIsVisible = "OFF";
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.BarStatusController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.BarStatusController barStatusController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.BarStatusController(jms, jms.getContext(), jms.getLock());
            }
            barStatusController = mSingleton;
        }
        return barStatusController;
    }

    private BarStatusController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
        if (this.mContext != null) {
            this.mContext.registerReceiverAsUser(this.mBarStatusReceiver, android.os.UserHandle.SYSTEM, new android.content.IntentFilter("com.android.systemui.statusbar.visible.change"), null, null);
        }
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("BarStatus")) {
            java.lang.String value = job.getActionFilterValue("BarStatus");
            java.lang.String action = job.getAction();
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob start tracking, action:");
                stringBuilder.append(action);
                stringBuilder.append(", value: ");
                stringBuilder.append(value);
                android.rms.iaware.AwareLog.i("BarStatusController", stringBuilder.toString());
            }
            if ("com.android.systemui.statusbar.visible.change".equals(action)) {
                updateBarVisible(job.getIntent());
            }
            if (this.mIsVisible.equals(value)) {
                job.setSatisfied("BarStatus", true);
            } else {
                job.setSatisfied("BarStatus", false);
            }
            addJobLocked(this.mTrackedJobs, job);
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("BarStatus")) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.i("BarStatusController", "iaware_brjob stop tracking begin");
            }
            this.mTrackedJobs.remove(job);
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    BarStatusController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("        now bar status is: ");
            stringBuilder.append(this.mIsVisible);
            pw.println(stringBuilder.toString());
        }
    }

    private void updateBarVisible(android.content.Intent intent) {
        if (intent != null) {
            this.mIsVisible = java.lang.Boolean.parseBoolean(intent.getStringExtra("visible")) ? "ON" : "OFF";
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob bar status changed, now is: ");
                stringBuilder.append(this.mIsVisible);
                android.rms.iaware.AwareLog.i("BarStatusController", stringBuilder.toString());
            }
        }
    }
}
