package com.android.server.mtm.iaware.brjob.controller;

public class BluetoothStatusController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_NAME = "BluetoothStatus";
    private static final java.lang.String TAG = "BluetoothStatusController";
    private static com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    private android.content.BroadcastReceiver mBluetoothReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            if (action != null && "android.bluetooth.adapter.action.CONNECTION_STATE_CHANGED".equals(action)) {
                int state = intent.getIntExtra("android.bluetooth.adapter.extra.CONNECTION_STATE", -1);
                if (com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController.this.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brjob bluetooth receiver, state:");
                    stringBuilder.append(state);
                    android.rms.iaware.AwareLog.i("BluetoothStatusController", stringBuilder.toString());
                }
                if (state == 0) {
                    com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController.this.updateTrackedJobs("BLUETOOTHDSCON");
                } else if (state == 2) {
                    com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController.this.updateTrackedJobs("BLUETOOTHCON");
                }
            }
        }
    };
    private java.lang.String mBluetoothState = "UNKNOWN";
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController bluetoothStatusController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController(jms, jms.getContext(), jms.getLock());
            }
            bluetoothStatusController = mSingleton;
        }
        return bluetoothStatusController;
    }

    private BluetoothStatusController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
        if (this.mContext != null) {
            this.mContext.registerReceiverAsUser(this.mBluetoothReceiver, android.os.UserHandle.SYSTEM, new android.content.IntentFilter("android.bluetooth.adapter.action.CONNECTION_STATE_CHANGED"), null, null);
        }
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("BluetoothStatus")) {
            java.lang.String filterValue = job.getActionFilterValue("BluetoothStatus");
            this.mBluetoothState = getBluetoothState();
            if (this.mBluetoothState.equals(filterValue)) {
                job.setSatisfied("BluetoothStatus", true);
            } else {
                job.setSatisfied("BluetoothStatus", false);
            }
            addJobLocked(this.mTrackedJobs, job);
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("BluetoothStatus")) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.i("BluetoothStatusController", "iaware_brjob stop tracking begin");
            }
            this.mTrackedJobs.remove(job);
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    BluetoothStatusController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("        now bluetooth state is ");
            stringBuilder.append(getBluetoothState());
            pw.println(stringBuilder.toString());
        }
    }

    private java.lang.String getBluetoothState() {
        android.bluetooth.BluetoothAdapter blueAdapter = android.bluetooth.BluetoothAdapter.getDefaultAdapter();
        java.lang.String bluetoothState = "UNKNOWN";
        if (blueAdapter == null) {
            return bluetoothState;
        }
        if (blueAdapter.isEnabled()) {
            int connectState = blueAdapter.getConnectionState();
            if (connectState == 2) {
                bluetoothState = "BLUETOOTHCON";
            } else if (connectState == 0) {
                bluetoothState = "BLUETOOTHDSCON";
            }
        } else {
            bluetoothState = "BLUETOOTHDSCON";
        }
        if (this.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob bluetooth state:");
            stringBuilder.append(bluetoothState);
            android.rms.iaware.AwareLog.i("BluetoothStatusController", stringBuilder.toString());
        }
        return bluetoothState;
    }

    /* JADX WARNING: Missing block: B:28:0x0072, code:
            return;
     */
    private void updateTrackedJobs(java.lang.String r9) {
        /*
        r8 = this;
        r0 = r8.mLock;
        monitor-enter(r0);
        r1 = 0;
        r2 = r8.mBluetoothState;	 Catch:{ all -> 0x0073 }
        r2 = r2.equals(r9);	 Catch:{ all -> 0x0073 }
        if (r2 == 0) goto L_0x000e;
    L_0x000c:
        monitor-exit(r0);	 Catch:{ all -> 0x0073 }
        return;
    L_0x000e:
        r8.mBluetoothState = r9;	 Catch:{ all -> 0x0073 }
        r2 = new java.util.ArrayList;	 Catch:{ all -> 0x0073 }
        r2.<init>();	 Catch:{ all -> 0x0073 }
        r3 = r8.mTrackedJobs;	 Catch:{ all -> 0x0073 }
        r3 = r3.iterator();	 Catch:{ all -> 0x0073 }
    L_0x001b:
        r4 = r3.hasNext();	 Catch:{ all -> 0x0073 }
        if (r4 == 0) goto L_0x005f;
    L_0x0021:
        r4 = r3.next();	 Catch:{ all -> 0x0073 }
        r4 = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) r4;	 Catch:{ all -> 0x0073 }
        r5 = "BluetoothStatus";
        r5 = r4.getActionFilterValue(r5);	 Catch:{ all -> 0x0073 }
        r6 = r8.mBluetoothState;	 Catch:{ all -> 0x0073 }
        r6 = r6.equals(r5);	 Catch:{ all -> 0x0073 }
        if (r6 == 0) goto L_0x0048;
    L_0x0035:
        r6 = "BluetoothStatus";
        r6 = r4.isSatisfied(r6);	 Catch:{ all -> 0x0073 }
        if (r6 != 0) goto L_0x0048;
    L_0x003d:
        r6 = "BluetoothStatus";
        r7 = 1;
        r4.setSatisfied(r6, r7);	 Catch:{ all -> 0x0073 }
        r1 = 1;
        r2.add(r4);	 Catch:{ all -> 0x0073 }
        goto L_0x005e;
    L_0x0048:
        r6 = r8.mBluetoothState;	 Catch:{ all -> 0x0073 }
        r6 = r6.equals(r5);	 Catch:{ all -> 0x0073 }
        if (r6 != 0) goto L_0x005e;
    L_0x0050:
        r6 = "BluetoothStatus";
        r6 = r4.isSatisfied(r6);	 Catch:{ all -> 0x0073 }
        if (r6 == 0) goto L_0x005e;
    L_0x0058:
        r6 = "BluetoothStatus";
        r7 = 0;
        r4.setSatisfied(r6, r7);	 Catch:{ all -> 0x0073 }
    L_0x005e:
        goto L_0x001b;
    L_0x005f:
        if (r1 == 0) goto L_0x0071;
    L_0x0061:
        r3 = r8.DEBUG;	 Catch:{ all -> 0x0073 }
        if (r3 == 0) goto L_0x006c;
    L_0x0065:
        r3 = "BluetoothStatusController";
        r4 = "iaware_brjob onControllerStateChanged";
        android.rms.iaware.AwareLog.i(r3, r4);	 Catch:{ all -> 0x0073 }
    L_0x006c:
        r3 = r8.mStateChangedListener;	 Catch:{ all -> 0x0073 }
        r3.onControllerStateChanged(r2);	 Catch:{ all -> 0x0073 }
    L_0x0071:
        monitor-exit(r0);	 Catch:{ all -> 0x0073 }
        return;
    L_0x0073:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0073 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController.updateTrackedJobs(java.lang.String):void");
    }
}
