package com.android.server.mtm.iaware.brjob.controller;

public class ConnectivityController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_NETWORK = "NetworkStatus";
    private static final java.lang.String CONDITION_WIFI = "WifiStatus";
    private static final java.lang.String TAG = "ConnectivityController";
    private static com.android.server.mtm.iaware.brjob.controller.ConnectivityController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    private android.net.ConnectivityManager mConnManager;
    private android.content.BroadcastReceiver mConnectivityReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brjob receive connectivity change :");
                    stringBuilder.append(intent);
                    android.rms.iaware.AwareLog.i("ConnectivityController", stringBuilder.toString());
                }
                if ("android.net.conn.CONNECTIVITY_CHANGE".equals(intent.getAction())) {
                    int type = intent.getIntExtra("networkType", -1);
                    if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("iaware_brjob connectivity change, type:");
                        stringBuilder2.append(type);
                        android.rms.iaware.AwareLog.i("ConnectivityController", stringBuilder2.toString());
                    }
                    if (type == 0 || type == 1) {
                        android.net.NetworkInfo info = null;
                        try {
                            info = (android.net.NetworkInfo) intent.getExtra("networkInfo");
                        } catch (java.lang.ClassCastException e) {
                            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                                android.rms.iaware.AwareLog.e("ConnectivityController", "iaware_brjob get NetworkInfo from intent error.");
                            }
                        }
                        if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                            java.lang.String str = "ConnectivityController";
                            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                            stringBuilder3.append("iaware_brjob connectivity change, info:");
                            stringBuilder3.append(info == null ? "null" : info);
                            android.rms.iaware.AwareLog.i(str, stringBuilder3.toString());
                        }
                        com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.updateTrackedJobs(info);
                    }
                }
            }
        }
    };
    private android.net.INetworkPolicyListener mNetPolicyListener = new android.net.INetworkPolicyListener.Stub() {
        public void onUidRulesChanged(int uid, int uidRules) {
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob onUidRulesChanged, do nothing ");
            }
        }

        public void onMeteredIfacesChanged(java.lang.String[] meteredIfaces) {
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob onMeteredIfacesChanged");
            }
            android.net.NetworkInfo info = com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.mConnManager != null ? com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.mConnManager.getActiveNetworkInfo() : null;
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                java.lang.String str = "ConnectivityController";
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob onMeteredIfacesChanged info: ");
                stringBuilder.append(info == null ? "null" : info);
                android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
            }
            com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.updateTrackedJobs(info);
        }

        public void onRestrictBackgroundChanged(boolean restrictBackground) {
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                android.rms.iaware.AwareLog.d("ConnectivityController", "iaware_brjob onRestrictBackgroundChanged");
            }
            android.net.NetworkInfo info = com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.mConnManager != null ? com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.mConnManager.getActiveNetworkInfo() : null;
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                java.lang.String str = "ConnectivityController";
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob onRestrictBackgroundChanged info: ");
                stringBuilder.append(info == null ? "null" : info);
                android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
            }
            com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.updateTrackedJobs(info);
        }

        public void onUidPoliciesChanged(int uid, int uidPolicies) {
            if (com.android.server.mtm.iaware.brjob.controller.ConnectivityController.this.DEBUG) {
                android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob onUidPoliciesChanged, do nothing ");
            }
        }

        public void onSubscriptionOverride(int subId, int overrideMask, int overrideValue) {
        }
    };
    private android.net.NetworkPolicyManager mNetPolicyManager;
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.ConnectivityController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.ConnectivityController connectivityController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.ConnectivityController(jms, jms.getContext(), jms.getLock());
            }
            connectivityController = mSingleton;
        }
        return connectivityController;
    }

    private ConnectivityController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
        if (context != null) {
            this.mConnManager = (android.net.ConnectivityManager) this.mContext.getSystemService(android.net.ConnectivityManager.class);
            this.mNetPolicyManager = (android.net.NetworkPolicyManager) this.mContext.getSystemService(android.net.NetworkPolicyManager.class);
            this.mContext.registerReceiverAsUser(this.mConnectivityReceiver, android.os.UserHandle.SYSTEM, new android.content.IntentFilter("android.net.conn.CONNECTIVITY_CHANGE"), null, null);
            this.mNetPolicyManager.registerListener(this.mNetPolicyListener);
        }
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("NetworkStatus") || job.hasConstraint("WifiStatus")) {
                java.lang.String netValue;
                java.lang.StringBuilder stringBuilder;
                boolean satisfied;
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob, start tracking.");
                }
                android.net.NetworkInfo info = getNetworkInfo();
                if (job.hasConstraint("NetworkStatus")) {
                    netValue = job.getActionFilterValue("NetworkStatus");
                    if (this.DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_brjob, netValue: ");
                        stringBuilder.append(netValue);
                        android.rms.iaware.AwareLog.i("ConnectivityController", stringBuilder.toString());
                    }
                    satisfied = false;
                    if (info == null) {
                        if ("MOBILEDATADSCON".equals(netValue)) {
                            satisfied = true;
                        }
                    } else if (isNetworkSatisfied(netValue, info)) {
                        satisfied = true;
                    } else {
                        satisfied = false;
                    }
                    job.setSatisfied("NetworkStatus", satisfied);
                }
                if (job.hasConstraint("WifiStatus")) {
                    netValue = job.getActionFilterValue("WifiStatus");
                    if (this.DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_brjob, wifiValue: ");
                        stringBuilder.append(netValue);
                        android.rms.iaware.AwareLog.i("ConnectivityController", stringBuilder.toString());
                    }
                    satisfied = false;
                    if (info == null) {
                        if ("WIFIDSCON".equals(netValue)) {
                            satisfied = true;
                        }
                    } else if (isWifiSatisfied(netValue, info)) {
                        satisfied = true;
                    } else {
                        satisfied = false;
                    }
                    job.setSatisfied("WifiStatus", satisfied);
                }
                addJobLocked(this.mTrackedJobs, job);
            }
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("NetworkStatus") || job.hasConstraint("WifiStatus")) {
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob stop tracking begin");
                }
                this.mTrackedJobs.remove(job);
            }
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.Object obj;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    ConnectivityController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("        now network info is ");
            if (this.mConnManager == null) {
                obj = "[connMngr = null]";
            } else {
                obj = this.mConnManager.getActiveNetworkInfo();
            }
            stringBuilder.append(obj);
            pw.println(stringBuilder.toString());
        }
    }

    private android.net.NetworkInfo getNetworkInfo() {
        android.net.NetworkInfo info = this.mConnManager != null ? this.mConnManager.getActiveNetworkInfo() : null;
        if (this.DEBUG) {
            java.lang.String str = "ConnectivityController";
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob getNetworkInfo: ");
            stringBuilder.append(info == null ? "null" : info);
            android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
        }
        if (info == null) {
            android.rms.iaware.AwareLog.w("ConnectivityController", "iaware_brjob network info is null.");
        }
        return info;
    }

    private boolean isWifiSatisfied(java.lang.String wifiValue, android.net.NetworkInfo info) {
        if ("WIFICON".equals(wifiValue)) {
            if (info.getType() == 1 && info.isConnected()) {
                return true;
            }
        } else if ("WIFIDSCON".equals(wifiValue)) {
            if (info.getType() == 1 && !info.isConnected()) {
                return true;
            }
            if (info.getType() != 1 && info.isConnected()) {
                return true;
            }
        }
        return false;
    }

    private boolean isNetworkSatisfied(java.lang.String netValue, android.net.NetworkInfo info) {
        if ("MOBILEDATACON".equals(netValue)) {
            if (info.getType() == 0 && info.isConnected()) {
                return true;
            }
        } else if ("MOBILEDATADSCON".equals(netValue)) {
            if (info.getType() == 0 && !info.isConnected()) {
                return true;
            }
            if (info.getType() != 0 && info.isConnected()) {
                return true;
            }
        } else if ("ALL".equals(netValue) && ((info.getType() == 0 || info.getType() == 1) && info.isConnected())) {
            return true;
        }
        return false;
    }

    private void updateTrackedJobs(android.net.NetworkInfo info) {
        synchronized (this.mLock) {
            boolean changed = false;
            java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> changedJobs = new java.util.ArrayList();
            int listSize = this.mTrackedJobs.size();
            for (int i = 0; i < listSize; i++) {
                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) this.mTrackedJobs.get(i);
                changed = updateJobSatisfiedLocked(job, info);
                if (changed) {
                    changedJobs.add(job);
                }
            }
            if (changed) {
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("ConnectivityController", "iaware_brjob onControllerStateChanged");
                }
                this.mStateChangedListener.onControllerStateChanged(changedJobs);
            }
        }
    }

    private boolean updateJobSatisfiedLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job, android.net.NetworkInfo info) {
        java.lang.String netValue = job.getActionFilterValue("NetworkStatus");
        java.lang.String wifiValue = job.getActionFilterValue("WifiStatus");
        boolean changed = false;
        if (info == null) {
            if ("MOBILEDATADSCON".equals(netValue) && !job.isSatisfied("NetworkStatus")) {
                job.setSatisfied("NetworkStatus", true);
                changed = true;
            }
            if ("WIFIDSCON".equals(wifiValue) && !job.isSatisfied("WifiStatus")) {
                job.setSatisfied("WifiStatus", true);
                changed = true;
            }
        } else {
            if (isNetworkSatisfied(netValue, info) && !job.isSatisfied("NetworkStatus")) {
                job.setSatisfied("NetworkStatus", true);
                changed = true;
            }
            if (isWifiSatisfied(wifiValue, info) && !job.isSatisfied("WifiStatus")) {
                job.setSatisfied("WifiStatus", true);
                changed = true;
            }
        }
        if (this.DEBUG) {
            java.lang.String str = "ConnectivityController";
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob updateJobSatisfiedLocked, netValue: ");
            stringBuilder.append(netValue);
            stringBuilder.append(", wifiValue: ");
            stringBuilder.append(wifiValue);
            stringBuilder.append(", changed: ");
            stringBuilder.append(changed);
            stringBuilder.append(", info: ");
            stringBuilder.append(info == null ? "null" : info);
            android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
        }
        return changed;
    }
}
