package com.android.server.mtm.iaware.brjob.controller;

public class KeyWordController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_EXTRA = "Extra";
    private static final java.lang.String CONDITION_KEYWORD = "KeyWord";
    private static final java.lang.String EXTRA_BOOLEAN = "boolean";
    private static final java.lang.String EXTRA_CHAR = "char";
    private static final java.lang.String EXTRA_DOUBLE = "double";
    private static final java.lang.String EXTRA_FLOAT = "float";
    private static final java.lang.String EXTRA_INT = "int";
    private static final java.lang.String EXTRA_LONG = "long";
    private static final java.lang.String EXTRA_OBJECT = "Object";
    private static final java.lang.String EXTRA_SHORT = "short";
    private static final int EXTRA_SPLIT_LENGTH = 3;
    private static final java.lang.String EXTRA_STRING = "String";
    private static final java.lang.String KEYWORD_HOST = "host";
    private static final java.lang.String KEYWORD_MIME = "mimeType";
    private static final java.lang.String KEYWORD_PACKAGE_NAME = "packageName";
    private static final java.lang.String KEYWORD_PATH = "path";
    private static final java.lang.String KEYWORD_PATH_PATTERN = "pathPattern";
    private static final java.lang.String KEYWORD_PATH_PREFIX = "pathPrefix";
    private static final java.lang.String KEYWORD_PORT = "port";
    private static final java.lang.String KEYWORD_SCHEME = "scheme";
    private static final int KEYWORD_SPLIT_LENGTH = 2;
    private static final int KEYWORD_SPLIT_PACKAGE_LENGTH = 3;
    private static final int KEYWORD_SPLIT_PACKAGE_VALUE_INDEX = 2;
    private static final java.lang.String KEYWORD_SSP = "ssp";
    private static final java.lang.String KEYWORD_SSP_PATTERN = "sspPattern";
    private static final java.lang.String KEYWORD_SSP_PREFIX = "sspPrefix";
    private static final java.lang.String TAG = "KeyWordController";
    private static com.android.server.mtm.iaware.brjob.controller.KeyWordController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();

    public static com.android.server.mtm.iaware.brjob.controller.KeyWordController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.KeyWordController keyWordController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.KeyWordController(jms, jms.getContext(), jms.getLock());
            }
            keyWordController = mSingleton;
        }
        return keyWordController;
    }

    private KeyWordController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("KeyWord") || job.hasConstraint("Extra")) {
                android.content.Intent intent = job.getIntent();
                if (this.DEBUG) {
                    java.lang.String str = "KeyWordController";
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brjob awarejobstatus, intent: ");
                    stringBuilder.append(intent);
                    stringBuilder.append(", extras: ");
                    stringBuilder.append(intent == null ? "null" : intent.getExtras());
                    android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
                }
                if (job.hasConstraint("KeyWord")) {
                    checkKeyword(job);
                } else if (job.hasConstraint("Extra")) {
                    checkExtra(job);
                }
            }
        }
    }

    private void checkKeyword(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        java.lang.StringBuilder stringBuilder;
        com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus awareJobStatus = job;
        java.lang.String filterValue = awareJobStatus.getActionFilterValue("KeyWord");
        if (this.DEBUG) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob checkKeyword: ");
            stringBuilder.append(filterValue);
            android.rms.iaware.AwareLog.i("KeyWordController", stringBuilder.toString());
        }
        int i = 0;
        if (android.text.TextUtils.isEmpty(filterValue)) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.w("KeyWordController", "iaware_brjob keyword config error!");
            }
            awareJobStatus.setSatisfied("KeyWord", false);
            return;
        }
        android.content.Intent intent = job.getIntent();
        if (intent == null) {
            android.rms.iaware.AwareLog.w("KeyWordController", "iaware_brjob intent is null.");
            awareJobStatus.setSatisfied("KeyWord", false);
            return;
        }
        java.lang.String[] keywords = filterValue.split("[\\[\\]]");
        android.content.IntentFilter filter = new android.content.IntentFilter(job.getAction());
        java.lang.String host = null;
        int i2 = 0;
        java.lang.String port = null;
        boolean specialFormat = false;
        while (true) {
            int i3 = i2;
            if (i3 < keywords.length) {
                java.lang.String filterValue2;
                if (!(keywords[i3] == null || keywords[i3].trim().length() == 0)) {
                    if (!":".equals(keywords[i3].trim())) {
                        java.lang.StringBuilder stringBuilder2;
                        java.lang.String[] values = keywords[i3].split("[:]");
                        java.lang.String[] pkgValues = keywords[i3].split("[:@]");
                        if (this.DEBUG) {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("iaware_brjob config keyword: ");
                            stringBuilder2.append(keywords[i3]);
                            android.rms.iaware.AwareLog.i("KeyWordController", stringBuilder2.toString());
                        }
                        if (pkgValues.length == 3) {
                            if (!"packageName".equals(pkgValues[i])) {
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("iaware_brjob KeyWord value format is wrong: ");
                                stringBuilder3.append(job.getComponentName());
                                android.rms.iaware.AwareLog.e("KeyWordController", stringBuilder3.toString());
                            } else if (checkPackgeKeyword(awareJobStatus, pkgValues, intent)) {
                                return;
                            }
                            specialFormat = true;
                        } else if (values.length != 2) {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("iaware_brjob KeyWord value format is wrong: ");
                            stringBuilder2.append(job.getComponentName());
                            android.rms.iaware.AwareLog.e("KeyWordController", stringBuilder2.toString());
                            awareJobStatus.setSatisfied("KeyWord", i);
                            return;
                        } else {
                            java.lang.String key = values[i];
                            java.lang.String value = values[1];
                            if (!android.text.TextUtils.isEmpty(key)) {
                                if (!android.text.TextUtils.isEmpty(value)) {
                                    if ("scheme".equals(key)) {
                                        filter.addDataScheme(value);
                                    } else if ("host".equals(key)) {
                                        host = value;
                                    } else if ("port".equals(key)) {
                                        port = value;
                                    } else if ("mimeType".equals(key)) {
                                        try {
                                            filter.addDataType(value);
                                        } catch (android.content.IntentFilter.MalformedMimeTypeException e) {
                                            android.content.IntentFilter.MalformedMimeTypeException malformedMimeTypeException = e;
                                            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob invalid mimeType!");
                                        }
                                    } else if ("path".equals(key)) {
                                        filter.addDataPath(value, 0);
                                    } else if ("pathPrefix".equals(key)) {
                                        filter.addDataPath(value, 1);
                                    } else if ("pathPattern".equals(key)) {
                                        filter.addDataPath(value, 2);
                                    } else if ("ssp".equals(key)) {
                                        filter.addDataSchemeSpecificPart(value, 0);
                                    } else if ("sspPrefix".equals(key)) {
                                        filter.addDataSchemeSpecificPart(value, 1);
                                    } else if ("sspPattern".equals(key)) {
                                        filter.addDataSchemeSpecificPart(value, 2);
                                    } else {
                                        stringBuilder = new java.lang.StringBuilder();
                                        filterValue2 = filterValue;
                                        stringBuilder.append("iaware_brjob invalid key: ");
                                        stringBuilder.append(key);
                                        android.rms.iaware.AwareLog.e("KeyWordController", stringBuilder.toString());
                                        i2 = i3 + 1;
                                        filterValue = filterValue2;
                                        i = 0;
                                    }
                                }
                            }
                        }
                    }
                    filterValue2 = filterValue;
                    i2 = i3 + 1;
                    filterValue = filterValue2;
                    i = 0;
                }
                filterValue2 = filterValue;
                i2 = i3 + 1;
                filterValue = filterValue2;
                i = 0;
            } else {
                if (specialFormat) {
                    filterValue = host;
                } else {
                    if (host != null) {
                        filter.addDataAuthority(host, port);
                    }
                    i = filter.match(intent.getAction(), job.getHwBroadcastRecord().getResolvedType(), intent.getScheme(), intent.getData(), null, "KeyWordController");
                    if (this.DEBUG) {
                        java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                        stringBuilder4.append("iaware_brjob filter match: ");
                        stringBuilder4.append(intent.getAction());
                        stringBuilder4.append(", ");
                        stringBuilder4.append(job.getHwBroadcastRecord().getResolvedType());
                        stringBuilder4.append(", ");
                        stringBuilder4.append(intent.getScheme());
                        stringBuilder4.append(", ");
                        stringBuilder4.append(intent.getData());
                        stringBuilder4.append(", result: ");
                        stringBuilder4.append(i);
                        android.rms.iaware.AwareLog.i("KeyWordController", stringBuilder4.toString());
                    }
                    if (i >= 0) {
                        awareJobStatus.setSatisfied("KeyWord", true);
                    } else {
                        awareJobStatus.setSatisfied("KeyWord", false);
                    }
                }
                return;
            }
        }
    }

    private boolean checkPackgeKeyword(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job, java.lang.String[] pkgValues, android.content.Intent intent) {
        if (intent.getData() == null) {
            android.rms.iaware.AwareLog.e("KeyWordController", "intent data is null.");
            job.setSatisfied("KeyWord", false);
            return false;
        }
        boolean result;
        java.lang.String pkgName = pkgValues[2];
        java.lang.String ssp = intent.getData().getSchemeSpecificPart();
        if (this.DEBUG) {
            java.lang.String str = "KeyWordController";
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob checkPackgeKeyword: ");
            stringBuilder.append(java.util.Arrays.toString(pkgValues));
            stringBuilder.append(", ssp: ");
            stringBuilder.append(ssp == null ? "null" : ssp);
            android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
        }
        if (ssp == null || pkgName == null || !ssp.contains(pkgName)) {
            result = false;
        } else {
            result = true;
        }
        job.setSatisfied("KeyWord", result);
        return result;
    }

    private void checkExtra(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        android.content.Intent intent = job.getIntent();
        if (intent == null) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob intent is null.");
            job.setSatisfied("Extra", false);
            return;
        }
        java.lang.String filterValue = job.getActionFilterValue("Extra");
        if (android.text.TextUtils.isEmpty(filterValue)) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.w("KeyWordController", "iaware_brjob extra config error!");
            }
            job.setSatisfied("Extra", false);
            return;
        }
        if (this.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob checkExtra: ");
            stringBuilder.append(filterValue);
            android.rms.iaware.AwareLog.w("KeyWordController", stringBuilder.toString());
        }
        java.lang.String[] extras = filterValue.split("[\\[\\]]");
        boolean hasMatch = false;
        int i = 0;
        while (i < extras.length) {
            if (!(extras[i] == null || extras[i].trim().length() == 0)) {
                if (!":".equals(extras[i].trim())) {
                    if (this.DEBUG) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("iaware_brjob compare extra: ");
                        stringBuilder2.append(extras[i]);
                        android.rms.iaware.AwareLog.i("KeyWordController", stringBuilder2.toString());
                    }
                    java.lang.String[] values = extras[i].split("[:@]");
                    if (values.length != 3) {
                        android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob extra value length is wrong.");
                        job.setSatisfied("Extra", false);
                        return;
                    } else if (match(values[0], values[1], values[2], intent)) {
                        hasMatch = true;
                        break;
                    }
                }
            }
            i++;
        }
        if (hasMatch) {
            job.setSatisfied("Extra", true);
        } else {
            job.setSatisfied("Extra", false);
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        if (jobStatus != null && this.DEBUG) {
            android.rms.iaware.AwareLog.i("KeyWordController", "iaware_brjob no tracked jobStatus.");
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            pw.println("    KeyWordController iaware_brjob nothing to dump.");
        }
    }

    public static boolean matchReg(java.lang.String key, java.lang.String type, java.lang.String value, android.content.Intent intent) {
        if (!(key == null || type == null || value == null)) {
            if (intent != null) {
                if (mSingleton != null) {
                    return mSingleton.match(key, type, value, intent);
                }
                return false;
            }
        }
        return false;
    }

    private boolean match(java.lang.String key, java.lang.String type, java.lang.String value, android.content.Intent intent) {
        if (type.equals("boolean")) {
            return matchBoolean(key, value, intent);
        }
        if (type.equals("int")) {
            return matchInt(key, value, intent);
        }
        if (type.equals("String")) {
            return matchString(key, value, intent);
        }
        if (type.equals("char")) {
            return matchChar(key, value, intent);
        }
        if (type.equals("short")) {
            return matchShort(key, value, intent);
        }
        if (type.equals("long")) {
            return matchLong(key, value, intent);
        }
        if (type.equals("double")) {
            return matchDouble(key, value, intent);
        }
        if (type.equals("float")) {
            return matchFloat(key, value, intent);
        }
        if (type.equals("Object")) {
            return matchObject(key, value, intent);
        }
        android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob type is error");
        return false;
    }

    private boolean matchBoolean(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        if (value.equals("true")) {
            return intent.getBooleanExtra(key, false);
        }
        if (value.equals("false")) {
            return 1 ^ intent.getBooleanExtra(key, true);
        }
        return false;
    }

    private boolean matchInt(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        try {
            int temp = java.lang.Integer.parseInt(value);
            if (intent.getIntExtra(key, temp - 1) == temp) {
                return true;
            }
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob value format error");
            return false;
        }
    }

    private boolean matchString(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        if (value.equals(intent.getStringExtra(key))) {
            return true;
        }
        return false;
    }

    private boolean matchChar(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        char[] chs = value.toCharArray();
        if (chs.length != 1) {
            return false;
        }
        char temp = chs[0];
        android.os.Bundle bundle = intent.getExtras();
        return bundle != null && bundle.getChar(key) == temp;
    }

    private boolean matchFloat(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        try {
            float temp = java.lang.Float.parseFloat(value);
            if (new java.math.BigDecimal((double) intent.getFloatExtra(key, temp - 1.0f)).equals(new java.math.BigDecimal((double) temp))) {
                return true;
            }
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob value format error");
            return false;
        }
    }

    private boolean matchDouble(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        try {
            double temp = java.lang.Double.parseDouble(value);
            if (new java.math.BigDecimal(intent.getDoubleExtra(key, temp - 1.0d)).equals(new java.math.BigDecimal(temp))) {
                return true;
            }
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob value format error");
            return false;
        }
    }

    private boolean matchShort(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        try {
            short temp = java.lang.Short.parseShort(value);
            if (intent.getShortExtra(key, (short) (temp - 1)) == temp) {
                return true;
            }
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob value format error");
            return false;
        }
    }

    private boolean matchLong(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        try {
            long temp = java.lang.Long.parseLong(value);
            if (intent.getLongExtra(key, temp - 1) == temp) {
                return true;
            }
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("KeyWordController", "iaware_brjob value format error");
            return false;
        }
    }

    private boolean matchObject(java.lang.String key, java.lang.String value, android.content.Intent intent) {
        android.os.Bundle extra = intent.getExtras();
        return (extra == null ? null : extra.get(key)) != null;
    }
}
