package com.android.server.mtm.iaware.brjob.controller;

public class LimitNumController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_DAY = "LimitNum#Day";
    private static final java.lang.String CONDITION_HOUR = "LimitNum#Hour";
    private static final long DAY_PERIOD_INTERVAL = 86400000;
    private static final long HOUR_PERIOD_INTERVAL = 3600000;
    private static final java.lang.String TAG = "LimitNumController";
    private static com.android.server.mtm.iaware.brjob.controller.LimitNumController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.LimitNumController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.LimitNumController limitNumController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.LimitNumController(jms, jms.getContext(), jms.getLock());
            }
            limitNumController = mSingleton;
        }
        return limitNumController;
    }

    private LimitNumController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("LimitNum#Day") || job.hasConstraint("LimitNum#Hour")) {
                java.lang.String filter;
                long interval;
                java.lang.String condition = "";
                if (job.hasConstraint("LimitNum#Day")) {
                    filter = job.getActionFilterValue("LimitNum#Day");
                    interval = 86400000;
                    condition = "LimitNum#Day";
                } else {
                    filter = job.getActionFilterValue("LimitNum#Hour");
                    interval = 3600000;
                    condition = "LimitNum#Hour";
                }
                if (this.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_brjob maybeStartTrackingJobLocked, ");
                    stringBuilder.append(condition);
                    android.rms.iaware.AwareLog.i("LimitNumController", stringBuilder.toString());
                }
                if (android.text.TextUtils.isEmpty(filter)) {
                    android.rms.iaware.AwareLog.w("LimitNumController", "iaware_brjob limitnum state value is null.");
                    job.setSatisfied(condition, false);
                    return;
                }
                java.lang.String receiverPkg = job.getReceiverPkg();
                java.lang.String action = job.getAction();
                if (android.text.TextUtils.isEmpty(action)) {
                    android.rms.iaware.AwareLog.w("LimitNumController", "iaware_brjob action is null.");
                    job.setSatisfied(condition, false);
                    return;
                }
                int launchCount = com.android.server.mtm.iaware.brjob.StartupByBroadcastRecorder.getInstance().getStartupCountsByBroadcast(receiverPkg, action, interval);
                if (this.DEBUG) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("iaware_brjob StartupCounts: ");
                    stringBuilder2.append(launchCount);
                    stringBuilder2.append("----");
                    stringBuilder2.append(filter);
                    android.rms.iaware.AwareLog.i("LimitNumController", stringBuilder2.toString());
                }
                int filterValue = 0;
                try {
                    if (java.lang.Integer.parseInt(filter) > launchCount) {
                        job.setSatisfied(condition, true);
                    } else {
                        job.setSatisfied(condition, false);
                    }
                    addJobLocked(this.mTrackedJobs, job);
                } catch (java.lang.NumberFormatException e) {
                    android.rms.iaware.AwareLog.e("LimitNumController", "iaware_brjob limitnum state value format is error, setShouldRunByError.");
                    job.setSatisfied(condition, false);
                }
            }
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("LimitNum#Day") || job.hasConstraint("LimitNum#Hour")) {
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("LimitNumController", "iaware_brjob stop tracking begin");
                }
                this.mTrackedJobs.remove(job);
            }
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    LimitNumController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            com.android.server.mtm.iaware.brjob.StartupByBroadcastRecorder.getInstance().dump(pw);
        }
    }
}
