package com.android.server.mtm.iaware.brjob.controller;

public class MinTimeController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_HOUR = "MinTime#Hour";
    private static final java.lang.String CONDITION_MINUTE = "MinTime#Minute";
    private static final long HOUR_PERIOD_INTERVAL = 3600000;
    private static final long MINUTE_PERIOD_INTERVAL = 60000;
    private static final java.lang.String TAG = "MinTimeController";
    private static com.android.server.mtm.iaware.brjob.controller.MinTimeController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.MinTimeController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.MinTimeController minTimeController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.MinTimeController(jms, jms.getContext(), jms.getLock());
            }
            minTimeController = mSingleton;
        }
        return minTimeController;
    }

    private MinTimeController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("MinTime#Hour") || job.hasConstraint("MinTime#Minute")) {
                java.lang.String filter;
                long intervalUnit;
                java.lang.String condition = "";
                if (job.hasConstraint("MinTime#Hour")) {
                    filter = job.getActionFilterValue("MinTime#Hour");
                    intervalUnit = 3600000;
                    condition = "MinTime#Hour";
                } else {
                    filter = job.getActionFilterValue("MinTime#Minute");
                    intervalUnit = 60000;
                    condition = "MinTime#Minute";
                }
                if (android.text.TextUtils.isEmpty(filter)) {
                    android.rms.iaware.AwareLog.w("MinTimeController", "iaware_brjob min time on hour state value is null.");
                    job.setSatisfied(condition, false);
                    return;
                }
                java.lang.String receiverPkg = job.getReceiverPkg();
                java.lang.String action = job.getAction();
                if (android.text.TextUtils.isEmpty(action)) {
                    android.rms.iaware.AwareLog.w("MinTimeController", "iaware_brjob action is null.");
                    job.setSatisfied(condition, false);
                    return;
                }
                int filterValue = 0;
                try {
                    if (com.android.server.mtm.iaware.brjob.StartupByBroadcastRecorder.getInstance().minTimeInterval(receiverPkg, action, ((long) java.lang.Integer.parseInt(filter)) * intervalUnit)) {
                        job.setSatisfied(condition, true);
                    } else {
                        job.setSatisfied(condition, false);
                    }
                    addJobLocked(this.mTrackedJobs, job);
                } catch (java.lang.NumberFormatException e) {
                    android.rms.iaware.AwareLog.e("MinTimeController", "iaware_brjob MinTime value format is error, setShouldRunByError.");
                    job.setSatisfied(condition, false);
                }
            }
        }
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null) {
            if (job.hasConstraint("MinTime#Hour") || job.hasConstraint("MinTime#Minute")) {
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("MinTimeController", "iaware_brjob stop tracking begin");
                }
                this.mTrackedJobs.remove(job);
            }
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    MinTimeController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
        }
    }
}
