package com.android.server.mtm.iaware.brjob.controller;

public class SIMStatusController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_NAME = "SIMStatus";
    private static final java.lang.String TAG = "SIMStatusController";
    private static com.android.server.mtm.iaware.brjob.controller.SIMStatusController mSingleton;
    private static final java.lang.Object sCreationLock = new java.lang.Object();
    private android.content.BroadcastReceiver mSimStateReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.isViceCardSimStateBroadcast(intent)) {
                    if (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.DEBUG) {
                        android.rms.iaware.AwareLog.i("SIMStatusController", "iaware_brjob br is vice card sim, not change state");
                    }
                    return;
                }
                if ("android.intent.action.SIM_STATE_CHANGED".equals(intent.getAction())) {
                    java.lang.String state = com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.getSimStateFromIntent(intent);
                    if (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_brjob onReceiver sim state:");
                        stringBuilder.append(state);
                        android.rms.iaware.AwareLog.i("SIMStatusController", stringBuilder.toString());
                    }
                    if (!com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.mSimStatus.equals(state)) {
                        synchronized (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.mLock) {
                            boolean changeToSatisfied = false;
                            com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.mSimStatus = state;
                            java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> changedJobs = new java.util.ArrayList();
                            java.util.Iterator it = com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.mTrackedJobs.iterator();
                            while (it.hasNext()) {
                                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) it.next();
                                java.lang.String value = job.getActionFilterValue("SIMStatus");
                                if (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.matchSimStatus(value) && !job.isSatisfied("SIMStatus")) {
                                    job.setSatisfied("SIMStatus", true);
                                    changeToSatisfied = true;
                                    changedJobs.add(job);
                                } else if (!com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.matchSimStatus(value) && job.isSatisfied("SIMStatus")) {
                                    job.setSatisfied("SIMStatus", false);
                                }
                            }
                            if (changeToSatisfied) {
                                if (com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.DEBUG) {
                                    android.rms.iaware.AwareLog.i("SIMStatusController", "iaware_brjob onControllerStateChanged");
                                }
                                com.android.server.mtm.iaware.brjob.controller.SIMStatusController.this.mStateChangedListener.onControllerStateChanged(changedJobs);
                            }
                        }
                    }
                }
            }
        }
    };
    private java.lang.String mSimStatus = "UNKNOWN";
    private android.telephony.TelephonyManager mTelephonyManager;
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.SIMStatusController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.SIMStatusController sIMStatusController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.SIMStatusController(jms, jms.getContext(), jms.getLock());
            }
            sIMStatusController = mSingleton;
        }
        return sIMStatusController;
    }

    private SIMStatusController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
        if (this.mContext != null) {
            this.mContext.registerReceiverAsUser(this.mSimStateReceiver, android.os.UserHandle.SYSTEM, new android.content.IntentFilter("android.intent.action.SIM_STATE_CHANGED"), null, null);
            this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        }
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("SIMStatus")) {
            this.mSimStatus = getSimState();
            java.lang.String filter = job.getActionFilterValue("SIMStatus");
            if (android.text.TextUtils.isEmpty(filter)) {
                android.rms.iaware.AwareLog.w("SIMStatusController", "iaware_brjob sim status value is null");
                job.setSatisfied("SIMStatus", false);
                return;
            }
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob start tracking SimState, filter:");
                stringBuilder.append(filter);
                stringBuilder.append("current: ");
                stringBuilder.append(this.mSimStatus);
                android.rms.iaware.AwareLog.i("SIMStatusController", stringBuilder.toString());
            }
            if (job.getIntent() == null || !isViceCardSimStateBroadcast(job.getIntent())) {
                job.setSatisfied("SIMStatus", matchSimStatus(filter));
                addJobLocked(this.mTrackedJobs, job);
            } else {
                job.setSatisfied("SIMStatus", true);
            }
        }
    }

    private boolean matchSimStatus(java.lang.String filterValue) {
        java.lang.String[] values = filterValue.split("[:]");
        for (java.lang.Object equals : values) {
            if (this.mSimStatus.equals(equals)) {
                return true;
            }
        }
        return false;
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        if (jobStatus != null && jobStatus.hasConstraint("SIMStatus")) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.i("SIMStatusController", "iaware_brjob stop tracking begin");
            }
            this.mTrackedJobs.remove(jobStatus);
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    SIMStatusController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("        now sim state is ");
            stringBuilder.append(this.mSimStatus);
            pw.println(stringBuilder.toString());
        }
    }

    private java.lang.String getSimState() {
        if (this.mTelephonyManager == null) {
            if (this.mContext == null) {
                return "UNKNOWN";
            }
            this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        }
        java.lang.String simstate = "UNKNOWN";
        switch (this.mTelephonyManager.getSimState()) {
            case 1:
                simstate = "ABSENT";
                break;
            case 2:
            case 3:
            case 4:
                simstate = "LOCKED";
                break;
            case 5:
                simstate = "READY";
                break;
            default:
                break;
        }
        return simstate;
    }

    private java.lang.String getSimStateFromIntent(android.content.Intent intent) {
        java.lang.String curSimState = intent.getStringExtra("ss");
        if (curSimState == null) {
            return "UNKNOWN";
        }
        if (this.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob curSimState : ");
            stringBuilder.append(curSimState);
            android.rms.iaware.AwareLog.i("SIMStatusController", stringBuilder.toString());
        }
        java.lang.String simstate = "UNKNOWN";
        if ("READY".equals(curSimState)) {
            simstate = "READY";
        } else {
            if (!"LOCKED".equals(curSimState)) {
                if (!"INTERNAL_LOCKED".equals(curSimState)) {
                    if ("ABSENT".equals(curSimState)) {
                        simstate = "ABSENT";
                    } else {
                        simstate = "UNKNOWN";
                    }
                }
            }
            simstate = "LOCKED";
        }
        return simstate;
    }

    private boolean isViceCardSimStateBroadcast(android.content.Intent intent) {
        if ("android.intent.action.SIM_STATE_CHANGED".equals(intent.getAction())) {
            int subKey = intent.getIntExtra("subscription", -1);
            int defaultSubId = android.telephony.SubscriptionManager.getDefaultSubId();
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob is Vice Card sim state Broadcast, subkey : ");
                stringBuilder.append(subKey);
                stringBuilder.append(", defaultSubId : ");
                stringBuilder.append(defaultSubId);
                android.rms.iaware.AwareLog.i("SIMStatusController", stringBuilder.toString());
            }
            if (subKey == -1 || subKey != defaultSubId) {
                return true;
            }
        }
        return false;
    }
}
