package com.android.server.mtm.iaware.brjob.controller;

public class ServicesStatusController extends com.android.server.mtm.iaware.brjob.controller.AwareStateController {
    private static final java.lang.String CONDITION_NAME = "ServicesStatus";
    private static final java.lang.String TAG = "ServicesStatusController";
    private static com.android.server.mtm.iaware.brjob.controller.ServicesStatusController mSingleton;
    private static java.lang.Object sCreationLock = new java.lang.Object();
    private boolean mIsRoaming = false;
    private android.content.BroadcastReceiver mServcicesStatusReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if (com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.isViceCardServicesStatusBroadcast(intent)) {
                    if (com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.DEBUG) {
                        android.rms.iaware.AwareLog.i("ServicesStatusController", "iaware_brjob br is vice card service, not change state");
                    }
                    return;
                }
                if ("android.intent.action.SERVICE_STATE".equals(intent.getAction())) {
                    boolean changed = false;
                    android.telephony.ServiceState serviceState = android.telephony.ServiceState.newFromBundle(intent.getExtras());
                    if (!(serviceState.getRoaming() == com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mIsRoaming && serviceState.getState() == com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mServicesState)) {
                        changed = true;
                    }
                    com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mIsRoaming = serviceState.getRoaming();
                    com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mServicesState = serviceState.getState();
                    if (changed) {
                        if (com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.DEBUG) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("iaware_brjob service changed, state: ");
                            stringBuilder.append(com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mServicesState);
                            stringBuilder.append(", isRoaming: ");
                            stringBuilder.append(com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.mIsRoaming);
                            android.rms.iaware.AwareLog.i("ServicesStatusController", stringBuilder.toString());
                        }
                        com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.this.updateJobs();
                    }
                }
            }
        }
    };
    private int mServicesState = 1;
    private android.telephony.TelephonyManager mTelephonyManager;
    @com.android.internal.annotations.GuardedBy("mLock")
    private final java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mTrackedJobs = new java.util.ArrayList();

    public static com.android.server.mtm.iaware.brjob.controller.ServicesStatusController get(com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService jms) {
        com.android.server.mtm.iaware.brjob.controller.ServicesStatusController servicesStatusController;
        synchronized (sCreationLock) {
            if (mSingleton == null) {
                mSingleton = new com.android.server.mtm.iaware.brjob.controller.ServicesStatusController(jms, jms.getContext(), jms.getLock());
            }
            servicesStatusController = mSingleton;
        }
        return servicesStatusController;
    }

    private ServicesStatusController(com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener stateChangedListener, android.content.Context context, java.lang.Object lock) {
        super(stateChangedListener, context, lock);
        if (this.mContext != null) {
            this.mContext.registerReceiverAsUser(this.mServcicesStatusReceiver, android.os.UserHandle.SYSTEM, new android.content.IntentFilter("android.intent.action.SERVICE_STATE"), null, null);
            this.mTelephonyManager = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        }
    }

    public void maybeStartTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("ServicesStatus")) {
            java.lang.StringBuilder stringBuilder;
            java.lang.String value = job.getActionFilterValue("ServicesStatus");
            java.lang.String action = job.getAction();
            android.content.Intent intent = job.getIntent();
            if (action != null) {
                if (intent != null) {
                    if (isViceCardServicesStatusBroadcast(intent)) {
                        job.setSatisfied("ServicesStatus", true);
                        return;
                    }
                    resetServicesState();
                    if (this.DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_brjob start tracking, action:");
                        stringBuilder.append(action);
                        stringBuilder.append(", value: ");
                        stringBuilder.append(value);
                        stringBuilder.append(", is roaming:");
                        stringBuilder.append(this.mIsRoaming);
                        stringBuilder.append(", service state: ");
                        stringBuilder.append(this.mServicesState);
                        android.rms.iaware.AwareLog.i("ServicesStatusController", stringBuilder.toString());
                    }
                    checkSatisfiedLocked(job, value);
                    addJobLocked(this.mTrackedJobs, job);
                }
            }
            java.lang.String str = "ServicesStatusController";
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob action: ");
            stringBuilder.append(action == null ? "null" : action);
            stringBuilder.append(", intent: ");
            stringBuilder.append(intent == null ? "null" : intent);
            android.rms.iaware.AwareLog.w(str, stringBuilder.toString());
            job.setSatisfied("ServicesStatus", false);
        }
    }

    private boolean checkSatisfiedLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job, java.lang.String filterValue) {
        boolean changeToSatisfied = false;
        java.lang.String[] values = filterValue.split("[:]");
        boolean match = false;
        for (int i = 0; i < values.length; i++) {
            if ("ROAMING".equals(values[i])) {
                match = this.mIsRoaming;
            } else {
                boolean z = true;
                if ("CONNECTED".equals(values[i])) {
                    if (this.mServicesState != 0) {
                        z = false;
                    }
                    match = z;
                } else if ("DSCONNECTED".equals(values[i])) {
                    if (this.mServicesState == 0) {
                        z = false;
                    }
                    match = z;
                }
            }
            if (match) {
                break;
            }
        }
        if (match && !job.isSatisfied("ServicesStatus")) {
            changeToSatisfied = true;
        }
        job.setSatisfied("ServicesStatus", match);
        return changeToSatisfied;
    }

    public void maybeStopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job != null && job.hasConstraint("ServicesStatus")) {
            if (this.DEBUG) {
                android.rms.iaware.AwareLog.i("ServicesStatusController", "iaware_brjob stop tracking begin");
            }
            this.mTrackedJobs.remove(job);
        }
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("    ServicesStatusController tracked job num: ");
            stringBuilder.append(this.mTrackedJobs.size());
            pw.println(stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("        now services state: ");
            stringBuilder.append(this.mServicesState);
            stringBuilder.append(", isRoaming: ");
            stringBuilder.append(this.mIsRoaming);
            pw.println(stringBuilder.toString());
        }
    }

    private void updateJobs() {
        synchronized (this.mLock) {
            boolean changeToSatisfied = false;
            java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> changedJobs = new java.util.ArrayList();
            java.util.Iterator it = this.mTrackedJobs.iterator();
            while (it.hasNext()) {
                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) it.next();
                changeToSatisfied = checkSatisfiedLocked(job, job.getActionFilterValue("ServicesStatus"));
                if (changeToSatisfied) {
                    changedJobs.add(job);
                }
            }
            if (changeToSatisfied) {
                if (this.DEBUG) {
                    android.rms.iaware.AwareLog.i("ServicesStatusController", "iaware_brjob onControllerStateChanged");
                }
                this.mStateChangedListener.onControllerStateChanged(changedJobs);
            }
        }
    }

    private void resetServicesState() {
        android.telephony.ServiceState state = this.mTelephonyManager != null ? this.mTelephonyManager.getServiceState() : null;
        if (state != null) {
            this.mIsRoaming = state.getRoaming();
            this.mServicesState = state.getState();
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob resetServicesState mServicesState: ");
                stringBuilder.append(this.mServicesState);
                stringBuilder.append(", mIsRoaming : ");
                stringBuilder.append(this.mIsRoaming);
                android.rms.iaware.AwareLog.i("ServicesStatusController", stringBuilder.toString());
            }
        }
    }

    private boolean isViceCardServicesStatusBroadcast(android.content.Intent intent) {
        if ("android.intent.action.SERVICE_STATE".equals(intent.getAction())) {
            int subKey = intent.getIntExtra("subscription", -1);
            int defaultSubId = android.telephony.SubscriptionManager.getDefaultSubId();
            if (this.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob is Vice Card ServicesStatus Broadcast, subkey : ");
                stringBuilder.append(subKey);
                stringBuilder.append(", defaultSubId : ");
                stringBuilder.append(defaultSubId);
                android.rms.iaware.AwareLog.i("ServicesStatusController", stringBuilder.toString());
            }
            if (subKey == -1 || subKey != defaultSubId) {
                return true;
            }
        }
        return false;
    }
}
