package com.android.server.mtm.iaware.brjob.scheduler;

public class AwareJobSchedulerService implements com.android.server.mtm.iaware.brjob.scheduler.AwareStateChangedListener {
    private static final int MSG_BEGIN = 400;
    public static final int MSG_CHECK_JOB = 402;
    public static final int MSG_CONTROLLER_CHANGED = 404;
    public static final int MSG_JOB_EXPIRED = 401;
    public static final int MSG_REMOVE_JOB = 403;
    public static final int MSG_SCHEDULE_JOB = 400;
    private static final java.lang.String TAG = "AwareJobSchedulerService";
    private boolean DEBUG = false;
    private final android.content.BroadcastReceiver mBroadcastReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null && "android.intent.action.PACKAGE_REMOVED".equals(intent.getAction()) && intent.getData() != null) {
                java.lang.String packageName = intent.getData().getSchemeSpecificPart();
                if (!android.text.TextUtils.isEmpty(packageName)) {
                    com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.cancelJobsForPkgLocked(packageName);
                }
            }
        }
    };
    private final android.content.Context mContext;
    private java.util.ArrayList<com.android.server.mtm.iaware.brjob.controller.AwareStateController> mControllers;
    private final com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.AwareJobHandler mHandler;
    private java.util.ArrayList<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> mJobs;
    private final java.lang.Object mLock = new java.lang.Object();

    private class AwareJobHandler extends android.os.Handler {
        public AwareJobHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message message) {
            switch (message.what) {
                case 400:
                    com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.scheduleJob(message.obj);
                    return;
                case 401:
                    synchronized (com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.mLock) {
                        com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus runNow = message.obj;
                        if (runNow != null) {
                            com.android.server.am.HwMtmBroadcastResourceManager.insertIawareOrderedBroadcast(runNow.getHwBroadcastRecord());
                            com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.stopTrackingJobLocked(runNow);
                        }
                    }
                    return;
                case 402:
                    com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.maybeQueueReadyJobsForExecution();
                    return;
                case 403:
                    synchronized (com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.mLock) {
                        com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.stopTrackingJobLocked(message.obj);
                    }
                    return;
                case 404:
                    java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> jobList = message.obj;
                    if (jobList != null) {
                        com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.this.controllerStateChanged(jobList);
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    }

    public AwareJobSchedulerService(android.content.Context context, android.os.HandlerThread handlerThread) {
        this.mContext = context;
        this.mHandler = new com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.AwareJobHandler(handlerThread.getLooper());
        this.mJobs = new java.util.ArrayList();
        this.mControllers = new java.util.ArrayList();
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.LimitNumController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.KeyWordController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.SIMStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.BluetoothStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.WidgetStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.BarStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.AppStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.MinTimeController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.ServicesStatusController.get(this));
        this.mControllers.add(com.android.server.mtm.iaware.brjob.controller.ConnectivityController.get(this));
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("android.intent.action.PACKAGE_REMOVED");
        filter.addDataScheme("package");
        context.registerReceiverAsUser(this.mBroadcastReceiver, android.os.UserHandle.ALL, filter, null, null);
    }

    public void onControllerStateChanged(java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> jobList) {
        if (jobList != null) {
            android.os.Message msg = this.mHandler.obtainMessage(404);
            msg.obj = jobList;
            msg.sendToTarget();
        }
    }

    public void onRunJobNow(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        this.mHandler.obtainMessage(401, jobStatus).sendToTarget();
    }

    public void onRemoveJobNow(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        this.mHandler.obtainMessage(403, jobStatus).sendToTarget();
    }

    public java.lang.Object getLock() {
        return this.mLock;
    }

    public android.content.Context getContext() {
        return this.mContext;
    }

    public boolean schedule(com.android.server.am.HwBroadcastRecord hwBr) {
        if (hwBr == null) {
            return false;
        }
        com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus = com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus.createFromBroadcastRecord(hwBr);
        if (this.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob schedule begin, receiver: ");
            stringBuilder.append(jobStatus.getComponentName());
            stringBuilder.append(", action: ");
            stringBuilder.append(hwBr.getAction());
            android.rms.iaware.AwareLog.i("AwareJobSchedulerService", stringBuilder.toString());
        }
        if (jobStatus.isParseError()) {
            android.rms.iaware.AwareLog.e("AwareJobSchedulerService", "iaware_brjob implicit config error, app will not be started.");
            return true;
        }
        if (!jobStatus.isParamError()) {
            if (jobStatus.getActionFilterSize() != 0) {
                this.mHandler.obtainMessage(400, jobStatus).sendToTarget();
                return true;
            }
        }
        android.rms.iaware.AwareLog.e("AwareJobSchedulerService", "iaware_brjob intent error or no implicit config, don't schedule!");
        return false;
    }

    private void scheduleJob(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        synchronized (this.mLock) {
            java.util.Iterator<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> it = this.mJobs.iterator();
            while (it.hasNext()) {
                if (((com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) it.next()).equalJob(jobStatus)) {
                    it.remove();
                    break;
                }
            }
            this.mJobs.add(jobStatus);
            int listSize = this.mControllers.size();
            for (int i = 0; i < listSize; i++) {
                ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(i)).maybeStartTrackingJobLocked(jobStatus);
            }
        }
        this.mHandler.obtainMessage(402).sendToTarget();
    }

    private void controllerStateChanged(java.util.List<com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus> jobList) {
        if (this.DEBUG) {
            android.rms.iaware.AwareLog.i("AwareJobSchedulerService", "iaware_brjob controllerStateChanged begin");
        }
        synchronized (this.mLock) {
            int listSize = jobList.size();
            for (int i = 0; i < listSize; i++) {
                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) jobList.get(i);
                int controllerSize = this.mControllers.size();
                for (int index = 0; index < controllerSize; index++) {
                    ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(index)).maybeStartTrackingJobLocked(job);
                }
            }
        }
        this.mHandler.obtainMessage(402).sendToTarget();
    }

    private void cancelJobsForPkgLocked(java.lang.String packageName) {
        synchronized (this.mLock) {
            int length = this.mJobs.size();
            if (length < 1) {
                android.rms.iaware.AwareLog.w("AwareJobSchedulerService", "iaware_brjob no job need to cancel.");
                return;
            }
            for (int i = length; i > 0; i--) {
                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) this.mJobs.get(i - 1);
                if (packageName.equals(jobStatus.getReceiverPkg())) {
                    stopTrackingJobLocked(jobStatus);
                }
            }
        }
    }

    private void stopTrackingJobLocked(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus jobStatus) {
        if (this.DEBUG) {
            android.rms.iaware.AwareLog.i("AwareJobSchedulerService", "iaware_brjob stopTrackingJobLocked begin");
        }
        this.mJobs.remove(jobStatus);
        int controllerSize = this.mControllers.size();
        for (int i = 0; i < controllerSize; i++) {
            ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(i)).maybeStopTrackingJobLocked(jobStatus);
        }
    }

    private void maybeQueueReadyJobsForExecution() {
        if (this.DEBUG) {
            android.rms.iaware.AwareLog.i("AwareJobSchedulerService", "iaware_brjob maybeQueueReadyJobsForExecution begin");
        }
        synchronized (this.mLock) {
            for (int i = this.mJobs.size() - 1; i >= 0; i--) {
                com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) this.mJobs.get(i);
                if (job.isReady()) {
                    com.android.server.am.HwMtmBroadcastResourceManager.insertIawareOrderedBroadcast(job.getHwBroadcastRecord());
                    stopTrackingJobLocked(job);
                } else if (job.shouldCancelled()) {
                    stopTrackingJobLocked(job);
                }
            }
        }
    }

    public void dump(java.io.PrintWriter pw, java.lang.String[] args) {
        if (pw != null) {
            if (args != null) {
                java.lang.String filterAction = "";
                java.lang.String filterReceiver = "";
                if (args.length >= 3) {
                    if (args[2] != null) {
                        if ("action".equals(args[2])) {
                            if (args.length >= 4) {
                                if (!android.text.TextUtils.isEmpty(args[3])) {
                                    dumpJobsForAction(pw, args[3]);
                                }
                            }
                            pw.println("  no action option found, please input action name.");
                        } else if ("receiver".equals(args[2])) {
                            if (args.length >= 4) {
                                if (!android.text.TextUtils.isEmpty(args[3])) {
                                    dumpJobsForReceiver(pw, args[3]);
                                }
                            }
                            pw.println("  no receiver option found, please input receiver name.");
                        } else if ("controller".equals(args[2])) {
                            dumpControllers(pw);
                        } else {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("  bad command");
                            stringBuilder.append(args[2]);
                            pw.println(stringBuilder.toString());
                        }
                    }
                }
                dumpAllJobs(pw);
            }
        }
    }

    private void dumpAllJobs(java.io.PrintWriter pw) {
        synchronized (this.mLock) {
            if (this.mJobs.size() == 0) {
                pw.println("    There is no job now.");
                return;
            }
            java.util.Iterator it = this.mJobs.iterator();
            while (it.hasNext()) {
                ((com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) it.next()).dump(pw);
            }
        }
    }

    /* JADX WARNING: Missing block: B:17:0x004c, code:
            return;
     */
    private void dumpJobsForAction(java.io.PrintWriter r7, java.lang.String r8) {
        /*
        r6 = this;
        r0 = r6.mLock;
        monitor-enter(r0);
        r1 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r1 = r1.size();	 Catch:{ all -> 0x004d }
        if (r1 != 0) goto L_0x0012;
    L_0x000b:
        r1 = "    There is no job now.";
        r7.println(r1);	 Catch:{ all -> 0x004d }
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x0012:
        r1 = 0;
        r2 = 0;
        r3 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r3 = r3.size();	 Catch:{ all -> 0x004d }
    L_0x001a:
        if (r2 >= r3) goto L_0x0035;
    L_0x001c:
        r4 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r4 = r4.get(r2);	 Catch:{ all -> 0x004d }
        r4 = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) r4;	 Catch:{ all -> 0x004d }
        r5 = r4.getAction();	 Catch:{ all -> 0x004d }
        r5 = r8.equals(r5);	 Catch:{ all -> 0x004d }
        if (r5 == 0) goto L_0x0032;
    L_0x002e:
        r4.dump(r7);	 Catch:{ all -> 0x004d }
        r1 = 1;
    L_0x0032:
        r2 = r2 + 1;
        goto L_0x001a;
    L_0x0035:
        if (r1 != 0) goto L_0x004b;
    L_0x0037:
        r2 = new java.lang.StringBuilder;	 Catch:{ all -> 0x004d }
        r2.<init>();	 Catch:{ all -> 0x004d }
        r3 = "    There is no job for action: ";
        r2.append(r3);	 Catch:{ all -> 0x004d }
        r2.append(r8);	 Catch:{ all -> 0x004d }
        r2 = r2.toString();	 Catch:{ all -> 0x004d }
        r7.println(r2);	 Catch:{ all -> 0x004d }
    L_0x004b:
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x004d:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.dumpJobsForAction(java.io.PrintWriter, java.lang.String):void");
    }

    /* JADX WARNING: Missing block: B:17:0x004c, code:
            return;
     */
    private void dumpJobsForReceiver(java.io.PrintWriter r7, java.lang.String r8) {
        /*
        r6 = this;
        r0 = r6.mLock;
        monitor-enter(r0);
        r1 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r1 = r1.size();	 Catch:{ all -> 0x004d }
        if (r1 != 0) goto L_0x0012;
    L_0x000b:
        r1 = "    There is no job now.";
        r7.println(r1);	 Catch:{ all -> 0x004d }
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x0012:
        r1 = 0;
        r2 = 0;
        r3 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r3 = r3.size();	 Catch:{ all -> 0x004d }
    L_0x001a:
        if (r2 >= r3) goto L_0x0035;
    L_0x001c:
        r4 = r6.mJobs;	 Catch:{ all -> 0x004d }
        r4 = r4.get(r2);	 Catch:{ all -> 0x004d }
        r4 = (com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus) r4;	 Catch:{ all -> 0x004d }
        r5 = r4.getReceiverPkg();	 Catch:{ all -> 0x004d }
        r5 = r8.equals(r5);	 Catch:{ all -> 0x004d }
        if (r5 == 0) goto L_0x0032;
    L_0x002e:
        r4.dump(r7);	 Catch:{ all -> 0x004d }
        r1 = 1;
    L_0x0032:
        r2 = r2 + 1;
        goto L_0x001a;
    L_0x0035:
        if (r1 != 0) goto L_0x004b;
    L_0x0037:
        r2 = new java.lang.StringBuilder;	 Catch:{ all -> 0x004d }
        r2.<init>();	 Catch:{ all -> 0x004d }
        r3 = "    There is no job for receiver: ";
        r2.append(r3);	 Catch:{ all -> 0x004d }
        r2.append(r8);	 Catch:{ all -> 0x004d }
        r2 = r2.toString();	 Catch:{ all -> 0x004d }
        r7.println(r2);	 Catch:{ all -> 0x004d }
    L_0x004b:
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x004d:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.brjob.scheduler.AwareJobSchedulerService.dumpJobsForReceiver(java.io.PrintWriter, java.lang.String):void");
    }

    private void dumpControllers(java.io.PrintWriter pw) {
        int size = this.mControllers.size();
        if (size == 0) {
            pw.println("    There is no controller in manager.");
            return;
        }
        for (int i = 0; i < size; i++) {
            ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(i)).dump(pw);
        }
    }

    public void disableDebug() {
        this.DEBUG = false;
        int controllerSize = this.mControllers.size();
        for (int i = 0; i < controllerSize; i++) {
            ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(i)).setDebug(false);
        }
        com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus.setDebug(false);
    }

    public void enableDebug() {
        this.DEBUG = true;
        int controllerSize = this.mControllers.size();
        for (int i = 0; i < controllerSize; i++) {
            ((com.android.server.mtm.iaware.brjob.controller.AwareStateController) this.mControllers.get(i)).setDebug(true);
        }
        com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus.setDebug(true);
    }
}
