package com.android.server.mtm.iaware.brjob.scheduler;

public final class AwareJobStatus {
    private static boolean DEBUG = false;
    private static final java.lang.String TAG = "AwareJobStatus";
    private java.util.Map<java.lang.String, java.lang.String> mActionFilters = new java.util.HashMap();
    private int mForceCacheTag = 2;
    private com.android.server.am.HwBroadcastRecord mHwBr;
    private java.util.concurrent.atomic.AtomicBoolean mParseError = new java.util.concurrent.atomic.AtomicBoolean(false);
    private android.content.pm.ResolveInfo mReceiver;
    private java.util.Map<java.lang.String, java.lang.Boolean> mSatisfied = new java.util.HashMap();
    private java.util.concurrent.atomic.AtomicBoolean mShouldCache = new java.util.concurrent.atomic.AtomicBoolean(true);
    private java.util.concurrent.atomic.AtomicBoolean mShouldRunByError = new java.util.concurrent.atomic.AtomicBoolean(false);

    private AwareJobStatus() {
    }

    public AwareJobStatus(com.android.server.am.HwBroadcastRecord hwBr) {
        if (hwBr != null) {
            this.mHwBr = hwBr;
            java.util.List receivers = this.mHwBr.getBrReceivers();
            if (receivers != null && receivers.size() > 0) {
                java.lang.Object target = receivers.get(0);
                if (target instanceof android.content.pm.ResolveInfo) {
                    this.mReceiver = (android.content.pm.ResolveInfo) target;
                } else {
                    return;
                }
            }
            if (this.mReceiver != null) {
                android.content.IntentFilter filter = this.mReceiver.filter;
                if (filter != null) {
                    java.util.Iterator<android.content.IntentFilter.ActionFilterEntry> it = filter.actionFilterIterator();
                    if (it != null) {
                        while (it.hasNext()) {
                            android.content.IntentFilter.ActionFilterEntry actionFilter = (android.content.IntentFilter.ActionFilterEntry) it.next();
                            if (actionFilter.getAction() != null) {
                                if (actionFilter.getAction().equals(hwBr.getAction())) {
                                    parseActionFilterEntry(actionFilter.getFilterName(), actionFilter.getFilterValue());
                                }
                            }
                            if (DEBUG) {
                                android.rms.iaware.AwareLog.w("AwareJobStatus", "iaware_brjob, action not match. ");
                            }
                        }
                    }
                }
            }
        }
    }

    private void parseActionFilterEntry(java.lang.String filterName, java.lang.String filterValue) {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_brjob parseActionFilterEntry: ");
            stringBuilder.append(filterName);
            stringBuilder.append(", ");
            stringBuilder.append(filterValue);
            android.rms.iaware.AwareLog.i("AwareJobStatus", stringBuilder.toString());
        }
        if (filterName != null) {
            if (filterName.length() != 0) {
                filterName = filterName.trim().toLowerCase(java.util.Locale.ENGLISH);
                if ("BrCache".toLowerCase(java.util.Locale.ENGLISH).equals(filterName)) {
                    try {
                        this.mForceCacheTag = java.lang.Integer.parseInt(filterValue);
                    } catch (java.lang.NumberFormatException e) {
                        android.rms.iaware.AwareLog.e("AwareJobStatus", "iaware_brjob scheduler force cache value error!");
                    }
                    return;
                }
                boolean hasMatch = false;
                java.lang.String[] conditionArray = com.android.server.mtm.iaware.brjob.AwareJobSchedulerConstants.getConditionArray();
                for (java.lang.String condition : conditionArray) {
                    if (condition.toLowerCase(java.util.Locale.ENGLISH).equals(filterName)) {
                        hasMatch = true;
                        this.mActionFilters.put(condition, filterValue);
                        break;
                    }
                }
                if (!hasMatch) {
                    android.rms.iaware.AwareLog.e("AwareJobStatus", "iaware_brjob scheduler state key is error!");
                    this.mParseError.set(true);
                }
                return;
            }
        }
        android.rms.iaware.AwareLog.e("AwareJobStatus", "iaware_brjob scheduler state key is error!");
        this.mParseError.set(true);
    }

    public boolean hasConstraint(java.lang.String key) {
        if (this.mActionFilters.containsKey(key)) {
            return true;
        }
        return false;
    }

    public boolean isParamError() {
        if (!android.text.TextUtils.isEmpty(getAction())) {
            if (!android.text.TextUtils.isEmpty(getComponentName())) {
                return false;
            }
        }
        return true;
    }

    public boolean isParseError() {
        return this.mParseError.get();
    }

    public void setSatisfied(java.lang.String condition, boolean satisfied) {
        if (condition != null) {
            boolean shouldCache = shouldCache(condition);
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob, receiver: ");
                stringBuilder.append(getComponentName());
                stringBuilder.append(", condition: ");
                stringBuilder.append(condition);
                stringBuilder.append(" satisfied: ");
                stringBuilder.append(satisfied);
                android.rms.iaware.AwareLog.i("AwareJobStatus", stringBuilder.toString());
            }
            this.mSatisfied.put(condition, java.lang.Boolean.valueOf(satisfied));
            this.mShouldCache.compareAndSet(true, shouldCache);
        }
    }

    public boolean isSatisfied(java.lang.String condition) {
        if (condition != null) {
            if (this.mSatisfied.containsKey(condition)) {
                return ((java.lang.Boolean) this.mSatisfied.get(condition)).booleanValue();
            }
        }
        return false;
    }

    private boolean shouldCache(java.lang.String condition) {
        if (com.android.server.mtm.iaware.brjob.AwareJobSchedulerConstants.getCacheConditionMap().containsKey(condition)) {
            return ((java.lang.Boolean) com.android.server.mtm.iaware.brjob.AwareJobSchedulerConstants.getCacheConditionMap().get(condition)).booleanValue();
        }
        return false;
    }

    public java.lang.String getActionFilterValue(java.lang.String filterName) {
        if (filterName == null) {
            return null;
        }
        return (java.lang.String) this.mActionFilters.get(filterName);
    }

    public int getActionFilterSize() {
        return this.mActionFilters.size();
    }

    public java.lang.String getReceiverPkg() {
        if (!(this.mReceiver == null || this.mReceiver.getComponentInfo() == null)) {
            try {
                return this.mReceiver.getComponentInfo().packageName;
            } catch (java.lang.IllegalStateException e) {
                android.rms.iaware.AwareLog.e("AwareJobStatus", "iaware_brjob, mReceiver.getComponentInfo() error!");
            }
        }
        return null;
    }

    public java.lang.String getComponentName() {
        if (!(this.mReceiver == null || this.mReceiver.getComponentInfo() == null)) {
            try {
                return this.mReceiver.getComponentInfo().getComponentName().getClassName();
            } catch (java.lang.IllegalStateException e) {
                android.rms.iaware.AwareLog.e("AwareJobStatus", "iaware_brjob, mReceiver.getComponentInfo() error!");
            }
        }
        return null;
    }

    public com.android.server.am.HwBroadcastRecord getHwBroadcastRecord() {
        return this.mHwBr;
    }

    public java.lang.String getAction() {
        if (this.mHwBr != null) {
            return this.mHwBr.getAction();
        }
        return null;
    }

    public android.content.Intent getIntent() {
        if (this.mHwBr != null) {
            return this.mHwBr.getIntent();
        }
        return null;
    }

    public boolean equalJob(com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus job) {
        if (job == null) {
            return false;
        }
        java.lang.String action = job.getAction();
        java.lang.String comp = job.getComponentName();
        if (action == null || !action.equals(getAction()) || comp == null || !comp.equals(getComponentName())) {
            return false;
        }
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x001b  */
    public boolean shouldCancelled() {
        /*
        r4 = this;
        r0 = r4.mForceCacheTag;
        r1 = 1;
        r2 = 2;
        if (r0 != r2) goto L_0x000f;
    L_0x0006:
        r0 = r4.mShouldCache;
        r0 = r0.get();
        r0 = r0 ^ r1;
        r1 = r0;
        goto L_0x0014;
    L_0x000f:
        r0 = r4.mForceCacheTag;
        if (r0 != r1) goto L_0x0015;
    L_0x0013:
        r1 = 0;
    L_0x0014:
        goto L_0x0016;
    L_0x0016:
        r0 = r1;
        r1 = DEBUG;
        if (r1 == 0) goto L_0x0031;
    L_0x001b:
        r1 = "AwareJobStatus";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "iaware_brjob, shouldCancelled: ";
        r2.append(r3);
        r2.append(r0);
        r2 = r2.toString();
        android.rms.iaware.AwareLog.i(r1, r2);
    L_0x0031:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus.shouldCancelled():boolean");
    }

    public void setShouldRunByError() {
        this.mShouldRunByError.set(true);
    }

    public boolean isShouldRunByError() {
        return this.mShouldRunByError.get();
    }

    public boolean isReady() {
        if (this.mShouldRunByError.get()) {
            if (DEBUG) {
                android.rms.iaware.AwareLog.i("AwareJobStatus", "iaware_brjob isReady all: ShouldRunByError");
            }
            return true;
        }
        boolean ready = true;
        for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : this.mActionFilters.entrySet()) {
            java.lang.String condition = (java.lang.String) entry.getKey();
            if (DEBUG) {
                java.lang.String str = "AwareJobStatus";
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_brjob isReady: ");
                stringBuilder.append(condition);
                stringBuilder.append(", ");
                stringBuilder.append(this.mSatisfied.containsKey(condition) ? (java.io.Serializable) this.mSatisfied.get(condition) : "false(not contains)");
                android.rms.iaware.AwareLog.i(str, stringBuilder.toString());
            }
            if (this.mSatisfied.containsKey(condition)) {
                if (((java.lang.Boolean) this.mSatisfied.get(condition)).booleanValue()) {
                }
            }
            ready = false;
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("iaware_brjob, receiver: ");
            stringBuilder2.append(getComponentName());
            stringBuilder2.append(", action: ");
            stringBuilder2.append(getAction());
            stringBuilder2.append(", isReady: ");
            stringBuilder2.append(ready);
            android.rms.iaware.AwareLog.i("AwareJobStatus", stringBuilder2.toString());
        }
        return ready;
    }

    public static com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus createFromBroadcastRecord(com.android.server.am.HwBroadcastRecord hwBr) {
        return new com.android.server.mtm.iaware.brjob.scheduler.AwareJobStatus(hwBr);
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw != null) {
            pw.print("  AwareJOB #");
            pw.print(" action:");
            if (this.mHwBr != null) {
                pw.print(this.mHwBr.getAction());
            }
            pw.print(" receiver:");
            pw.println(getReceiverPkg());
            pw.println("    filter:");
            for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : this.mActionFilters.entrySet()) {
                pw.print("        name: ");
                pw.print((java.lang.String) entry.getKey());
                pw.print("  value: ");
                pw.println((java.lang.String) entry.getValue());
            }
        }
    }

    public java.lang.String toString() {
        java.lang.String jobinfo = this.mHwBr.toString();
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("[");
        sb.append(getComponentName());
        sb.append("]");
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(jobinfo);
        stringBuilder.append(sb.toString());
        return stringBuilder.toString();
    }

    public static final void setDebug(boolean debug) {
        DEBUG = debug;
    }
}
