package com.android.server.mtm.iaware.srms;

public class AwareBroadcastProcess {
    private static final int IAWARE_FIRST_UNPROXY_DELAY_TIME = 5;
    private static final int IAWARE_PARALLEL_EXCEPTION_LENGTH = 10000;
    private static final int IAWARE_PARALLEL_PROXY_LIST_HIGH_ID = 1;
    private static final int IAWARE_PARALLEL_PROXY_LIST_LOW_ID = 3;
    private static final int IAWARE_PARALLEL_PROXY_LIST_MIDDLE_ID = 2;
    private static final int IAWARE_PARALLEL_PROXY_LIST_NUM = 4;
    private static final int IAWARE_PARALLEL_PROXY_LIST_TOP_ID = 0;
    private static final int IAWARE_PROXY_QUEUE_MIN_LENGTH = 10;
    private static final int IAWARE_UNPROXY_SCREEN_OFF_TIME = 5000;
    private static final int MSG_ENQUEUE_PARALL_BR = 102;
    private static final int MSG_PROCESS_FGAPP_PARALL_BR = 103;
    private static final int MSG_PROCESS_PARALL_BR = 101;
    static final java.lang.String TAG = "AwareBroadcastProcess";
    private java.lang.String mBrName;
    private final com.android.server.mtm.iaware.srms.AwareBroadcastProcess.IawareBroadcastHandler mHandler;
    private com.android.server.mtm.iaware.srms.AwareBroadcastPolicy mIawareBrPolicy;
    private final java.util.HashMap<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> mIawareParallelProxyBrMap = new java.util.HashMap();
    private int mIawareUnProxyTime;
    private int mProxyKeyBrIndex;
    private boolean mStartUnproxy;
    private int mUnproxyHighSpeed;
    private int mUnproxyMaxDuration;
    private int mUnproxyMaxSpeed;
    private int mUnproxyMiddleSpeed;
    private int mUnproxyMinSpeed;

    private final class IawareBroadcastHandler extends android.os.Handler {
        public IawareBroadcastHandler(android.os.Looper looper) {
            super(looper, null, true);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 101:
                    com.android.server.mtm.iaware.srms.AwareBroadcastProcess.this.processException();
                    com.android.server.mtm.iaware.srms.AwareBroadcastProcess.this.unproxyEachBroacast();
                    return;
                case 102:
                    if (msg.obj instanceof com.android.server.am.HwBroadcastRecord) {
                        com.android.server.mtm.iaware.srms.AwareBroadcastProcess.this.insertProxyParalledBroadcast(msg.obj);
                        return;
                    }
                    return;
                case 103:
                    com.android.server.mtm.iaware.srms.AwareBroadcastProcess.this.unProxyForegroundAppBroadcast(msg.arg1, msg.arg2);
                    return;
                default:
                    return;
            }
        }
    }

    public AwareBroadcastProcess(com.android.server.mtm.iaware.srms.AwareBroadcastPolicy iawareBrPolicy, android.os.Handler handler, java.lang.String name) {
        int index = 0;
        this.mStartUnproxy = false;
        this.mIawareUnProxyTime = 150;
        this.mProxyKeyBrIndex = -1;
        this.mIawareBrPolicy = null;
        this.mBrName = null;
        this.mUnproxyMaxDuration = 20000;
        this.mUnproxyMaxSpeed = 150;
        this.mUnproxyMinSpeed = 60;
        this.mUnproxyMiddleSpeed = 40;
        this.mUnproxyHighSpeed = 20;
        this.mIawareBrPolicy = iawareBrPolicy;
        this.mHandler = new com.android.server.mtm.iaware.srms.AwareBroadcastProcess.IawareBroadcastHandler(handler.getLooper());
        this.mBrName = name;
        while (index < 4) {
            this.mIawareParallelProxyBrMap.put(java.lang.Integer.valueOf(index), new java.util.ArrayList());
            index++;
        }
    }

    public void enqueueIawareProxyBroacast(boolean isParallel, com.android.server.am.HwBroadcastRecord r) {
        if (isParallel) {
            android.os.Message msg = this.mHandler.obtainMessage(102, this);
            msg.obj = r;
            this.mHandler.sendMessage(msg);
        }
    }

    public void starUnproxyBroadcast() {
        if (!this.mStartUnproxy && getIawareBrSize() > 0) {
            if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_br start unproxy, mStartBgUnproxy = true, queue name : ");
                stringBuilder.append(this.mBrName);
                android.rms.iaware.AwareLog.d("AwareBroadcastProcess", stringBuilder.toString());
            }
            this.mStartUnproxy = true;
            unProxyBroadcast(5);
        }
    }

    private void insertProxyParalledBroadcast(com.android.server.am.HwBroadcastRecord r) {
        synchronized (this.mIawareParallelProxyBrMap) {
            int curAdj = r.getReceiverCurAdj();
            if (2 == r.getReceiverCurProcState()) {
                if (!r.isSysApp()) {
                    trimProxyBr(r, 0);
                }
                ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(0))).add(r);
            } else if (curAdj < 0) {
                trimProxyBr(r, 1);
                ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(1))).add(r);
            } else if (curAdj >= 900) {
                trimProxyBr(r, 3);
                ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(3))).add(r);
            } else {
                processAdjChange(r);
                trimProxyBr(r, 2);
                ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(2))).add(r);
            }
        }
    }

    private void unProxyBroadcast(int unproxyTime) {
        if (!this.mHandler.hasMessages(101)) {
            this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(101, this), (long) unproxyTime);
        }
    }

    private void unproxyEachBroacast() {
        if (isEmptyProxyMap()) {
            this.mStartUnproxy = false;
            return;
        }
        java.util.ArrayList<com.android.server.am.HwBroadcastRecord> parallelList = new java.util.ArrayList();
        synchronized (this.mIawareParallelProxyBrMap) {
            com.android.server.am.HwBroadcastRecord proxyBr = getNextUnProxyBr();
            if (proxyBr != null) {
                parallelList.add(proxyBr);
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iaware_br unproxy cost time : ");
                    stringBuilder.append(java.lang.System.currentTimeMillis() - proxyBr.getDispatchClockTime());
                    stringBuilder.append(" : receiver :");
                    stringBuilder.append(proxyBr.getBrReceivers().get(0));
                    stringBuilder.append(" : action : ");
                    stringBuilder.append(proxyBr.getAction());
                    stringBuilder.append(" : processState : ");
                    stringBuilder.append(proxyBr.getReceiverCurProcState());
                    stringBuilder.append(": adj : ");
                    stringBuilder.append(proxyBr.getReceiverCurAdj());
                    stringBuilder.append(": unproxy speed: ");
                    stringBuilder.append(this.mIawareUnProxyTime);
                    stringBuilder.append(" : size:");
                    stringBuilder.append(getIawareBrSize());
                    android.rms.iaware.AwareLog.i("AwareBroadcastProcess", stringBuilder.toString());
                }
            }
            if (proxyBr != null && proxyBr.getReceiverCurAdj() <= 0 && this.mProxyKeyBrIndex >= 0) {
                this.mProxyKeyBrIndex--;
            }
        }
        iAwareUnproxyBroadcastList(parallelList);
        parallelList.clear();
        calculateUnproxySpeed();
        unProxyBroadcast(this.mIawareUnProxyTime);
    }

    private void calculateUnproxySpeed() {
        if (!this.mIawareBrPolicy.isScreenOff()) {
            if (!isRestrictTopApp()) {
                if (isProcessProxyTopList()) {
                    if (this.mIawareBrPolicy.isSpeedNoCtrol()) {
                        this.mIawareUnProxyTime = this.mUnproxyHighSpeed;
                    } else {
                        this.mIawareUnProxyTime = this.mUnproxyMaxSpeed;
                    }
                    return;
                }
            }
            if (isProcessProxyHighAdjList()) {
                this.mIawareUnProxyTime = this.mUnproxyHighSpeed;
            } else if (this.mIawareBrPolicy.isSpeedNoCtrol()) {
                if (isProcessProxyMiddleAdjList()) {
                    this.mIawareUnProxyTime = this.mUnproxyMiddleSpeed;
                } else {
                    this.mIawareUnProxyTime = this.mUnproxyMinSpeed;
                }
            } else {
                java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareParallelBroadcasts = getProcessingList();
                int length = iawareParallelBroadcasts.size();
                if (length > 0) {
                    int minDuration;
                    int i;
                    int duration;
                    if (this.mProxyKeyBrIndex < 0) {
                        minDuration = Integer.MAX_VALUE;
                        for (i = 0; i < length; i++) {
                            duration = (int) (((((com.android.server.am.HwBroadcastRecord) iawareParallelBroadcasts.get(i)).getDispatchClockTime() + ((long) this.mUnproxyMaxDuration)) - java.lang.System.currentTimeMillis()) / ((long) (i + 1)));
                            if (duration < minDuration) {
                                minDuration = duration;
                                this.mProxyKeyBrIndex = i;
                            }
                        }
                        this.mIawareUnProxyTime = minDuration;
                    } else if (this.mProxyKeyBrIndex < length - 1) {
                        minDuration = this.mIawareUnProxyTime;
                        i = this.mProxyKeyBrIndex;
                        while (true) {
                            i++;
                            if (i >= length) {
                                break;
                            }
                            duration = (int) (((((com.android.server.am.HwBroadcastRecord) iawareParallelBroadcasts.get(i)).getDispatchClockTime() + ((long) this.mUnproxyMaxDuration)) - java.lang.System.currentTimeMillis()) / ((long) (i + 1)));
                            if (duration < minDuration) {
                                minDuration = duration;
                                this.mProxyKeyBrIndex = i;
                            }
                        }
                        this.mIawareUnProxyTime = minDuration;
                    }
                }
                resetUnproxyTime();
            }
        }
    }

    private void resetUnproxyTime() {
        int tempUnProxyTime = this.mIawareUnProxyTime > this.mUnproxyMinSpeed ? this.mIawareUnProxyTime : this.mUnproxyMinSpeed;
        this.mIawareUnProxyTime = this.mUnproxyMaxSpeed < tempUnProxyTime ? this.mUnproxyMaxSpeed : tempUnProxyTime;
    }

    private void iAwareUnproxyBroadcastList(java.util.ArrayList<com.android.server.am.HwBroadcastRecord> parallelList) {
        if (parallelList.size() > 0) {
            com.android.server.am.HwMtmBroadcastResourceManager.insertIawareBroadcast(parallelList, this.mBrName);
        }
    }

    public int getIawareBrSize() {
        int length;
        synchronized (this.mIawareParallelProxyBrMap) {
            length = 0;
            for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
                length += ((java.util.ArrayList) ent.getValue()).size();
            }
        }
        return length;
    }

    public void setUnProxySpeedScreenOff() {
        int size = getIawareBrSize();
        if (size > 0) {
            int speed = 5000 / size;
            this.mIawareUnProxyTime = speed < this.mUnproxyMinSpeed ? speed : this.mUnproxyMinSpeed;
        }
    }

    public void setUnProxyMaxDuration(int duration) {
        this.mUnproxyMaxDuration = duration;
    }

    public void setUnProxyMaxSpeed(int speed) {
        this.mUnproxyMaxSpeed = speed;
    }

    public void setUnProxyMinSpeed(int speed) {
        this.mUnproxyMinSpeed = speed;
    }

    public void setUnProxyMiddleSpeed(int speed) {
        this.mUnproxyMiddleSpeed = speed;
    }

    public void setUnProxyHighSpeed(int speed) {
        this.mUnproxyHighSpeed = speed;
    }

    public void dump(java.io.PrintWriter pw) {
        java.io.PrintWriter printWriter = pw;
        if (printWriter != null) {
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareTopParallelBroadcasts;
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareHighAdjParallelBroadcasts;
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareMiddleAdjParallelBroadcasts;
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareLowAdjParallelBroadcasts;
            int listSize;
            java.lang.String action;
            com.android.server.am.HwBroadcastRecord hwBr;
            java.lang.StringBuilder stringBuilder;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      Proxy broadcast [");
            stringBuilder2.append(this.mBrName);
            stringBuilder2.append("]");
            printWriter.println(stringBuilder2.toString());
            java.util.Set<java.lang.String> proxyActions = new android.util.ArraySet();
            android.util.ArraySet proxyTopPkgs = new android.util.ArraySet();
            android.util.ArraySet proxyHighAdjPkgs = new android.util.ArraySet();
            android.util.ArraySet proxyMiddleAdjPkgs = new android.util.ArraySet();
            android.util.ArraySet proxyLowAdjPkgs = new android.util.ArraySet();
            synchronized (this.mIawareParallelProxyBrMap) {
                try {
                    iawareTopParallelBroadcasts = new java.util.ArrayList((java.util.Collection) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(0)));
                    iawareHighAdjParallelBroadcasts = new java.util.ArrayList((java.util.Collection) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(1)));
                    iawareMiddleAdjParallelBroadcasts = new java.util.ArrayList((java.util.Collection) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(2)));
                    iawareLowAdjParallelBroadcasts = new java.util.ArrayList((java.util.Collection) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(3)));
                } catch (Throwable th) {
                    java.util.Set<java.lang.String> set = proxyActions;
                    while (true) {
                    }
                }
            }
            int lengthTop = iawareTopParallelBroadcasts.size();
            int lengthHighAdj = iawareHighAdjParallelBroadcasts.size();
            int lengthMiddleAdj = iawareMiddleAdjParallelBroadcasts.size();
            int lengthLowAdj = iawareLowAdjParallelBroadcasts.size();
            int index = 0;
            int listSize2 = iawareTopParallelBroadcasts.size();
            while (true) {
                listSize = listSize2;
                if (index >= listSize) {
                    break;
                }
                java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareTopParallelBroadcasts2 = iawareTopParallelBroadcasts;
                com.android.server.am.HwBroadcastRecord iawareTopParallelBroadcasts3 = (com.android.server.am.HwBroadcastRecord) iawareTopParallelBroadcasts.get(index);
                int listSize3 = listSize;
                action = iawareTopParallelBroadcasts3.getAction();
                proxyActions.add(action);
                proxyTopPkgs.add(iawareTopParallelBroadcasts3.getReceiverPkg());
                index++;
                iawareTopParallelBroadcasts = iawareTopParallelBroadcasts2;
                listSize2 = listSize3;
            }
            int index2 = 0;
            listSize = iawareHighAdjParallelBroadcasts.size();
            while (index2 < listSize) {
                hwBr = (com.android.server.am.HwBroadcastRecord) iawareHighAdjParallelBroadcasts.get(index2);
                int listSize4 = listSize;
                action = hwBr.getAction();
                proxyActions.add(action);
                proxyHighAdjPkgs.add(hwBr.getReceiverPkg());
                index2++;
                listSize = listSize4;
            }
            index2 = 0;
            listSize = iawareMiddleAdjParallelBroadcasts.size();
            while (index2 < listSize) {
                hwBr = (com.android.server.am.HwBroadcastRecord) iawareMiddleAdjParallelBroadcasts.get(index2);
                int listSize5 = listSize;
                action = hwBr.getAction();
                proxyActions.add(action);
                proxyMiddleAdjPkgs.add(hwBr.getReceiverPkg());
                index2++;
                listSize = listSize5;
            }
            index2 = 0;
            listSize = iawareLowAdjParallelBroadcasts.size();
            while (index2 < listSize) {
                hwBr = (com.android.server.am.HwBroadcastRecord) iawareLowAdjParallelBroadcasts.get(index2);
                int listSize6 = listSize;
                action = hwBr.getAction();
                proxyActions.add(action);
                proxyLowAdjPkgs.add(hwBr.getReceiverPkg());
                index2++;
                listSize = listSize6;
            }
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      proxy action :");
            stringBuilder2.append(proxyActions);
            printWriter.println(stringBuilder2.toString());
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      proxy Top pkg :");
            stringBuilder2.append(proxyTopPkgs);
            printWriter.println(stringBuilder2.toString());
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      proxy high adj pkg :");
            stringBuilder2.append(proxyHighAdjPkgs);
            printWriter.println(stringBuilder2.toString());
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      proxy middle adj pkg :");
            stringBuilder2.append(proxyMiddleAdjPkgs);
            printWriter.println(stringBuilder2.toString());
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("      proxy low adj pkg :");
            stringBuilder2.append(proxyLowAdjPkgs);
            printWriter.println(stringBuilder2.toString());
            index2 = ((lengthTop + lengthHighAdj) + lengthMiddleAdj) + lengthLowAdj;
            if (index2 == 0) {
                printWriter.println("      Unproxy speed :0");
                java.lang.Object obj = proxyActions;
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("      Unproxy speed :");
                stringBuilder.append(this.mIawareUnProxyTime);
                printWriter.println(stringBuilder.toString());
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("      Proxy broadcast count :");
            stringBuilder.append(index2);
            stringBuilder.append(", Top count:");
            stringBuilder.append(lengthTop);
            stringBuilder.append(", high adj count:");
            stringBuilder.append(lengthHighAdj);
            stringBuilder.append(", middle adj count:");
            stringBuilder.append(lengthMiddleAdj);
            stringBuilder.append(", low adj count:");
            stringBuilder.append(lengthLowAdj);
            printWriter.println(stringBuilder.toString());
        }
    }

    public void startUnproxyFgAppBroadcast(int pid, int uid) {
        if (getIawareBrSize() != 0) {
            android.os.Message msg = this.mHandler.obtainMessage(103, this);
            msg.arg1 = pid;
            msg.arg2 = uid;
            this.mHandler.sendMessage(msg);
        }
    }

    private void unProxyForegroundAppBroadcast(int pid, int uid) {
        if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iaware_br unProxyForegroundAppBroadcast, uid:");
            stringBuilder.append(uid);
            stringBuilder.append(", pid: ");
            stringBuilder.append(pid);
            android.rms.iaware.AwareLog.d("AwareBroadcastProcess", stringBuilder.toString());
        }
        java.util.ArrayList<com.android.server.am.HwBroadcastRecord> parallelList = (java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(0));
        synchronized (this.mIawareParallelProxyBrMap) {
            java.lang.String pkgSys = null;
            if (1000 == uid) {
                try {
                    pkgSys = getSysPkg(pid, uid);
                    if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("iaware_br unProxyForegroundAppBroadcast system app, uid:");
                        stringBuilder2.append(uid);
                        stringBuilder2.append(", pid: ");
                        stringBuilder2.append(pid);
                        stringBuilder2.append(": pkg : ");
                        stringBuilder2.append(pkgSys);
                        android.rms.iaware.AwareLog.i("AwareBroadcastProcess", stringBuilder2.toString());
                    }
                    if (pkgSys == null) {
                        return;
                    }
                } catch (Throwable th) {
                }
            }
            for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
                if (((java.lang.Integer) ent.getKey()).intValue() != 0) {
                    iAwareUnproxyBroadcastInner((java.util.ArrayList) ent.getValue(), uid, parallelList, pkgSys);
                }
            }
        }
    }

    private void iAwareUnproxyBroadcastInner(java.util.ArrayList<com.android.server.am.HwBroadcastRecord> pendingBroadcasts, int unProxyUid, java.util.ArrayList<com.android.server.am.HwBroadcastRecord> unProxyBroadcasts, java.lang.String unProxyPkgSys) {
        java.util.Iterator it = pendingBroadcasts.iterator();
        while (it.hasNext()) {
            com.android.server.am.HwBroadcastRecord br = (com.android.server.am.HwBroadcastRecord) it.next();
            if (unProxyUid != 1000 || unProxyPkgSys == null) {
                if (br.getReceiverUid() == unProxyUid) {
                    unProxyBroadcasts.add(br);
                    it.remove();
                }
            } else if (unProxyPkgSys.equals(br.getReceiverPkg())) {
                unProxyBroadcasts.add(br);
                it.remove();
            }
        }
    }

    private boolean isEmptyProxyMap() {
        for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
            if (((java.util.ArrayList) ent.getValue()).size() > 0) {
                return false;
            }
        }
        return true;
    }

    private boolean isProcessProxyTopList() {
        return ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(0))).size() != 0;
    }

    private boolean isProcessProxyHighAdjList() {
        return ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(1))).size() != 0;
    }

    private boolean isProcessProxyMiddleAdjList() {
        return ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(0))).size() == 0 && ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(1))).size() == 0 && ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(2))).size() != 0;
    }

    private com.android.server.am.HwBroadcastRecord getNextUnProxyBr() {
        for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareParallelBrList = (java.util.ArrayList) ent.getValue();
            if (isRestrictTopApp() && ((java.lang.Integer) ent.getKey()).intValue() == 0) {
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    android.rms.iaware.AwareLog.i("AwareBroadcastProcess", "iaware_br don't unproxy top app's br");
                }
            } else if (iawareParallelBrList.size() > 0) {
                return (com.android.server.am.HwBroadcastRecord) iawareParallelBrList.remove(0);
            }
        }
        return null;
    }

    private java.util.ArrayList<com.android.server.am.HwBroadcastRecord> getProcessingList() {
        if (isProcessProxyMiddleAdjList()) {
            return (java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(2));
        }
        return (java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(3));
    }

    private void processAdjChange(com.android.server.am.HwBroadcastRecord r) {
        java.lang.String pkg = r.getReceiverPkg();
        if (pkg != null) {
            int pid = r.getReceiverPid();
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareMiddleBrList = (java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(2));
            java.util.Iterator it = ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(3))).iterator();
            while (it.hasNext()) {
                com.android.server.am.HwBroadcastRecord br = (com.android.server.am.HwBroadcastRecord) it.next();
                if (br.getReceiverPid() == pid && pkg.equals(br.getReceiverPkg())) {
                    if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_br adj change, transfer: ");
                        stringBuilder.append(br.getBrReceivers().get(0));
                        android.rms.iaware.AwareLog.d("AwareBroadcastProcess", stringBuilder.toString());
                    }
                    iawareMiddleBrList.add(br);
                    it.remove();
                }
            }
        }
    }

    private void trimProxyBr(com.android.server.am.HwBroadcastRecord r, int level) {
        if (this.mIawareBrPolicy.isTrimAction(r.getAction())) {
            java.util.Iterator it = ((java.util.ArrayList) this.mIawareParallelProxyBrMap.get(java.lang.Integer.valueOf(level))).iterator();
            while (it.hasNext()) {
                com.android.server.am.HwBroadcastRecord br = (com.android.server.am.HwBroadcastRecord) it.next();
                if (canTrim(r, br)) {
                    if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("iaware_br brtrim success: ");
                        stringBuilder.append(br.getBrReceivers().get(0));
                        stringBuilder.append(": action: ");
                        stringBuilder.append(r.getAction());
                        android.rms.iaware.AwareLog.d("AwareBroadcastProcess", stringBuilder.toString());
                    }
                    it.remove();
                    return;
                }
            }
        }
    }

    private boolean canTrim(com.android.server.am.HwBroadcastRecord newBr, com.android.server.am.HwBroadcastRecord oldBr) {
        java.lang.String pkg1 = newBr.getReceiverPkg();
        java.lang.String pkg2 = oldBr.getReceiverPkg();
        if (pkg1 != null) {
            if (pkg2 != null) {
                if (!pkg1.equals(pkg2) || !newBr.isSameReceiver(oldBr)) {
                    return false;
                }
                java.lang.String action1 = newBr.getAction();
                java.lang.String action2 = oldBr.getAction();
                if (action1 != null) {
                    if (action2 != null) {
                        if (!action1.equals(action2)) {
                            return false;
                        }
                        if ("android.net.conn.CONNECTIVITY_CHANGE".equals(action1)) {
                            return canConnectivityDataTrim(newBr.getIntent(), oldBr.getIntent());
                        }
                        if ("android.net.wifi.STATE_CHANGE".equals(action1)) {
                            return canWifiDataTrim(newBr.getIntent(), oldBr.getIntent());
                        }
                        return true;
                    }
                }
                return false;
            }
        }
        return false;
    }

    private boolean canConnectivityDataTrim(android.content.Intent newIntent, android.content.Intent oldIntent) {
        int newType = newIntent.getIntExtra("networkType", -1);
        if (newType != oldIntent.getIntExtra("networkType", -1)) {
            return false;
        }
        if (newType == 0 || newType == 1) {
            android.net.NetworkInfo newInfo = null;
            android.net.NetworkInfo oldInfo = null;
            try {
                newInfo = (android.net.NetworkInfo) newIntent.getExtra("networkInfo");
                oldInfo = (android.net.NetworkInfo) oldIntent.getExtra("networkInfo");
            } catch (java.lang.ClassCastException e) {
                if (com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail()) {
                    android.rms.iaware.AwareLog.e("AwareBroadcastProcess", "iaware_br get NetworkInfo from intent error.");
                }
            }
            if (newInfo == null || oldInfo == null || newInfo.getState() != oldInfo.getState()) {
                return false;
            }
            return true;
        }
        return false;
    }

    private boolean canWifiDataTrim(android.content.Intent newIntent, android.content.Intent oldIntent) {
        android.net.NetworkInfo newNetworkInfo = (android.net.NetworkInfo) newIntent.getParcelableExtra("networkInfo");
        android.net.NetworkInfo oldNetworkInfo = (android.net.NetworkInfo) oldIntent.getParcelableExtra("networkInfo");
        if (newNetworkInfo == null || oldNetworkInfo == null || newNetworkInfo.getState() != oldNetworkInfo.getState() || newNetworkInfo.getDetailedState() != oldNetworkInfo.getDetailedState()) {
            return false;
        }
        return true;
    }

    private java.lang.String getSysPkg(int pid, int uid) {
        for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
            java.util.ArrayList<com.android.server.am.HwBroadcastRecord> iawareBrList = (java.util.ArrayList) ent.getValue();
            int listSize = iawareBrList.size();
            for (int index = 0; index < listSize; index++) {
                com.android.server.am.HwBroadcastRecord hwBr = (com.android.server.am.HwBroadcastRecord) iawareBrList.get(index);
                if (hwBr.getReceiverPid() == pid && hwBr.getReceiverUid() == uid) {
                    return hwBr.getReceiverPkg();
                }
            }
        }
        return null;
    }

    private boolean isRestrictTopApp() {
        return this.mIawareBrPolicy.isInstallApp() && !this.mIawareBrPolicy.isSpeedNoCtrol() && isProcessProxyTopList();
    }

    private void processException() {
        synchronized (this.mIawareParallelProxyBrMap) {
            int length = 0;
            for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent : this.mIawareParallelProxyBrMap.entrySet()) {
                length += ((java.util.ArrayList) ent.getValue()).size();
            }
            if (length > 10000) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("iaware_br proxy length more than ");
                stringBuilder.append(length);
                stringBuilder.append(", clear all proxy br");
                android.rms.iaware.AwareLog.w("AwareBroadcastProcess", stringBuilder.toString());
                for (java.util.Map.Entry<java.lang.Integer, java.util.ArrayList<com.android.server.am.HwBroadcastRecord>> ent2 : this.mIawareParallelProxyBrMap.entrySet()) {
                    ((java.util.ArrayList) ent2.getValue()).clear();
                }
            }
        }
    }
}
