package com.android.server.mtm.iaware.srms;

public class AwareBroadcastRegister {
    private static final java.lang.String ITEM_REPORT_THRESHOLD = "brreg_report_threshold";
    private static final java.lang.String MISC_ASSEMBLE_CONDITION = "brreg_assemble_condition";
    private static final java.lang.String MISC_BIGDATA_THRESHOLD = "bigdata_threshold";
    private static final java.lang.String SPLIT_VALUE = ",";
    private static final java.lang.String TAG = "AwareBroadcastRegister brreg";
    private static com.android.server.mtm.iaware.srms.AwareBroadcastRegister mBroadcastRegister = null;
    private final java.util.HashMap<java.lang.String, java.util.HashMap<java.lang.String, java.lang.String>> mBRAssembleConditons;
    private final java.util.HashMap<java.lang.String, java.lang.Integer> mBRCounts;
    private int mBrRegisterReportThreshold;
    private final java.lang.Object mConfigLock;
    private com.android.server.am.HwActivityManagerService mHwAMS;
    private final java.util.HashMap<java.lang.String, java.util.HashMap<java.lang.String, java.lang.String>> mPkgBRsWithCondition;

    public static synchronized com.android.server.mtm.iaware.srms.AwareBroadcastRegister getInstance() {
        com.android.server.mtm.iaware.srms.AwareBroadcastRegister awareBroadcastRegister;
        synchronized (com.android.server.mtm.iaware.srms.AwareBroadcastRegister.class) {
            if (mBroadcastRegister == null) {
                mBroadcastRegister = new com.android.server.mtm.iaware.srms.AwareBroadcastRegister();
                mBroadcastRegister.updateConfigData();
            }
            awareBroadcastRegister = mBroadcastRegister;
        }
        return awareBroadcastRegister;
    }

    private AwareBroadcastRegister() {
        this.mBRCounts = new java.util.HashMap();
        this.mPkgBRsWithCondition = new java.util.HashMap();
        this.mBRAssembleConditons = new java.util.HashMap();
        this.mHwAMS = null;
        this.mConfigLock = new java.lang.Object();
        this.mBrRegisterReportThreshold = 30;
        this.mHwAMS = com.android.server.am.HwActivityManagerService.self();
    }

    public void updateConfigData() {
        java.lang.StringBuilder stringBuilder;
        if (this.mHwAMS == null) {
            android.rms.iaware.AwareLog.e("AwareBroadcastRegister brreg", "failed to get HwAMS");
            return;
        }
        com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().updateRule(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.BROADCAST, this.mHwAMS.getUiContext());
        synchronized (this.mConfigLock) {
            int size;
            int i;
            java.lang.String item;
            java.lang.String[] configList;
            java.util.ArrayList<java.lang.String> defaultThresholdList = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.BROADCAST.getDesc(), "bigdata_threshold");
            int i2 = 0;
            int i3 = 2;
            int i4 = 1;
            if (defaultThresholdList != null) {
                size = defaultThresholdList.size();
                for (i = 0; i < size; i++) {
                    item = (java.lang.String) defaultThresholdList.get(i);
                    if (!(item == null || item.isEmpty())) {
                        configList = item.split(",");
                        if (configList.length < 2) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("invalid config: ");
                            stringBuilder2.append(item);
                            android.rms.iaware.AwareLog.e("AwareBroadcastRegister brreg", stringBuilder2.toString());
                        } else {
                            try {
                                if (configList[0].trim().equals("brreg_report_threshold")) {
                                    this.mBrRegisterReportThreshold = java.lang.Integer.parseInt(configList[1].trim());
                                }
                            } catch (java.lang.NumberFormatException e) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("invalid config: ");
                                stringBuilder.append(item);
                                android.rms.iaware.AwareLog.e("AwareBroadcastRegister brreg", stringBuilder.toString());
                            }
                        }
                    }
                }
            }
            this.mBRAssembleConditons.clear();
            this.mPkgBRsWithCondition.clear();
            java.util.ArrayList<java.lang.String> brAssembleCondition = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.BROADCAST.getDesc(), "brreg_assemble_condition");
            if (brAssembleCondition != null) {
                size = 0;
                i = brAssembleCondition.size();
                while (size < i) {
                    item = (java.lang.String) brAssembleCondition.get(size);
                    if (!(item == null || item.isEmpty())) {
                        configList = item.split(",");
                        if (configList.length < i3) {
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("invalid config: ");
                            stringBuilder.append(item);
                            android.rms.iaware.AwareLog.e("AwareBroadcastRegister brreg", stringBuilder.toString());
                        } else {
                            java.lang.String acId = configList[i2].trim();
                            java.lang.String condition = configList[i4].trim();
                            java.lang.String action = getActionFromAssembleCondition(condition);
                            java.lang.String pkg = getPackageNameFromId(acId);
                            java.lang.String receiver = getReceiverFromAcID(acId);
                            if (!(receiver == null || receiver.startsWith("."))) {
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append(".");
                                stringBuilder3.append(receiver);
                                receiver = stringBuilder3.toString();
                            }
                            if (!(action == null || pkg == null)) {
                                java.util.HashMap<java.lang.String, java.lang.String> receiverMap = (java.util.HashMap) this.mPkgBRsWithCondition.get(pkg);
                                if (receiverMap == null) {
                                    receiverMap = new java.util.HashMap();
                                    this.mPkgBRsWithCondition.put(pkg, receiverMap);
                                }
                                receiverMap.put(receiver, acId);
                                java.util.HashMap<java.lang.String, java.lang.String> innerMap = (java.util.HashMap) this.mBRAssembleConditons.get(acId);
                                if (innerMap == null) {
                                    innerMap = new java.util.HashMap();
                                    this.mBRAssembleConditons.put(acId, innerMap);
                                }
                                innerMap.put(action, condition);
                            }
                        }
                    }
                    size++;
                    i2 = 0;
                    i3 = 2;
                    i4 = 1;
                }
            }
        }
    }

    public int getBRRegisterReportThreshold() {
        int i;
        synchronized (this.mConfigLock) {
            i = this.mBrRegisterReportThreshold;
        }
        return i;
    }

    public java.util.HashMap<java.lang.String, java.lang.Integer> getBRCounts() {
        java.util.HashMap hashMap;
        synchronized (this.mBRCounts) {
            hashMap = this.mBRCounts;
        }
        return hashMap;
    }

    public int countReceiverRegister(boolean isRegister, java.lang.String brId) {
        int intValue;
        synchronized (this.mBRCounts) {
            java.lang.Integer count;
            if (isRegister) {
                if (brId != null) {
                    try {
                        if (!brId.isEmpty()) {
                            count = (java.lang.Integer) this.mBRCounts.get(brId);
                            if (count == null) {
                                this.mBRCounts.put(brId, java.lang.Integer.valueOf(1));
                            } else {
                                this.mBRCounts.put(brId, java.lang.Integer.valueOf(count.intValue() + 1));
                            }
                        }
                    } finally {
                    }
                }
            } else if (!(brId == null || brId.isEmpty())) {
                count = (java.lang.Integer) this.mBRCounts.get(brId);
                if (count != null) {
                    java.lang.Integer newCount = java.lang.Integer.valueOf(count.intValue() - 1);
                    if (newCount.intValue() == 0) {
                        this.mBRCounts.remove(brId);
                    } else {
                        this.mBRCounts.put(brId, newCount);
                    }
                }
            }
            intValue = this.mBRCounts.get(brId) == null ? 0 : ((java.lang.Integer) this.mBRCounts.get(brId)).intValue();
        }
        return intValue;
    }

    public static java.lang.String removeBRIdUncommonData(java.lang.String brId) {
        int pidPositionEnd;
        java.lang.StringBuffer sb = new java.lang.StringBuffer(brId);
        int pidPositionStart = sb.indexOf("+");
        if (pidPositionStart != -1) {
            pidPositionEnd = sb.indexOf("+", pidPositionStart + 1);
            if (pidPositionEnd != -1) {
                sb.delete(pidPositionStart, pidPositionEnd);
            }
        }
        pidPositionEnd = sb.indexOf("@");
        if (pidPositionEnd != -1) {
            int objectAddressPositionEnd = sb.indexOf("+", pidPositionEnd);
            if (objectAddressPositionEnd != -1) {
                sb.delete(pidPositionEnd, objectAddressPositionEnd);
            }
        }
        return sb.toString();
    }

    /* JADX WARNING: Missing block: B:30:0x007a, code:
            return null;
     */
    public java.lang.String findMatchedAssembleConditionId(java.lang.String r9) {
        /*
        r8 = this;
        r0 = 0;
        if (r9 != 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = getPackageNameFromId(r9);
        if (r1 == 0) goto L_0x007e;
    L_0x000a:
        r2 = r1.isEmpty();
        if (r2 == 0) goto L_0x0011;
    L_0x0010:
        goto L_0x007e;
    L_0x0011:
        r2 = r8.mConfigLock;
        monitor-enter(r2);
        r3 = r8.mPkgBRsWithCondition;	 Catch:{ all -> 0x007b }
        r3 = r3.get(r1);	 Catch:{ all -> 0x007b }
        r3 = (java.util.HashMap) r3;	 Catch:{ all -> 0x007b }
        if (r3 == 0) goto L_0x0079;
    L_0x001e:
        r4 = r3.entrySet();	 Catch:{ all -> 0x007b }
        r4 = r4.iterator();	 Catch:{ all -> 0x007b }
    L_0x0026:
        r5 = r4.hasNext();	 Catch:{ all -> 0x007b }
        if (r5 == 0) goto L_0x0079;
    L_0x002c:
        r5 = r4.next();	 Catch:{ all -> 0x007b }
        r5 = (java.util.Map.Entry) r5;	 Catch:{ all -> 0x007b }
        r6 = r5.getKey();	 Catch:{ all -> 0x007b }
        r6 = (java.lang.String) r6;	 Catch:{ all -> 0x007b }
        if (r6 == 0) goto L_0x0078;
    L_0x003a:
        r7 = r6.isEmpty();	 Catch:{ all -> 0x007b }
        if (r7 != 0) goto L_0x0078;
    L_0x0040:
        r7 = r9.contains(r6);	 Catch:{ all -> 0x007b }
        if (r7 == 0) goto L_0x0078;
    L_0x0046:
        r0 = com.android.server.mtm.iaware.srms.AwareBroadcastDebug.getDebugDetail();	 Catch:{ all -> 0x007b }
        if (r0 == 0) goto L_0x0070;
    L_0x004c:
        r0 = "AwareBroadcastRegister brreg";
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x007b }
        r4.<init>();	 Catch:{ all -> 0x007b }
        r7 = "Hit !  brId:";
        r4.append(r7);	 Catch:{ all -> 0x007b }
        r4.append(r9);	 Catch:{ all -> 0x007b }
        r7 = " match  acId: ";
        r4.append(r7);	 Catch:{ all -> 0x007b }
        r7 = r5.getValue();	 Catch:{ all -> 0x007b }
        r7 = (java.lang.String) r7;	 Catch:{ all -> 0x007b }
        r4.append(r7);	 Catch:{ all -> 0x007b }
        r4 = r4.toString();	 Catch:{ all -> 0x007b }
        android.rms.iaware.AwareLog.i(r0, r4);	 Catch:{ all -> 0x007b }
    L_0x0070:
        r0 = r5.getValue();	 Catch:{ all -> 0x007b }
        r0 = (java.lang.String) r0;	 Catch:{ all -> 0x007b }
        monitor-exit(r2);	 Catch:{ all -> 0x007b }
        return r0;
    L_0x0078:
        goto L_0x0026;
    L_0x0079:
        monitor-exit(r2);	 Catch:{ all -> 0x007b }
        return r0;
    L_0x007b:
        r0 = move-exception;
        monitor-exit(r2);	 Catch:{ all -> 0x007b }
        throw r0;
    L_0x007e:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.srms.AwareBroadcastRegister.findMatchedAssembleConditionId(java.lang.String):java.lang.String");
    }

    public java.lang.String getBRAssembleCondition(java.lang.String acId, java.lang.String action) {
        if (acId != null) {
            if (action != null) {
                synchronized (this.mConfigLock) {
                    java.util.HashMap<java.lang.String, java.lang.String> conditions = (java.util.HashMap) this.mBRAssembleConditons.get(acId);
                    if (conditions != null) {
                        java.lang.String str = (java.lang.String) conditions.get(action);
                        return str;
                    }
                    return null;
                }
            }
        }
        return null;
    }

    private static java.lang.String getPackageNameFromId(java.lang.String brId) {
        if (brId == null) {
            return null;
        }
        int pkgPositionEnd = brId.indexOf("+");
        if (pkgPositionEnd != -1) {
            return brId.substring(0, pkgPositionEnd);
        }
        return null;
    }

    private static java.lang.String getReceiverFromAcID(java.lang.String acId) {
        if (acId == null) {
            return null;
        }
        int receiverPositionStart = acId.lastIndexOf("+");
        if (receiverPositionStart == -1) {
            return null;
        }
        try {
            return acId.substring(receiverPositionStart + 1, acId.length());
        } catch (java.lang.IndexOutOfBoundsException e) {
            android.rms.iaware.AwareLog.e("AwareBroadcastRegister brreg", "acId process error");
            return null;
        }
    }

    private static java.lang.String getActionFromAssembleCondition(java.lang.String condition) {
        if (condition == null) {
            return null;
        }
        java.lang.String action = null;
        int actionEndPosition = condition.indexOf("@");
        if (actionEndPosition != -1) {
            action = condition.substring(0, actionEndPosition);
        }
        return action;
    }

    public void dumpBRRegConfig(java.io.PrintWriter pw) {
        updateConfigData();
        synchronized (this.mConfigLock) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("brreg_report_threshold: ");
            stringBuilder.append(this.mBrRegisterReportThreshold);
            pw.println(stringBuilder.toString());
            pw.println("Assemble conditions:");
            for (java.util.Map.Entry<java.lang.String, java.util.HashMap<java.lang.String, java.lang.String>> entry : this.mBRAssembleConditons.entrySet()) {
                if (entry.getValue() != null) {
                    for (java.util.Map.Entry<java.lang.String, java.lang.String> innerEntry : ((java.util.HashMap) entry.getValue()).entrySet()) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append((java.lang.String) entry.getKey());
                        stringBuilder2.append(", ");
                        stringBuilder2.append((java.lang.String) innerEntry.getValue());
                        pw.println(stringBuilder2.toString());
                    }
                }
            }
        }
    }

    public void dumpIawareBRRegInfo(java.io.PrintWriter pw) {
        synchronized (this.mBRCounts) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("BR register ID and count:");
            stringBuilder.append(this.mBRCounts.size());
            pw.println(stringBuilder.toString());
            for (java.util.Map.Entry<java.lang.String, java.lang.Integer> entry : this.mBRCounts.entrySet()) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("");
                stringBuilder2.append((java.lang.String) entry.getKey());
                stringBuilder2.append(",");
                stringBuilder2.append(entry.getValue());
                pw.println(stringBuilder2.toString());
            }
        }
    }
}
