package com.android.server.mtm.taskstatus;

public class ProcessCleaner {
    private static final int CLEAN_PID_NOTIFICATION = 2;
    private static final int CLEAN_UID_NOTIFICATION = 1;
    private static final int PROTECTED_APP_NUM_FROM_MDM = 3;
    private static final java.lang.String TAG = "ProcessCleaner";
    private static com.android.server.mtm.taskstatus.ProcessCleaner mProcessCleaner = null;
    private android.app.ActivityManager mActivityManager;
    android.os.Handler mHandler;
    private com.android.server.am.HwActivityManagerService mHwAMS;
    private java.util.ArrayList<java.lang.String> mMDMProtectedList;
    private com.android.server.mtm.taskstatus.ProcessInfoCollector mProcInfoCollector;

    public enum CleanType {
        NONE("do-nothing"),
        COMPACT("compact"),
        REMOVETASK("removetask"),
        KILL_ALLOW_START("kill-allow-start"),
        KILL_FORBID_START("kill-forbid-start"),
        KILL_DELAY_START("kill-delay-start"),
        FORCESTOP("force-stop"),
        FORCESTOP_REMOVETASK("force-stop-removetask"),
        FREEZE_NOMAL("freeze-nomal"),
        FREEZE_UP_DOWNLOAD("freeze-up-download"),
        IOLIMIT("iolimit"),
        FORCESTOP_ALARM("force-stop-alarm");
        
        java.lang.String mDescription;

        private CleanType(java.lang.String description) {
            this.mDescription = description;
        }

        public java.lang.String description() {
            return this.mDescription;
        }
    }

    private ProcessCleaner(android.content.Context context) {
        this.mHwAMS = null;
        this.mProcInfoCollector = null;
        this.mActivityManager = null;
        this.mMDMProtectedList = new java.util.ArrayList();
        this.mHandler = new android.os.Handler(android.os.Looper.getMainLooper()) {
            public void handleMessage(android.os.Message msg) {
                switch (msg.what) {
                    case 1:
                        com.android.server.mtm.taskstatus.ProcessCleaner.this.cleanPackageNotifications((java.util.List) msg.obj, msg.arg1);
                        return;
                    case 2:
                        com.android.server.mtm.taskstatus.ProcessCleaner.this.cleanNotificationWithPid((java.util.List) msg.obj, msg.arg1, msg.arg2);
                        return;
                    default:
                        return;
                }
            }
        };
        this.mProcInfoCollector = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance();
        this.mHwAMS = com.android.server.am.HwActivityManagerService.self();
        if (this.mHwAMS == null) {
            android.util.Slog.e("ProcessCleaner", "init failed to get HwAMS handler");
        }
        this.mActivityManager = (android.app.ActivityManager) context.getSystemService("activity");
    }

    public static synchronized com.android.server.mtm.taskstatus.ProcessCleaner getInstance(android.content.Context context) {
        com.android.server.mtm.taskstatus.ProcessCleaner processCleaner;
        synchronized (com.android.server.mtm.taskstatus.ProcessCleaner.class) {
            if (mProcessCleaner == null) {
                mProcessCleaner = new com.android.server.mtm.taskstatus.ProcessCleaner(context);
            }
            processCleaner = mProcessCleaner;
        }
        return processCleaner;
    }

    public int uniformClean(com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo procGroup, android.os.Bundle extras, java.lang.String reason) {
        int killedCount = 0;
        if (procGroup == null) {
            return 0;
        }
        if (!(procGroup.mProcessList == null || procGroup.mProcessList.isEmpty())) {
            switch (procGroup.mCleanType) {
                case KILL_ALLOW_START:
                case KILL_FORBID_START:
                    for (com.android.server.mtm.iaware.appmng.AwareProcessInfo awareProc : procGroup.mProcessList) {
                        if (killProcess(awareProc.mPid, procGroup.mCleanType == com.android.server.mtm.taskstatus.ProcessCleaner.CleanType.KILL_ALLOW_START, reason)) {
                            killedCount++;
                        }
                    }
                    break;
                case REMOVETASK:
                    int result = removetask(procGroup);
                    if (result > 0) {
                        killedCount = 0 + result;
                        break;
                    }
                    break;
                case FORCESTOP_REMOVETASK:
                    if (forcestopAppsAsUser((com.android.server.mtm.iaware.appmng.AwareProcessInfo) procGroup.mProcessList.get(0), reason)) {
                        killedCount = 0 + procGroup.mProcessList.size();
                    }
                    removetask(procGroup);
                    break;
                case FORCESTOP:
                    if (forcestopAppsAsUser((com.android.server.mtm.iaware.appmng.AwareProcessInfo) procGroup.mProcessList.get(0), reason)) {
                        killedCount = 0 + procGroup.mProcessList.size();
                        break;
                    }
                    break;
                case FORCESTOP_ALARM:
                    java.util.List<java.lang.Integer> killedPid = killProcessesSameUidExt(procGroup, null, false, false, reason);
                    if (killedPid != null) {
                        killedCount = 0 + killedPid.size();
                        break;
                    }
                    break;
                default:
                    break;
            }
        }
        return killedCount;
    }

    private java.util.Map<java.lang.String, java.util.List<java.lang.String>> getAlarmTags(int uid, java.util.List<java.lang.String> packageList) {
        java.util.Map<java.lang.String, java.util.List<java.lang.String>> map = null;
        if (packageList != null) {
            if (!packageList.isEmpty()) {
                java.util.Map<java.lang.String, java.util.List<java.lang.String>> tags = new android.util.ArrayMap();
                boolean clearAll = true;
                for (java.lang.String pkg : packageList) {
                    java.util.List<java.lang.String> list = com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance().getAllInvalidAlarmTags(uid, pkg);
                    if (list != null) {
                        clearAll = false;
                        tags.put(pkg, list);
                    }
                }
                if (!clearAll) {
                    map = tags;
                }
                return map;
            }
        }
        return null;
    }

    public boolean killProcess(int pid, boolean restartservice) {
        return killProcess(pid, restartservice, "null");
    }

    public boolean killProcess(int pid, boolean restartservice, java.lang.String reason) {
        long start = android.os.SystemClock.elapsedRealtime();
        if (this.mProcInfoCollector.INFO) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("process cleaner kill process: pid is ");
            stringBuilder.append(pid);
            stringBuilder.append(", restart service :");
            stringBuilder.append(restartservice);
            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
        }
        com.android.server.mtm.taskstatus.ProcessInfo temp = this.mProcInfoCollector.getProcessInfo(pid);
        if (temp == null) {
            android.util.Slog.e("ProcessCleaner", "process cleaner kill process: process info is null ");
            return false;
        } else if (this.mHwAMS == null) {
            android.util.Slog.e("ProcessCleaner", "process cleaner kill process: mHwAMS is null ");
            return false;
        } else if (com.huawei.android.app.HwActivityManager.killProcessRecordFromMTM(temp, restartservice, reason)) {
            this.mProcInfoCollector.recordKilledProcess(temp);
            long end = android.os.SystemClock.elapsedRealtime();
            if (this.mProcInfoCollector.INFO) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("process cleaner kill process: pid is ");
                stringBuilder2.append(pid);
                stringBuilder2.append(",last time :");
                stringBuilder2.append(end - start);
                android.util.Slog.d("ProcessCleaner", stringBuilder2.toString());
            }
            return true;
        } else {
            android.util.Slog.e("ProcessCleaner", "process cleaner kill process: failed to kill ");
            return false;
        }
    }

    public int removetask(com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo procGroup) {
        if (procGroup == null) {
            return 0;
        }
        if (this.mHwAMS == null) {
            android.rms.iaware.AwareLog.e("ProcessCleaner", "process cleaner kill process: mHwAMS is null ");
            return 0;
        } else if (procGroup.mProcessList == null) {
            return 0;
        } else {
            java.util.HashSet<java.lang.Integer> taskIdSet = new java.util.HashSet();
            boolean success = false;
            for (com.android.server.mtm.iaware.appmng.AwareProcessInfo awareProc : procGroup.mProcessList) {
                if (awareProc != null) {
                    taskIdSet.add(java.lang.Integer.valueOf(awareProc.mTaskId));
                }
            }
            java.util.Iterator it = taskIdSet.iterator();
            while (it.hasNext()) {
                java.lang.Integer taskId = (java.lang.Integer) it.next();
                if (taskId.intValue() != -1) {
                    if (this.mHwAMS.removeTask(taskId.intValue())) {
                        success = true;
                    } else {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("fail to removeTask: ");
                        stringBuilder.append(taskId);
                        android.rms.iaware.AwareLog.e("ProcessCleaner", stringBuilder.toString());
                    }
                }
            }
            if (success) {
                return procGroup.mProcessList.size();
            }
            return 0;
        }
    }

    public java.util.List<java.lang.Integer> killProcessesSameUidExt(com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo procGroup, boolean quickKillAction, java.lang.String reason) {
        return killProcessesSameUidExt(procGroup, null, true, quickKillAction, reason);
    }

    public java.util.List<java.lang.Integer> killProcessesSameUidExt(com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo procGroup, java.util.concurrent.atomic.AtomicBoolean interrupt, boolean isAsynchronous, boolean quickKillAction, java.lang.String reason) {
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> dfxDataList;
        java.lang.Throwable pidCantStop;
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> list;
        boolean isCleanAllRes;
        boolean hasPerceptAlarm;
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> pidsWithNotification;
        boolean hasPerceptAlarm2;
        boolean isCleanAllRes2;
        com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo awareProcessBlockInfo = procGroup;
        java.lang.String str = reason;
        if (awareProcessBlockInfo == null) {
            return null;
        }
        java.lang.StringBuilder stringBuilder;
        int targetUid = awareProcessBlockInfo.mUid;
        boolean resCleanAllow = awareProcessBlockInfo.mResCleanAllow;
        if (resCleanAllow) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iAwareF[");
            stringBuilder.append(str);
            stringBuilder.append("]");
            str = stringBuilder.toString();
        } else {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("iAwareK[");
            stringBuilder.append(str);
            stringBuilder.append("]");
            str = stringBuilder.toString();
        }
        java.lang.String reason2 = str;
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procInfoAllStopList = procGroup.getProcessList();
        boolean z;
        int i;
        if (targetUid == 0) {
            z = quickKillAction;
            i = targetUid;
        } else if (procInfoAllStopList == null) {
            z = quickKillAction;
            i = targetUid;
        } else if (this.mHwAMS == null) {
            android.util.Slog.e("ProcessCleaner", "[aware_mem] Why mHwAMS is null!!");
            return null;
        } else if (checkPkgInProtectedListFromMDM(awareProcessBlockInfo.mPackageName)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[aware_mem] ");
            stringBuilder.append(awareProcessBlockInfo.mPackageName);
            stringBuilder.append(" protected by MDM");
            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
            return null;
        } else {
            java.util.List<java.lang.Integer> killList = new java.util.ArrayList();
            java.util.List<java.lang.String> packageList = getPackageList(procInfoAllStopList);
            java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> pidsWithNotification2 = getPidsWithNotification(procInfoAllStopList);
            if (this.mProcInfoCollector.INFO) {
                android.util.Slog.d("ProcessCleaner", "[aware_mem] start process cleaner kill process start");
            }
            com.android.server.mtm.iaware.appmng.AwareAppMngSort appMngSort = com.android.server.mtm.iaware.appmng.AwareAppMngSort.getInstance();
            java.lang.StringBuilder stringBuilder2;
            if (awareProcessBlockInfo.mIsNativeForceStop || appMngSort == null || !appMngSort.isProcessBlockPidChanged(awareProcessBlockInfo)) {
                boolean isCleanAllRes3 = resCleanAllow;
                boolean isCleanUidActivity = false;
                boolean needCheckAlarm = appMngSort != null ? appMngSort.needCheckAlarm(awareProcessBlockInfo) : true;
                java.util.Map<java.lang.String, java.util.List<java.lang.String>> alarmTagMap = null;
                if (!awareProcessBlockInfo.mIsNativeForceStop) {
                    alarmTagMap = getAlarmTags(targetUid, packageList);
                }
                java.util.Map<java.lang.String, java.util.List<java.lang.String>> alarmTagMap2 = alarmTagMap;
                boolean hasPerceptAlarm3 = com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance().hasPerceptAlarm(targetUid, packageList);
                java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> pidsWithNotification3 = pidsWithNotification2;
                com.android.server.am.HwActivityManagerService targetUid2 = this.mHwAMS;
                synchronized (targetUid2) {
                    boolean z2;
                    com.android.server.mtm.iaware.appmng.AwareAppMngSort awareAppMngSort;
                    com.android.server.am.HwActivityManagerService hwActivityManagerService;
                    java.util.Map<java.lang.String, java.util.List<java.lang.String>> map;
                    java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> dfxDataList2;
                    android.util.ArraySet<java.lang.Integer> pidCantStop2;
                    com.android.server.mtm.iaware.appmng.AwareProcessInfo info;
                    int targetUid3;
                    java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> list2;
                    if (resCleanAllow) {
                        try {
                            dfxDataList = null;
                            try {
                                android.util.Slog.d("ProcessCleaner", "[aware_mem] start process cleaner setPackageStoppedState");
                                this.mHwAMS.setPackageStoppedState(packageList, true, targetUid);
                            } catch (Throwable th) {
                                pidCantStop = th;
                                z = quickKillAction;
                                z2 = false;
                                isCleanUidActivity = hasPerceptAlarm3;
                                awareAppMngSort = appMngSort;
                                hwActivityManagerService = targetUid2;
                                map = alarmTagMap2;
                                i = targetUid;
                                list = pidsWithNotification3;
                                targetUid = dfxDataList;
                            }
                        } catch (Throwable th2) {
                            pidCantStop = th2;
                            dfxDataList2 = quickKillAction;
                            z2 = false;
                            isCleanUidActivity = hasPerceptAlarm3;
                            awareAppMngSort = appMngSort;
                            hwActivityManagerService = targetUid2;
                            map = alarmTagMap2;
                            i = targetUid;
                            list = pidsWithNotification3;
                            targetUid = null;
                            while (true) {
                                try {
                                    break;
                                } catch (Throwable th3) {
                                    pidCantStop = th3;
                                }
                            }
                            throw pidCantStop;
                        }
                    }
                    dfxDataList = null;
                    try {
                        pidCantStop2 = new android.util.ArraySet();
                        if (!awareProcessBlockInfo.mIsNativeForceStop) {
                            try {
                                java.util.Iterator it = procInfoAllStopList.iterator();
                                while (it.hasNext()) {
                                    java.util.Iterator it2;
                                    com.android.server.mtm.iaware.appmng.AwareProcessInfo info2 = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) it.next();
                                    if (appMngSort != null) {
                                        it2 = it;
                                        info = info2;
                                        if (info != null) {
                                            isCleanAllRes = isCleanAllRes3;
                                            try {
                                                if (info.mProcInfo) {
                                                    z2 = isCleanUidActivity;
                                                    try {
                                                        hasPerceptAlarm = hasPerceptAlarm3;
                                                        try {
                                                            map = alarmTagMap2;
                                                        } catch (Throwable th4) {
                                                            pidCantStop = th4;
                                                            map = alarmTagMap2;
                                                            z = quickKillAction;
                                                            awareAppMngSort = appMngSort;
                                                            hwActivityManagerService = targetUid2;
                                                            i = targetUid;
                                                            list = pidsWithNotification3;
                                                            targetUid = dfxDataList;
                                                            isCleanAllRes3 = isCleanAllRes;
                                                            isCleanUidActivity = hasPerceptAlarm;
                                                            while (true) {
                                                                break;
                                                            }
                                                            throw pidCantStop;
                                                        }
                                                    } catch (Throwable th5) {
                                                        pidCantStop = th5;
                                                        map = alarmTagMap2;
                                                        z = quickKillAction;
                                                        isCleanUidActivity = hasPerceptAlarm3;
                                                        awareAppMngSort = appMngSort;
                                                        hwActivityManagerService = targetUid2;
                                                        i = targetUid;
                                                        list = pidsWithNotification3;
                                                        targetUid = dfxDataList;
                                                        isCleanAllRes3 = isCleanAllRes;
                                                        while (true) {
                                                            break;
                                                        }
                                                        throw pidCantStop;
                                                    }
                                                    try {
                                                        targetUid3 = targetUid;
                                                        try {
                                                            if (appMngSort.isGroupBeHigher(info.mPid, info.mProcInfo.mUid, info.mProcInfo.mProcessName, info.mProcInfo.mPackageName, info.mMemGroup)) {
                                                                pidCantStop2.add(java.lang.Integer.valueOf(info.mPid));
                                                            }
                                                        } catch (Throwable th6) {
                                                            pidCantStop = th6;
                                                            z = quickKillAction;
                                                            awareAppMngSort = appMngSort;
                                                            hwActivityManagerService = targetUid2;
                                                            list = pidsWithNotification3;
                                                            list2 = dfxDataList;
                                                            while (true) {
                                                                break;
                                                            }
                                                            throw pidCantStop;
                                                        }
                                                    } catch (Throwable th7) {
                                                        pidCantStop = th7;
                                                        z = quickKillAction;
                                                        awareAppMngSort = appMngSort;
                                                        hwActivityManagerService = targetUid2;
                                                        i = targetUid;
                                                        list = pidsWithNotification3;
                                                        targetUid = dfxDataList;
                                                        isCleanAllRes3 = isCleanAllRes;
                                                        isCleanUidActivity = hasPerceptAlarm;
                                                        while (true) {
                                                            break;
                                                        }
                                                        throw pidCantStop;
                                                    }
                                                }
                                                z2 = isCleanUidActivity;
                                                hasPerceptAlarm = hasPerceptAlarm3;
                                                map = alarmTagMap2;
                                                targetUid3 = targetUid;
                                                it = it2;
                                                isCleanAllRes3 = isCleanAllRes;
                                                isCleanUidActivity = z2;
                                                hasPerceptAlarm3 = hasPerceptAlarm;
                                                alarmTagMap2 = map;
                                                targetUid = targetUid3;
                                            } catch (Throwable th8) {
                                                pidCantStop = th8;
                                                z2 = isCleanUidActivity;
                                                map = alarmTagMap2;
                                                z = quickKillAction;
                                                isCleanUidActivity = hasPerceptAlarm3;
                                                awareAppMngSort = appMngSort;
                                                hwActivityManagerService = targetUid2;
                                                i = targetUid;
                                                list = pidsWithNotification3;
                                                targetUid = dfxDataList;
                                                isCleanAllRes3 = isCleanAllRes;
                                                while (true) {
                                                    break;
                                                }
                                                throw pidCantStop;
                                            }
                                        }
                                    }
                                    it2 = it;
                                    isCleanAllRes = isCleanAllRes3;
                                    z2 = isCleanUidActivity;
                                    hasPerceptAlarm = hasPerceptAlarm3;
                                    map = alarmTagMap2;
                                    targetUid3 = targetUid;
                                    it = it2;
                                    isCleanAllRes3 = isCleanAllRes;
                                    isCleanUidActivity = z2;
                                    hasPerceptAlarm3 = hasPerceptAlarm;
                                    alarmTagMap2 = map;
                                    targetUid = targetUid3;
                                }
                            } catch (Throwable th9) {
                                pidCantStop = th9;
                                isCleanAllRes = isCleanAllRes3;
                                z2 = false;
                                map = alarmTagMap2;
                                z = quickKillAction;
                                isCleanUidActivity = hasPerceptAlarm3;
                                awareAppMngSort = appMngSort;
                                hwActivityManagerService = targetUid2;
                                i = targetUid;
                                list = pidsWithNotification3;
                                targetUid = dfxDataList;
                                while (true) {
                                    break;
                                }
                                throw pidCantStop;
                            }
                        }
                        isCleanAllRes = isCleanAllRes3;
                        z2 = isCleanUidActivity;
                        hasPerceptAlarm = hasPerceptAlarm3;
                        map = alarmTagMap2;
                        targetUid3 = targetUid;
                    } catch (Throwable th10) {
                        pidCantStop = th10;
                        z = quickKillAction;
                        isCleanAllRes = isCleanAllRes3;
                        z2 = false;
                        awareAppMngSort = appMngSort;
                        hwActivityManagerService = targetUid2;
                        map = alarmTagMap2;
                        i = targetUid;
                        list = pidsWithNotification3;
                        targetUid = dfxDataList;
                        while (true) {
                            break;
                        }
                        throw pidCantStop;
                    }
                    try {
                        android.util.ArraySet<java.lang.Integer> pidCantStop3;
                        int i2;
                        java.lang.Object obj;
                        java.lang.String killHint;
                        boolean z3;
                        java.util.Iterator pidsWithNotification4 = procInfoAllStopList.iterator();
                        list2 = dfxDataList;
                        while (pidsWithNotification4.hasNext()) {
                            try {
                                try {
                                    java.util.Iterator it3;
                                    info = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) pidsWithNotification4.next();
                                    if (interrupt != null) {
                                        try {
                                            if (interrupt.get()) {
                                                pidCantStop3 = pidCantStop2;
                                                i2 = 3;
                                                awareAppMngSort = appMngSort;
                                                hwActivityManagerService = targetUid2;
                                                isCleanUidActivity = false;
                                                pidsWithNotification = pidsWithNotification3;
                                                hasPerceptAlarm2 = hasPerceptAlarm;
                                                i = targetUid3;
                                                obj = 1;
                                                break;
                                            }
                                        } catch (Throwable th11) {
                                            pidCantStop = th11;
                                            z = quickKillAction;
                                            hwActivityManagerService = targetUid2;
                                            while (true) {
                                                break;
                                            }
                                            throw pidCantStop;
                                        }
                                    }
                                    boolean killResult = false;
                                    if (awareProcessBlockInfo.mIsNativeForceStop) {
                                        com.android.server.mtm.iaware.appmng.AwareProcessInfo info3;
                                        try {
                                            info3 = info;
                                            hasPerceptAlarm2 = hasPerceptAlarm;
                                            awareAppMngSort = appMngSort;
                                            hwActivityManagerService = targetUid2;
                                            it3 = pidsWithNotification4;
                                            pidsWithNotification = pidsWithNotification3;
                                        } catch (Throwable th12) {
                                            pidCantStop = th12;
                                            awareAppMngSort = appMngSort;
                                            hwActivityManagerService = targetUid2;
                                            z = quickKillAction;
                                            list = pidsWithNotification3;
                                            isCleanAllRes3 = isCleanAllRes;
                                            isCleanUidActivity = hasPerceptAlarm;
                                            i = targetUid3;
                                            while (true) {
                                                break;
                                            }
                                            throw pidCantStop;
                                        }
                                        try {
                                            killProcessSameUid(info.mPid, info.getRestartFlag(), isAsynchronous, reason2, true);
                                            killResult = true;
                                            pidCantStop3 = pidCantStop2;
                                            pidCantStop2 = info3;
                                        } catch (Throwable th13) {
                                            pidCantStop = th13;
                                            z = quickKillAction;
                                            list = pidsWithNotification;
                                            isCleanAllRes3 = isCleanAllRes;
                                            i = targetUid3;
                                            isCleanUidActivity = hasPerceptAlarm2;
                                            while (true) {
                                                break;
                                            }
                                            throw pidCantStop;
                                        }
                                    }
                                    awareAppMngSort = appMngSort;
                                    hwActivityManagerService = targetUid2;
                                    it3 = pidsWithNotification4;
                                    pidsWithNotification = pidsWithNotification3;
                                    hasPerceptAlarm2 = hasPerceptAlarm;
                                    com.android.server.mtm.iaware.appmng.AwareProcessInfo info4 = info;
                                    try {
                                        if (pidCantStop2.contains(java.lang.Integer.valueOf(info4.mPid))) {
                                            pidCantStop3 = pidCantStop2;
                                            pidCantStop2 = info4;
                                        } else {
                                            pidCantStop3 = pidCantStop2;
                                            pidCantStop2 = info4;
                                            killResult = killProcessSameUid(info4.mPid, info4.getRestartFlag(), isAsynchronous, reason2, null);
                                        }
                                    } catch (Throwable th14) {
                                        pidCantStop = th14;
                                        i = targetUid3;
                                        z = quickKillAction;
                                        list = pidsWithNotification;
                                        isCleanAllRes3 = isCleanAllRes;
                                        isCleanUidActivity = hasPerceptAlarm2;
                                        while (true) {
                                            break;
                                        }
                                        throw pidCantStop;
                                    }
                                    if (killResult) {
                                        killList.add(java.lang.Integer.valueOf(pidCantStop2.mPid));
                                        if (resCleanAllow || pidCantStop2.mProcInfo == null || !pidsWithNotification.contains(pidCantStop2) || pidCantStop2.mRestartFlag) {
                                            i = targetUid3;
                                        } else {
                                            android.os.Message msg = this.mHandler.obtainMessage(2);
                                            msg.obj = packageList;
                                            i = targetUid3;
                                            try {
                                                msg.arg1 = i;
                                                msg.arg2 = pidCantStop2.mPid;
                                                this.mHandler.sendMessageDelayed(msg, 200);
                                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                                stringBuilder3.append("[aware_mem] clean notification ");
                                                stringBuilder3.append(pidCantStop2.mProcInfo.mProcessName);
                                                android.util.Slog.d("ProcessCleaner", stringBuilder3.toString());
                                            } catch (Throwable th15) {
                                                pidCantStop = th15;
                                                z = quickKillAction;
                                                isCleanUidActivity = hasPerceptAlarm2;
                                                while (true) {
                                                    break;
                                                }
                                                throw pidCantStop;
                                            }
                                        }
                                        isCleanUidActivity = (!resCleanAllow && pidCantStop2.mHasShownUi && this.mHwAMS.numOfPidWithActivity(i) == 0) ? true : z2;
                                        try {
                                            if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
                                                if (list2 == null) {
                                                    dfxDataList2 = new java.util.ArrayList();
                                                } else {
                                                    dfxDataList2 = list2;
                                                }
                                                try {
                                                    dfxDataList2.add(pidCantStop2);
                                                    list2 = dfxDataList2;
                                                } catch (Throwable th16) {
                                                    pidCantStop = th16;
                                                    list2 = dfxDataList2;
                                                    z2 = isCleanUidActivity;
                                                    list = pidsWithNotification;
                                                    isCleanAllRes3 = isCleanAllRes;
                                                    isCleanUidActivity = hasPerceptAlarm2;
                                                    dfxDataList2 = quickKillAction;
                                                    while (true) {
                                                        break;
                                                    }
                                                    throw pidCantStop;
                                                }
                                            }
                                            z2 = isCleanUidActivity;
                                        } catch (Throwable th17) {
                                            pidCantStop = th17;
                                            z = quickKillAction;
                                            z2 = isCleanUidActivity;
                                            isCleanUidActivity = hasPerceptAlarm2;
                                            while (true) {
                                                break;
                                            }
                                            throw pidCantStop;
                                        }
                                    }
                                    i = targetUid3;
                                    isCleanAllRes = false;
                                    if (pidCantStop2.mProcInfo != null) {
                                        killHint = killResult ? "success " : "fail ";
                                        java.lang.String str2 = "ProcessCleaner";
                                        isCleanUidActivity = new java.lang.StringBuilder();
                                        isCleanUidActivity.append("[aware_mem] process cleaner ");
                                        isCleanUidActivity.append(killHint);
                                        isCleanUidActivity.append("pid:");
                                        isCleanUidActivity.append(pidCantStop2.mPid);
                                        isCleanUidActivity.append(",uid:");
                                        isCleanUidActivity.append(pidCantStop2.mProcInfo.mUid);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(pidCantStop2.mProcInfo.mProcessName);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(pidCantStop2.mProcInfo.mPackageName);
                                        isCleanUidActivity.append(",mHasShownUi:");
                                        isCleanUidActivity.append(pidCantStop2.mHasShownUi);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(awareProcessBlockInfo.mSubTypeStr);
                                        isCleanUidActivity.append(",class:");
                                        isCleanUidActivity.append(awareProcessBlockInfo.mClassRate);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(awareProcessBlockInfo.mSubClassRate);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(pidCantStop2.mClassRate);
                                        isCleanUidActivity.append(",");
                                        isCleanUidActivity.append(pidCantStop2.mSubClassRate);
                                        isCleanUidActivity.append(",adj:");
                                        isCleanUidActivity.append(pidCantStop2.mProcInfo.mCurAdj);
                                        isCleanUidActivity.append(killResult ? " is killed" : "");
                                        android.util.Slog.d(str2, isCleanUidActivity.toString());
                                    }
                                    targetUid3 = i;
                                    pidsWithNotification3 = pidsWithNotification;
                                    appMngSort = awareAppMngSort;
                                    targetUid2 = hwActivityManagerService;
                                    hasPerceptAlarm = hasPerceptAlarm2;
                                    pidsWithNotification4 = it3;
                                    pidCantStop2 = pidCantStop3;
                                } catch (Throwable th18) {
                                    pidCantStop = th18;
                                    awareAppMngSort = appMngSort;
                                    hwActivityManagerService = targetUid2;
                                    i = targetUid3;
                                    z = quickKillAction;
                                    list = pidsWithNotification3;
                                    isCleanAllRes3 = isCleanAllRes;
                                    isCleanUidActivity = hasPerceptAlarm;
                                    while (true) {
                                        break;
                                    }
                                    throw pidCantStop;
                                }
                            } catch (Throwable th19) {
                                pidCantStop = th19;
                                z = quickKillAction;
                                awareAppMngSort = appMngSort;
                                hwActivityManagerService = targetUid2;
                                list = pidsWithNotification3;
                                isCleanUidActivity = hasPerceptAlarm;
                                i = targetUid3;
                                while (true) {
                                    break;
                                }
                                throw pidCantStop;
                            }
                        }
                        pidCantStop3 = pidCantStop2;
                        i2 = 3;
                        awareAppMngSort = appMngSort;
                        hwActivityManagerService = targetUid2;
                        pidsWithNotification = pidsWithNotification3;
                        hasPerceptAlarm2 = hasPerceptAlarm;
                        i = targetUid3;
                        obj = 1;
                        isCleanUidActivity = isCleanAllRes;
                        android.util.ArraySet<java.lang.Integer> arraySet;
                        if (isCleanUidActivity) {
                            boolean z4 = false;
                            if (needCheckAlarm) {
                                try {
                                    z4 = this.mHwAMS.isPkgHasAlarm(packageList, i);
                                } catch (Throwable th20) {
                                    pidCantStop = th20;
                                    z = quickKillAction;
                                    isCleanAllRes3 = isCleanUidActivity;
                                    list = pidsWithNotification;
                                    isCleanUidActivity = hasPerceptAlarm2;
                                    while (true) {
                                        break;
                                    }
                                    throw pidCantStop;
                                }
                            }
                            if (z4) {
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("[aware_mem] is alarm ");
                                stringBuilder2.append(packageList);
                                android.util.Slog.d("ProcessCleaner", stringBuilder2.toString());
                                this.mHwAMS.setPackageStoppedState(packageList, false, i);
                                isCleanAllRes2 = isCleanUidActivity;
                                list = pidsWithNotification;
                                isCleanUidActivity = hasPerceptAlarm2;
                                arraySet = pidCantStop3;
                            } else {
                                try {
                                    java.lang.Object obj2 = obj;
                                    list = pidsWithNotification;
                                    z3 = false;
                                    isCleanAllRes2 = isCleanUidActivity;
                                    try {
                                        z4 = com.huawei.android.app.HwActivityManager.cleanPackageRes(packageList, map, i, awareProcessBlockInfo.mCleanAlarm, awareProcessBlockInfo.mIsNativeForceStop, hasPerceptAlarm2);
                                        killHint = "ProcessCleaner";
                                        stringBuilder2 = new java.lang.StringBuilder();
                                        stringBuilder2.append("[aware_mem] start process cleaner cleanPackageRes, clnAlarm:");
                                        stringBuilder2.append(awareProcessBlockInfo.mCleanAlarm);
                                        stringBuilder2.append(", hasPerceptAlarm:");
                                        isCleanUidActivity = hasPerceptAlarm2;
                                        stringBuilder2.append(isCleanUidActivity);
                                        stringBuilder2.append(", isNative:");
                                        stringBuilder2.append(awareProcessBlockInfo.mIsNativeForceStop);
                                        stringBuilder2.append(", cleanResult: ");
                                        stringBuilder2.append(z4);
                                        android.util.Slog.d(killHint, stringBuilder2.toString());
                                        if (!awareProcessBlockInfo.mIsNativeForceStop && isCleanUidActivity) {
                                            this.mHwAMS.setPackageStoppedState(packageList, z3, i);
                                        }
                                    } catch (Throwable th21) {
                                        pidCantStop = th21;
                                        z = quickKillAction;
                                        isCleanAllRes3 = isCleanAllRes2;
                                        while (true) {
                                            break;
                                        }
                                        throw pidCantStop;
                                    }
                                } catch (Throwable th22) {
                                    pidCantStop = th22;
                                    isCleanAllRes2 = isCleanUidActivity;
                                    list = pidsWithNotification;
                                    isCleanUidActivity = hasPerceptAlarm2;
                                    z = quickKillAction;
                                    isCleanAllRes3 = isCleanAllRes2;
                                    while (true) {
                                        break;
                                    }
                                    throw pidCantStop;
                                }
                            }
                        }
                        isCleanAllRes2 = isCleanUidActivity;
                        list = pidsWithNotification;
                        arraySet = pidCantStop3;
                        z3 = false;
                        if (resCleanAllow) {
                            android.util.Slog.d("ProcessCleaner", "[aware_mem] start process cleaner reset PackageStoppedState");
                            this.mHwAMS.setPackageStoppedState(packageList, z3, i);
                        }
                        if (z2) {
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("[aware_mem] clean uid activity:");
                            stringBuilder.append(i);
                            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
                            this.mHwAMS.cleanActivityByUid(packageList, i);
                        }
                        try {
                            z3 = isCleanAllRes2;
                            if (z3) {
                                android.os.Message msg2 = this.mHandler.obtainMessage(1);
                                msg2.obj = packageList;
                                msg2.arg1 = i;
                                this.mHandler.sendMessageDelayed(msg2, 200);
                            }
                            if (this.mProcInfoCollector.INFO) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("[aware_mem] process cleaner kill pids:");
                                stringBuilder.append(killList.toString());
                                android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
                            }
                            if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
                                com.android.server.rms.iaware.appmng.AwareAppMngDFX.getInstance().trackeKillInfo(list2, z3, quickKillAction);
                            } else {
                                z = quickKillAction;
                            }
                            return killList.size() > 0 ? killList : null;
                        } catch (Throwable th23) {
                            pidCantStop = th23;
                            z = quickKillAction;
                            java.util.Map<java.lang.String, java.util.List<java.lang.String>> map2 = isCleanAllRes2;
                            while (true) {
                                break;
                            }
                            throw pidCantStop;
                        }
                    } catch (Throwable th24) {
                        pidCantStop = th24;
                        z = quickKillAction;
                        awareAppMngSort = appMngSort;
                        hwActivityManagerService = targetUid2;
                        list = pidsWithNotification3;
                        isCleanUidActivity = hasPerceptAlarm;
                        i = targetUid3;
                        targetUid = dfxDataList;
                        while (true) {
                            break;
                        }
                        throw pidCantStop;
                    }
                }
            }
            if (this.mProcInfoCollector.INFO) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("[aware_mem] new process has started in block, uid: ");
                stringBuilder2.append(targetUid);
                android.util.Slog.d("ProcessCleaner", stringBuilder2.toString());
            }
            return null;
        }
        return null;
    }

    public boolean forcestopAppsAsUser(com.android.server.mtm.iaware.appmng.AwareProcessInfo awareProc, java.lang.String reason) {
        if (awareProc == null) {
            return false;
        }
        com.android.server.mtm.taskstatus.ProcessInfo temp = awareProc.mProcInfo;
        if (temp == null) {
            android.rms.iaware.AwareLog.e("ProcessCleaner", "forcestopAppsAsUser kill package: package info is null ");
            return false;
        }
        java.lang.String packagename = (java.lang.String) temp.mPackageName.get(0);
        if (packagename != null) {
            if (!packagename.equals(" ")) {
                int userId = android.os.UserHandle.getUserId(temp.mUid);
                if (this.mHwAMS != null) {
                    java.lang.ThreadLocal threadLocal = this.mHwAMS.mLocalStopReason;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("iAwareF[");
                    stringBuilder.append(reason);
                    stringBuilder.append("]");
                    threadLocal.set(stringBuilder.toString());
                    this.mHwAMS.forceStopPackage(packagename, userId);
                    return true;
                }
                android.rms.iaware.AwareLog.e("ProcessCleaner", "forcestopAppsAsUser process: mActivityManager is null ");
                return false;
            }
        }
        android.rms.iaware.AwareLog.e("ProcessCleaner", "forcestopAppsAsUser kill package: packagename == null");
        return false;
    }

    public boolean forcestopApps(int pid) {
        long start = android.os.SystemClock.elapsedRealtime();
        if (this.mProcInfoCollector.INFO) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("forcestopApps kill process: pid is ");
            stringBuilder.append(pid);
            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
        }
        com.android.server.mtm.taskstatus.ProcessInfo temp = this.mProcInfoCollector.getProcessInfo(pid);
        if (temp == null) {
            android.util.Slog.e("ProcessCleaner", "forcestopApps kill process: process info is null ");
            return false;
        } else if (temp.mCurSchedGroup != 0) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("forcestopApps kill process: process ");
            stringBuilder2.append(temp.mProcessName);
            stringBuilder2.append(" is not in BG");
            android.util.Slog.e("ProcessCleaner", stringBuilder2.toString());
            return false;
        } else {
            java.lang.String packagename = (java.lang.String) temp.mPackageName.get(0);
            if (packagename != null) {
                if (!packagename.equals(" ")) {
                    if (this.mActivityManager != null) {
                        this.mActivityManager.forceStopPackage(packagename);
                        this.mProcInfoCollector.recordKilledProcess(temp);
                        long end = android.os.SystemClock.elapsedRealtime();
                        if (this.mProcInfoCollector.INFO) {
                            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                            stringBuilder3.append("pforcestopApps kill process: pid is ");
                            stringBuilder3.append(pid);
                            stringBuilder3.append(",last time :");
                            stringBuilder3.append(end - start);
                            android.util.Slog.d("ProcessCleaner", stringBuilder3.toString());
                        }
                        return true;
                    }
                    android.util.Slog.e("ProcessCleaner", "forcestopApps process: mActivityManager is null ");
                    return false;
                }
            }
            android.util.Slog.e("ProcessCleaner", "forcestopApps kill process: packagename == null");
            return false;
        }
    }

    private java.util.List<java.lang.String> getPackageList(java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procInfoAllStopList) {
        java.util.List<java.lang.String> packageList = new java.util.ArrayList();
        for (com.android.server.mtm.iaware.appmng.AwareProcessInfo curPIAllStop : procInfoAllStopList) {
            if (curPIAllStop.mProcInfo != null) {
                if (curPIAllStop.mProcInfo.mPackageName != null) {
                    java.util.Iterator it = curPIAllStop.mProcInfo.mPackageName.iterator();
                    while (it.hasNext()) {
                        java.lang.String packageName = (java.lang.String) it.next();
                        if (!packageList.contains(packageName)) {
                            packageList.add(packageName);
                        }
                    }
                }
            }
        }
        return packageList;
    }

    private java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getPidsWithNotification(java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procInfoAllStopList) {
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> pidsWithNotification = new java.util.ArrayList();
        for (com.android.server.mtm.iaware.appmng.AwareProcessInfo info : procInfoAllStopList) {
            if (hasNotification(info.mPid)) {
                pidsWithNotification.add(info);
            }
        }
        return pidsWithNotification;
    }

    public boolean killProcessSameUid(int pid, boolean restartservice, boolean isAsynchronous, java.lang.String reason, boolean isNative) {
        long start = android.os.SystemClock.elapsedRealtime();
        if (this.mProcInfoCollector.INFO) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[aware_mem] process cleaner kill process: pid is ");
            stringBuilder.append(pid);
            stringBuilder.append(", restart service :");
            stringBuilder.append(restartservice);
            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
        }
        com.android.server.mtm.taskstatus.ProcessInfo temp = this.mProcInfoCollector.getProcessInfo(pid);
        if (temp == null) {
            android.util.Slog.e("ProcessCleaner", "[aware_mem] process cleaner kill process: process info is null ");
            return false;
        }
        if (isNative) {
            if (!com.huawei.android.app.HwActivityManager.killProcessRecordFromIAwareNative(temp, restartservice, isAsynchronous, reason)) {
                return false;
            }
        } else if (!com.huawei.android.app.HwActivityManager.killProcessRecordFromIAware(temp, restartservice, isAsynchronous, reason)) {
            return false;
        }
        this.mProcInfoCollector.recordKilledProcess(temp);
        long end = android.os.SystemClock.elapsedRealtime();
        if (this.mProcInfoCollector.INFO) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("[aware_mem] process cleaner kill process: pid is ");
            stringBuilder2.append(pid);
            stringBuilder2.append(",last time :");
            stringBuilder2.append(end - start);
            android.util.Slog.d("ProcessCleaner", stringBuilder2.toString());
        }
        return true;
    }

    public void setProtectedListFromMDM(java.util.List<java.lang.String> protectedList) {
        if (protectedList == null) {
            android.util.Slog.e("ProcessCleaner", "[aware_mem] Set MDM protected list error");
            return;
        }
        java.util.ArrayList<java.lang.String> tempList = new java.util.ArrayList();
        if (protectedList.size() < 3) {
            tempList.addAll(protectedList);
        } else {
            for (int i = 0; i < 3; i++) {
                tempList.add((java.lang.String) protectedList.get(i));
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[aware_mem] Only 3 apps will be protected from MDM.");
            stringBuilder.append(tempList.toString());
            android.util.Slog.d("ProcessCleaner", stringBuilder.toString());
        }
        synchronized (this.mMDMProtectedList) {
            this.mMDMProtectedList.clear();
            this.mMDMProtectedList.addAll(tempList);
        }
    }

    public void removeProtectedListFromMDM() {
        synchronized (this.mMDMProtectedList) {
            this.mMDMProtectedList.clear();
        }
        android.util.Slog.d("ProcessCleaner", "[aware_mem] Remove MDM protected list");
    }

    public java.util.ArrayList<java.lang.String> getProtectedListFromMDM() {
        java.util.ArrayList<java.lang.String> tempList = new java.util.ArrayList();
        synchronized (this.mMDMProtectedList) {
            tempList.addAll(this.mMDMProtectedList);
        }
        return tempList;
    }

    private boolean checkPkgInProtectedListFromMDM(java.lang.String pkgName) {
        if (pkgName == null) {
            return false;
        }
        synchronized (this.mMDMProtectedList) {
            if (this.mMDMProtectedList.contains(pkgName)) {
                return true;
            }
            return false;
        }
    }

    private void cleanPackageNotifications(java.util.List<java.lang.String> packageList, int targetUid) {
        if (packageList != null) {
            android.app.INotificationManager service = android.app.NotificationManager.getService();
            if (service != null) {
                int userId = android.os.UserHandle.getUserId(targetUid);
                try {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("cleanupPackageNotifications, userId=");
                    stringBuilder.append(userId);
                    stringBuilder.append("|");
                    stringBuilder.append(packageList);
                    android.util.Slog.v("ProcessCleaner", stringBuilder.toString());
                    for (java.lang.String packageName : packageList) {
                        service.cancelAllNotifications(packageName, userId);
                    }
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("ProcessCleaner", "Unable to talk to notification manager. Woe!");
                }
            }
        }
    }

    private void cleanNotificationWithPid(java.util.List<java.lang.String> packageList, int targetUid, int pid) {
        if (packageList != null) {
            android.app.INotificationManager service = android.app.NotificationManager.getService();
            if (service != null) {
                try {
                    android.service.notification.StatusBarNotification[] notifications = service.getActiveNotifications("android");
                    int userId = android.os.UserHandle.getUserId(targetUid);
                    if (notifications != null) {
                        for (android.service.notification.StatusBarNotification notification : notifications) {
                            if (notification.getInitialPid() == pid) {
                                for (java.lang.String packageName : packageList) {
                                    service.cancelNotificationWithTag(packageName, notification.getTag(), notification.getId(), userId);
                                }
                            }
                        }
                    }
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("ProcessCleaner", "Unable to talk to notification manager. Woe!");
                }
            }
        }
    }

    private boolean hasNotification(int pid) {
        if (pid < 0) {
            return false;
        }
        android.app.INotificationManager service = android.app.NotificationManager.getService();
        if (service == null) {
            return false;
        }
        try {
            android.service.notification.StatusBarNotification[] notifications = service.getActiveNotifications("android");
            if (notifications == null) {
                return false;
            }
            for (android.service.notification.StatusBarNotification notification : notifications) {
                if (notification.getInitialPid() == pid) {
                    return true;
                }
            }
            return false;
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("ProcessCleaner", "Unable to talk to notification manager. Woe!");
        }
    }
}
