package com.android.server.mtm.taskstatus;

public class ProcessInfoCollector {
    private static final int CAPACITY = 10;
    private static final int MAX_TASKS = 100;
    private static final java.lang.String TAG = "ProcessInfoCollector";
    private static com.android.server.mtm.taskstatus.ProcessInfoCollector mProcessInfoCollector = null;
    boolean DEBUG = false;
    boolean INFO = false;
    private java.util.HashMap<java.lang.Integer, com.android.server.mtm.iaware.appmng.AwareProcessInfo> mAwareProcMap = new java.util.HashMap();
    private com.android.server.mtm.taskstatus.ProcessInfo mCacheInfo = new com.android.server.mtm.taskstatus.ProcessInfo(0, 0);
    private com.android.server.am.HwActivityManagerService mHwAMS = null;
    private com.android.server.mtm.iaware.srms.AwareBroadcastPolicy mIawareBrPolicy = null;
    private int mIndex = 0;
    private com.android.server.mtm.taskstatus.ProcessInfo[] mKilledProcList = new com.android.server.mtm.taskstatus.ProcessInfo[10];
    private java.util.HashMap<java.lang.Integer, com.android.server.mtm.taskstatus.ProcessInfo> mProcMap = new java.util.HashMap();

    private ProcessInfoCollector() {
        init();
    }

    public static synchronized com.android.server.mtm.taskstatus.ProcessInfoCollector getInstance() {
        com.android.server.mtm.taskstatus.ProcessInfoCollector processInfoCollector;
        synchronized (com.android.server.mtm.taskstatus.ProcessInfoCollector.class) {
            if (mProcessInfoCollector == null) {
                mProcessInfoCollector = new com.android.server.mtm.taskstatus.ProcessInfoCollector();
            }
            processInfoCollector = mProcessInfoCollector;
        }
        return processInfoCollector;
    }

    private void init() {
        this.mHwAMS = com.android.server.am.HwActivityManagerService.self();
        if (this.mHwAMS == null) {
            android.util.Slog.e("ProcessInfoCollector", "init failed to get HwAMS handler");
        }
    }

    public synchronized void recordKilledProcess(com.android.server.mtm.taskstatus.ProcessInfo info) {
        info.mKilledTime = android.os.SystemClock.uptimeMillis();
        if (this.mIndex >= 10) {
            this.mIndex = 0;
        }
        this.mKilledProcList[this.mIndex] = info;
        this.mIndex++;
    }

    public void removeKilledProcess(int pid) {
        com.android.server.mtm.taskstatus.ProcessInfo info;
        if (pid < 0) {
            android.util.Slog.e("ProcessInfoCollector", "removeKilledProcess: proc should not less than zero ");
        }
        synchronized (this.mProcMap) {
            info = (com.android.server.mtm.taskstatus.ProcessInfo) this.mProcMap.remove(java.lang.Integer.valueOf(pid));
            this.mAwareProcMap.remove(java.lang.Integer.valueOf(pid));
        }
        if (info != null) {
            com.android.server.wm.HwStartWindowRecord.getInstance().removeStartWindowApp(info.mProcessName);
        }
    }

    public com.android.server.mtm.taskstatus.ProcessInfo getProcessInfo(int pid) {
        if (pid < 0) {
            android.util.Slog.e("ProcessInfoCollector", "getProcessInfo: proc should not less than zero ");
            return null;
        }
        com.android.server.mtm.taskstatus.ProcessInfo copyInfo = null;
        synchronized (this.mProcMap) {
            com.android.server.mtm.taskstatus.ProcessInfo info = (com.android.server.mtm.taskstatus.ProcessInfo) this.mProcMap.get(java.lang.Integer.valueOf(pid));
            if (info == null) {
                android.util.Slog.e("ProcessInfoCollector", "getProcessInfo: failed to find this proc ");
            } else {
                copyInfo = new com.android.server.mtm.taskstatus.ProcessInfo(0, 0);
                com.android.server.mtm.taskstatus.ProcessInfo.copyProcessInfo(info, copyInfo);
            }
        }
        return copyInfo;
    }

    public com.android.server.mtm.iaware.appmng.AwareProcessInfo getAwareProcessInfo(int pid) {
        if (pid < 0) {
            android.util.Slog.e("ProcessInfoCollector", "getProcessInfo: proc should not less than zero ");
            return null;
        }
        com.android.server.mtm.iaware.appmng.AwareProcessInfo info;
        synchronized (this.mProcMap) {
            info = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) this.mAwareProcMap.get(java.lang.Integer.valueOf(pid));
        }
        return info;
    }

    public java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> getProcessInfosFromPackage(java.lang.String packageName, int userId) {
        java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList = new java.util.ArrayList();
        if (userId >= 0) {
            if (packageName != null) {
                synchronized (this.mProcMap) {
                    for (java.util.Map.Entry entry : this.mProcMap.entrySet()) {
                        com.android.server.mtm.taskstatus.ProcessInfo info = (com.android.server.mtm.taskstatus.ProcessInfo) entry.getValue();
                        if (info != null) {
                            java.util.ArrayList<java.lang.String> packageNames = info.mPackageName;
                            if (packageNames != null) {
                                if (!packageNames.isEmpty()) {
                                    if (packageName.equals((java.lang.String) packageNames.get(0))) {
                                        if (userId == android.os.UserHandle.getUserId(info.mUid)) {
                                            com.android.server.mtm.taskstatus.ProcessInfo copyInfo = new com.android.server.mtm.taskstatus.ProcessInfo(0, 0);
                                            com.android.server.mtm.taskstatus.ProcessInfo.copyProcessInfo(info, copyInfo);
                                            procList.add(copyInfo);
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                return procList;
            }
        }
        return procList;
    }

    public java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcessInfosFromPackage(java.lang.String packageName, int userId) {
        java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procList = new java.util.ArrayList();
        if (packageName == null) {
            return procList;
        }
        synchronized (this.mProcMap) {
            for (java.util.Map.Entry entry : this.mAwareProcMap.entrySet()) {
                com.android.server.mtm.iaware.appmng.AwareProcessInfo info = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) entry.getValue();
                if (info != null) {
                    java.util.ArrayList<java.lang.String> packageNames = info.mProcInfo.mPackageName;
                    if (packageNames != null) {
                        if (!packageNames.isEmpty()) {
                            if (packageName.equals((java.lang.String) packageNames.get(0))) {
                                if (userId == -1 || userId == android.os.UserHandle.getUserId(info.mProcInfo.mUid)) {
                                    procList.add(info);
                                }
                            }
                        }
                    }
                }
            }
        }
        return procList;
    }

    public java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> getProcessInfosFromPackageMap(android.util.ArrayMap<java.lang.String, java.lang.Integer> packMap) {
        java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList = new java.util.ArrayList();
        if (packMap == null) {
            return procList;
        }
        synchronized (this.mProcMap) {
            for (java.util.Map.Entry entry : this.mProcMap.entrySet()) {
                com.android.server.mtm.taskstatus.ProcessInfo info = (com.android.server.mtm.taskstatus.ProcessInfo) entry.getValue();
                if (info != null) {
                    java.util.ArrayList<java.lang.String> packageNames = info.mPackageName;
                    if (packageNames != null) {
                        if (!packageNames.isEmpty()) {
                            java.lang.String procInfoPackageName = (java.lang.String) packageNames.get(0);
                            if (packMap.get(procInfoPackageName) != null) {
                                if (((java.lang.Integer) packMap.get(procInfoPackageName)).intValue() == android.os.UserHandle.getUserId(info.mUid)) {
                                    com.android.server.mtm.taskstatus.ProcessInfo copyInfo = new com.android.server.mtm.taskstatus.ProcessInfo(0, 0);
                                    com.android.server.mtm.taskstatus.ProcessInfo.copyProcessInfo(info, copyInfo);
                                    procList.add(copyInfo);
                                }
                            }
                        }
                    }
                }
            }
        }
        return procList;
    }

    public void dumpPackageTask(java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> processInfos, java.io.PrintWriter pw) {
        if (pw == null) {
            android.util.Slog.e("ProcessInfoCollector", "dump PrintWriter pw is null");
            return;
        }
        if (processInfos != null) {
            if (!processInfos.isEmpty()) {
                pw.println("  Package/Task Processes Information dump :");
                java.util.Iterator it = processInfos.iterator();
                while (it.hasNext()) {
                    com.android.server.mtm.taskstatus.ProcessInfo procinfo = (com.android.server.mtm.taskstatus.ProcessInfo) it.next();
                    pw.println("\r\n  Running Process information :");
                    printProcInfo(procinfo, pw);
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0051  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0050 A:{RETURN} */
    public java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> getProcessInfosFromTask(int r10, int r11) {
        /*
        r9 = this;
        r0 = new java.util.ArrayList;
        r0.<init>();
        if (r11 < 0) goto L_0x0056;
    L_0x0007:
        if (r10 >= 0) goto L_0x000a;
    L_0x0009:
        goto L_0x0056;
    L_0x000a:
        r1 = 2;
        r2 = 0;
        r3 = r9.mHwAMS;
        r4 = 100;
        r2 = r3.getRecentTasks(r4, r1, r11);
        r3 = r2.getList();
        r4 = 0;
        r5 = r3.iterator();
    L_0x001d:
        r6 = r5.hasNext();
        if (r6 == 0) goto L_0x004e;
    L_0x0023:
        r6 = r5.next();
        r6 = (android.app.ActivityManager.RecentTaskInfo) r6;
        r7 = r6.persistentId;
        if (r7 != r10) goto L_0x004d;
    L_0x002d:
        r7 = new android.content.Intent;
        r8 = r6.baseIntent;
        r7.<init>(r8);
        r8 = r6.origActivity;
        if (r8 == 0) goto L_0x003d;
    L_0x0038:
        r8 = r6.origActivity;
        r7.setComponent(r8);
    L_0x003d:
        r8 = r7.getComponent();
        if (r8 != 0) goto L_0x0044;
    L_0x0043:
        goto L_0x004e;
    L_0x0044:
        r8 = r7.getComponent();
        r4 = r8.getPackageName();
        goto L_0x004e;
    L_0x004d:
        goto L_0x001d;
    L_0x004e:
        if (r4 != 0) goto L_0x0051;
    L_0x0050:
        return r0;
    L_0x0051:
        r6 = r9.getProcessInfosFromPackage(r4, r11);
        return r6;
    L_0x0056:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.taskstatus.ProcessInfoCollector.getProcessInfosFromTask(int, int):java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo>");
    }

    public java.util.ArrayList<java.lang.Integer> getPidsFromUid(int uid, int userId) {
        java.util.ArrayList<java.lang.Integer> pids = new java.util.ArrayList();
        if (userId >= 0) {
            if (uid >= 0) {
                synchronized (this.mProcMap) {
                    for (java.util.Map.Entry entry : this.mProcMap.entrySet()) {
                        com.android.server.mtm.taskstatus.ProcessInfo info = (com.android.server.mtm.taskstatus.ProcessInfo) entry.getValue();
                        if (info != null) {
                            if (info.mAppUid == uid || info.mUid == uid) {
                                if (userId == android.os.UserHandle.getUserId(info.mUid)) {
                                    pids.add(java.lang.Integer.valueOf(info.mPid));
                                }
                            }
                        }
                    }
                }
                return pids;
            }
        }
        return pids;
    }

    public java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> getProcessInfoList() {
        java.util.ArrayList<com.android.server.mtm.taskstatus.ProcessInfo> procList;
        synchronized (this.mProcMap) {
            procList = new java.util.ArrayList(this.mProcMap.size());
            for (java.util.Map.Entry entry : this.mProcMap.entrySet()) {
                com.android.server.mtm.taskstatus.ProcessInfo Info = (com.android.server.mtm.taskstatus.ProcessInfo) entry.getValue();
                com.android.server.mtm.taskstatus.ProcessInfo copyInfo = new com.android.server.mtm.taskstatus.ProcessInfo(0, 0);
                com.android.server.mtm.taskstatus.ProcessInfo.copyProcessInfo(Info, copyInfo);
                procList.add(copyInfo);
            }
        }
        return procList;
    }

    public java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAwareProcessInfoList() {
        java.util.ArrayList<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procList;
        synchronized (this.mProcMap) {
            procList = new java.util.ArrayList(this.mAwareProcMap.size());
            for (java.util.Map.Entry entry : this.mAwareProcMap.entrySet()) {
                procList.add((com.android.server.mtm.iaware.appmng.AwareProcessInfo) entry.getValue());
            }
        }
        return procList;
    }

    /* JADX WARNING: Missing block: B:24:0x0081, code:
            if (r1 != false) goto L_0x0086;
     */
    /* JADX WARNING: Missing block: B:25:0x0083, code:
            reportToRms(r0);
     */
    /* JADX WARNING: Missing block: B:26:0x0086, code:
            return;
     */
    public void recordProcessInfo(int r8, int r9) {
        /*
        r7 = this;
        r0 = 0;
        r1 = 0;
        r2 = r7.mCacheInfo;
        r2.initialProcessInfo(r8, r9);
        r2 = r7.mCacheInfo;
        r2 = com.huawei.android.app.HwActivityManager.getProcessRecordFromMTM(r2);
        if (r2 != 0) goto L_0x001b;
    L_0x000f:
        r3 = r7.DEBUG;
        if (r3 == 0) goto L_0x001a;
    L_0x0013:
        r3 = "ProcessInfoCollector";
        r4 = "recordProcessInfo  failed to get process record";
        android.util.Slog.e(r3, r4);
    L_0x001a:
        return;
    L_0x001b:
        r3 = r7.mProcMap;
        monitor-enter(r3);
        r4 = r7.mProcMap;	 Catch:{ all -> 0x0087 }
        r5 = java.lang.Integer.valueOf(r8);	 Catch:{ all -> 0x0087 }
        r4 = r4.get(r5);	 Catch:{ all -> 0x0087 }
        r4 = (com.android.server.mtm.taskstatus.ProcessInfo) r4;	 Catch:{ all -> 0x0087 }
        r0 = r4;
        if (r0 != 0) goto L_0x003c;
    L_0x002d:
        r4 = new com.android.server.mtm.taskstatus.ProcessInfo;	 Catch:{ all -> 0x0087 }
        r4.<init>(r8, r9);	 Catch:{ all -> 0x0087 }
        r0 = r4;
        r4 = r7.mCacheInfo;	 Catch:{ all -> 0x0087 }
        r5 = android.os.SystemClock.elapsedRealtime();	 Catch:{ all -> 0x0087 }
        r4.mCreatedTime = r5;	 Catch:{ all -> 0x0087 }
        goto L_0x0043;
    L_0x003c:
        r4 = r7.mCacheInfo;	 Catch:{ all -> 0x0087 }
        r5 = r0.mCreatedTime;	 Catch:{ all -> 0x0087 }
        r4.mCreatedTime = r5;	 Catch:{ all -> 0x0087 }
        r1 = 1;
    L_0x0043:
        r4 = r7.mCacheInfo;	 Catch:{ all -> 0x0087 }
        r4 = com.android.server.mtm.taskstatus.ProcessInfo.copyProcessInfo(r4, r0);	 Catch:{ all -> 0x0087 }
        r2 = r4;
        if (r2 != 0) goto L_0x0055;
    L_0x004c:
        r4 = "ProcessInfoCollector";
        r5 = "recordProcessInfo  source or target object is null";
        android.util.Slog.e(r4, r5);	 Catch:{ all -> 0x0087 }
        monitor-exit(r3);	 Catch:{ all -> 0x0087 }
        return;
    L_0x0055:
        r4 = r0.mCount;	 Catch:{ all -> 0x0087 }
        r4 = r4 + 1;
        r0.mCount = r4;	 Catch:{ all -> 0x0087 }
        if (r1 != 0) goto L_0x0080;
    L_0x005d:
        r4 = r7.mProcMap;	 Catch:{ all -> 0x0087 }
        r5 = java.lang.Integer.valueOf(r8);	 Catch:{ all -> 0x0087 }
        r4.put(r5, r0);	 Catch:{ all -> 0x0087 }
        r4 = new com.android.server.mtm.iaware.appmng.AwareProcessInfo;	 Catch:{ all -> 0x0087 }
        r4.<init>(r8, r0);	 Catch:{ all -> 0x0087 }
        r5 = r7.mAwareProcMap;	 Catch:{ all -> 0x0087 }
        r6 = java.lang.Integer.valueOf(r8);	 Catch:{ all -> 0x0087 }
        r5.put(r6, r4);	 Catch:{ all -> 0x0087 }
        r5 = r7.getIawareBrPolicy();	 Catch:{ all -> 0x0087 }
        if (r5 == 0) goto L_0x0080;
    L_0x007a:
        r5 = r7.mIawareBrPolicy;	 Catch:{ all -> 0x0087 }
        r6 = -1;
        r5.updateProcessBrPolicy(r4, r6);	 Catch:{ all -> 0x0087 }
    L_0x0080:
        monitor-exit(r3);	 Catch:{ all -> 0x0087 }
        if (r1 != 0) goto L_0x0086;
    L_0x0083:
        r7.reportToRms(r0);
    L_0x0086:
        return;
    L_0x0087:
        r4 = move-exception;
        monitor-exit(r3);	 Catch:{ all -> 0x0087 }
        throw r4;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.taskstatus.ProcessInfoCollector.recordProcessInfo(int, int):void");
    }

    public void enableDebug() {
        this.DEBUG = true;
        this.INFO = true;
    }

    public void disableDebug() {
        this.DEBUG = false;
        this.INFO = false;
    }

    public void dump(java.io.PrintWriter pw) {
        if (pw == null) {
            android.util.Slog.e("ProcessInfoCollector", "dump PrintWriter pw is null");
            return;
        }
        pw.println("  Process Information Collector dump :");
        synchronized (this.mProcMap) {
            for (java.util.Map.Entry entry : this.mProcMap.entrySet()) {
                com.android.server.mtm.taskstatus.ProcessInfo Info = (com.android.server.mtm.taskstatus.ProcessInfo) entry.getValue();
                pw.println("\r\n  Running Process information :");
                printProcInfo(Info, pw);
            }
        }
        synchronized (this) {
            for (int i = 0; i < this.mIndex; i++) {
                com.android.server.mtm.taskstatus.ProcessInfo Info2 = this.mKilledProcList[i];
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("\r\n  Killed Process information ");
                stringBuilder.append(i);
                stringBuilder.append(":");
                pw.println(stringBuilder.toString());
                printProcInfo(Info2, pw);
            }
        }
    }

    private void reportToRms(com.android.server.mtm.taskstatus.ProcessInfo info) {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC)) && info != null) {
            android.os.Bundle args = new android.os.Bundle();
            args.putInt("callPid", info.mPid);
            args.putInt("callUid", info.mUid);
            args.putString("callProcName", info.mProcessName);
            java.util.ArrayList<java.lang.String> pkgs = new java.util.ArrayList();
            pkgs.addAll(info.mPackageName);
            args.putStringArrayList("pkgname", pkgs);
            args.putInt("relationType", 4);
            resManager.reportData(new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC), java.lang.System.currentTimeMillis(), args));
        }
    }

    private void printProcInfo(com.android.server.mtm.taskstatus.ProcessInfo Info, java.io.PrintWriter pw) {
        java.util.Date dat;
        java.util.GregorianCalendar gc;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  pid =  ");
        stringBuilder.append(Info.mPid);
        stringBuilder.append(", uid = ");
        stringBuilder.append(Info.mUid);
        stringBuilder.append(", count = ");
        stringBuilder.append(Info.mCount);
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  ProcessName = ");
        stringBuilder.append(Info.mProcessName);
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  Group = ");
        stringBuilder.append(Info.mCurSchedGroup);
        stringBuilder.append(" (-1:default, 0:backgroud, 5:top visible, 6:perceptible)");
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  oom_Adj = ");
        stringBuilder.append(Info.mCurAdj);
        stringBuilder.append(", AdjType = ");
        stringBuilder.append(Info.mAdjType);
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  package type = ");
        stringBuilder.append(Info.mType);
        stringBuilder.append(" (1:SYSTEM_SERVER, 2:SYSTEM_APP , 3:HW_INSTALL, 4:THIRDPARTY)");
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  LRU = ");
        stringBuilder.append(Info.mLru);
        stringBuilder.append(" ( The first entry in the list is the least recently used)");
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("  FG Activities = ");
        stringBuilder.append(Info.mForegroundActivities);
        stringBuilder.append(", FG Services = ");
        stringBuilder.append(Info.mForegroundServices);
        stringBuilder.append(",Force FG =");
        stringBuilder.append(Info.mForceToForeground);
        pw.println(stringBuilder.toString());
        int list_size = Info.mPackageName.size();
        for (int i = 0; i < list_size; i++) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("  package name = ");
            stringBuilder2.append((java.lang.String) Info.mPackageName.get(i));
            pw.println(stringBuilder2.toString());
        }
        if (Info.mCreatedTime > 0) {
            dat = new java.util.Date(Info.mCreatedTime);
            gc = new java.util.GregorianCalendar();
            gc.setTime(dat);
            java.lang.String sb = new java.text.SimpleDateFormat("yyyy-MM-dd hh:mm:ss").format(gc.getTime());
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("  created time = ");
            stringBuilder3.append(Info.mCreatedTime);
            stringBuilder3.append(", data:");
            stringBuilder3.append(sb);
            pw.println(stringBuilder3.toString());
        }
        if (Info.mKilledTime > 0) {
            dat = new java.util.Date(Info.mKilledTime);
            gc = new java.util.GregorianCalendar();
            gc.setTime(dat);
            java.lang.String sb2 = new java.text.SimpleDateFormat("yyyy-MM-dd hh:mm:ss").format(gc.getTime());
            java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
            stringBuilder4.append("  Killed time = ");
            stringBuilder4.append(Info.mKilledTime);
            stringBuilder4.append(", data:");
            stringBuilder4.append(sb2);
            pw.println(stringBuilder4.toString());
        }
    }

    /* JADX WARNING: Missing block: B:15:0x004c, code:
            return;
     */
    public void setAwareProcessState(int r6, int r7, int r8) {
        /*
        r5 = this;
        r0 = r5.mProcMap;
        monitor-enter(r0);
        r1 = r5.mAwareProcMap;	 Catch:{ all -> 0x004d }
        r2 = java.lang.Integer.valueOf(r6);	 Catch:{ all -> 0x004d }
        r1 = r1.get(r2);	 Catch:{ all -> 0x004d }
        r1 = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) r1;	 Catch:{ all -> 0x004d }
        if (r1 != 0) goto L_0x003a;
    L_0x0011:
        r2 = "ProcessInfoCollector";
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x004d }
        r3.<init>();	 Catch:{ all -> 0x004d }
        r4 = "setAwareProcessState: fail to set state! pid: ";
        r3.append(r4);	 Catch:{ all -> 0x004d }
        r3.append(r6);	 Catch:{ all -> 0x004d }
        r4 = ", uid:";
        r3.append(r4);	 Catch:{ all -> 0x004d }
        r3.append(r7);	 Catch:{ all -> 0x004d }
        r4 = ", state:";
        r3.append(r4);	 Catch:{ all -> 0x004d }
        r3.append(r8);	 Catch:{ all -> 0x004d }
        r3 = r3.toString();	 Catch:{ all -> 0x004d }
        android.util.Slog.e(r2, r3);	 Catch:{ all -> 0x004d }
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x003a:
        r2 = -1;
        if (r8 == r2) goto L_0x0040;
    L_0x003d:
        r1.setState(r8);	 Catch:{ all -> 0x004d }
    L_0x0040:
        r2 = r5.getIawareBrPolicy();	 Catch:{ all -> 0x004d }
        if (r2 == 0) goto L_0x004b;
    L_0x0046:
        r2 = r5.mIawareBrPolicy;	 Catch:{ all -> 0x004d }
        r2.updateProcessBrPolicy(r1, r8);	 Catch:{ all -> 0x004d }
    L_0x004b:
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        return;
    L_0x004d:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x004d }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.taskstatus.ProcessInfoCollector.setAwareProcessState(int, int, int):void");
    }

    public void setAwareProcessStateByUid(int pid, int uid, int state) {
        synchronized (this.mProcMap) {
            for (java.util.Map.Entry entry : this.mAwareProcMap.entrySet()) {
                com.android.server.mtm.iaware.appmng.AwareProcessInfo info = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) entry.getValue();
                if (info != null && info.mProcInfo.mUid == uid) {
                    if (state != -1) {
                        info.setState(state);
                    }
                    if (getIawareBrPolicy() != null) {
                        this.mIawareBrPolicy.updateProcessBrPolicy(info, state);
                    }
                }
            }
        }
    }

    public void resetAwareProcessStatePgRestart() {
        synchronized (this.mProcMap) {
            for (java.util.Map.Entry entry : this.mAwareProcMap.entrySet()) {
                com.android.server.mtm.iaware.appmng.AwareProcessInfo info = (com.android.server.mtm.iaware.appmng.AwareProcessInfo) entry.getValue();
                if (info != null && info.getState() == 1) {
                    info.setState(2);
                    if (getIawareBrPolicy() != null) {
                        this.mIawareBrPolicy.updateProcessBrPolicy(info, 2);
                    }
                }
            }
        }
    }

    private com.android.server.mtm.iaware.srms.AwareBroadcastPolicy getIawareBrPolicy() {
        if (this.mIawareBrPolicy == null && com.android.server.mtm.MultiTaskManagerService.self() != null) {
            this.mIawareBrPolicy = com.android.server.mtm.MultiTaskManagerService.self().getIawareBrPolicy();
        }
        return this.mIawareBrPolicy;
    }
}
