package com.android.server.mtm.utils;

public final class InnerUtils {
    private static final boolean DEBUG = false;
    private static final java.lang.String TAG = "InnerUtils";
    private static android.content.pm.IPackageManager pm = null;

    public static java.lang.String getPackageNameByUid(int uid) {
        java.lang.String packageName = null;
        try {
            java.lang.String[] packageNameList;
            if (pm != null) {
                packageNameList = pm.getPackagesForUid(uid);
            } else {
                pm = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
                packageNameList = pm.getPackagesForUid(uid);
            }
            if (packageNameList != null && packageNameList.length > 0) {
                packageName = packageNameList[0];
            }
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("InnerUtils", "can not connect to packagemanagerservice");
        }
        return packageName;
    }

    public static android.content.pm.ApplicationInfo getApplicationInfo(java.lang.String pkg) {
        android.content.pm.ApplicationInfo appInfo = null;
        if (pkg == null) {
            return null;
        }
        try {
            if (pm != null) {
                appInfo = pm.getApplicationInfo(pkg, 0, android.os.UserHandle.getCallingUserId());
            } else {
                pm = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
                appInfo = pm.getApplicationInfo(pkg, 0, android.os.UserHandle.getCallingUserId());
            }
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("InnerUtils", "can not connect to packagemanagerservice");
        }
        return appInfo;
    }

    public static java.lang.String getAwarePkgName(int pid) {
        com.android.server.mtm.taskstatus.ProcessInfo procInfo = com.android.server.mtm.taskstatus.ProcessInfoCollector.getInstance().getProcessInfo(pid);
        if (!(procInfo == null || procInfo.mProcessName == null || procInfo.mPackageName == null)) {
            if (procInfo.mPackageName.size() != 0) {
                java.lang.String processName = procInfo.mProcessName;
                java.util.ArrayList<java.lang.String> packageNameList = procInfo.mPackageName;
                if (packageNameList.size() == 1) {
                    return (java.lang.String) packageNameList.get(0);
                }
                for (int i = 0; i < packageNameList.size(); i++) {
                    android.content.pm.ApplicationInfo appinfo = getApplicationInfo((java.lang.String) packageNameList.get(i));
                    if (appinfo != null && processName.equals(appinfo.processName)) {
                        return appinfo.packageName;
                    }
                }
                return (java.lang.String) packageNameList.get(0);
            }
        }
        return null;
    }

    public static boolean checkPackageNameByUid(int uid, java.lang.String pkgname) {
        try {
            java.lang.String[] packageNameList;
            if (pm != null) {
                packageNameList = pm.getPackagesForUid(uid);
            } else {
                pm = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
                packageNameList = pm.getPackagesForUid(uid);
            }
            if (packageNameList != null && packageNameList.length > 0) {
                for (java.lang.String packageName : packageNameList) {
                    if (packageName != null && packageName.equals(pkgname)) {
                        return true;
                    }
                }
            }
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("InnerUtils", "can not connect to packagemanagerservice");
        }
        return false;
    }

    public static boolean checkPackageNameContainsByUid(int uid, java.lang.String pkgname) {
        try {
            java.lang.String[] packageNameList;
            if (pm != null) {
                packageNameList = pm.getPackagesForUid(uid);
            } else {
                pm = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
                packageNameList = pm.getPackagesForUid(uid);
            }
            if (packageNameList != null && packageNameList.length > 0) {
                for (java.lang.String packageName : packageNameList) {
                    if (packageName != null && packageName.contains(pkgname)) {
                        return true;
                    }
                }
            }
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("InnerUtils", "can not connect to packagemanagerservice");
        }
        return false;
    }

    public static java.util.List<android.content.pm.PackageInfo> getAllInstalledAppsInfo(int userId) {
        try {
            if (pm == null) {
                pm = android.content.pm.IPackageManager.Stub.asInterface(android.os.ServiceManager.getService("package"));
            }
            android.content.pm.ParceledListSlice<android.content.pm.PackageInfo> parceledList = pm.getInstalledPackages(131072, userId);
            if (parceledList == null) {
                return java.util.Collections.emptyList();
            }
            return parceledList.getList();
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("InnerUtils", "can not connect to packagemanagerservice");
            return java.util.Collections.emptyList();
        }
    }
}
