package com.android.server.net;

public class HwNetworkPolicyManagerService extends com.android.server.net.NetworkPolicyManagerService {
    private static final java.lang.String ATTR_OPPACKAGENAME = "packagename";
    private static final java.lang.String ATTR_POLICY = "policy";
    private static final java.lang.String ATTR_UID = "uid";
    private static final java.lang.String ATTR_VERSION = "version";
    private static final int HSM_NETWORKMANAGER_SERVICE_TRANSACTION_CODE = 201;
    private static final java.lang.String HW_CONNECTIVITY_ACTION = "huawei.net.conn.HW_CONNECTIVITY_CHANGE";
    private static final int HW_RULE_ALL_ACCESS = 0;
    private static final int HW_RULE_MOBILE_RESTRICT = 1;
    private static final int HW_RULE_WIFI_RESTRICT = 2;
    private static final boolean HW_SIM_ACTIVATION = android.os.SystemProperties.getBoolean("ro.config.hw_sim_activation", false);
    static final java.lang.String TAG = "HwNetworkPolicy";
    private static final java.lang.String TAG_APP_POLICY = "app-policy";
    private static final java.lang.String TAG_NETWORK_POLICY = "network-policy";
    private static final java.lang.String TAG_POLICY_LIST = "policy-list";
    private static final java.lang.String TAG_UID_POLICY = "uid-policy";
    private static final java.lang.String VERIZON_ICCID_PREFIX = "891480";
    private static final int VERSION_INIT = 1;
    private static final int VERSION_LATEST = 1;
    final android.content.Context mContext;
    final android.util.AtomicFile mHwPolicyFile;
    final android.util.SparseIntArray mHwUidPolicy = new android.util.SparseIntArray();
    final android.util.SparseArray<java.lang.String> mHwUidPolicyWriters = new android.util.SparseArray();
    final android.util.SparseIntArray mHwUidRules = new android.util.SparseIntArray();
    private boolean mIsRoaming = false;
    final java.lang.Object mRulesLock = new java.lang.Object();
    private android.content.BroadcastReceiver netReceiver = new com.android.server.net.HwNetworkPolicyManagerService.IntenterBoradCastReceiver();
    private int sIncreaseCmdCount = 0;

    private class IntenterBoradCastReceiver extends android.content.BroadcastReceiver {
        private IntenterBoradCastReceiver() {
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (com.android.server.net.HwNetworkPolicyManagerService.this.isMatchedOperator()) {
                java.lang.String action = intent.getAction();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onReceive ");
                stringBuilder.append(action);
                android.util.Log.d("network-policy", stringBuilder.toString());
                if ("huawei.net.conn.HW_CONNECTIVITY_CHANGE".equals(action)) {
                    com.android.server.net.HwNetworkPolicyManagerService.this.updateInterfaceWhiteList(context, intent.getStringExtra("intfName"));
                }
                if ("android.intent.action.AIRPLANE_MODE".equals(action)) {
                    com.android.server.net.HwNetworkPolicyManagerService.this.updateInterfaceWhiteList(context, null);
                }
            }
        }
    }

    public HwNetworkPolicyManagerService(android.content.Context context, android.app.IActivityManager activityManager, android.os.INetworkManagementService networkManagement) {
        super(context, activityManager, networkManagement);
        this.mContext = context;
        this.mHwPolicyFile = new android.util.AtomicFile(new java.io.File(getHwSystemDir(), "hwnetpolicy.xml"));
        initRegisterReceiver();
    }

    static java.io.File getHwSystemDir() {
        return new java.io.File(android.os.Environment.getDataDirectory(), "system");
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onTransact, code = ");
        stringBuilder.append(code);
        android.util.Slog.i("HwNetworkPolicy", stringBuilder.toString());
        if (code == 200) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            setHwUidPolicy(data);
            return true;
        }
        if (code == 201) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            addHwUidPolicy(data);
        } else if (code == 202) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            removeHwUidPolicy(data);
            return true;
        } else if (code == 203) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            getHwUidPolicy(data, reply);
            return true;
        } else if (code == 204) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            getHwUidsWithPolicy(data, reply);
            return true;
        } else if (code == 205) {
            this.mContext.enforceCallingOrSelfPermission("android.permission.MANAGE_NETWORK_POLICY", "HwNetworkPolicy");
            forceUpdatePolicyLocked(data);
            return true;
        }
        return super.onTransact(code, data, reply, flags);
    }

    public void setHwUidPolicy(android.os.Parcel data) {
        setHwUidPolicy(data.readInt(), data.readInt(), data.readString());
    }

    public void setHwUidPolicy(int uid, int policy, java.lang.String opPackageName) {
        synchronized (this.mRulesLock) {
            if (this.mHwUidPolicy.get(uid, 0) != policy) {
                setHwUidPolicyUncheckedLocked(uid, policy, opPackageName, true);
            }
        }
    }

    public void setHwUidPolicyUncheckedLocked(int uid, int policy, java.lang.String opPackageName, boolean persist) {
        this.mHwUidPolicy.put(uid, policy);
        this.mHwUidPolicyWriters.put(uid, opPackageName);
        updateHwRuleForRestrictLocked(uid);
        if (persist) {
            writeHwPolicyLocked();
        }
    }

    public void addHwUidPolicy(android.os.Parcel data) {
        addHwUidPolicy(data.readInt(), data.readInt(), data.readString());
    }

    public void addHwUidPolicy(int uid, int policy, java.lang.String opPackageName) {
        synchronized (this.mRulesLock) {
            int oldPolicy = this.mHwUidPolicy.get(uid, 0);
            policy |= oldPolicy;
            if (oldPolicy != policy) {
                setHwUidPolicyUncheckedLocked(uid, policy, opPackageName, true);
            }
        }
    }

    public void removeHwUidPolicy(android.os.Parcel data) {
        removeHwUidPolicy(data.readInt(), data.readInt(), data.readString());
    }

    public void removeHwUidPolicy(int uid, int policy, java.lang.String opPackageName) {
        synchronized (this.mRulesLock) {
            int oldPolicy = this.mHwUidPolicy.get(uid, 0);
            policy = oldPolicy & (~policy);
            if (oldPolicy != policy) {
                setHwUidPolicyUncheckedLocked(uid, policy, opPackageName, true);
            }
        }
    }

    public void getHwUidPolicy(android.os.Parcel data, android.os.Parcel reply) {
        reply.writeInt(getHwUidPolicy(data.readInt()));
    }

    public int getHwUidPolicy(int uid) {
        int i;
        synchronized (this.mRulesLock) {
            i = this.mHwUidPolicy.get(uid, 0);
        }
        return i;
    }

    public void getHwUidsWithPolicy(android.os.Parcel data, android.os.Parcel reply) {
        int[] uids = getHwUidsWithPolicy(data.readInt());
        reply.writeInt(uids.length);
        reply.writeIntArray(uids);
    }

    public int[] getHwUidsWithPolicy(int policy) {
        int i = 0;
        int[] uids = new int[0];
        synchronized (this.mRulesLock) {
            while (i < this.mHwUidPolicy.size()) {
                int uid = this.mHwUidPolicy.keyAt(i);
                if ((this.mHwUidPolicy.valueAt(i) & policy) != 0) {
                    uids = com.android.internal.util.ArrayUtils.appendInt(uids, uid);
                }
                i++;
            }
        }
        return uids;
    }

    void updateHwRuleForRestrictLocked(int uid) {
        int newPolicy;
        int uidPolicy = this.mHwUidPolicy.get(uid, 0);
        boolean ruleRestrict = true;
        boolean isMobileRestrict = (uidPolicy & 1) != 0;
        boolean isWifiRestrict = (uidPolicy & 2) != 0;
        boolean isRoamingRestrict = (uidPolicy & 4) != 0;
        if (this.mIsRoaming) {
            if (isMobileRestrict || isRoamingRestrict) {
                newPolicy = 0 | 1;
            } else {
                newPolicy = 0 & -2;
            }
        } else if (isMobileRestrict) {
            newPolicy = 0 | 1;
        } else {
            newPolicy = 0 & -2;
        }
        if (isWifiRestrict) {
            newPolicy |= 2;
        } else {
            newPolicy &= -3;
        }
        int oldPolicy = this.mHwUidRules.get(uid, 0);
        if (newPolicy != oldPolicy) {
            if (newPolicy == 0) {
                this.mHwUidRules.delete(uid);
            } else {
                this.mHwUidRules.put(uid, newPolicy);
            }
            android.os.IBinder networkManager = android.os.ServiceManager.getService("network_management");
            if (networkManager != null) {
                if ((newPolicy & 1) != (oldPolicy & 1)) {
                    setHwNetworkRestrict(uid, (newPolicy & 1) != 0, true, networkManager);
                }
                if ((newPolicy & 2) != (oldPolicy & 2)) {
                    if ((newPolicy & 2) == 0) {
                        ruleRestrict = false;
                    }
                    setHwNetworkRestrict(uid, ruleRestrict, false, networkManager);
                }
            }
        }
    }

    private void setHwNetworkRestrict(int uid, boolean isRestrict, boolean isMobileNetwork, android.os.IBinder networkManager) {
        android.os.Parcel data = android.os.Parcel.obtain();
        android.os.Parcel reply = android.os.Parcel.obtain();
        java.lang.String cmd = "bandwidth";
        java.lang.String[] args = new java.lang.String[5];
        args[0] = "firewall";
        args[1] = isRestrict ? "block" : "allow";
        args[2] = isMobileNetwork ? "mobile" : "wifi";
        args[3] = java.lang.String.valueOf(uid);
        args[4] = java.lang.String.valueOf(this.sIncreaseCmdCount);
        try {
            data.writeString(cmd);
            data.writeArray(args);
            networkManager.transact(201, data, reply, 0);
            this.sIncreaseCmdCount++;
            if (data != null) {
                data.recycle();
            }
            if (reply == null) {
            }
        } catch (java.lang.Exception e) {
            e.printStackTrace();
        } finally {
            if (data != null) {
                data.recycle();
            }
            if (reply != null) {
                reply.recycle();
            }
        }
    }

    public void writeHwPolicyLocked() {
        android.util.Slog.i("HwNetworkPolicy", "writeHwPolicyLocked");
        java.io.FileOutputStream fos = null;
        try {
            fos = this.mHwPolicyFile.startWrite();
            org.xmlpull.v1.XmlSerializer out = new com.android.internal.util.FastXmlSerializer();
            out.setOutput(fos, java.nio.charset.StandardCharsets.UTF_8.name());
            out.startDocument(null, java.lang.Boolean.valueOf(true));
            out.startTag(null, "policy-list");
            com.android.internal.util.XmlUtils.writeIntAttribute(out, "version", 1);
            for (int i = 0; i < this.mHwUidPolicy.size(); i++) {
                int uid = this.mHwUidPolicy.keyAt(i);
                int policy = this.mHwUidPolicy.valueAt(i);
                java.lang.String opPackageName = (java.lang.String) this.mHwUidPolicyWriters.get(uid);
                if (policy != 0) {
                    out.startTag(null, "uid-policy");
                    com.android.internal.util.XmlUtils.writeIntAttribute(out, "uid", uid);
                    com.android.internal.util.XmlUtils.writeIntAttribute(out, "policy", policy);
                    com.android.internal.util.XmlUtils.writeStringAttribute(out, "packagename", opPackageName);
                    out.endTag(null, "uid-policy");
                }
            }
            out.endTag(null, "policy-list");
            out.endDocument();
            this.mHwPolicyFile.finishWrite(fos);
        } catch (java.io.IOException e) {
            if (fos != null) {
                this.mHwPolicyFile.failWrite(fos);
            }
        }
    }

    public void factoryReset(java.lang.String subscriber) {
        super.factoryReset(subscriber);
        for (int i = 0; i < this.mHwUidPolicy.size(); i++) {
            setUidPolicy(this.mHwUidPolicy.keyAt(i), 0);
        }
    }

    protected void readPolicyAL() {
        java.lang.StringBuilder stringBuilder;
        super.readPolicyAL();
        android.util.Slog.i("HwNetworkPolicy", "readHwPolicyLocked");
        this.mHwUidPolicy.clear();
        java.io.FileInputStream fis = null;
        try {
            fis = this.mHwPolicyFile.openRead();
            org.xmlpull.v1.XmlPullParser in = android.util.Xml.newPullParser();
            in.setInput(fis, java.nio.charset.StandardCharsets.UTF_8.name());
            int version = 1;
            while (true) {
                int next = in.next();
                int type = next;
                if (next == 1) {
                    break;
                }
                java.lang.String tag = in.getName();
                if (type == 2 && "uid-policy".equals(tag)) {
                    setHwUidPolicyUncheckedLocked(com.android.internal.util.XmlUtils.readIntAttribute(in, "uid"), com.android.internal.util.XmlUtils.readIntAttribute(in, "policy"), com.android.internal.util.XmlUtils.readStringAttribute(in, "packagename"), false);
                }
            }
        } catch (java.io.FileNotFoundException e) {
            android.util.Slog.e("HwNetworkPolicy", "problem reading hw network policy, file not found");
        } catch (java.io.IOException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("problem reading hw network policy");
            stringBuilder.append(e2);
            android.util.Slog.e("HwNetworkPolicy", stringBuilder.toString());
        } catch (org.xmlpull.v1.XmlPullParserException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("problem reading hw network policy");
            stringBuilder.append(e3);
            android.util.Slog.e("HwNetworkPolicy", stringBuilder.toString());
        } catch (Throwable th) {
            libcore.io.IoUtils.closeQuietly(null);
        }
        libcore.io.IoUtils.closeQuietly(fis);
    }

    public void forceUpdatePolicyLocked(android.os.Parcel data) {
        synchronized (this.mRulesLock) {
            int i = 0;
            boolean z = true;
            if (data.readInt() != 1) {
                z = false;
            }
            this.mIsRoaming = z;
            while (true) {
                int i2 = i;
                if (i2 < this.mHwUidPolicy.size()) {
                    updateHwRuleForRestrictLocked(this.mHwUidPolicy.keyAt(i2));
                    i = i2 + 1;
                }
            }
        }
    }

    private void initRegisterReceiver() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("initRegisterReceiver ");
        stringBuilder.append(this.mContext);
        android.util.Log.i("network-policy", stringBuilder.toString());
        if (this.mContext != null) {
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("huawei.net.conn.HW_CONNECTIVITY_CHANGE");
            filter.addAction("android.intent.action.AIRPLANE_MODE");
            this.mContext.registerReceiver(this.netReceiver, filter);
        }
    }

    private void updateInterfaceWhiteList(android.content.Context context, java.lang.String itfName) {
        android.net.ConnectivityManager connManager = (android.net.ConnectivityManager) context.getSystemService("connectivity");
        java.util.Set<java.lang.String> need2UpdateIntfList = new java.util.HashSet();
        java.util.Set<java.lang.String> allIntfList = new java.util.HashSet();
        android.net.Network[] networks = connManager.getAllNetworks();
        for (int i = 0; i < networks.length; i++) {
            android.net.NetworkCapabilities networkCapabilities = connManager.getNetworkCapabilities(networks[i]);
            android.net.LinkProperties linkProperties = connManager.getLinkProperties(networks[i]);
            android.net.NetworkInfo networkInfo = connManager.getNetworkInfo(networks[i]);
            if (networkInfo != null && networkInfo.isConnected()) {
                java.lang.String intfName = linkProperties.getInterfaceName();
                allIntfList.add(intfName);
                if (networkCapabilities.hasCapability(11)) {
                    need2UpdateIntfList.add(intfName);
                }
            }
        }
        if (itfName != null) {
            allIntfList.add(itfName);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("allIntfList ");
        stringBuilder.append(allIntfList);
        android.util.Log.d("network-policy", stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("need2UpdateIntfList ");
        stringBuilder.append(need2UpdateIntfList);
        android.util.Log.d("network-policy", stringBuilder.toString());
        for (java.lang.String intfName2 : allIntfList) {
            setMeteredInterface(intfName2, true);
        }
        for (java.lang.String intfName22 : need2UpdateIntfList) {
            setMeteredInterface(intfName22, false);
        }
    }

    private void setMeteredInterface(java.lang.String itfName, boolean isMetered) {
        if (itfName != null) {
            android.os.IBinder networkManager = android.os.ServiceManager.getService("network_management");
            if (networkManager == null) {
                android.util.Log.e("network-policy", "setIfWhitelist networkManager is null");
                return;
            }
            android.os.Parcel data = android.os.Parcel.obtain();
            android.os.Parcel reply = android.os.Parcel.obtain();
            java.lang.String cmd = "bandwidth";
            java.lang.String[] args = new java.lang.String[2];
            args[0] = !isMetered ? "enable_ifwhitelist" : "disable_ifwhitelist";
            args[1] = itfName;
            try {
                data.writeString(cmd);
                data.writeArray(args);
                networkManager.transact(201, data, reply, 0);
                this.sIncreaseCmdCount++;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("");
                stringBuilder.append(reply);
                android.util.Log.e("network-policy", stringBuilder.toString());
                if (data != null) {
                    data.recycle();
                }
                if (reply != null) {
                }
            } catch (java.lang.Exception e) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("setIfWhitelist-->");
                stringBuilder2.append(e);
                android.util.Slog.e("HwNetworkPolicy", stringBuilder2.toString());
            } finally {
                if (data != null) {
                    data.recycle();
                }
                if (reply != null) {
                    reply.recycle();
                }
            }
        }
    }

    private boolean isMatchedOperator() {
        android.telephony.TelephonyManager tm = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        java.lang.String iccid = new java.lang.StringBuilder();
        iccid.append("");
        iccid.append(tm.getSimSerialNumber());
        iccid = iccid.toString();
        if (HW_SIM_ACTIVATION && iccid.startsWith("891480")) {
            return true;
        }
        return false;
    }
}
