package com.android.server.net;

public class HwNetworkStatsService extends com.android.server.net.NetworkStatsService {
    private static final boolean DEBUG;
    public static final long MAX_TRAFFIC_PER_PROCESS = 5242880;
    private static final java.lang.String PREFIX_UID_AND_PROC = "uid_and_proc";
    private static final java.lang.String PREFIX_UID_PROC = "uid_proc";
    private static final java.lang.String TAG = "HwNetworkStatsService";
    private static final java.lang.String TAG_MONITOR = "HwNetworkStatsService_IMONITOR";
    public static final int TRAFFIC_EVENT_ID = 907400017;
    public static final long UPLOAD_INTERVAL = 1800000;
    private static long mLastUploadTime = 0;
    private android.net.NetworkTemplate mMobileTemplate = android.net.NetworkTemplate.buildTemplateMobileWildcard();
    private android.util.ArrayMap<java.lang.String, com.android.server.net.HwNetworkStatsService.ProcInfo> mProcInfos = new android.util.ArrayMap();
    private final com.android.internal.net.NetworkStatsFactory mStatsFactory = new com.android.internal.net.NetworkStatsFactory();
    private com.android.server.net.NetworkStatsRecorder mUidAndProcRecorder;
    private com.android.server.net.NetworkStatsRecorder mUidProcRecorder;
    private com.android.server.net.NetworkStatsCollection mUidProcStatsCached;
    private android.util.ArrayMap<java.lang.String, com.android.server.net.HwNetworkStatsService.UploadCycle> mUploadCycles = new android.util.ArrayMap();

    private static final class ProcInfo {
        java.lang.String mPkgName;
        java.lang.String mVersionName;

        public ProcInfo() {
            this.mPkgName = "";
            this.mVersionName = "";
        }

        public ProcInfo(java.lang.String pkgName, java.lang.String versionName) {
            this.mPkgName = pkgName;
            this.mVersionName = versionName;
        }
    }

    private static final class UploadCycle {
        long mLastUploadTraffic;
        java.lang.String mProc;
        int mUploadCount;

        public UploadCycle() {
            this("", 0);
        }

        public UploadCycle(java.lang.String proc, long lastUploadTraffic) {
            this.mProc = proc;
            this.mLastUploadTraffic = lastUploadTraffic;
            this.mUploadCount = 0;
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWLog) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwNetworkStatsService", 3)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwNetworkStatsService(android.content.Context context, android.os.INetworkManagementService networkManager, android.app.AlarmManager alarmManager, android.os.PowerManager.WakeLock wakeLock, java.time.Clock clock, android.telephony.TelephonyManager teleManager, com.android.server.net.NetworkStatsService.NetworkStatsSettings settings, com.android.server.net.NetworkStatsObservers statsObservers, java.io.File systemDir, java.io.File baseDir) {
        super(context, networkManager, alarmManager, wakeLock, clock, teleManager, settings, statsObservers, systemDir, baseDir);
    }

    public void hwInitProcRecorder() {
        this.mUidProcRecorder = buildRecorder("uid_proc", this.mSettings.getUidConfig(), false);
    }

    public void hwInitProcStatsCollection() {
        this.mUidProcStatsCached = this.mUidProcRecorder.getOrLoadCompleteLocked();
    }

    public void hwUpdateProcPersistThresholds(long persistThreshold) {
        this.mUidProcRecorder.setPersistThreshold(this.mSettings.getUidPersistBytes(persistThreshold));
    }

    public void hwRecordSnapshotLocked(long currentTime) {
        android.net.NetworkStats res = getNetworkStatsProcDetail(this.mActiveIface);
        if (res != null) {
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mActiveIface: ");
                stringBuilder.append(this.mActiveIface);
                android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
            }
            this.mUidProcRecorder.recordSnapshotLocked(res, this.mActiveUidIfaces, null, currentTime);
            if (isMobile(this.mActiveIface)) {
                shouldUploadTraffic(res);
            }
        }
    }

    private boolean isMobile(java.lang.String iface) {
        boolean isMobile = false;
        int i = 0;
        if (iface == null) {
            return false;
        }
        java.lang.String[] allMobiles = getMobileIfaces();
        int length = allMobiles.length;
        while (i < length) {
            java.lang.String curIface = allMobiles[i];
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mobile iface:");
                stringBuilder.append(curIface);
                android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
            }
            if (iface.equals(curIface)) {
                isMobile = true;
                break;
            }
            i++;
        }
        return isMobile;
    }

    private android.net.NetworkStats getNetworkStatsProcDetail(java.lang.String iface) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.CONNECTIVITY_INTERNAL", "HwNetworkStatsService");
        return this.mStatsFactory.readNetworkStatsProcDetail(iface);
    }

    private void shouldUploadTraffic(android.net.NetworkStats stats) {
        android.net.NetworkStats networkStats = stats;
        if (networkStats != null) {
            android.net.NetworkStats.Entry entry = null;
            int i = 0;
            while (i < stats.size()) {
                int i2;
                entry = networkStats.getValues(i, entry);
                if (entry.uid >= 10000) {
                    i2 = i;
                } else {
                    com.android.server.net.HwNetworkStatsService.UploadCycle uploadCycle;
                    java.lang.String proc = entry.proc;
                    com.android.server.net.HwNetworkStatsService.ProcInfo procInfo = (com.android.server.net.HwNetworkStatsService.ProcInfo) this.mProcInfos.get(proc);
                    if (this.mUploadCycles.containsKey(proc)) {
                        uploadCycle = (com.android.server.net.HwNetworkStatsService.UploadCycle) this.mUploadCycles.get(proc);
                    } else {
                        uploadCycle = new com.android.server.net.HwNetworkStatsService.UploadCycle();
                        uploadCycle.mProc = proc;
                        this.mUploadCycles.put(proc, uploadCycle);
                    }
                    long curTime = android.os.SystemClock.elapsedRealtime();
                    android.net.NetworkStatsHistory history = this.mUidProcStatsCached.getHistory(this.mMobileTemplate, null, entry.uid, entry.set, entry.tag, -1, Long.MIN_VALUE, Long.MAX_VALUE, 3, android.os.Binder.getCallingUid());
                    long deltaTime = curTime - mLastUploadTime;
                    long deltaTotal = history.getTotalBytes() - uploadCycle.mLastUploadTraffic;
                    if (DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("maybe report, proc:");
                        stringBuilder.append(uploadCycle.mProc);
                        stringBuilder.append(", interval:");
                        i2 = i;
                        stringBuilder.append(curTime - mLastUploadTime);
                        stringBuilder.append(", mLastUploadTraffic:");
                        stringBuilder.append(uploadCycle.mLastUploadTraffic);
                        stringBuilder.append(", curTotal:");
                        stringBuilder.append(history.getTotalBytes());
                        stringBuilder.append(", uploadCount:");
                        stringBuilder.append(uploadCycle.mUploadCount);
                        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
                    } else {
                        i2 = i;
                        java.lang.String str = proc;
                    }
                    if (deltaTime > 1800000 && deltaTotal > 5242880) {
                        upload(entry, history, procInfo, uploadCycle);
                    }
                }
                i = i2 + 1;
                networkStats = stats;
            }
        }
    }

    private boolean upload(android.net.NetworkStats.Entry entry, android.net.NetworkStatsHistory history, com.android.server.net.HwNetworkStatsService.ProcInfo procInfo, com.android.server.net.HwNetworkStatsService.UploadCycle uploadCycle) {
        android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(907400017);
        if (eStream != null) {
            eStream.setParam((short) 1, procInfo != null ? procInfo.mVersionName : "unknown");
            eStream.setParam((short) 2, entry.uid);
            eStream.setParam((short) 3, history.getTotalBytes());
            eStream.setParam((short) 4, history.getTotalTxBytes());
            eStream.setParam((short) 5, history.getTotalRxBytes());
            java.lang.StringBuilder extraInfo = new java.lang.StringBuilder();
            extraInfo.append("PackageName: ");
            extraInfo.append(procInfo != null ? procInfo.mPkgName : entry.proc);
            extraInfo.append("\n");
            extraInfo.append("ProcessName: ");
            extraInfo.append(entry.proc);
            extraInfo.append("\n");
            extraInfo.append("UploadCount: ");
            int i = uploadCycle.mUploadCount + 1;
            uploadCycle.mUploadCount = i;
            extraInfo.append(i);
            eStream.setParam((short) 6, extraInfo.toString()).setTime(java.lang.System.currentTimeMillis());
            android.util.IMonitor.sendEvent(eStream);
            android.util.IMonitor.closeEventStream(eStream);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("upload traffic for proc:");
            stringBuilder.append(entry.proc);
            stringBuilder.append(", total:");
            stringBuilder.append(history.getTotalBytes());
            stringBuilder.append(", rx:");
            stringBuilder.append(history.getTotalRxBytes());
            stringBuilder.append(", tx:");
            stringBuilder.append(history.getTotalTxBytes());
            stringBuilder.append(", count:");
            stringBuilder.append(uploadCycle.mUploadCount);
            android.util.Slog.i("HwNetworkStatsService", stringBuilder.toString());
            mLastUploadTime = android.os.SystemClock.elapsedRealtime();
            uploadCycle.mLastUploadTraffic = history.getTotalBytes();
            return true;
        }
        android.util.Slog.w("HwNetworkStatsService_IMONITOR", "Open EventStream failed for event:907400017");
        return false;
    }

    public void hwShutdownLocked(long currentTime) {
        this.mUidProcRecorder.forcePersistLocked(currentTime);
        this.mUidProcRecorder = null;
        this.mUidProcStatsCached = null;
    }

    public boolean hwImportLegacyNetworkLocked() throws java.io.IOException {
        java.io.File file = new java.io.File(this.mSystemDir, "netstats_uid_proc.bin");
        if (!file.exists()) {
            return false;
        }
        this.mUidProcRecorder.importLegacyNetworkLocked(file);
        return file.delete();
    }

    public void hwMaybePersistLocked(long currentTime) {
        this.mUidProcRecorder.maybePersistLocked(currentTime);
    }

    public void hwForcePersistLocked(long currentTime) {
        this.mUidProcRecorder.forcePersistLocked(currentTime);
    }

    private android.net.NetworkStats getNetworkStatsUidAndProcDetail() {
        this.mContext.enforceCallingOrSelfPermission("android.permission.CONNECTIVITY_INTERNAL", "HwNetworkStatsService");
        try {
            return this.mStatsFactory.javaReadNetworkStatsUidAndProcDetail(-1, null, -1);
        } catch (java.io.IOException e) {
            android.util.Slog.e("HwNetworkStatsService", "problem reading uid-and_proc from kernel", e);
            throw new java.lang.IllegalStateException(e);
        }
    }

    public void hwInitUidAndProcRecorder() {
        android.util.Slog.d("HwNetworkStatsService", "hwInitUidAndProcRecorder");
        this.mUidAndProcRecorder = buildRecorder("uid_and_proc", this.mSettings.getUidConfig(), false);
    }

    public void hwUpdateUidAndProcPersistThresholds(long persistThreshold) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwUpdateUidAndProcPersistThresholds persistThreshold = ");
        stringBuilder.append(persistThreshold);
        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
        this.mUidAndProcRecorder.setPersistThreshold(this.mSettings.getUidPersistBytes(persistThreshold));
    }

    public void hwRecordUidAndProcSnapshotLocked(long currentTime) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwRecordUidAndProcSnapshotLocked currentTime = ");
        stringBuilder.append(currentTime);
        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
        this.mUidAndProcRecorder.recordSnapshotLocked(getNetworkStatsUidAndProcDetail(), this.mActiveUidIfaces, null, currentTime);
    }

    public void hwMaybeUidAndProcPersistLocked(long currentTime) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwMaybeUidAndProcPersistLocked currentTime = ");
        stringBuilder.append(currentTime);
        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
        this.mUidAndProcRecorder.maybePersistLocked(currentTime);
    }

    public void hwForceUidAndProcPersistLocked(long currentTime) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwForceUidAndProcPersistLocked currentTime = ");
        stringBuilder.append(currentTime);
        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
        this.mUidAndProcRecorder.forcePersistLocked(currentTime);
    }

    public void hwShutdownUidAndProcLocked(long currentTime) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("hwShutdownUidAndProcLocked currentTime = ");
        stringBuilder.append(currentTime);
        android.util.Slog.d("HwNetworkStatsService", stringBuilder.toString());
        this.mUidAndProcRecorder.forcePersistLocked(currentTime);
        this.mUidAndProcRecorder = null;
    }

    public com.android.server.net.NetworkStatsRecorder getUidAndProcNetworkStatsRecorder() {
        return this.mUidAndProcRecorder;
    }
}
