package com.android.server.os;

public class FreezeScreenWindowMonitor implements com.android.server.os.IFreezeScreenWindowMonitor {
    public static final java.lang.String TAG = "FreezeScreenWindowMonitor";
    private static com.android.server.os.FreezeScreenWindowMonitor mWinMonitor = null;
    private com.android.server.os.FreezeScreenWindowMonitor.DisplayEventLostScene mDisplayEventLostScene;
    private com.android.server.os.FreezeScreenWindowMonitor.FocusWindowErrorScene mFocusWindowErrorScene;
    private com.android.server.os.FreezeScreenWindowMonitor.FocusWindowNullScene mFocusWindowNullScene;
    private com.android.server.os.FreezeScreenWindowMonitor.HighWindowLayerScene mHighWindowLayerScene;
    private android.util.ArrayMap<java.lang.String, java.lang.Integer> mSceneMap;

    public static class DisplayEventLostScene extends android.os.FreezeScreenScene {
        private java.lang.String mProcessName;

        public boolean checkParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params != null && (params.get("context") instanceof android.content.Context) && (params.get("looper") instanceof android.os.Looper) && (params.get("pid") instanceof java.lang.Integer)) {
                return true;
            }
            return false;
        }

        public void checkFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (checkParamsValid(params)) {
                int pid = ((java.lang.Integer) params.get("pid")).intValue();
                if (isAppAlive((android.content.Context) params.get("context"), pid)) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("DisplayEventLostScene find FreezeScreen,mProcessName:");
                    stringBuilder.append(this.mProcessName);
                    android.util.Log.i("FreezeScreenWindowMonitor", stringBuilder.toString());
                    android.util.ArrayMap<java.lang.String, java.lang.Object> paramsRadar = new android.util.ArrayMap();
                    paramsRadar.put("checkType", java.lang.Integer.valueOf(907400012));
                    paramsRadar.put("pid", java.lang.Integer.valueOf(pid));
                    paramsRadar.put("processName", this.mProcessName);
                    getFreezeScreenRadar().upload(paramsRadar);
                }
            }
        }

        private boolean isAppAlive(android.content.Context context, int pid) {
            java.util.List<android.app.ActivityManager.RunningAppProcessInfo> appProcessList = ((android.app.ActivityManager) context.getSystemService("activity")).getRunningAppProcesses();
            if (appProcessList == null) {
                return false;
            }
            for (android.app.ActivityManager.RunningAppProcessInfo appProcess : appProcessList) {
                if (appProcess != null && pid == appProcess.pid) {
                    this.mProcessName = appProcess.processName;
                    return true;
                }
            }
            return false;
        }
    }

    public static class FocusWindowErrorScene extends android.os.FreezeScreenScene {
        private static final java.lang.String GET_FOCUSED_WINDOW_METHOD_NAME = "getFocusedWindow";
        private static final java.lang.String NULL_STRING = "null";
        private static final java.lang.String PHONE_WINDOW_MANAGER_FIELD = "mPhoneWindowManager";
        private static final java.lang.String SEPARATOR_CODE = "/";
        private static final java.lang.String WINDOW_MANAGER_SERVICE_CLASS = "com.android.server.wm.WindowManagerService";
        private java.lang.String mFocusedActivity = null;
        private java.lang.String mFocusedActivityHashCode = null;
        private java.lang.String mFocusedPackage = null;
        private java.lang.String mFocusedWindow = null;
        private java.lang.String mFocusedWindowHashCode = null;

        public void checkFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (checkParamsValid(params)) {
                if ("null".equals(this.mFocusedActivity) || "null".equals(this.mFocusedWindow) || (!this.mFocusedActivityHashCode.equals(this.mFocusedWindowHashCode) && this.mFocusedWindow.contains("/"))) {
                    java.lang.StringBuilder sb = new java.lang.StringBuilder();
                    sb.append(this.mFocusedPackage);
                    sb.append("\n");
                    sb.append("FocusWindowErrorScene find freezeScreen, ");
                    sb.append("FOCUS_WINDOW: ");
                    sb.append(this.mFocusedWindow);
                    sb.append(",FOCUS_APP: ");
                    sb.append(this.mFocusedActivity);
                    android.util.Log.i("FreezeScreenWindowMonitor", sb.toString());
                    android.util.ZRHung.sendHungEvent((short) 15, null, sb.toString());
                }
            }
        }

        /* JADX WARNING: Missing block: B:11:0x004d, code:
            return;
     */
        public synchronized void cancelCheckFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> r3) {
            /*
            r2 = this;
            monitor-enter(r2);
            r0 = r2.checkParamsValid(r3);	 Catch:{ all -> 0x004e }
            if (r0 != 0) goto L_0x0009;
        L_0x0007:
            monitor-exit(r2);
            return;
        L_0x0009:
            r0 = "focusedWindowName";
            r0 = r3.get(r0);	 Catch:{ all -> 0x004e }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x004e }
            r2.mFocusedWindow = r0;	 Catch:{ all -> 0x004e }
            r0 = "focusedWindowHashCode";
            r0 = r3.get(r0);	 Catch:{ all -> 0x004e }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x004e }
            r2.mFocusedWindowHashCode = r0;	 Catch:{ all -> 0x004e }
            r0 = "focusedPackageName";
            r0 = r3.get(r0);	 Catch:{ all -> 0x004e }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x004e }
            r2.mFocusedPackage = r0;	 Catch:{ all -> 0x004e }
            r0 = "focusedActivityName";
            r0 = r3.get(r0);	 Catch:{ all -> 0x004e }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x004e }
            r2.mFocusedActivity = r0;	 Catch:{ all -> 0x004e }
            r0 = "focusedActivityHashCode";
            r0 = r3.get(r0);	 Catch:{ all -> 0x004e }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x004e }
            r2.mFocusedActivityHashCode = r0;	 Catch:{ all -> 0x004e }
            r0 = r2.mHandler;	 Catch:{ all -> 0x004e }
            if (r0 == 0) goto L_0x004c;
        L_0x003f:
            r0 = "FreezeScreenWindowMonitor";
            r1 = "FocusWindowErrorScene cancelCheckFreezeScreen";
            android.util.Log.d(r0, r1);	 Catch:{ all -> 0x004e }
            r0 = r2.mHandler;	 Catch:{ all -> 0x004e }
            r1 = 2;
            r0.removeMessages(r1);	 Catch:{ all -> 0x004e }
        L_0x004c:
            monitor-exit(r2);
            return;
        L_0x004e:
            r3 = move-exception;
            monitor-exit(r2);
            throw r3;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.android.server.os.FreezeScreenWindowMonitor.FocusWindowErrorScene.cancelCheckFreezeScreen(android.util.ArrayMap):void");
        }

        public boolean checkCancelParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params != null && (params.get("looper") instanceof android.os.Looper)) {
                return true;
            }
            return false;
        }

        public boolean checkParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params == null || !(params.get("looper") instanceof android.os.Looper) || !(params.get("focusedWindowName") instanceof java.lang.String) || !(params.get("focusedWindowHashCode") instanceof java.lang.String) || !(params.get("focusedPackageName") instanceof java.lang.String) || !(params.get("focusedActivityName") instanceof java.lang.String) || !(params.get("focusedActivityHashCode") instanceof java.lang.String)) {
                return false;
            }
            this.mFocusedWindow = (java.lang.String) params.get("focusedWindowName");
            this.mFocusedWindowHashCode = (java.lang.String) params.get("focusedWindowHashCode");
            this.mFocusedPackage = (java.lang.String) params.get("focusedPackageName");
            this.mFocusedActivity = (java.lang.String) params.get("focusedActivityName");
            this.mFocusedActivityHashCode = (java.lang.String) params.get("focusedActivityHashCode");
            return true;
        }
    }

    public static class FocusWindowNullScene extends android.os.FreezeScreenScene {
        private static final java.lang.String GET_FOCUSED_WINDOW_METHOD_NAME = "getFocusedWindow";
        private static final java.lang.String PHONE_WINDOW_MANAGER_FIELD = "mPhoneWindowManager";
        private static final java.lang.String WINDOW_MANAGER_SERVICE_CLASS = "com.android.server.wm.WindowManagerService";
        private java.lang.String mFocusedActivity = null;

        public void checkFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (checkParamsValid(params)) {
                processCurWinAndAppStatus((java.lang.String) params.get("focusedActivityName"), (com.android.server.wm.WindowManagerService) params.get("windowManager"));
            }
        }

        /* JADX WARNING: Missing block: B:13:0x002b, code:
            return;
     */
        public synchronized void cancelCheckFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> r3) {
            /*
            r2 = this;
            monitor-enter(r2);
            r0 = r2.checkCancelParamsValid(r3);	 Catch:{ all -> 0x002c }
            if (r0 != 0) goto L_0x0009;
        L_0x0007:
            monitor-exit(r2);
            return;
        L_0x0009:
            r0 = r2.mHandler;	 Catch:{ all -> 0x002c }
            if (r0 == 0) goto L_0x002a;
        L_0x000d:
            r0 = "anrActivityName";
            r0 = r3.get(r0);	 Catch:{ all -> 0x002c }
            r0 = (java.lang.String) r0;	 Catch:{ all -> 0x002c }
            r1 = r2.mFocusedActivity;	 Catch:{ all -> 0x002c }
            r0 = r0.equals(r1);	 Catch:{ all -> 0x002c }
            if (r0 == 0) goto L_0x002a;
        L_0x001d:
            r0 = "FreezeScreenWindowMonitor";
            r1 = "FocusWindowNullScene ANR appear and cancelCheckFreezeScreen";
            android.util.Log.d(r0, r1);	 Catch:{ all -> 0x002c }
            r0 = r2.mHandler;	 Catch:{ all -> 0x002c }
            r1 = 1;
            r0.removeMessages(r1);	 Catch:{ all -> 0x002c }
        L_0x002a:
            monitor-exit(r2);
            return;
        L_0x002c:
            r3 = move-exception;
            monitor-exit(r2);
            throw r3;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.android.server.os.FreezeScreenWindowMonitor.FocusWindowNullScene.cancelCheckFreezeScreen(android.util.ArrayMap):void");
        }

        public boolean checkCancelParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params != null && (params.get("anrActivityName") instanceof java.lang.String)) {
                return true;
            }
            return false;
        }

        public boolean checkParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params != null && (params.get("looper") instanceof android.os.Looper) && (params.get("focusedActivityName") instanceof java.lang.String) && (params.get("windowManager") instanceof com.android.server.wm.WindowManagerService)) {
                return true;
            }
            return false;
        }

        private synchronized void processCurWinAndAppStatus(java.lang.String focusedActivity, com.android.server.wm.WindowManagerService windowManager) {
            java.lang.reflect.Method method = com.android.server.os.FreezeScreenWindowMonitor.MonitorHelperExtend.getReflectPrivateMethod("com.android.server.wm.WindowManagerService", "getFocusedWindow");
            if (method != null) {
                try {
                    if (((com.android.server.policy.WindowManagerPolicy.WindowState) method.invoke(windowManager, new java.lang.Object[0])) == null) {
                        this.mFocusedActivity = focusedActivity;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("FocusWindowNullScene find FreezeScreen,mFocusedActivity:");
                        stringBuilder.append(this.mFocusedActivity);
                        android.util.Log.i("FreezeScreenWindowMonitor", stringBuilder.toString());
                        android.util.ArrayMap<java.lang.String, java.lang.Object> paramsRadar = new android.util.ArrayMap();
                        paramsRadar.put("checkType", java.lang.Integer.valueOf(907400013));
                        paramsRadar.put("focusedActivityName", focusedActivity);
                        getFreezeScreenRadar().upload(paramsRadar);
                    }
                } catch (java.lang.IllegalAccessException e) {
                } catch (java.lang.reflect.InvocationTargetException e2) {
                }
            }
        }
    }

    public static final class HighWindowLayerScene extends android.os.FreezeScreenScene {
        private static final long AUTO_CHECK_MIN_INTERVAL_TIME = 60000;
        private static long sLastAutoUploadTime;
        private com.android.server.policy.WindowManagerPolicy.WindowState mCurWindowState;
        private int mNumber;

        public synchronized void checkFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (!checkParamsValid(params)) {
                return;
            }
            if (checkFreq(params)) {
                checkFreezeScreen((com.android.server.policy.WindowManagerPolicy.WindowState) params.get("windowState"));
            }
        }

        public boolean checkParamsValid(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            if (params != null) {
                if (params.get("windowState") instanceof com.android.server.policy.WindowManagerPolicy.WindowState) {
                    return true;
                }
            }
            return false;
        }

        public void checkFreezeScreen(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            this.mCurWindowState = curWin;
            if (isWinMayCauseFreezeScreen(curWin)) {
                java.lang.String windowState = this.mCurWindowState.toString();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("HighWindowLayerScene find FreezeScreen,mCurWindowState:");
                stringBuilder.append(windowState);
                android.util.Log.i("FreezeScreenWindowMonitor", stringBuilder.toString());
                android.util.ArrayMap<java.lang.String, java.lang.Object> paramsRadar = new android.util.ArrayMap();
                paramsRadar.put("checkType", java.lang.Integer.valueOf(907400011));
                paramsRadar.put("highLevelWindowName", windowState);
                getFreezeScreenRadar().upload(paramsRadar);
            }
        }

        private boolean checkFreq(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
            long currentTime = java.lang.System.currentTimeMillis();
            if (currentTime - sLastAutoUploadTime > 60000 && (params.get("newCirCle") instanceof java.lang.Boolean)) {
                if (params.get("number") instanceof java.lang.Integer) {
                    if (((java.lang.Boolean) params.get("newCircle")).booleanValue()) {
                        this.mNumber = ((java.lang.Integer) params.get("number")).intValue();
                        android.util.Log.i("FreezeScreenWindowMonitor", "HighWindowLayerScene start to check");
                    }
                    int i = this.mNumber;
                    this.mNumber = i - 1;
                    if (i == 0) {
                        sLastAutoUploadTime = currentTime;
                    }
                    return true;
                }
            }
            return false;
        }

        private boolean isWinMayCauseFreezeScreen(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return isWinLayerAboveSystem(curWin) && isFullWindow(curWin) && (!(isTouchModal(curWin) && isTouchable(curWin)) && isWindowVisible(curWin) && hasInputChannel(curWin));
        }

        private boolean isWinLayerAboveSystem(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return com.android.server.os.FreezeScreenWindowMonitor.MonitorHelperExtend.windowTypeToLayerLw(curWin.getAttrs().type) >= com.android.server.os.FreezeScreenWindowMonitor.MonitorHelperExtend.windowTypeToLayerLw(2003);
        }

        private boolean isFullWindow(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return com.android.server.os.FreezeScreenWindowMonitor.MonitorHelperExtend.isFullWindow(curWin);
        }

        private boolean isTouchable(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return (curWin.getAttrs().flags & 16) == 0;
        }

        private boolean isTouchModal(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return (curWin.getAttrs().flags & 40) == 0;
        }

        private boolean isWindowVisible(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return false;
        }

        private boolean hasInputChannel(com.android.server.policy.WindowManagerPolicy.WindowState curWin) {
            return (curWin.getAttrs().inputFeatures & 2) == 0;
        }
    }

    public static class MonitorHelperExtend extends android.os.FreezeScreenScene.MonitorHelper {
        public static int windowTypeToLayerLw(int type) {
            return com.android.server.policy.HwPolicyFactory.getHwPhoneWindowManager().getWindowLayerFromTypeLw(type);
        }

        public static boolean isFullWindow(com.android.server.policy.WindowManagerPolicy.WindowState win) {
            if (win == null) {
                return false;
            }
            return isFullWindow(win.getAttrs());
        }

        public static java.lang.Class<?> getWMSClass(java.lang.String className) {
            try {
                return java.lang.Class.forName(className);
            } catch (java.lang.ClassNotFoundException e) {
                android.util.Log.e("FreezeScreenWindowMonitor", e.toString());
                return null;
            }
        }

        public static java.lang.reflect.Method getReflectPrivateMethod(java.lang.String className, java.lang.String methodName) {
            java.lang.Class<?> cls = getWMSClass(className);
            if (cls != null) {
                try {
                    final java.lang.reflect.Method method = cls.getDeclaredMethod(methodName, new java.lang.Class[0]);
                    java.security.AccessController.doPrivileged(new java.security.PrivilegedAction() {
                        public java.lang.Object run() {
                            method.setAccessible(true);
                            return null;
                        }
                    });
                    return method;
                } catch (java.lang.NoSuchMethodException e) {
                    e.printStackTrace();
                }
            }
            return null;
        }
    }

    public static synchronized com.android.server.os.FreezeScreenWindowMonitor getInstance() {
        com.android.server.os.FreezeScreenWindowMonitor freezeScreenWindowMonitor;
        synchronized (com.android.server.os.FreezeScreenWindowMonitor.class) {
            if (mWinMonitor == null) {
                mWinMonitor = new com.android.server.os.FreezeScreenWindowMonitor();
            }
            freezeScreenWindowMonitor = mWinMonitor;
        }
        return freezeScreenWindowMonitor;
    }

    private FreezeScreenWindowMonitor() {
        initScene();
        initSceneMap();
    }

    private void initScene() {
        this.mHighWindowLayerScene = new com.android.server.os.FreezeScreenWindowMonitor.HighWindowLayerScene();
        this.mDisplayEventLostScene = new com.android.server.os.FreezeScreenWindowMonitor.DisplayEventLostScene();
        this.mFocusWindowNullScene = new com.android.server.os.FreezeScreenWindowMonitor.FocusWindowNullScene();
        this.mFocusWindowErrorScene = new com.android.server.os.FreezeScreenWindowMonitor.FocusWindowErrorScene();
    }

    private void initSceneMap() {
        this.mSceneMap = new android.util.ArrayMap();
        this.mSceneMap.put("HighWindowLayerScene", java.lang.Integer.valueOf(907400011));
        this.mSceneMap.put("DisplayEventLostScene", java.lang.Integer.valueOf(907400012));
        this.mSceneMap.put("FocusWindowNullScene", java.lang.Integer.valueOf(907400013));
        this.mSceneMap.put("FocusWindowErrorScene", java.lang.Integer.valueOf(907400014));
    }

    public void checkFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        if (params != null) {
            if (params.get("checkType") instanceof java.lang.String) {
                switch (((java.lang.Integer) this.mSceneMap.get((java.lang.String) params.get("checkType"))).intValue()) {
                    case 907400011:
                        this.mHighWindowLayerScene.checkFreezeScreen((android.util.ArrayMap) params);
                        break;
                    case 907400012:
                        this.mDisplayEventLostScene.scheduleCheckFreezeScreen(params);
                        break;
                    case 907400013:
                        this.mFocusWindowNullScene.scheduleCheckFreezeScreen(params);
                        break;
                    case 907400014:
                        this.mFocusWindowErrorScene.scheduleCheckFreezeScreen(params);
                        break;
                    default:
                        break;
                }
            }
        }
    }

    public void cancelCheckFreezeScreen(android.util.ArrayMap<java.lang.String, java.lang.Object> params) {
        switch (((java.lang.Integer) this.mSceneMap.get((java.lang.String) params.get("checkType"))).intValue()) {
            case 907400013:
                this.mFocusWindowNullScene.cancelCheckFreezeScreen(params);
                return;
            case 907400014:
                this.mFocusWindowErrorScene.cancelCheckFreezeScreen(params);
                return;
            default:
                return;
        }
    }
}
