package com.android.server.pc;

public class DisplayDriverCommunicator {
    private static final java.lang.String FILE_PATH = "/sys/class/dp/source/source_mode";
    private static java.lang.String KEYBOARD_STATE_INFO = "/sys/devices/platform/hwsw_kb/stateinfo";
    private static final int KEYBOARD_STATE_INFO_MAX_LENGTH = 100;
    public static final java.lang.String START_DESKTOP_MODE_VALUE = "0";
    public static final java.lang.String START_PHONE_MODE_VALUE = "1";
    private static final java.lang.String TAG = "DisplayDriverCommunicator";
    private static volatile com.android.server.pc.DisplayDriverCommunicator mInstance = null;
    private boolean isFeatureSupport;

    private DisplayDriverCommunicator() {
        this.isFeatureSupport = false;
        this.isFeatureSupport = isFeatureSupport();
    }

    private boolean isFeatureSupport() {
        if (new java.io.File("/sys/class/dp/source/source_mode").exists()) {
            return true;
        }
        return false;
    }

    public synchronized void resetProjectionMode() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("resetProjectionMode isFeatureSupport = ");
        stringBuilder.append(this.isFeatureSupport);
        android.util.Log.v("DisplayDriverCommunicator", stringBuilder.toString());
        if (this.isFeatureSupport) {
            setProjectionModeValue("1");
        }
    }

    public synchronized void enableProjectionMode() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("enableProjectionMode isFeatureSupport = ");
        stringBuilder.append(this.isFeatureSupport);
        android.util.Log.v("DisplayDriverCommunicator", stringBuilder.toString());
        if (this.isFeatureSupport) {
            setProjectionModeValue("0");
        }
    }

    private void setProjectionModeValue(java.lang.String val) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setProjectionModeValue ");
        stringBuilder.append(val);
        android.util.Log.v("DisplayDriverCommunicator", stringBuilder.toString());
        java.io.FileOutputStream fileOutWriteMode = null;
        try {
            fileOutWriteMode = new java.io.FileOutputStream(new java.io.File("/sys/class/dp/source/source_mode"));
            fileOutWriteMode.write(val.getBytes("utf-8"));
            try {
                fileOutWriteMode.close();
            } catch (java.io.IOException e) {
                android.util.Log.e("DisplayDriverCommunicator", "fail to setProjectionModeValue");
            }
        } catch (java.io.FileNotFoundException e2) {
            if (fileOutWriteMode != null) {
                fileOutWriteMode.close();
            }
        } catch (java.io.IOException e3) {
            if (fileOutWriteMode != null) {
                fileOutWriteMode.close();
            }
        } catch (Throwable th) {
            if (fileOutWriteMode != null) {
                try {
                    fileOutWriteMode.close();
                } catch (java.io.IOException e4) {
                    android.util.Log.e("DisplayDriverCommunicator", "fail to setProjectionModeValue");
                }
            }
        }
        android.util.Log.v("DisplayDriverCommunicator", "setProjectionModeValue end");
    }

    public static synchronized com.android.server.pc.DisplayDriverCommunicator getInstance() {
        com.android.server.pc.DisplayDriverCommunicator displayDriverCommunicator;
        synchronized (com.android.server.pc.DisplayDriverCommunicator.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.pc.DisplayDriverCommunicator();
            }
            displayDriverCommunicator = mInstance;
        }
        return displayDriverCommunicator;
    }

    public static boolean isExclusiveKeyboardOnline() {
        java.io.BufferedReader reader = null;
        try {
            reader = new java.io.BufferedReader(new java.io.InputStreamReader(new java.io.FileInputStream(KEYBOARD_STATE_INFO), java.nio.charset.StandardCharsets.UTF_8));
            java.lang.StringBuilder sb = new java.lang.StringBuilder();
            while (true) {
                int read = reader.read();
                int intC = read;
                if (read == -1) {
                    break;
                }
                char c = (char) intC;
                if (c == 10) {
                    break;
                } else if (sb.length() >= 100) {
                    break;
                } else {
                    sb.append(c);
                }
            }
            java.lang.String keyboardStatus = sb.toString();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Exclisive status:");
            stringBuilder.append(keyboardStatus);
            android.util.HwPCUtils.log("DisplayDriverCommunicator", stringBuilder.toString());
            if (keyboardStatus == null || !keyboardStatus.trim().equals("keyboard is online".trim())) {
                try {
                    reader.close();
                } catch (java.io.IOException e) {
                    android.util.HwPCUtils.log("DisplayDriverCommunicator", "isExclisiveKeyboardOnline() close():IOException");
                }
                return false;
            }
            android.util.HwPCUtils.log("DisplayDriverCommunicator", "isExclisiveKeyboardOnline():true");
            try {
                reader.close();
            } catch (java.io.IOException e2) {
                android.util.HwPCUtils.log("DisplayDriverCommunicator", "isExclisiveKeyboardOnline() close():IOException");
            }
            return true;
        } catch (java.io.IOException e3) {
            android.util.HwPCUtils.log("DisplayDriverCommunicator", "isExclisiveKeyboardOnline():IOException");
            if (reader != null) {
                reader.close();
            }
        } catch (Throwable th) {
            if (reader != null) {
                try {
                    reader.close();
                } catch (java.io.IOException e4) {
                    android.util.HwPCUtils.log("DisplayDriverCommunicator", "isExclisiveKeyboardOnline() close():IOException");
                }
            }
        }
    }
}
