package com.android.server.pc;

public class HwPCMkManager {
    public static final boolean DEBUG = android.os.SystemProperties.getBoolean("hw_pc_mkmanager_debug", false);
    public static final int MOTION_DOUBLE_CLICK_DELAY_TIME = 300;
    public static final java.lang.String TAG = "HwPCMkManager";
    private static com.android.server.pc.HwPCMkManager mStatic;
    private final int SHOW_DEFAULT = 0;
    private final int SHOW_LASERPOINTER = 1;
    private final int SHOW_UNUSE = -1;
    final float default_height = 50.0f;
    final float default_width = 0.0f;
    private int mClickCount = 0;
    private float mCoefficientX = 1.7f;
    private float mCoefficientY = 0.8f;
    private android.content.Context mContext;
    private float mCurrentEventX = 0.0f;
    private float mCurrentEventY = 0.0f;
    private float mCurrentPointerX = 100.0f;
    private float mCurrentPointerY = 100.0f;
    private float mDensity = 3.0f;
    private android.hardware.display.DisplayManager mDisplayManager;
    private android.view.MotionEvent mDownEvent = null;
    private com.android.server.input.HwInputManagerService.HwInputManagerLocalService mInputManager = null;
    private boolean mIsMove = false;
    private boolean mIsSequent = false;
    private android.view.MotionEvent mMultiPointerDownEvent = null;
    private long mOldClickTime = 0;
    private com.android.server.pc.HwPCManagerService mPCManager;
    private com.android.server.pc.HwPCMkManager.PoninterMode mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
    private int mScreentHeight;
    private int mScreentWidth;
    private com.android.server.pc.HwPCMkManager.SendEventThread mSendEvent = null;
    private int mShowMode = 0;
    private int mTouchSlopSquare = 0;
    final float showlaserpointer_height = 90.0f;
    final float showlaserpointer_width = 46.0f;

    private enum PoninterMode {
        NORMAL_POINTER_MODE,
        MULTI_POINTER_MODE,
        SINGLE_POINTER_MODE
    }

    class SendEventThread extends android.os.HandlerThread implements android.os.Handler.Callback {
        public static final int MSG_MOTIONEVENT = 0;
        public static final int MSG_MOTIONEVENT_MOVE = 1;
        private android.os.Handler mEventHandler;

        public SendEventThread(java.lang.String name) {
            super(name);
        }

        public SendEventThread(java.lang.String name, int priority) {
            super(name, priority);
        }

        protected void onLooperPrepared() {
            this.mEventHandler = new android.os.Handler(getLooper(), this);
        }

        public boolean handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 0:
                case 1:
                    if (msg.obj instanceof android.view.InputEvent) {
                        com.android.server.pc.HwPCMkManager.this.sendPointerSync(msg.obj);
                        break;
                    }
                    break;
                default:
                    break;
            }
            return true;
        }

        public void send(android.view.InputEvent event) {
            if (com.android.server.pc.HwPCMkManager.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("SendEventThread send event:");
                stringBuilder.append(event);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
            }
            android.os.Message msg = android.os.Message.obtain();
            msg.what = 0;
            msg.obj = event;
            this.mEventHandler.sendMessage(msg);
        }

        public void sendMoveEvent(android.view.InputEvent event) {
            if (com.android.server.pc.HwPCMkManager.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("SendEventThread send move event:");
                stringBuilder.append(event);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
            }
            this.mEventHandler.removeMessages(1);
            android.os.Message msg = android.os.Message.obtain();
            msg.what = 1;
            msg.obj = event;
            this.mEventHandler.sendMessage(msg);
        }

        public void clear() {
            this.mEventHandler.removeMessages(1);
            this.mEventHandler.removeMessages(0);
        }
    }

    public static synchronized com.android.server.pc.HwPCMkManager getInstance(android.content.Context context) {
        com.android.server.pc.HwPCMkManager hwPCMkManager;
        synchronized (com.android.server.pc.HwPCMkManager.class) {
            if (mStatic == null) {
                mStatic = new com.android.server.pc.HwPCMkManager(context);
            }
            hwPCMkManager = mStatic;
        }
        return hwPCMkManager;
    }

    private HwPCMkManager(android.content.Context context) {
        this.mContext = context;
        this.mDisplayManager = (android.hardware.display.DisplayManager) this.mContext.getSystemService("display");
        android.util.DisplayMetrics dm = new android.util.DisplayMetrics();
        android.view.Display mDefaultDisplay = this.mDisplayManager.getDisplay(0);
        if (mDefaultDisplay != null) {
            mDefaultDisplay.getMetrics(dm);
            this.mDensity = dm.density;
        }
        int touchSlop = android.view.ViewConfiguration.get(context).getScaledTouchSlop();
        this.mTouchSlopSquare = touchSlop * touchSlop;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("MkManager mTouchSlopSquare:");
        stringBuilder.append(this.mTouchSlopSquare);
        android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
    }

    public void initCrop(android.content.Context context, com.android.server.pc.HwPCManagerService pcManager) {
        this.mPCManager = pcManager;
        if (this.mDisplayManager != null) {
            android.view.Display mDisplay = this.mDisplayManager.getDisplay(android.util.HwPCUtils.getPCDisplayID());
            if (mDisplay != null) {
                android.graphics.Point size = new android.graphics.Point();
                mDisplay.getRealSize(size);
                this.mScreentWidth = size.x;
                this.mScreentHeight = size.y;
            } else {
                android.util.HwPCUtils.log("HwPCMkManager", "initCrop display is null");
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HwPCMkManager mScreentWidth:");
        stringBuilder.append(this.mScreentWidth);
        stringBuilder.append(" mScreentHeight:");
        stringBuilder.append(this.mScreentHeight);
        stringBuilder.append(" mDensity = ");
        stringBuilder.append(this.mDensity);
        stringBuilder.append(" mTouchSlopSquare = ");
        stringBuilder.append(this.mTouchSlopSquare);
        android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
    }

    public void startSendEventThread() {
        synchronized (this) {
            if (this.mSendEvent == null) {
                this.mSendEvent = new com.android.server.pc.HwPCMkManager.SendEventThread("PCSendEvent", -4);
                this.mSendEvent.start();
            }
        }
    }

    public void stopSendEventThreadAndRelease() {
        synchronized (this) {
            this.mScreentWidth = 0;
            this.mScreentHeight = 0;
            if (this.mSendEvent != null) {
                this.mSendEvent.clear();
            }
        }
    }

    final float dipsToPixels(float dips) {
        return (this.mDensity * dips) + 0.5f;
    }

    final float pixelsToDips(float pixels) {
        return (pixels / this.mDensity) + 0.5f;
    }

    public boolean sendEvent(android.view.MotionEvent event, android.graphics.Rect visibleRect, android.graphics.Rect displayRect, int mode) {
        if (event != null) {
            if (this.mSendEvent != null) {
                if (DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("sendEvent event = ");
                    stringBuilder.append(event);
                    stringBuilder.append("  visibleRect = ");
                    stringBuilder.append(visibleRect);
                    stringBuilder.append(" displayRect = ");
                    stringBuilder.append(displayRect);
                    android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
                }
                if (!isInTouchRect(event, visibleRect, displayRect, mode)) {
                    return false;
                }
                int pointerCount = event.getPointerCount();
                if (DEBUG) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("sendEvent pointerCount:");
                    stringBuilder2.append(pointerCount);
                    stringBuilder2.append(" mPoninterMode:");
                    stringBuilder2.append(this.mPoninterMode);
                    stringBuilder2.append(" event:");
                    stringBuilder2.append(event);
                    android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
                }
                OnDownEventProcess(event);
                if (this.mPoninterMode == com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE) {
                    if (pointerCount > 1) {
                        this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.MULTI_POINTER_MODE;
                    } else {
                        this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.SINGLE_POINTER_MODE;
                    }
                }
                if (this.mPoninterMode == com.android.server.pc.HwPCMkManager.PoninterMode.SINGLE_POINTER_MODE) {
                    onSinglePointerMode(event);
                } else if (this.mPoninterMode == com.android.server.pc.HwPCMkManager.PoninterMode.MULTI_POINTER_MODE) {
                    this.mDownEvent = null;
                    this.mClickCount = 0;
                    onMultiPointerMode(event);
                }
                return true;
            }
        }
        return false;
    }

    private boolean isInTouchRect(android.view.MotionEvent event, android.graphics.Rect visibleRect, android.graphics.Rect displayRect, int mode) {
        if (mode != -1) {
            this.mShowMode = mode;
        }
        float height = 50.0f;
        float width = 0.0f;
        if (displayRect.right < displayRect.bottom) {
            if (this.mShowMode == 1) {
                height = 90.0f;
            }
            if (event.getX() < ((float) visibleRect.left) || event.getX() > ((float) visibleRect.right) || event.getY() < ((float) visibleRect.top) + dipsToPixels(height) || event.getY() > ((float) visibleRect.bottom)) {
                android.util.HwPCUtils.log("HwPCMkManager", "sendEvent donot in visibleRect, right < bottom");
                return false;
            }
        }
        if (this.mShowMode == 1) {
            width = 46.0f;
        }
        if (event.getX() >= ((float) visibleRect.left) && event.getX() <= ((float) visibleRect.right) - dipsToPixels(width) && event.getY() >= ((float) visibleRect.top) + dipsToPixels(50.0f)) {
            if (event.getY() > ((float) visibleRect.bottom)) {
            }
        }
        android.util.HwPCUtils.log("HwPCMkManager", "sendEvent donot in visibleRect right >= bottom");
        return false;
        return true;
    }

    private void OnDownEventProcess(android.view.MotionEvent event) {
        int action = event.getAction();
        java.lang.StringBuilder stringBuilder;
        if (action == 0) {
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("OnDownEventProcess ACTION_DOWN mPoninterMode:");
                stringBuilder.append(this.mPoninterMode);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
            }
            this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.SINGLE_POINTER_MODE;
            this.mIsSequent = true;
        } else if ((action & 255) == 5) {
            if (DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("OnDownEventProcess ACTION_POINTER_DOWN mPoninterMode:");
                stringBuilder.append(this.mPoninterMode);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
            }
            if (this.mPoninterMode == com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE) {
                this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.MULTI_POINTER_MODE;
            }
            if (this.mIsSequent) {
                this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.MULTI_POINTER_MODE;
            }
        } else if (this.mPoninterMode != com.android.server.pc.HwPCMkManager.PoninterMode.SINGLE_POINTER_MODE || action != 2 || !this.mIsSequent) {
            this.mIsSequent = false;
        } else if (!isShakeMove(event.getX(), event.getY(), this.mCurrentEventX, this.mCurrentEventY)) {
            this.mIsSequent = false;
        }
    }

    private void onSinglePointerMode(android.view.MotionEvent event) {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onSinglePointerMode event:");
            stringBuilder.append(event);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        int action = event.getAction();
        if (this.mDownEvent != null) {
            int pointerId = this.mDownEvent.getPointerId(0);
            int curPointerId = event.getPointerId(0);
            java.lang.StringBuilder stringBuilder2;
            if (pointerId == curPointerId) {
                java.lang.StringBuilder stringBuilder3;
                switch (action) {
                    case 1:
                        if (DEBUG) {
                            stringBuilder3 = new java.lang.StringBuilder();
                            stringBuilder3.append("sendEvent ACTION_UP mClickCount:");
                            stringBuilder3.append(this.mClickCount);
                            stringBuilder3.append(" mIsMove:");
                            stringBuilder3.append(this.mIsMove);
                            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder3.toString());
                        }
                        if (this.mIsMove) {
                            if (this.mClickCount >= 1) {
                                onClickUpMouseEvent(event);
                            } else {
                                onUpMouseEvent(event);
                            }
                            this.mOldClickTime = 0;
                            this.mClickCount = 0;
                        } else {
                            if (this.mClickCount >= 1) {
                                onClickUpMouseEvent(event);
                                this.mOldClickTime = 0;
                                this.mClickCount = 0;
                            } else {
                                onClickMouseEvent(this.mDownEvent, event);
                            }
                            this.mClickCount++;
                            this.mOldClickTime = android.os.SystemClock.uptimeMillis();
                        }
                        this.mIsMove = false;
                        this.mDownEvent = null;
                        this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
                        break;
                    case 2:
                        if (this.mIsMove || !isShakeMove(event.getX(), event.getY(), this.mDownEvent.getX(), this.mDownEvent.getY())) {
                            this.mIsMove = true;
                        }
                        if (DEBUG) {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("sendEvent ACTION_MOVE mClickCount:");
                            stringBuilder2.append(this.mClickCount);
                            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
                        }
                        if (this.mClickCount < 1) {
                            onHoverEvent(event);
                            break;
                        } else {
                            onMouseEvent(event);
                            break;
                        }
                    default:
                        if (((65280 & action) >> 8) <= 0) {
                            if (DEBUG) {
                                stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("sendEvent nukown action:");
                                stringBuilder3.append(action);
                                stringBuilder3.append(" mClickCount:");
                                stringBuilder3.append(this.mClickCount);
                                stringBuilder3.append(" mIsMove:");
                                stringBuilder3.append(this.mIsMove);
                                stringBuilder3.append(" mOldClickTime:");
                                stringBuilder3.append(this.mOldClickTime);
                                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder3.toString());
                            }
                            onUpMouseEvent(event);
                            this.mOldClickTime = 0;
                            this.mIsMove = false;
                            this.mDownEvent = null;
                            this.mClickCount = 0;
                            this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
                            break;
                        }
                        break;
                }
            }
            if (DEBUG) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("sendEvent pointerId:");
                stringBuilder2.append(pointerId);
                stringBuilder2.append(" curPointerId:");
                stringBuilder2.append(curPointerId);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
            }
            this.mIsMove = false;
            this.mDownEvent = null;
            this.mClickCount = 0;
            this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
        } else if (action == 0) {
            this.mIsMove = false;
            this.mCurrentEventX = event.getX();
            this.mCurrentEventY = event.getY();
            this.mDownEvent = android.view.MotionEvent.obtain(event);
            long clickTime = android.os.SystemClock.uptimeMillis() - this.mOldClickTime;
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                stringBuilder4.append("sendEvent ACTION_DOWN clickTime:");
                stringBuilder4.append(clickTime);
                stringBuilder4.append(" mOldClickTime:");
                stringBuilder4.append(this.mOldClickTime);
                stringBuilder4.append(" mClickCount:");
                stringBuilder4.append(this.mClickCount);
                android.util.HwPCUtils.log("HwPCMkManager", stringBuilder4.toString());
            }
            if (clickTime > 300) {
                this.mOldClickTime = 0;
                this.mClickCount = 0;
            }
            if (this.mClickCount >= 1) {
                onClickMouseEvent(event);
            }
        }
    }

    private void onMultiPointerMode(android.view.MotionEvent event) {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onMultiPointerMode event:");
            stringBuilder.append(event);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        int action = event.getAction();
        java.lang.StringBuilder stringBuilder2;
        switch (action & 255) {
            case 5:
                this.mCurrentEventX = event.getX();
                this.mCurrentEventY = event.getY();
                if (DEBUG) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("sendEvent ACTION_POINTER_DOWN mCurrentEventX:");
                    stringBuilder2.append(this.mCurrentEventX);
                    stringBuilder2.append(" mCurrentEventY:");
                    stringBuilder2.append(this.mCurrentEventY);
                    android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
                }
                this.mMultiPointerDownEvent = android.view.MotionEvent.obtain(event);
                this.mIsMove = false;
                onHoverExitForRightClick(event);
                break;
            case 6:
                if (DEBUG) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("sendEvent ACTION_POINTER_UP mCurrentPointerX:");
                    stringBuilder3.append(this.mCurrentPointerX);
                    stringBuilder3.append(" mCurrentPointerY:");
                    stringBuilder3.append(this.mCurrentPointerY);
                    android.util.HwPCUtils.log("HwPCMkManager", stringBuilder3.toString());
                }
                if (!(this.mIsMove || this.mMultiPointerDownEvent == null)) {
                    onMouseSecondaryClick(this.mMultiPointerDownEvent, event, this.mCurrentPointerX, this.mCurrentPointerY);
                }
                this.mIsMove = false;
                onHoverEnterForRightClick(event);
                this.mMultiPointerDownEvent = null;
                this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
                break;
            default:
                if (action != 2) {
                    if (action == 3) {
                        this.mIsMove = false;
                        this.mMultiPointerDownEvent = null;
                        this.mPoninterMode = com.android.server.pc.HwPCMkManager.PoninterMode.NORMAL_POINTER_MODE;
                        break;
                    }
                }
                if (DEBUG) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("sendEvent multi pointer ACTION_MOVE mCurrentPointerX:");
                    stringBuilder2.append(this.mCurrentPointerX);
                    stringBuilder2.append(" mCurrentPointerY:");
                    stringBuilder2.append(this.mCurrentPointerY);
                    stringBuilder2.append(" eventX:");
                    stringBuilder2.append(event.getX());
                    stringBuilder2.append(" eventY:");
                    stringBuilder2.append(event.getY());
                    android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
                }
                if (this.mIsMove || !isShakeMove(event.getX(), event.getY(), this.mCurrentEventX, this.mCurrentEventY)) {
                    this.mIsMove = true;
                    if (onScrollEvent(event, event.getX() - this.mCurrentEventX, event.getY() - this.mCurrentEventY)) {
                        this.mCurrentEventX = event.getX();
                        this.mCurrentEventY = event.getY();
                        break;
                    }
                }
                if (DEBUG) {
                    android.util.HwPCUtils.log("HwPCMkManager", "onMultiPointerMode isShakeMove");
                }
                return;
                break;
        }
    }

    private boolean isShakeMove(float moveX, float moveY, float downX, float downY) {
        int deltaX = (int) (moveX - downX);
        int deltaY = (int) (moveY - downY);
        int distance = (deltaX * deltaX) + (deltaY * deltaY);
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("distance:");
            stringBuilder.append(distance);
            stringBuilder.append(" mTouchSlopSquare:");
            stringBuilder.append(this.mTouchSlopSquare);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        return distance < this.mTouchSlopSquare;
    }

    private void onMouseSecondaryClick(android.view.MotionEvent downEvent, android.view.MotionEvent upEvent, float x, float y) {
        if (this.mSendEvent != null) {
            this.mSendEvent.send(obtainMotionEvent(downEvent, x, y, 0, 2, 2));
            float f = x;
            float f2 = y;
            this.mSendEvent.send(obtainMotionEvent(downEvent, f, f2, 11, 2, 2));
            android.view.MotionEvent motionEvent = upEvent;
            this.mSendEvent.send(obtainMotionEvent(motionEvent, f, f2, 12, 2, 2));
            this.mSendEvent.send(obtainMotionEvent(motionEvent, f, f2, 1, upEvent.getButtonState(), 0));
        }
    }

    private android.view.MotionEvent obtainMotionEvent(android.view.MotionEvent event, float x, float y, int action, int buttonState) {
        float f;
        float f2;
        android.view.MotionEvent motionEvent = event;
        android.view.MotionEvent.PointerProperties[] pointerProperties = new android.view.MotionEvent.PointerProperties[1];
        android.view.MotionEvent.PointerCoords[] pointerCoords = new android.view.MotionEvent.PointerCoords[1];
        for (int index = 0; index < 1; index++) {
            android.view.MotionEvent.PointerProperties outPointerProperties = new android.view.MotionEvent.PointerProperties();
            motionEvent.getPointerProperties(index, outPointerProperties);
            outPointerProperties.toolType = 3;
            pointerProperties[index] = outPointerProperties;
            android.view.MotionEvent.PointerCoords outPointerCoords = new android.view.MotionEvent.PointerCoords();
            motionEvent.getPointerCoords(index, outPointerCoords);
            pointerCoords[index] = outPointerCoords;
            if (index == 0) {
                outPointerCoords.x = x;
                outPointerCoords.y = y;
            } else {
                f = x;
                f2 = y;
            }
        }
        f = x;
        f2 = y;
        long downTime = event.getDownTime();
        long eventTime = event.getEventTime();
        int metaState = event.getMetaState();
        float xPrecision = event.getXPrecision();
        f = xPrecision;
        return android.view.MotionEvent.obtain(downTime, eventTime, action, 1, pointerProperties, pointerCoords, metaState, buttonState, f, event.getYPrecision(), event.getDeviceId(), event.getEdgeFlags(), 8194, 0);
    }

    public static android.view.MotionEvent obtainMotionEvent(android.view.MotionEvent event, float x, float y, int action, int buttonState, float vScroll, float hScroll) {
        float f;
        float f2;
        android.view.MotionEvent motionEvent = event;
        android.view.MotionEvent.PointerProperties[] pointerProperties = new android.view.MotionEvent.PointerProperties[1];
        android.view.MotionEvent.PointerCoords[] pointerCoords = new android.view.MotionEvent.PointerCoords[1];
        for (int index = 0; index < 1; index++) {
            android.view.MotionEvent.PointerProperties outPointerProperties = new android.view.MotionEvent.PointerProperties();
            motionEvent.getPointerProperties(index, outPointerProperties);
            outPointerProperties.toolType = 3;
            pointerProperties[index] = outPointerProperties;
            android.view.MotionEvent.PointerCoords outPointerCoords = new android.view.MotionEvent.PointerCoords();
            motionEvent.getPointerCoords(index, outPointerCoords);
            outPointerCoords.setAxisValue(9, vScroll);
            outPointerCoords.setAxisValue(10, hScroll);
            pointerCoords[index] = outPointerCoords;
            if (index == 0) {
                outPointerCoords.x = x;
                outPointerCoords.y = y;
            } else {
                f = x;
                f2 = y;
            }
        }
        f = x;
        f2 = y;
        float f3 = vScroll;
        float f4 = hScroll;
        return android.view.MotionEvent.obtain(event.getDownTime(), event.getEventTime(), action, 1, pointerProperties, pointerCoords, event.getMetaState(), buttonState, event.getXPrecision(), event.getYPrecision(), event.getDeviceId(), event.getEdgeFlags(), 8194, 0);
    }

    private android.view.MotionEvent obtainMotionEvent(android.view.MotionEvent event, float x, float y, int action, int buttonState, int actionButton) {
        android.view.MotionEvent motionEvent = obtainMotionEvent(event, x, y, action, buttonState);
        motionEvent.setActionButton(actionButton);
        return motionEvent;
    }

    private void updatePointer(android.view.MotionEvent motionEvent) {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updatePointer mCurrentEventX:");
            stringBuilder.append(this.mCurrentEventX);
            stringBuilder.append(" mCurrentEventY:");
            stringBuilder.append(this.mCurrentEventY);
            stringBuilder.append(" mCurrentPointerX:");
            stringBuilder.append(this.mCurrentPointerX);
            stringBuilder.append(" mCurrentEventY:");
            stringBuilder.append(this.mCurrentPointerY);
            stringBuilder.append(" motionX:");
            stringBuilder.append(motionEvent.getX());
            stringBuilder.append(" motionY:");
            stringBuilder.append(motionEvent.getY());
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        float x = (motionEvent.getX() - this.mCurrentEventX) + this.mCurrentPointerX;
        float y = (motionEvent.getY() - this.mCurrentEventY) + this.mCurrentPointerY;
        this.mCurrentEventX = motionEvent.getX();
        this.mCurrentEventY = motionEvent.getY();
        if (x < 0.0f) {
            x = 0.0f;
        }
        if (x >= ((float) this.mScreentWidth)) {
            x = (float) (this.mScreentWidth - 1);
        }
        if (y < 0.0f) {
            y = 0.0f;
        }
        if (y >= ((float) this.mScreentHeight)) {
            y = (float) (this.mScreentHeight - 1);
        }
        this.mCurrentPointerX = x;
        this.mCurrentPointerY = y;
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("updatePointer end mCurrentPointerX:");
            stringBuilder2.append(this.mCurrentPointerX);
            stringBuilder2.append(" mCurrentPointerY:");
            stringBuilder2.append(this.mCurrentPointerY);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder2.toString());
        }
    }

    private boolean onScrollEvent(android.view.MotionEvent motionEvent, float distanceX, float distanceY) {
        float f = distanceX;
        float f2 = distanceY;
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onScrollEvent distanceX:");
            stringBuilder.append(f);
            stringBuilder.append(" distanceY:");
            stringBuilder.append(f2);
            stringBuilder.append(" mDensity");
            stringBuilder.append(this.mDensity);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        if (this.mSendEvent == null) {
            return false;
        }
        float distance = 16.0f * this.mDensity;
        if (java.lang.Math.abs(distanceX) < distance && java.lang.Math.abs(distanceY) < distance) {
            return false;
        }
        float vScroll = 0.0f;
        float hScroll = 0.0f;
        float f3 = -1.0f;
        if (java.lang.Math.abs(distanceY) >= distance) {
            vScroll = f2 > 0.0f ? 1.0f : -1.0f;
        }
        if (java.lang.Math.abs(distanceX) >= distance) {
            if (f > 0.0f) {
                f3 = 1.0f;
            }
            hScroll = f3;
        }
        this.mSendEvent.sendMoveEvent(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 8, motionEvent.getButtonState(), vScroll, hScroll));
        return true;
    }

    private void onHoverEvent(android.view.MotionEvent motionEvent) {
        if (this.mSendEvent != null) {
            updatePointer(motionEvent);
            this.mSendEvent.sendMoveEvent(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 7, motionEvent.getButtonState()));
        }
    }

    private void onHoverEnterForRightClick(android.view.MotionEvent motionEvent) {
        if (this.mSendEvent != null) {
            this.mSendEvent.send(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 9, 2, 0));
        }
    }

    private void onHoverExitForRightClick(android.view.MotionEvent motionEvent) {
        if (this.mSendEvent != null) {
            this.mSendEvent.send(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 10, 2, 0));
        }
    }

    private void onMouseEvent(android.view.MotionEvent motionEvent) {
        if (this.mSendEvent != null) {
            updatePointer(motionEvent);
            this.mSendEvent.sendMoveEvent(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, motionEvent.getAction(), 1));
        }
    }

    private void onClickMouseEvent(android.view.MotionEvent motionEvent) {
        if (this.mSendEvent != null) {
            modifyToMouseEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 1);
            this.mSendEvent.send(obtainMotionEvent(motionEvent, this.mCurrentPointerX, this.mCurrentPointerY, 11, 1, 1));
        }
    }

    private void onUpMouseEvent(android.view.MotionEvent upEvent) {
        modifyToMouseEvent(upEvent, this.mCurrentPointerX, this.mCurrentPointerY, upEvent.getButtonState());
    }

    private void onClickUpMouseEvent(android.view.MotionEvent upEvent) {
        if (this.mSendEvent != null) {
            this.mSendEvent.send(obtainMotionEvent(upEvent, this.mCurrentPointerX, this.mCurrentPointerY, 12, 1, 1));
            modifyToMouseEvent(upEvent, this.mCurrentPointerX, this.mCurrentPointerY, upEvent.getButtonState());
        }
    }

    private void onClickMouseEvent(android.view.MotionEvent downEvent, android.view.MotionEvent upEvent) {
        if (this.mSendEvent != null) {
            sendMouseEvent(0, 1, this.mCurrentPointerX, this.mCurrentPointerY, 0, 0);
            this.mSendEvent.send(obtainMotionEvent(downEvent, this.mCurrentPointerX, this.mCurrentPointerY, 11, 1, 1));
            this.mSendEvent.send(obtainMotionEvent(upEvent, this.mCurrentPointerX, this.mCurrentPointerY, 12, 1, 1));
            sendMouseEvent(1, 0, this.mCurrentPointerX, this.mCurrentPointerY, 0, 0);
        }
    }

    private void modifyToMouseEvent(android.view.MotionEvent event, float x, float y, int buttonState) {
        android.view.MotionEvent motionEvent = event;
        if (this.mSendEvent != null) {
            float f;
            float f2;
            int pointerCount = event.getPointerCount();
            android.view.MotionEvent.PointerProperties[] pointerProperties = new android.view.MotionEvent.PointerProperties[pointerCount];
            android.view.MotionEvent.PointerCoords[] pointerCoords = new android.view.MotionEvent.PointerCoords[pointerCount];
            for (int index = 0; index < pointerCount; index++) {
                android.view.MotionEvent.PointerProperties outPointerProperties = new android.view.MotionEvent.PointerProperties();
                motionEvent.getPointerProperties(index, outPointerProperties);
                outPointerProperties.toolType = 3;
                pointerProperties[index] = outPointerProperties;
                android.view.MotionEvent.PointerCoords outPointerCoords = new android.view.MotionEvent.PointerCoords();
                motionEvent.getPointerCoords(index, outPointerCoords);
                pointerCoords[index] = outPointerCoords;
                if (index == 0) {
                    outPointerCoords.x = x;
                    outPointerCoords.y = y;
                } else {
                    f = x;
                    f2 = y;
                }
            }
            f = x;
            f2 = y;
            this.mSendEvent.send(android.view.MotionEvent.obtain(event.getDownTime(), event.getEventTime(), event.getAction(), event.getPointerCount(), pointerProperties, pointerCoords, event.getMetaState(), buttonState, event.getXPrecision(), event.getYPrecision(), event.getDeviceId(), event.getEdgeFlags(), 8194, 0));
        }
    }

    private void sendMouseEvent(int action, int buttonState, float xx, float yy, int offsetX, int offsetY) {
        if (this.mSendEvent != null) {
            this.mSendEvent.send(obtainMouseEvent(action, buttonState, xx, yy, offsetX, offsetY));
        }
    }

    public void sendFakedMouseMoveEvent() {
        if (this.mSendEvent != null) {
            this.mSendEvent.sendMoveEvent(obtainMouseEvent(2, 0, this.mCurrentPointerX, this.mCurrentPointerY, 0, 0));
        }
    }

    public static android.view.MotionEvent obtainMouseEvent(int action, int buttonState, float xx, float yy, int offsetX, int offsetY) {
        long eventTime = android.os.SystemClock.uptimeMillis();
        android.view.MotionEvent.PointerProperties[] props = new android.view.MotionEvent.PointerProperties[]{new android.view.MotionEvent.PointerProperties()};
        props[0].id = 0;
        props[0].toolType = 3;
        android.view.MotionEvent.PointerCoords[] coords = new android.view.MotionEvent.PointerCoords[]{new android.view.MotionEvent.PointerCoords()};
        coords[0].x = xx + ((float) offsetX);
        coords[0].y = yy + ((float) offsetY);
        return android.view.MotionEvent.obtain(eventTime, eventTime, action, 1, props, coords, 0, buttonState, 0.0f, 0.0f, -1, 0, 8194, 0);
    }

    private boolean sendPointerSync(android.view.InputEvent event) {
        if (this.mInputManager == null) {
            this.mInputManager = (com.android.server.input.HwInputManagerService.HwInputManagerLocalService) com.android.server.LocalServices.getService(com.android.server.input.HwInputManagerService.HwInputManagerLocalService.class);
        }
        if (this.mInputManager == null) {
            return false;
        }
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sendPointerSync event = ");
            stringBuilder.append(event);
            android.util.HwPCUtils.log("HwPCMkManager", stringBuilder.toString());
        }
        return this.mInputManager.injectInputEvent(event, 0);
    }

    public void updatePointerAxis(float[] axis) {
        this.mCurrentPointerX = axis[0];
        this.mCurrentPointerY = axis[1];
    }
}
