package com.android.server.pm;

public class BlackListAppsUtils {
    private static final java.lang.String APP_BLACKLIST_FILE_NAME = "app_blacklist.xml";
    private static final java.lang.String DISABLED_APP_FILE_NAME = "disabled_app.xml";
    private static final java.lang.String MANIFEST_NAME = "META-INF/MANIFEST.MF";
    private static final java.lang.String TAG = "BlackListAppsUtils";

    public static void writeToXml(org.xmlpull.v1.XmlSerializer out, com.android.server.pm.BlackListInfo.BlackListApp app) throws java.lang.IllegalArgumentException, java.lang.IllegalStateException, java.io.IOException {
        if (out != null) {
            if (app != null) {
                out.startTag(null, "app");
                out.startTag(null, "packageName");
                out.text(app.mPackageName);
                out.endTag(null, "packageName");
                android.content.pm.Signature[] signs = app.mSignature;
                boolean versionIsValid = false;
                if (!(signs == null || signs.length == 0)) {
                    out.startTag(null, "signature");
                    java.lang.StringBuilder signsString = new java.lang.StringBuilder();
                    for (android.content.pm.Signature sigStr : signs) {
                        if (!android.text.TextUtils.isEmpty(signsString)) {
                            signsString.append(";");
                        }
                        signsString.append(sigStr.toCharsString());
                    }
                    out.text(signsString.toString());
                    out.endTag(null, "signature");
                }
                if ((app.mMinVersionId | app.mMaxVersionId) != 0) {
                    versionIsValid = true;
                }
                if (versionIsValid) {
                    out.startTag(null, "versionIDs");
                    out.startTag(null, "versionIDStart");
                    out.text(java.lang.String.valueOf(app.mMinVersionId));
                    out.endTag(null, "versionIDStart");
                    out.startTag(null, "versionIDEnd");
                    out.text(java.lang.String.valueOf(app.mMaxVersionId));
                    out.endTag(null, "versionIDEnd");
                    out.endTag(null, "versionIDs");
                }
                if (!android.text.TextUtils.isEmpty(app.mHashValue)) {
                    out.startTag(null, "hashValue");
                    out.text(app.mHashValue);
                    out.endTag(null, "hashValue");
                }
                out.endTag(null, "app");
            }
        }
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public static boolean writeBlackListToXml(com.android.server.pm.BlackListInfo disableApp) {
        if (disableApp == null) {
            return false;
        }
        java.io.FileOutputStream fis = null;
        try {
            fis = new java.io.FileOutputStream(android.os.Environment.buildPath(android.os.Environment.getDataDirectory(), new java.lang.String[]{"system", "disabled_app.xml"}), false);
            org.xmlpull.v1.XmlSerializer out = new com.android.internal.util.FastXmlSerializer();
            out.setOutput(fis, "utf-8");
            out.startDocument(null, java.lang.Boolean.valueOf(true));
            out.startTag(null, "blacklist");
            com.android.internal.util.XmlUtils.writeIntAttribute(out, "version", disableApp.mVersionCode);
            java.util.Iterator it = disableApp.mBlackList.iterator();
            while (it.hasNext()) {
                writeToXml(out, (com.android.server.pm.BlackListInfo.BlackListApp) it.next());
            }
            out.endTag(null, "blacklist");
            out.endDocument();
            fis.flush();
            try {
                fis.close();
            } catch (java.io.IOException e) {
                android.util.Slog.e("BlackListAppsUtils", "close OutputStream failed when write blacklist file");
            }
            return true;
        } catch (java.io.IOException e2) {
            android.util.Slog.e("BlackListAppsUtils", "write disabled app file failed due to IOException");
            deleteDisableAppListFile();
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e3) {
                    android.util.Slog.e("BlackListAppsUtils", "close OutputStream failed when write blacklist file");
                }
            }
            return false;
        } catch (Throwable th) {
            if (fis != null) {
                try {
                    fis.close();
                } catch (java.io.IOException e4) {
                    android.util.Slog.e("BlackListAppsUtils", "close OutputStream failed when write blacklist file");
                }
            }
        }
    }

    public static boolean deleteDisableAppListFile() {
        java.io.File file = android.os.Environment.buildPath(android.os.Environment.getDataDirectory(), new java.lang.String[]{"system", "disabled_app.xml"});
        if (file == null || !file.exists()) {
            return false;
        }
        return file.delete();
    }

    public static void readDisableAppList(com.android.server.pm.BlackListInfo info) {
        readBlackListFromXml(info, android.os.Environment.buildPath(android.os.Environment.getDataDirectory(), new java.lang.String[]{"system", "disabled_app.xml"}));
    }

    public static void readBlackList(com.android.server.pm.BlackListInfo info) {
        readBlackListFromXml(info, android.os.Environment.buildPath(android.os.Environment.getRootDirectory(), new java.lang.String[]{"etc", "xml", "app_blacklist.xml"}));
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private static void readBlackListFromXml(com.android.server.pm.BlackListInfo info, java.io.File file) {
        if (!(info == null || file == null)) {
            if (file.exists()) {
                java.io.FileInputStream fis = null;
                com.android.server.pm.BlackListInfo.BlackListApp app = null;
                java.util.ArrayList<com.android.server.pm.BlackListInfo.BlackListApp> blacklist = new java.util.ArrayList();
                int version = -1;
                boolean parserError = false;
                try {
                    fis = new java.io.FileInputStream(file);
                    org.xmlpull.v1.XmlPullParser xpp = org.xmlpull.v1.XmlPullParserFactory.newInstance().newPullParser();
                    xpp.setInput(fis, "UTF-8");
                    for (int type = xpp.getEventType(); type != 1; type = xpp.next()) {
                        if (type != 0) {
                            switch (type) {
                                case 2:
                                    java.lang.String name = xpp.getName();
                                    if (!android.text.TextUtils.equals("blacklist", name)) {
                                        if (!android.text.TextUtils.equals("app", name)) {
                                            if (!android.text.TextUtils.equals("packageName", name) || app == null) {
                                                if (!android.text.TextUtils.equals("signature", name) || app == null) {
                                                    int i;
                                                    if (!android.text.TextUtils.equals("versionIDStart", name) || app == null) {
                                                        if (!android.text.TextUtils.equals("versionIDEnd", name) || app == null) {
                                                            if (android.text.TextUtils.equals("hashValue", name) && app != null) {
                                                                app.mHashValue = xpp.nextText();
                                                                break;
                                                            }
                                                        }
                                                        i = 0;
                                                        try {
                                                            app.mMaxVersionId = java.lang.Integer.parseInt(xpp.nextText());
                                                            break;
                                                        } catch (java.lang.NumberFormatException e) {
                                                            parserError = true;
                                                            break;
                                                        }
                                                    }
                                                    i = 0;
                                                    try {
                                                        app.mMinVersionId = java.lang.Integer.parseInt(xpp.nextText());
                                                        break;
                                                    } catch (java.lang.NumberFormatException e2) {
                                                        parserError = true;
                                                        break;
                                                    }
                                                }
                                                try {
                                                    app.setSignature(xpp.nextText().split(";"));
                                                    break;
                                                } catch (java.lang.Exception e3) {
                                                    parserError = true;
                                                    break;
                                                }
                                            }
                                            app.mPackageName = xpp.nextText();
                                            break;
                                        }
                                        app = new com.android.server.pm.BlackListInfo.BlackListApp();
                                        break;
                                    }
                                    try {
                                        version = java.lang.Integer.parseInt(xpp.getAttributeValue(0));
                                        break;
                                    } catch (java.lang.NumberFormatException e4) {
                                        parserError = true;
                                        break;
                                    }
                                    break;
                                case 3:
                                    if (android.text.TextUtils.equals("app", xpp.getName())) {
                                        blacklist.add(app);
                                        app = null;
                                        break;
                                    }
                                    break;
                                default:
                                    break;
                            }
                        }
                        if (parserError) {
                            try {
                                fis.close();
                            } catch (java.io.IOException e5) {
                                android.util.Slog.e("BlackListAppsUtils", "close InputStream failed when read blacklist file");
                            }
                            return;
                        }
                    }
                    try {
                        fis.close();
                    } catch (java.io.IOException e6) {
                        android.util.Slog.e("BlackListAppsUtils", "close InputStream failed when read blacklist file");
                    }
                } catch (java.io.IOException e7) {
                    android.util.Slog.e("BlackListAppsUtils", "read blacklist file failed due to IOException");
                    parserError = true;
                    if (fis != null) {
                        fis.close();
                    }
                } catch (org.xmlpull.v1.XmlPullParserException e8) {
                    android.util.Slog.e("BlackListAppsUtils", "read blacklist file failed due to XmlPullParserException");
                    if (fis != null) {
                        fis.close();
                    }
                } catch (Throwable th) {
                    if (fis != null) {
                        try {
                            fis.close();
                        } catch (java.io.IOException e9) {
                            android.util.Slog.e("BlackListAppsUtils", "close InputStream failed when read blacklist file");
                        }
                    }
                }
                if (checkAppInfo(blacklist) && version >= 0 && !parserError) {
                    info.mBlackList.clear();
                    java.util.Iterator it = blacklist.iterator();
                    while (it.hasNext()) {
                        info.mBlackList.add((com.android.server.pm.BlackListInfo.BlackListApp) it.next());
                    }
                    info.mVersionCode = version;
                }
            }
        }
    }

    public static boolean comparePackage(android.content.pm.PackageParser.Package info, com.android.server.pm.BlackListInfo.BlackListApp app) {
        if (!(info == null || app == null)) {
            if (android.text.TextUtils.equals(info.packageName, app.mPackageName)) {
                int versionStart = app.mMinVersionId;
                int versionEnd = app.mMaxVersionId;
                if (((versionStart | versionEnd) != 0) && (info.mVersionCode < versionStart || info.mVersionCode > versionEnd)) {
                    return false;
                }
                if (app.mSignature != null && com.android.server.pm.PackageManagerServiceUtils.compareSignatures(info.mSigningDetails.signatures, app.mSignature) != 0) {
                    return false;
                }
                if (!android.text.TextUtils.isEmpty(app.mHashValue)) {
                    if (!android.text.TextUtils.equals(app.mHashValue, getSHA256(new java.io.File(info.applicationInfo.sourceDir)))) {
                        return false;
                    }
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("find blacklist apk : ");
                stringBuilder.append(app.mPackageName);
                android.util.Slog.d("BlackListAppsUtils", stringBuilder.toString());
                return true;
            }
        }
        return false;
    }

    private static java.lang.String getSHA256(java.io.File file) {
        byte[] manifest = getManifestFile(file);
        if (manifest.length == 0) {
            return null;
        }
        return sha256(manifest);
    }

    private static byte[] getManifestFile(java.io.File apkFile) {
        java.io.ByteArrayOutputStream os = new java.io.ByteArrayOutputStream();
        byte[] b = new byte[1024];
        java.util.zip.ZipFile zipFile = null;
        boolean catchFlag = false;
        java.io.InputStream zipInputStream = null;
        try {
            zipFile = new java.util.zip.ZipFile(apkFile);
            zipInputStream = zipFile.getInputStream(zipFile.getEntry("META-INF/MANIFEST.MF"));
            if (zipInputStream != null) {
                while (true) {
                    int read = zipInputStream.read(b);
                    int length = read;
                    if (read <= 0) {
                        break;
                    }
                    os.write(b, 0, length);
                }
                catchFlag = true;
            }
            if (zipInputStream != null) {
                try {
                    zipInputStream.close();
                } catch (java.io.IOException e) {
                }
            }
            try {
                zipFile.close();
            } catch (java.io.IOException e2) {
            }
            return catchFlag ? os.toByteArray() : new byte[0];
        } catch (java.io.IOException e3) {
            android.util.Slog.e("BlackListAppsUtils", " get manifest file failed due to IOException");
            if (zipInputStream != null) {
                try {
                    zipInputStream.close();
                } catch (java.io.IOException e4) {
                }
            }
            if (zipFile != null) {
                try {
                    zipFile.close();
                } catch (java.io.IOException e5) {
                }
            }
            return null;
        } catch (Throwable th) {
            if (zipInputStream != null) {
                try {
                    zipInputStream.close();
                } catch (java.io.IOException e6) {
                }
            }
            if (zipFile != null) {
                try {
                    zipFile.close();
                } catch (java.io.IOException e7) {
                }
            }
        }
    }

    public static java.lang.String sha256(byte[] data) {
        if (data == null) {
            return null;
        }
        try {
            java.security.MessageDigest md = java.security.MessageDigest.getInstance("SHA-256");
            md.update(data);
            return bytesToString(md.digest());
        } catch (java.security.NoSuchAlgorithmException e) {
            android.util.Slog.e("BlackListAppsUtils", "get sha256 failed");
            return null;
        }
    }

    private static java.lang.String bytesToString(byte[] bytes) {
        if (bytes == null) {
            return null;
        }
        char[] hexChars = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
        char[] chars = new char[(bytes.length * 2)];
        for (int j = 0; j < bytes.length; j++) {
            int byteValue = bytes[j] & 255;
            chars[j * 2] = hexChars[byteValue >>> 4];
            chars[(j * 2) + 1] = hexChars[byteValue & 15];
        }
        return new java.lang.String(chars);
    }

    public static boolean isBlackListUpdate(com.android.server.pm.BlackListInfo blacklist, com.android.server.pm.BlackListInfo disableApp) {
        int blacklistVersion = blacklist.mVersionCode;
        int disableAppVersion = disableApp.mVersionCode;
        java.lang.StringBuilder stringBuilder;
        if (disableAppVersion == -1) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("blacklist update, version = ");
            stringBuilder.append(blacklistVersion);
            android.util.Slog.d("BlackListAppsUtils", stringBuilder.toString());
            return true;
        } else if (blacklistVersion < disableAppVersion) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("blacklist downgrade: from ");
            stringBuilder.append(disableAppVersion);
            stringBuilder.append(" to ");
            stringBuilder.append(blacklistVersion);
            android.util.Slog.d("BlackListAppsUtils", stringBuilder.toString());
            return true;
        } else if (blacklistVersion > disableAppVersion) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("blacklist upgrade: from ");
            stringBuilder.append(disableAppVersion);
            stringBuilder.append(" to ");
            stringBuilder.append(blacklistVersion);
            android.util.Slog.d("BlackListAppsUtils", stringBuilder.toString());
            return true;
        } else {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("blacklist version = ");
            stringBuilder2.append(blacklistVersion);
            android.util.Slog.d("BlackListAppsUtils", stringBuilder2.toString());
            return false;
        }
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private static boolean checkAppInfo(java.util.ArrayList<com.android.server.pm.BlackListInfo.BlackListApp> blacklist) {
        if (blacklist == null) {
            return false;
        }
        java.util.Iterator it = blacklist.iterator();
        while (it.hasNext()) {
            com.android.server.pm.BlackListInfo.BlackListApp app = (com.android.server.pm.BlackListInfo.BlackListApp) it.next();
            if (android.text.TextUtils.isEmpty(app.mPackageName)) {
                return false;
            }
            int count = 0;
            if (app.mSignature != null && app.mSignature.length > 0) {
                count = 0 + 1;
            }
            if (app.mMaxVersionId >= 0 && app.mMinVersionId >= 0 && app.mMaxVersionId >= app.mMinVersionId && (app.mMinVersionId | app.mMaxVersionId) != 0) {
                count++;
            }
            if (!android.text.TextUtils.isEmpty(app.mHashValue)) {
                count++;
            }
            if (count < 1) {
                return false;
            }
        }
        return true;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public static boolean containsApp(java.util.ArrayList<com.android.server.pm.BlackListInfo.BlackListApp> blacklist, com.android.server.pm.BlackListInfo.BlackListApp app) {
        if (blacklist != null) {
            if (app != null) {
                java.util.Iterator it = blacklist.iterator();
                while (it.hasNext()) {
                    com.android.server.pm.BlackListInfo.BlackListApp blacklistApp = (com.android.server.pm.BlackListInfo.BlackListApp) it.next();
                    if (android.text.TextUtils.equals(blacklistApp.mPackageName, app.mPackageName) && java.util.Arrays.equals(blacklistApp.mSignature, app.mSignature) && app.mMinVersionId == blacklistApp.mMinVersionId && app.mMaxVersionId == blacklistApp.mMaxVersionId && android.text.TextUtils.equals(app.mHashValue, blacklistApp.mHashValue)) {
                        return true;
                    }
                }
                return false;
            }
        }
        return false;
    }
}
