package com.android.server.pm;

public class ComponentChangeMonitor {
    static final java.lang.String COMCHANGE_REPORT_FILE_DIR;
    static final java.lang.String COM_CHANGE_REPORT_FILE_LATEST = "com_change_report.1";
    static final java.lang.String COM_CHANGE_REPORT_FILE_PREFIX = "com_change_report.";
    static final boolean DEBUG = false;
    static final int MAX_FILE_COUNT = 5;
    static final int MAX_FILE_SIZE = 102400;
    static final int MSG_WIRTE_FILE = 0;
    static final java.lang.String TAG = "ComponentChangeMonitor";
    private android.content.Context mContext;
    private android.os.Looper mHandlerLooper = null;
    private java.util.List<java.lang.String> mMonitorList = new java.util.ArrayList();
    private com.android.server.pm.ComponentChangeMonitor.WriteFileHandler mWriteHandler = null;

    private class WriteFileHandler extends android.os.Handler {
        public WriteFileHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what != 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("WriteFileHandler unsupport operator ");
                stringBuilder.append(msg.what);
                android.util.Log.w("ComponentChangeMonitor", stringBuilder.toString());
                return;
            }
            com.android.server.pm.ComponentChangeMonitor.this.writeLogToFile((java.lang.String) msg.obj);
        }
    }

    static {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(android.os.Environment.getDataDirectory());
        stringBuilder.append("/log/com_change/");
        COMCHANGE_REPORT_FILE_DIR = stringBuilder.toString();
    }

    public ComponentChangeMonitor(android.content.Context context, android.os.Looper looper) {
        this.mContext = context;
        this.mHandlerLooper = looper;
        init();
    }

    private void init() {
        parseComChangeMonitorsXml();
        if (!this.mMonitorList.isEmpty()) {
            initComChangeDir();
            if (this.mHandlerLooper == null) {
                android.os.HandlerThread handlerThread = new android.os.HandlerThread("ComponentChangeMonitor");
                handlerThread.start();
                this.mHandlerLooper = handlerThread.getLooper();
            }
            this.mWriteHandler = new com.android.server.pm.ComponentChangeMonitor.WriteFileHandler(this.mHandlerLooper);
        }
    }

    private void initComChangeDir() {
        java.io.File gmsDir = new java.io.File(COMCHANGE_REPORT_FILE_DIR);
        if (!gmsDir.exists()) {
            boolean mdir = gmsDir.mkdir();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("comChange directory not exist, make it: ");
            stringBuilder.append(mdir);
            android.util.Log.i("ComponentChangeMonitor", stringBuilder.toString());
        }
    }

    protected void writeComponetChangeLogToFile(android.content.ComponentName componentName, int newState, int userId) {
        if (componentName != null && isMonitorComponent(componentName.getPackageName())) {
            if (this.mWriteHandler != null) {
                java.lang.String enable;
                java.lang.String callPkgName = getAppNameByPid(android.os.Binder.getCallingPid());
                if (newState <= 1) {
                    enable = "enable";
                } else {
                    enable = "disable";
                }
                java.text.SimpleDateFormat sdf = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                long nowRTC = java.lang.System.currentTimeMillis();
                java.lang.String writeLine = new java.lang.StringBuilder();
                writeLine.append("User{");
                writeLine.append(userId);
                writeLine.append("}: ");
                writeLine.append(callPkgName);
                writeLine.append(" ");
                writeLine.append(enable);
                writeLine.append(" ");
                writeLine.append(componentName);
                writeLine.append(" at ");
                writeLine.append(sdf.format(new java.util.Date(nowRTC)));
                writeLine.append(".\n");
                writeLine = writeLine.toString();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("writeComponetChangeLogToFile writeLine: ");
                stringBuilder.append(writeLine);
                android.util.Log.i("ComponentChangeMonitor", stringBuilder.toString());
                this.mWriteHandler.sendMessage(this.mWriteHandler.obtainMessage(0, writeLine));
            }
        }
    }

    private boolean isMonitorComponent(java.lang.String appName) {
        if (this.mMonitorList.isEmpty()) {
            return false;
        }
        return this.mMonitorList.contains(appName);
    }

    private void writeLogToFile(java.lang.String oneLine) {
        java.io.BufferedWriter out = null;
        java.io.OutputStreamWriter osw = null;
        java.io.FileOutputStream fos = null;
        try {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(COMCHANGE_REPORT_FILE_DIR);
            stringBuilder.append("com_change_report.1");
            fos = new java.io.FileOutputStream(stringBuilder.toString(), true);
            osw = new java.io.OutputStreamWriter(fos, "utf-8");
            out = new java.io.BufferedWriter(osw);
            out.write(oneLine);
            try {
                out.close();
            } catch (java.io.IOException e) {
                android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST out IOException");
            }
            try {
                osw.close();
            } catch (java.io.IOException e2) {
                android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST osw IOException");
            }
            try {
                fos.close();
            } catch (java.io.IOException e3) {
            }
        } catch (java.io.FileNotFoundException e4) {
            android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST FileNotFoundException");
            if (out != null) {
                try {
                    out.close();
                } catch (java.io.IOException e5) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST out IOException");
                }
            }
            if (osw != null) {
                try {
                    osw.close();
                } catch (java.io.IOException e6) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST osw IOException");
                }
            }
            if (fos != null) {
                try {
                    fos.close();
                } catch (java.io.IOException e7) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST fos IOException");
                    checkFilesStatus();
                }
            }
        } catch (java.io.IOException e8) {
            android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST IOException");
            if (out != null) {
                try {
                    out.close();
                } catch (java.io.IOException e9) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST out IOException");
                }
            }
            if (osw != null) {
                try {
                    osw.close();
                } catch (java.io.IOException e10) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST osw IOException");
                }
            }
            if (fos != null) {
                try {
                    fos.close();
                } catch (java.io.IOException e11) {
                }
            }
        } catch (java.lang.Exception e12) {
            android.util.Log.e("ComponentChangeMonitor", "writeLogToFile Exception: ", e12);
            if (out != null) {
                try {
                    out.close();
                } catch (java.io.IOException e13) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST out IOException");
                }
            }
            if (osw != null) {
                try {
                    osw.close();
                } catch (java.io.IOException e14) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST osw IOException");
                }
            }
            if (fos != null) {
                try {
                    fos.close();
                } catch (java.io.IOException e15) {
                }
            }
        } catch (Throwable th) {
            if (out != null) {
                try {
                    out.close();
                } catch (java.io.IOException e16) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST out IOException");
                }
            }
            if (osw != null) {
                try {
                    osw.close();
                } catch (java.io.IOException e17) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST osw IOException");
                }
            }
            if (fos != null) {
                try {
                    fos.close();
                } catch (java.io.IOException e18) {
                    android.util.Log.e("ComponentChangeMonitor", "COM_CHANGE_REPORT_FILE_LATEST fos IOException");
                }
            }
        }
        checkFilesStatus();
    }

    private void checkFilesStatus() {
        java.io.File[] subFiles = new java.io.File(COMCHANGE_REPORT_FILE_DIR).listFiles();
        if (subFiles != null) {
            int dirFileCount = subFiles.length;
            java.io.File tempFile;
            java.lang.StringBuilder stringBuilder;
            if (dirFileCount > 5) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("deleteOldAndCreateNewFile abnormal file Count: ");
                stringBuilder2.append(dirFileCount);
                android.util.Log.w("ComponentChangeMonitor", stringBuilder2.toString());
                for (int fileIndex = 0; fileIndex < dirFileCount; fileIndex++) {
                    tempFile = subFiles[fileIndex];
                    if (!(tempFile == null || !tempFile.exists() || tempFile.delete())) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("checkFilesStatus delete failed: ");
                        stringBuilder.append(fileIndex);
                        android.util.Log.w("ComponentChangeMonitor", stringBuilder.toString());
                    }
                }
                return;
            }
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append(COMCHANGE_REPORT_FILE_DIR);
            stringBuilder3.append("com_change_report.1");
            tempFile = new java.io.File(stringBuilder3.toString());
            if (tempFile.exists() && tempFile.length() > 102400) {
                for (int i = dirFileCount; i > 0; i--) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(COMCHANGE_REPORT_FILE_DIR);
                    stringBuilder.append("com_change_report.");
                    stringBuilder.append(i);
                    java.io.File tempFile2 = new java.io.File(stringBuilder.toString());
                    if (tempFile2.exists()) {
                        java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                        stringBuilder4.append(COMCHANGE_REPORT_FILE_DIR);
                        stringBuilder4.append("com_change_report.");
                        stringBuilder4.append(i + 1);
                        if (!tempFile2.renameTo(new java.io.File(stringBuilder4.toString()))) {
                            java.lang.StringBuilder stringBuilder5 = new java.lang.StringBuilder();
                            stringBuilder5.append("checkFilesStatus rename failed: ");
                            stringBuilder5.append(i);
                            android.util.Log.w("ComponentChangeMonitor", stringBuilder5.toString());
                        }
                    }
                }
                if (5 == dirFileCount) {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append(COMCHANGE_REPORT_FILE_DIR);
                    stringBuilder3.append("com_change_report.");
                    stringBuilder3.append(6);
                    java.io.File delFile = new java.io.File(stringBuilder3.toString());
                    if (delFile.exists() && !delFile.delete()) {
                        android.util.Log.w("ComponentChangeMonitor", "checkFilesStatus delete last file failed");
                    }
                }
            }
        }
    }

    private java.lang.String getAppNameByPid(int pid) {
        java.util.List<android.app.ActivityManager.RunningAppProcessInfo> processes = getRunningProcesses();
        if (processes == null) {
            android.util.Log.d("ComponentChangeMonitor", "get app name, get running process failed");
            return null;
        }
        for (android.app.ActivityManager.RunningAppProcessInfo processInfo : processes) {
            if (processInfo.pid == pid) {
                return processInfo.processName;
            }
        }
        return null;
    }

    private java.util.List<android.app.ActivityManager.RunningAppProcessInfo> getRunningProcesses() {
        if (this.mContext == null) {
            android.util.Log.d("ComponentChangeMonitor", "getRunningProcesses, mContext is null");
            return null;
        }
        android.app.ActivityManager activityManager = (android.app.ActivityManager) this.mContext.getSystemService("activity");
        if (activityManager != null) {
            return activityManager.getRunningAppProcesses();
        }
        android.util.Log.d("ComponentChangeMonitor", "get process status, get ams service failed");
        return null;
    }

    private void parseComChangeMonitorsXml() {
        java.io.File monitorFile = null;
        java.io.InputStream inputstream = null;
        try {
            monitorFile = huawei.cust.HwCfgFilePolicy.getCfgFile("xml/com_change_monitors.xml", 0);
        } catch (java.lang.NoClassDefFoundError e) {
            try {
                android.util.Log.e("ComponentChangeMonitor", "HwCfgFilePolicy NoClassDefFoundError");
            } catch (java.io.FileNotFoundException e2) {
                android.util.Log.e("ComponentChangeMonitor", "com_change_monitors.xml FileNotFoundException");
                if (inputstream != null) {
                    try {
                        inputstream.close();
                    } catch (java.io.IOException e3) {
                        android.util.Log.e("ComponentChangeMonitor", "inputstream IOException");
                    }
                }
            } catch (org.xmlpull.v1.XmlPullParserException e4) {
                android.util.Log.e("ComponentChangeMonitor", "com_change_monitors.xml XmlPullParserException");
                if (inputstream != null) {
                    try {
                        inputstream.close();
                    } catch (java.io.IOException e5) {
                    }
                }
            } catch (java.io.IOException e6) {
                android.util.Log.e("ComponentChangeMonitor", "com_change_monitors.xml IOException");
                if (inputstream != null) {
                    try {
                        inputstream.close();
                    } catch (java.io.IOException e7) {
                    }
                }
            } catch (java.lang.Exception e8) {
                android.util.Log.e("ComponentChangeMonitor", "parseComChangeMonitorsXml e: ", e8);
                if (inputstream != null) {
                    try {
                        inputstream.close();
                    } catch (java.io.IOException e9) {
                    }
                }
            } catch (Throwable th) {
                if (inputstream != null) {
                    try {
                        inputstream.close();
                    } catch (java.io.IOException e10) {
                        android.util.Log.e("ComponentChangeMonitor", "inputstream IOException");
                    }
                }
            }
        }
        if (monitorFile == null) {
            android.util.Log.i("ComponentChangeMonitor", "com_change_monitors.xml is not exist");
            if (inputstream != null) {
                try {
                    inputstream.close();
                } catch (java.io.IOException e11) {
                    android.util.Log.e("ComponentChangeMonitor", "inputstream IOException");
                }
            }
            return;
        }
        inputstream = new java.io.FileInputStream(monitorFile);
        parseComChangeData(inputstream);
        try {
            inputstream.close();
        } catch (java.io.IOException e12) {
        }
    }

    private void parseComChangeData(java.io.InputStream inputstream) throws org.xmlpull.v1.XmlPullParserException, java.io.IOException {
        org.xmlpull.v1.XmlPullParser pullParser = android.util.Xml.newPullParser();
        pullParser.setInput(inputstream, null);
        for (int event = pullParser.getEventType(); event != 1; event = pullParser.next()) {
            if (event != 0) {
                switch (event) {
                    case 2:
                        if (!"component".equals(pullParser.getName())) {
                            break;
                        }
                        this.mMonitorList.add(pullParser.nextText());
                        break;
                    case 3:
                        break;
                    default:
                        break;
                }
            }
        }
    }
}
