package com.android.server.pm;

public final class HwFileBackupManager {
    public static final int BACKUP_TASK_CMD_ARG_MAX = 6;
    public static final int BACKUP_TASK_FAILED = -1;
    public static final int BACKUP_TASK_NO_PERMISSION = -2;
    public static final int BACKUP_TASK_SUCCESS = 0;
    public static final int BACKUP_TASK_UNSUPPORTED_CMD = -3;
    private static final java.lang.String[] PACKAGE_NAMES_FILE_BACKUP = new java.lang.String[]{"com.hicloud.android.clone", "com.huawei.intelligent", "com.huawei.KoBackup", "com.huawei.hidisk"};
    private static final java.lang.String TAG = "HwFileBackupManager_BackupSession";
    private static final int VERSION_CODE = 1;
    private static volatile com.android.server.pm.HwFileBackupManager mInstance;
    private final java.util.ArrayList<com.android.server.pm.HwFileBackupManager.BackupDeathHandler> mBackupDeathHandlers = new java.util.ArrayList();
    private final com.android.server.pm.Installer mInstaller;
    private com.android.server.pm.HwFileBackupManager.NativeBackupCallback mNativeBackupCallback = new com.android.server.pm.HwFileBackupManager.NativeBackupCallback();
    private final android.util.SparseArray<android.os.IBackupSessionCallback> mSessions = new android.util.SparseArray();
    private android.os.UserManagerInternal mUserManagerInternal;

    private class BackupDeathHandler implements android.os.IBinder.DeathRecipient {
        public android.os.IBinder mCb;
        public int mSessionId;

        BackupDeathHandler(int sessionId, android.os.IBinder cb) {
            this.mSessionId = sessionId;
            this.mCb = cb;
        }

        public void binderDied() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("backup client with sessionId ");
            stringBuilder.append(this.mSessionId);
            stringBuilder.append(" died");
            android.util.Log.w("HwFileBackupManager_BackupSession", stringBuilder.toString());
            long ident = android.os.Binder.clearCallingIdentity();
            com.android.server.pm.HwFileBackupManager.this.finishBackupSession(this.mSessionId);
            android.os.Binder.restoreCallingIdentity(ident);
        }

        public android.os.IBinder getBinder() {
            return this.mCb;
        }

        public int getSessionId() {
            return this.mSessionId;
        }
    }

    private final class NativeBackupCallback extends android.os.IBackupSessionCallback.Stub {
        private NativeBackupCallback() {
        }

        public void onTaskStatusChanged(int sessionId, int taskId, int statusCode, java.lang.String appendData) {
            com.android.server.pm.HwFileBackupManager.this.handleNativeBackupSessionCallback(sessionId, taskId, statusCode, appendData);
        }
    }

    private static class PathData {
        private static final java.lang.String DATA_DATA_PATH = "/data/data/";
        private static final java.lang.String MULTI_USER_PATH = "/data/user/";
        public boolean isAppDataPath = true;
        public boolean isMultiUserPath;
        public java.lang.String packageName;
        public java.lang.String path;
        public int userId = -10000;

        private PathData() {
        }

        public static com.android.server.pm.HwFileBackupManager.PathData create(java.lang.String path) {
            if (android.text.TextUtils.isEmpty(path)) {
                return null;
            }
            com.android.server.pm.HwFileBackupManager.PathData instance = new com.android.server.pm.HwFileBackupManager.PathData();
            instance.path = path;
            if (path.startsWith("/data/user/")) {
                instance.isMultiUserPath = true;
            } else if (path.startsWith("/data/data/")) {
                instance.isMultiUserPath = false;
            } else {
                instance.isAppDataPath = false;
            }
            instance.parsePath();
            return instance;
        }

        private void parsePath() {
            if (this.isAppDataPath) {
                if (this.isMultiUserPath) {
                    parseMultiUserPath();
                } else {
                    parseDefaultDataPath();
                }
                return;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(this.path);
            stringBuilder.append(" is not a app data path,no need parse!");
            android.util.Slog.d("HwFileBackupManager_BackupSession", stringBuilder.toString());
        }

        private void parseMultiUserPath() {
            int startIndex = "/data/user/".length();
            if (startIndex >= this.path.length()) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(this.path);
                stringBuilder.append(" does not contain userId!");
                android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder.toString());
                return;
            }
            int userIdLocation = this.path.indexOf("/", startIndex);
            if (-1 == userIdLocation) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append(this.path);
                stringBuilder2.append(" does not contain userId or package name!");
                android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder2.toString());
                return;
            }
            java.lang.String userIdStr = this.path.substring(startIndex, userIdLocation);
            if (!android.text.TextUtils.isEmpty(userIdStr)) {
                try {
                    this.userId = java.lang.Integer.parseInt(userIdStr);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append(this.path);
                    stringBuilder3.append(" does not contain correct userId, find:");
                    stringBuilder3.append(userIdStr);
                    android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder3.toString());
                    return;
                }
            }
            this.packageName = getPackageName(this.path, userIdLocation + 1);
        }

        private void parseDefaultDataPath() {
            this.packageName = getPackageName(this.path, "/data/data/".length());
        }

        private java.lang.String getPackageName(java.lang.String path, int startIndex) {
            if (!android.text.TextUtils.isEmpty(path)) {
                if (startIndex < path.length()) {
                    java.lang.String pkgName = "";
                    int endIndex = path.indexOf("/", startIndex);
                    if (endIndex == -1) {
                        pkgName = path.substring(startIndex).trim();
                    } else {
                        pkgName = path.substring(startIndex, endIndex).trim();
                    }
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(pkgName);
                    stringBuilder.append(" found in ");
                    stringBuilder.append(path);
                    android.util.Slog.d("HwFileBackupManager_BackupSession", stringBuilder.toString());
                    return pkgName;
                }
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(path);
            stringBuilder2.append(" does not contain package name!");
            android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder2.toString());
            return null;
        }
    }

    private HwFileBackupManager(com.android.server.pm.Installer installer) {
        this.mInstaller = installer;
    }

    public static com.android.server.pm.HwFileBackupManager getInstance(com.android.server.pm.Installer installer) {
        if (mInstance == null) {
            synchronized (com.android.server.pm.HwFileBackupManager.class) {
                if (mInstance == null) {
                    mInstance = new com.android.server.pm.HwFileBackupManager(installer);
                }
            }
        }
        return mInstance;
    }

    private void handleNativeBackupSessionCallback(int sessionId, int taskId, int statusCode, java.lang.String appendData) {
        synchronized (this.mSessions) {
            android.os.IBackupSessionCallback callback = (android.os.IBackupSessionCallback) this.mSessions.get(sessionId);
            if (callback == null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("no callback set for session:");
                stringBuilder.append(sessionId);
                android.util.Log.e("HwFileBackupManager_BackupSession", stringBuilder.toString());
                return;
            }
            try {
                callback.onTaskStatusChanged(sessionId, taskId, statusCode, appendData);
            } catch (android.os.RemoteException e) {
                android.util.Log.w("HwFileBackupManager_BackupSession", "callback binder death!");
            }
        }
    }

    public int startBackupSession(android.os.IBackupSessionCallback callback) {
        android.util.Slog.i("HwFileBackupManager_BackupSession", "application bind call startBackupSession");
        try {
            if (this.mInstaller == null) {
                android.util.Slog.e("HwFileBackupManager_BackupSession", "installer is null!");
                return -1;
            }
            int sessionId = this.mInstaller.startBackupSession(this.mNativeBackupCallback);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("application startBackupSession sessionid:");
            stringBuilder.append(sessionId);
            android.util.Slog.i("HwFileBackupManager_BackupSession", stringBuilder.toString());
            if (sessionId < 0) {
                return -1;
            }
            synchronized (this.mBackupDeathHandlers) {
                com.android.server.pm.HwFileBackupManager.BackupDeathHandler hdlr = new com.android.server.pm.HwFileBackupManager.BackupDeathHandler(sessionId, callback.asBinder());
                try {
                    callback.asBinder().linkToDeath(hdlr, 0);
                    this.mBackupDeathHandlers.add(hdlr);
                } catch (android.os.RemoteException e) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("startBackupSession() could not link to ");
                    stringBuilder2.append(callback.asBinder());
                    stringBuilder2.append(" binder death");
                    android.util.Log.w("HwFileBackupManager_BackupSession", stringBuilder2.toString());
                    return -1;
                }
            }
            synchronized (this.mSessions) {
                this.mSessions.put(sessionId, callback);
            }
            return sessionId;
        } catch (com.android.server.pm.Installer.InstallerException e2) {
            android.util.Slog.w("HwFileBackupManager_BackupSession", "Trouble startBackupSession", e2);
            return -1;
        }
    }

    /* JADX WARNING: Missing block: B:17:0x004b, code:
            if (android.text.TextUtils.isEmpty(r7) == false) goto L_0x004f;
     */
    /* JADX WARNING: Missing block: B:19:0x004e, code:
            return -3;
     */
    /* JADX WARNING: Missing block: B:21:0x0051, code:
            if (r5.mInstaller != null) goto L_0x005b;
     */
    /* JADX WARNING: Missing block: B:22:0x0053, code:
            android.util.Slog.e("HwFileBackupManager_BackupSession", "installer is null!");
     */
    /* JADX WARNING: Missing block: B:23:0x005a, code:
            return -1;
     */
    /* JADX WARNING: Missing block: B:25:0x0061, code:
            return r5.mInstaller.executeBackupTask(r6, r7);
     */
    /* JADX WARNING: Missing block: B:26:0x0062, code:
            r1 = move-exception;
     */
    /* JADX WARNING: Missing block: B:27:0x0063, code:
            android.util.Slog.w("HwFileBackupManager_BackupSession", "Trouble executeBackupTask", r1);
     */
    /* JADX WARNING: Missing block: B:28:0x006a, code:
            return -1;
     */
    public int executeBackupTask(int r6, java.lang.String r7) {
        /*
        r5 = this;
        r0 = "HwFileBackupManager_BackupSession";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "bind call executeBackupTask on session:";
        r1.append(r2);
        r1.append(r6);
        r1 = r1.toString();
        android.util.Slog.i(r0, r1);
        r0 = -1;
        if (r6 != r0) goto L_0x0023;
    L_0x0019:
        r1 = "getVersionCode";
        r1 = r1.equalsIgnoreCase(r7);
        if (r1 == 0) goto L_0x0023;
    L_0x0021:
        r0 = 1;
        return r0;
    L_0x0023:
        r1 = r5.mSessions;
        monitor-enter(r1);
        r2 = r5.mSessions;	 Catch:{ all -> 0x006b }
        r2 = r2.indexOfKey(r6);	 Catch:{ all -> 0x006b }
        if (r2 >= 0) goto L_0x0046;
    L_0x002e:
        r2 = "HwFileBackupManager_BackupSession";
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x006b }
        r3.<init>();	 Catch:{ all -> 0x006b }
        r4 = "no session with id=";
        r3.append(r4);	 Catch:{ all -> 0x006b }
        r3.append(r6);	 Catch:{ all -> 0x006b }
        r3 = r3.toString();	 Catch:{ all -> 0x006b }
        android.util.Slog.e(r2, r3);	 Catch:{ all -> 0x006b }
        monitor-exit(r1);	 Catch:{ all -> 0x006b }
        return r0;
    L_0x0046:
        monitor-exit(r1);	 Catch:{ all -> 0x006b }
        r1 = android.text.TextUtils.isEmpty(r7);	 Catch:{ InstallerException -> 0x0062 }
        if (r1 == 0) goto L_0x004f;
    L_0x004d:
        r0 = -3;
        return r0;
    L_0x004f:
        r1 = r5.mInstaller;	 Catch:{ InstallerException -> 0x0062 }
        if (r1 != 0) goto L_0x005b;
    L_0x0053:
        r1 = "HwFileBackupManager_BackupSession";
        r2 = "installer is null!";
        android.util.Slog.e(r1, r2);	 Catch:{ InstallerException -> 0x0062 }
        return r0;
    L_0x005b:
        r1 = r5.mInstaller;	 Catch:{ InstallerException -> 0x0062 }
        r1 = r1.executeBackupTask(r6, r7);	 Catch:{ InstallerException -> 0x0062 }
        return r1;
    L_0x0062:
        r1 = move-exception;
        r2 = "HwFileBackupManager_BackupSession";
        r3 = "Trouble executeBackupTask";
        android.util.Slog.w(r2, r3, r1);
        return r0;
    L_0x006b:
        r0 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x006b }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.pm.HwFileBackupManager.executeBackupTask(int, java.lang.String):int");
    }

    public int finishBackupSession(int sessionId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("bind call finishBackupSession sessionId:");
        stringBuilder.append(sessionId);
        android.util.Slog.i("HwFileBackupManager_BackupSession", stringBuilder.toString());
        int result = -1;
        try {
            if (this.mInstaller == null) {
                android.util.Slog.e("HwFileBackupManager_BackupSession", "installer is null!");
                return -1;
            }
            result = this.mInstaller.finishBackupSession(sessionId);
            synchronized (this.mSessions) {
                this.mSessions.remove(sessionId);
            }
            synchronized (this.mBackupDeathHandlers) {
                for (int i = this.mBackupDeathHandlers.size() - 1; i >= 0; i--) {
                    com.android.server.pm.HwFileBackupManager.BackupDeathHandler hdlr = (com.android.server.pm.HwFileBackupManager.BackupDeathHandler) this.mBackupDeathHandlers.get(i);
                    if (hdlr.getSessionId() == sessionId) {
                        this.mBackupDeathHandlers.remove(i);
                        try {
                            hdlr.getBinder().unlinkToDeath(hdlr, 0);
                        } catch (java.lang.Exception e) {
                        }
                    }
                }
            }
            return result;
        } catch (com.android.server.pm.Installer.InstallerException e2) {
            android.util.Slog.w("HwFileBackupManager_BackupSession", "Trouble finishBackupSession", e2);
        }
    }

    public boolean checkBackupPackageName(java.lang.String pkgName) {
        boolean result = false;
        for (java.lang.CharSequence equals : PACKAGE_NAMES_FILE_BACKUP) {
            if (android.text.TextUtils.equals(pkgName, equals)) {
                result = true;
                break;
            }
        }
        if (!result) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("BackupSession checkBackupPackageName failed, pkgName is ");
            stringBuilder.append(pkgName);
            android.util.Slog.d("HwFileBackupManager_BackupSession", stringBuilder.toString());
        }
        return result;
    }

    private java.lang.String normalizeTaskCmd(java.lang.String taskCmd, java.util.List<java.lang.String> cmdInfo) {
        java.lang.String[] args = taskCmd.split(" ");
        java.lang.StringBuilder sbTaskCmd = new java.lang.StringBuilder();
        for (java.lang.String arg : args) {
            java.lang.String arg2 = arg2.replace(" ", "");
            if (!android.text.TextUtils.isEmpty(arg2)) {
                if (cmdInfo != null) {
                    cmdInfo.add(arg2);
                }
                sbTaskCmd.append(arg2);
                sbTaskCmd.append(" ");
            }
        }
        java.lang.String normalizedTaskCmd = sbTaskCmd.toString().trim();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("BackupSession prepareBackupTaskCmd,after normalize is:");
        stringBuilder.append(normalizedTaskCmd);
        android.util.Slog.d("HwFileBackupManager_BackupSession", stringBuilder.toString());
        return normalizedTaskCmd;
    }

    public java.lang.String prepareBackupTaskCmd(java.lang.String taskCmd, android.util.ArrayMap<java.lang.String, android.content.pm.PackageParser.Package> packages) {
        if (android.text.TextUtils.isEmpty(taskCmd)) {
            return null;
        }
        java.util.List<java.lang.String> cmdInfo = new java.util.ArrayList(6);
        java.lang.String normalizedTaskCmd = normalizeTaskCmd(taskCmd, cmdInfo);
        if (cmdInfo.size() > 6) {
            return null;
        }
        if (cmdInfo.size() < 4) {
            return normalizedTaskCmd;
        }
        java.lang.String srcPath = (java.lang.String) cmdInfo.get(2);
        if (isUsableSrcPath(com.android.server.pm.HwFileBackupManager.PathData.create(srcPath))) {
            java.lang.String destPath = (java.lang.String) cmdInfo.get(3);
            com.android.server.pm.HwFileBackupManager.PathData destPathData = com.android.server.pm.HwFileBackupManager.PathData.create(destPath);
            java.lang.StringBuilder sb;
            if (isUsableDestPath(destPathData)) {
                synchronized (packages) {
                    android.content.pm.PackageParser.Package pkg = (android.content.pm.PackageParser.Package) packages.get(destPathData.packageName);
                    if (pkg == null || pkg.applicationInfo == null) {
                        android.util.Slog.d("HwFileBackupManager_BackupSession", "BackupSession prepareBackupTaskCmd, target path must begin with a existing app's data directory since we need get seinfo for task cmd!");
                        return null;
                    }
                    android.content.pm.ApplicationInfo app = pkg.applicationInfo;
                    sb = new java.lang.StringBuilder(normalizedTaskCmd);
                    sb.append(" ");
                    sb.append(app.seInfo);
                    sb.append(" ");
                    if (destPathData.isMultiUserPath) {
                        sb.append(android.os.UserHandle.getUid(destPathData.userId, app.uid));
                    } else {
                        sb.append(app.uid);
                    }
                    java.lang.String stringBuilder = sb.toString();
                    return stringBuilder;
                }
            }
            sb = new java.lang.StringBuilder();
            sb.append(destPath);
            sb.append(" is not a supported dest path!");
            android.util.Slog.e("HwFileBackupManager_BackupSession", sb.toString());
            return null;
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append(srcPath);
        stringBuilder2.append(" is not a supported src data path!");
        android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder2.toString());
        return null;
    }

    private android.os.UserManagerInternal getUserManagerInternal() {
        if (this.mUserManagerInternal == null) {
            this.mUserManagerInternal = (android.os.UserManagerInternal) com.android.server.LocalServices.getService(android.os.UserManagerInternal.class);
        }
        return this.mUserManagerInternal;
    }

    private boolean isUsableSrcPath(com.android.server.pm.HwFileBackupManager.PathData pathData) {
        if (pathData == null) {
            return false;
        }
        if (pathData.isAppDataPath) {
            return isUsableAppDataPath(pathData);
        }
        return true;
    }

    private boolean isUsableDestPath(com.android.server.pm.HwFileBackupManager.PathData pathData) {
        if (pathData != null) {
            if (!android.text.TextUtils.isEmpty(pathData.packageName)) {
                return isUsableAppDataPath(pathData);
            }
        }
        android.util.Slog.e("HwFileBackupManager_BackupSession", "dest path does not contain package name, check package name is null!");
        return false;
    }

    private boolean isUsableAppDataPath(com.android.server.pm.HwFileBackupManager.PathData pathData) {
        if (pathData == null || !pathData.isAppDataPath) {
            return false;
        }
        if (!pathData.isMultiUserPath || pathData.userId == 0) {
            return true;
        }
        if (com.android.server.pm.HwPackageManagerService.isSupportCloneAppInCust(pathData.packageName)) {
            if (getUserManagerInternal().isClonedProfile(pathData.userId)) {
                return true;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(pathData.path);
        stringBuilder.append(" is not a support clone app data path!");
        android.util.Slog.e("HwFileBackupManager_BackupSession", stringBuilder.toString());
        return false;
    }
}
