package com.android.server.pm;

public final class HwPersistentAppManager {
    private static final boolean PERSISTENT_CONFIG_DISABLED = android.os.SystemProperties.get("ro.hw_persistent.disable", "0").equals("1");
    private static final java.lang.String PERSISTENT_CONFIG_FILE_PATH = "xml/hw_persistent_config.xml";
    private static final java.lang.String TAG = "HwPersistentAppManager";
    private static java.util.HashMap<java.lang.String, com.android.server.pm.HwPersistentAppManager.PersistentInfo> sPersistentConfigMap = null;

    private static final class PersistentInfo {
        public java.lang.String original;
        public java.lang.String packageName;
        public java.lang.String persistent;
        public java.lang.String updatable;

        private PersistentInfo() {
            this.packageName = "";
            this.original = "";
            this.persistent = "";
            this.updatable = "";
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("packageName:");
            stringBuilder.append(this.packageName);
            stringBuilder.append(" original:");
            stringBuilder.append(this.original);
            stringBuilder.append(" persistent:");
            stringBuilder.append(this.persistent);
            stringBuilder.append(" updatable:");
            stringBuilder.append(this.updatable);
            return stringBuilder.toString();
        }
    }

    private static java.util.ArrayList<java.io.File> getPersistentConfigFileList(java.lang.String filePath) {
        java.util.ArrayList<java.io.File> fileList = new java.util.ArrayList();
        if (android.text.TextUtils.isEmpty(filePath)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Error: file = [");
            stringBuilder.append(filePath);
            stringBuilder.append("]");
            android.util.Log.e("HwPersistentAppManager", stringBuilder.toString());
            return fileList;
        }
        java.lang.String[] policyDir = null;
        int i = 0;
        try {
            policyDir = huawei.cust.HwCfgFilePolicy.getCfgPolicyDir(0);
        } catch (java.lang.NoClassDefFoundError e) {
            android.util.Slog.w("HwPersistentAppManager", "HwCfgFilePolicy NoClassDefFoundError");
        }
        if (policyDir == null) {
            return fileList;
        }
        while (i < policyDir.length) {
            java.io.File file = new java.io.File(policyDir[i], filePath);
            if (file.exists()) {
                fileList.add(file);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("getPersistentConfigFileList from  i=");
                stringBuilder2.append(i);
                stringBuilder2.append("| ");
                stringBuilder2.append(file.getAbsolutePath());
                android.util.Slog.d("HwPersistentAppManager", stringBuilder2.toString());
            }
            i++;
        }
        if (fileList.size() == 0) {
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("No persistent config file found for:");
            stringBuilder3.append(filePath);
            android.util.Log.w("HwPersistentAppManager", stringBuilder3.toString());
        }
        return fileList;
    }

    private static java.util.HashMap<java.lang.String, com.android.server.pm.HwPersistentAppManager.PersistentInfo> loadPersistentConfigInfo() {
        java.util.ArrayList<java.io.File> fileList = null;
        try {
            fileList = getPersistentConfigFileList("xml/hw_persistent_config.xml");
        } catch (java.lang.NoClassDefFoundError er) {
            android.util.Slog.e("HwPersistentAppManager", er.getMessage());
        }
        if (fileList != null) {
            if (fileList.size() != 0) {
                java.util.HashMap<java.lang.String, com.android.server.pm.HwPersistentAppManager.PersistentInfo> persistentConfigMap = new java.util.HashMap();
                int N = fileList.size();
                for (int i = 0; i < N; i++) {
                    java.io.File file = (java.io.File) fileList.get(i);
                    if (file != null) {
                        if (file.exists()) {
                            persistentConfigMap.putAll(readPersistentConfigFile(file));
                        }
                    }
                }
                return persistentConfigMap;
            }
        }
        return null;
    }

    private static java.util.HashMap<java.lang.String, com.android.server.pm.HwPersistentAppManager.PersistentInfo> readPersistentConfigFile(java.io.File file) {
        java.lang.StringBuilder stringBuilder;
        java.util.HashMap<java.lang.String, com.android.server.pm.HwPersistentAppManager.PersistentInfo> result = new java.util.HashMap();
        if (file != null) {
            if (file.exists()) {
                java.io.FileInputStream stream = null;
                try {
                    int type;
                    java.lang.String tag;
                    stream = new java.io.FileInputStream(file);
                    org.xmlpull.v1.XmlPullParser parser = android.util.Xml.newPullParser();
                    parser.setInput(stream, null);
                    while (true) {
                        int next = parser.next();
                        type = next;
                        if (next == 1 || type == 2) {
                            tag = parser.getName();
                        }
                    }
                    tag = parser.getName();
                    if ("persistent-config".equals(tag)) {
                        parser.next();
                        int outerDepth = parser.getDepth();
                        while (true) {
                            int next2 = parser.next();
                            type = next2;
                            if (next2 != 1 && (type != 3 || parser.getDepth() > outerDepth)) {
                                if (type != 3) {
                                    if (type != 4) {
                                        if ("item".equals(parser.getName())) {
                                            com.android.server.pm.HwPersistentAppManager.PersistentInfo info = new com.android.server.pm.HwPersistentAppManager.PersistentInfo();
                                            info.packageName = parser.getAttributeValue(null, "package");
                                            info.original = parser.getAttributeValue(null, "original");
                                            info.persistent = parser.getAttributeValue(null, "persistent");
                                            info.updatable = parser.getAttributeValue(null, "updatable");
                                            result.put(info.packageName, info);
                                            android.util.Slog.d("HwPersistentAppManager", info.toString());
                                        }
                                    }
                                }
                            }
                        }
                        try {
                            stream.close();
                        } catch (java.io.IOException e) {
                        }
                        return result;
                    }
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("Settings do not start with policies tag: found ");
                    stringBuilder2.append(tag);
                    throw new org.xmlpull.v1.XmlPullParserException(stringBuilder2.toString());
                } catch (java.io.FileNotFoundException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("file is not exist ");
                    stringBuilder.append(e2.getMessage());
                    android.util.Slog.w("HwPersistentAppManager", stringBuilder.toString());
                    if (stream != null) {
                        stream.close();
                    }
                } catch (org.xmlpull.v1.XmlPullParserException e3) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("failed parsing ");
                    stringBuilder.append(file);
                    stringBuilder.append(" ");
                    stringBuilder.append(e3.getMessage());
                    android.util.Slog.w("HwPersistentAppManager", stringBuilder.toString());
                    if (stream != null) {
                        stream.close();
                    }
                } catch (java.lang.Exception e4) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("failed parsing ");
                    stringBuilder.append(file);
                    stringBuilder.append(" ");
                    stringBuilder.append(e4.getMessage());
                    android.util.Slog.w("HwPersistentAppManager", stringBuilder.toString());
                    if (stream != null) {
                        stream.close();
                    }
                } catch (Throwable th) {
                    if (stream != null) {
                        try {
                            stream.close();
                        } catch (java.io.IOException e5) {
                        }
                    }
                }
            }
        }
        return result;
    }

    private static boolean fixPkgPersistentFlag(android.content.pm.PackageParser.Package pkg) {
        if (sPersistentConfigMap != null) {
            com.android.server.pm.HwPersistentAppManager.PersistentInfo persistentInfo = (com.android.server.pm.HwPersistentAppManager.PersistentInfo) sPersistentConfigMap.get(pkg.packageName);
            com.android.server.pm.HwPersistentAppManager.PersistentInfo info = persistentInfo;
            if (persistentInfo != null) {
                if ("true".equals(info.original) || "true".equals(info.persistent)) {
                    return false;
                }
            }
        }
        android.content.pm.ApplicationInfo applicationInfo = pkg.applicationInfo;
        applicationInfo.flags &= -9;
        return true;
    }

    public static void readPersistentConfig() {
        if (!PERSISTENT_CONFIG_DISABLED) {
            sPersistentConfigMap = loadPersistentConfigInfo();
        }
    }

    public static void resolvePersistentFlagForPackage(int oldFlags, android.content.pm.PackageParser.Package pkg) {
        if (!(PERSISTENT_CONFIG_DISABLED || pkg == null)) {
            if (pkg.applicationInfo != null) {
                boolean oldNonPersistent = false;
                boolean newPersistent = (pkg.applicationInfo.flags & 8) != 0;
                if (newPersistent) {
                    if ((oldFlags & 8) == 0) {
                        oldNonPersistent = true;
                    }
                    if (oldNonPersistent && newPersistent && fixPkgPersistentFlag(pkg)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(pkg.packageName);
                        stringBuilder.append(" does not allow to become a persistent app since old app is not a persistent app!");
                        android.util.Slog.i("HwPersistentAppManager", stringBuilder.toString());
                    }
                }
            }
        }
    }

    public static boolean isPersistentUpdatable(android.content.pm.PackageParser.Package pkg) {
        if (!(PERSISTENT_CONFIG_DISABLED || pkg == null || sPersistentConfigMap == null)) {
            com.android.server.pm.HwPersistentAppManager.PersistentInfo persistentInfo = (com.android.server.pm.HwPersistentAppManager.PersistentInfo) sPersistentConfigMap.get(pkg.packageName);
            com.android.server.pm.HwPersistentAppManager.PersistentInfo info = persistentInfo;
            if (persistentInfo != null) {
                if (!"true".equals(info.updatable)) {
                    return false;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(pkg.packageName);
                stringBuilder.append(" is marked as a updatable persistent app!");
                android.util.Slog.i("HwPersistentAppManager", stringBuilder.toString());
                return true;
            }
        }
        return false;
    }
}
