package com.android.server.pm;

class HwShellAppsHandler {
    private static final java.lang.String CONFIG_FILE = "/system/etc/dexopt/shell_identify_and_oat_clean.xml";
    private static final boolean DEBUG = false;
    private static final java.lang.String INFO_TYPE_ShellByPackageName = "shellByPackageName";
    private static final java.lang.String INFO_TYPE_ShellClearOat = "shellClearOat";
    private static final java.lang.String INFO_TYPE_ShellIdentify = "shellIdentify";
    private static final java.lang.String TAG = "HwShellAppsHandler";
    private java.io.File mAppDataDir;
    private final com.android.server.pm.Installer mInstaller;
    private java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> mShellByPackageName;
    private java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> mShellClearOats;
    private java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> mShellIdentifies;
    private java.io.File mUserAppDataDir;

    private static class ShellItem {
        private java.util.ArrayList<java.lang.String> mFiles;
        private java.lang.String mName;

        public ShellItem(java.lang.String name, java.util.ArrayList<java.lang.String> files) {
            this.mName = name;
            this.mFiles = files;
        }

        public java.lang.String getName() {
            return this.mName;
        }

        public java.util.ArrayList<java.lang.String> getFiles() {
            return this.mFiles;
        }
    }

    public HwShellAppsHandler(com.android.server.pm.Installer installer, com.android.server.pm.UserManagerService userManager) {
        this.mShellIdentifies = null;
        this.mShellClearOats = null;
        this.mShellByPackageName = null;
        this.mShellClearOats = new java.util.ArrayList();
        this.mShellIdentifies = new java.util.ArrayList();
        this.mShellByPackageName = new java.util.ArrayList();
        parseShellConfig();
        java.io.File dataDir = android.os.Environment.getDataDirectory();
        this.mAppDataDir = new java.io.File(dataDir, "data");
        this.mUserAppDataDir = new java.io.File(dataDir, "user");
        this.mInstaller = installer;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public java.lang.String AnalyseShell(android.content.pm.PackageParser.Package pkg) {
        java.lang.StringBuilder stringBuilder;
        java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> tmpShellIdentifies = DeepcopyShellItem(this.mShellIdentifies);
        try {
            java.util.zip.ZipFile file = new java.util.zip.ZipFile(pkg.baseCodePath);
            try {
                java.util.Enumeration<? extends java.util.zip.ZipEntry> entries = file.entries();
                while (entries.hasMoreElements()) {
                    java.util.zip.ZipEntry entry = (java.util.zip.ZipEntry) entries.nextElement();
                    if (!entry.isDirectory()) {
                        filterOutIdentifyFiles(entry.getName(), tmpShellIdentifies);
                    }
                }
            } catch (java.lang.Exception e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("fail to process apk file: ");
                stringBuilder.append(pkg.baseCodePath);
                android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
            }
            file.close();
        } catch (java.io.IOException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("fail to process apk file: ");
            stringBuilder.append(pkg.baseCodePath);
            android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
        }
        java.util.Iterator it = tmpShellIdentifies.iterator();
        while (it.hasNext()) {
            com.android.server.pm.HwShellAppsHandler.ShellItem shellIdentify = (com.android.server.pm.HwShellAppsHandler.ShellItem) it.next();
            if (shellIdentify.getFiles().size() == 0) {
                return shellIdentify.getName();
            }
        }
        return AnalyseShellByPackageName(pkg);
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private java.lang.String AnalyseShellByPackageName(android.content.pm.PackageParser.Package pkg) {
        if (!(this.mShellByPackageName == null || pkg == null)) {
            if (pkg.packageName != null) {
                java.util.Iterator it = this.mShellByPackageName.iterator();
                while (it.hasNext()) {
                    com.android.server.pm.HwShellAppsHandler.ShellItem shellIdentify = (com.android.server.pm.HwShellAppsHandler.ShellItem) it.next();
                    java.util.Iterator<java.lang.String> i = shellIdentify.getFiles().iterator();
                    while (i.hasNext()) {
                        java.lang.String identifyPackageName = (java.lang.String) i.next();
                        if (identifyPackageName != null && identifyPackageName.equals(pkg.packageName)) {
                            return shellIdentify.getName();
                        }
                    }
                }
                return null;
            }
        }
        return null;
    }

    public void ProcessShellApp(android.content.pm.PackageParser.Package pkg) {
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private void filterOutIdentifyFiles(java.lang.String fileName, java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> tmpShellIdentifies) {
        java.util.Iterator it = tmpShellIdentifies.iterator();
        while (it.hasNext()) {
            java.util.Iterator<java.lang.String> i = ((com.android.server.pm.HwShellAppsHandler.ShellItem) it.next()).getFiles().iterator();
            while (i.hasNext()) {
                java.lang.String identifyFileName = (java.lang.String) i.next();
                if (!fileName.equals(identifyFileName)) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("/");
                    stringBuilder.append(identifyFileName);
                    if (!fileName.endsWith(stringBuilder.toString())) {
                    }
                }
                i.remove();
            }
        }
    }

    private java.io.File getDataPathForPackage(java.lang.String packageName, int userId) {
        if (userId == 0) {
            return new java.io.File(this.mAppDataDir, packageName);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(this.mUserAppDataDir.getAbsolutePath());
        stringBuilder.append(java.io.File.separator);
        stringBuilder.append(userId);
        stringBuilder.append(java.io.File.separator);
        stringBuilder.append(packageName);
        return new java.io.File(stringBuilder.toString());
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public java.lang.String DumpIdentifies() {
        com.android.server.pm.HwShellAppsHandler.ShellItem shellItem;
        java.util.Iterator it;
        java.lang.String fileName;
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        sb.append("\nINFO_TYPE_ShellIdentify");
        java.util.Iterator it2 = this.mShellIdentifies.iterator();
        while (it2.hasNext()) {
            shellItem = (com.android.server.pm.HwShellAppsHandler.ShellItem) it2.next();
            sb.append("    ");
            sb.append(shellItem.getName());
            sb.append("\n");
            it = shellItem.getFiles().iterator();
            while (it.hasNext()) {
                fileName = (java.lang.String) it.next();
                sb.append("        ");
                sb.append(fileName);
                sb.append("\n");
            }
        }
        sb.append("\nINFO_TYPE_ClearOat");
        it2 = this.mShellClearOats.iterator();
        while (it2.hasNext()) {
            shellItem = (com.android.server.pm.HwShellAppsHandler.ShellItem) it2.next();
            sb.append("    ");
            sb.append(shellItem.getName());
            sb.append("\n");
            it = shellItem.getFiles().iterator();
            while (it.hasNext()) {
                fileName = (java.lang.String) it.next();
                sb.append("        ");
                sb.append(fileName);
                sb.append("\n");
            }
        }
        return sb.toString();
    }

    private void parseShellConfig() {
        java.lang.StringBuilder stringBuilder;
        java.io.File file = new java.io.File("/system/etc", "dexopt/shell_identify_and_oat_clean.xml");
        java.io.FileInputStream stream = null;
        try {
            java.io.File cfg = huawei.cust.HwCfgFilePolicy.getCfgFile("dexopt/shell_identify_and_oat_clean.xml", 0);
            if (cfg != null) {
                file = cfg;
            }
            stream = new java.io.FileInputStream(file);
            org.xmlpull.v1.XmlPullParser parser = android.util.Xml.newPullParser();
            parser.setInput(stream, null);
            ParseXml(parser);
            try {
                stream.close();
            } catch (java.io.IOException e) {
                android.util.Log.d("HwShellAppsHandler", "parseShellConfig stream close FAIL!");
            }
        } catch (java.lang.NoClassDefFoundError e2) {
            android.util.Log.d("HwShellAppsHandler", "HwCfgFilePolicy NoClassDefFoundError");
            if (stream != null) {
                stream.close();
            }
        } catch (java.io.FileNotFoundException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("file is not exist ");
            stringBuilder.append(e3);
            android.util.Log.w("HwShellAppsHandler", stringBuilder.toString());
            if (stream != null) {
                stream.close();
            }
        } catch (org.xmlpull.v1.XmlPullParserException e4) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("failed parsing ");
            stringBuilder.append(file);
            stringBuilder.append(" ");
            stringBuilder.append(e4);
            android.util.Log.w("HwShellAppsHandler", stringBuilder.toString());
            if (stream != null) {
                stream.close();
            }
        } catch (java.io.IOException e5) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("failed parsing ");
            stringBuilder.append(file);
            stringBuilder.append(" ");
            stringBuilder.append(e5);
            android.util.Log.w("HwShellAppsHandler", stringBuilder.toString());
            if (stream != null) {
                stream.close();
            }
        } catch (Throwable th) {
            if (stream != null) {
                try {
                    stream.close();
                } catch (java.io.IOException e6) {
                    android.util.Log.d("HwShellAppsHandler", "parseShellConfig stream close FAIL!");
                }
            }
        }
        java.util.Iterator<com.android.server.pm.HwShellAppsHandler.ShellItem> i = this.mShellIdentifies.iterator();
        while (i.hasNext()) {
            if (((com.android.server.pm.HwShellAppsHandler.ShellItem) i.next()).getFiles().size() == 0) {
                i.remove();
            }
        }
    }

    private void ParseXml(org.xmlpull.v1.XmlPullParser parser) throws org.xmlpull.v1.XmlPullParserException, java.io.IOException {
        java.lang.String tag = "";
        java.lang.String fileName = "";
        com.android.server.pm.HwShellAppsHandler.ShellItem currentShell = null;
        java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> currentArray = null;
        while (true) {
            int next = parser.next();
            int type = next;
            if (next != 1) {
                if (2 == type) {
                    tag = parser.getName();
                    java.lang.StringBuilder stringBuilder;
                    switch (parser.getDepth()) {
                        case 0:
                            break;
                        case 1:
                            if ("shell".equals(tag)) {
                                break;
                            }
                            android.util.Log.w("HwShellAppsHandler", "invalid file: /system/etc/dexopt/shell_identify_and_oat_clean.xml");
                            return;
                        case 2:
                            if (!"shellIdentify".equals(tag)) {
                                if (!"shellClearOat".equals(tag)) {
                                    if (!"shellByPackageName".equals(tag)) {
                                        currentArray = null;
                                        stringBuilder = new java.lang.StringBuilder();
                                        stringBuilder.append("Parsing Shell Identify Xml, Find an unknown infoType: ");
                                        stringBuilder.append(tag);
                                        android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
                                        break;
                                    }
                                    currentArray = this.mShellByPackageName;
                                    break;
                                }
                                currentArray = this.mShellClearOats;
                                break;
                            }
                            currentArray = this.mShellIdentifies;
                            break;
                        case 3:
                            if (currentArray == null) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("Parsing Shell Identify Xml, Find an unknown Tag ");
                                stringBuilder.append(tag);
                                stringBuilder.append(" before a InfoType Tag.");
                                android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
                                currentShell = null;
                                break;
                            }
                            currentShell = AddShellItem(tag, currentArray);
                            break;
                        case 4:
                            if (currentShell != null) {
                                if (!"File".equals(tag) && !"Packagename".equals(tag)) {
                                    stringBuilder = new java.lang.StringBuilder();
                                    stringBuilder.append("Find an unknown Tag: ");
                                    stringBuilder.append(tag);
                                    android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
                                    break;
                                }
                                currentShell.getFiles().add(parser.nextText());
                                break;
                            }
                            android.util.Log.e("HwShellAppsHandler", "Parsing Shell Identify Xml, Find File Tag before a Shell Tag.");
                            break;
                        default:
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Parse Shell Identify Xml Reach a invalid Depth: ");
                            stringBuilder.append(java.lang.String.valueOf(0));
                            android.util.Log.e("HwShellAppsHandler", stringBuilder.toString());
                            break;
                    }
                }
            } else {
                return;
            }
        }
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private com.android.server.pm.HwShellAppsHandler.ShellItem AddShellItem(java.lang.String shellName, java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> shellItems) {
        java.util.Iterator it = shellItems.iterator();
        while (it.hasNext()) {
            com.android.server.pm.HwShellAppsHandler.ShellItem shellItem = (com.android.server.pm.HwShellAppsHandler.ShellItem) it.next();
            if (shellItem.getName().equals(shellName)) {
                return shellItem;
            }
        }
        com.android.server.pm.HwShellAppsHandler.ShellItem newShell = new com.android.server.pm.HwShellAppsHandler.ShellItem(shellName, new java.util.ArrayList());
        shellItems.add(newShell);
        return newShell;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> DeepcopyShellItem(java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> oriShellItems) {
        if (oriShellItems == null) {
            return null;
        }
        java.util.ArrayList<com.android.server.pm.HwShellAppsHandler.ShellItem> shellItems = new java.util.ArrayList();
        java.util.Iterator it = oriShellItems.iterator();
        while (it.hasNext()) {
            com.android.server.pm.HwShellAppsHandler.ShellItem oriShellItem = (com.android.server.pm.HwShellAppsHandler.ShellItem) it.next();
            com.android.server.pm.HwShellAppsHandler.ShellItem shellItem = new com.android.server.pm.HwShellAppsHandler.ShellItem(oriShellItem.getName(), new java.util.ArrayList());
            java.util.Iterator it2 = oriShellItem.getFiles().iterator();
            while (it2.hasNext()) {
                shellItem.getFiles().add((java.lang.String) it2.next());
            }
            shellItems.add(shellItem);
        }
        return shellItems;
    }
}
