package com.android.server.pm;

public class HwUserManagerService extends com.android.server.pm.UserManagerService {
    private static final int CREATE_USER_STATUS = 0;
    private static final int DELETE_USER_STATUS = 1;
    private static final java.lang.String TAG = "HwUserManagerService";
    private static boolean isSupportJni;
    private static com.android.server.pm.HwUserManagerService mInstance = null;
    private android.content.Context mContext;

    private native void nativeSendUserChangedNotification(int i, int i2);

    static {
        isSupportJni = false;
        try {
            java.lang.System.loadLibrary("hwtee_jni");
            isSupportJni = true;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.e("HwUserManagerService", "can not find lib hwtee_jni");
            isSupportJni = false;
        }
    }

    public HwUserManagerService(android.content.Context context, com.android.server.pm.PackageManagerService pm, com.android.server.pm.UserDataPreparer userDataPreparer, java.lang.Object packagesLock) {
        super(context, pm, userDataPreparer, packagesLock);
        this.mContext = context;
        mInstance = this;
    }

    public static synchronized com.android.server.pm.HwUserManagerService getInstance() {
        com.android.server.pm.HwUserManagerService hwUserManagerService;
        synchronized (com.android.server.pm.HwUserManagerService.class) {
            hwUserManagerService = mInstance;
        }
        return hwUserManagerService;
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        if (code != 1001) {
            return super.onTransact(code, data, reply, flags);
        }
        android.util.Flog.i(900, "onTransact MKDIR_FOR_USER_TRANSACTION.");
        createUserDir(data.readInt());
        return true;
    }

    public android.content.pm.UserInfo createProfileForUser(java.lang.String name, int flags, int userId, java.lang.String[] disallowedPackages) {
        if (isStorageLow()) {
            return null;
        }
        boolean isClonedProfile = (67108864 & flags) != 0;
        android.content.pm.UserInfo parent = null;
        if (com.android.server.am.HwActivityManagerService.IS_SUPPORT_CLONE_APP && isClonedProfile) {
            if ("1".equals(android.os.SystemProperties.get("persist.sys.primarysd", "0"))) {
                android.util.Slog.i("HwUserManagerService", "current default location is external sdcard and forbid to create user");
                return null;
            } else if (userId != 0) {
                return null;
            } else {
                for (android.content.pm.UserInfo user : super.getProfiles(userId, true)) {
                    if (user.isClonedProfile()) {
                        return null;
                    }
                    if (user.id == userId) {
                        parent = user;
                        if (!parent.canHaveProfile()) {
                            return null;
                        }
                    }
                }
            }
        }
        android.content.pm.UserInfo ui = super.createProfileForUser(name, flags, userId, disallowedPackages);
        if (!(!isClonedProfile || parent == null || ui == null)) {
            pretreatClonedProfile(this.mPm, parent.id, ui.id);
        }
        if (ui != null) {
            hwCreateUser(ui.id);
        }
        return ui;
    }

    public android.content.pm.UserInfo createUser(java.lang.String name, int flags) {
        if (isStorageLow()) {
            return null;
        }
        if ((33554432 & flags) != 0) {
            for (android.content.pm.UserInfo info : getUsers(true)) {
                if (info.isHwHiddenSpace()) {
                    android.util.Slog.e("HwUserManagerService", "Hidden space already exist!");
                    return null;
                }
            }
        }
        android.content.pm.UserInfo ui = super.createUser(name, flags);
        if (ui == null) {
            return null;
        }
        hwCreateUser(ui.id);
        setDeviceProvisioned(ui.id);
        return ui;
    }

    void setDeviceProvisioned(int userId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HwUserManagerService setDeviceProvisioned, userId ");
        stringBuilder.append(userId);
        android.util.Flog.i(900, stringBuilder.toString());
        android.content.ContentResolver cr = this.mContext.getContentResolver();
        long identity = android.os.Binder.clearCallingIdentity();
        try {
            if ((android.provider.Settings.Global.getInt(cr, "device_provisioned", 0) == 0 || android.provider.Settings.Secure.getIntForUser(cr, "user_setup_complete", 0, userId) == 0) && ((com.android.server.pm.PackageManagerService) android.os.ServiceManager.getService("package")).isSetupDisabled()) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("Setup is disabled putInt USER_SETUP_COMPLETE for userId ");
                stringBuilder2.append(userId);
                android.util.Flog.i(900, stringBuilder2.toString());
                android.provider.Settings.Global.putInt(cr, "device_provisioned", 1);
                android.provider.Settings.Secure.putIntForUser(cr, "user_setup_complete", 1, userId);
            }
            android.os.Binder.restoreCallingIdentity(identity);
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(identity);
        }
    }

    void finishRemoveUser(int userHandle) {
        super.finishRemoveUser(userHandle);
        hwRemoveUser(userHandle);
    }

    private void hwCreateUser(int userid) {
        if (userid > 0) {
            if (isSupportJni) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("native create user ");
                stringBuilder.append(userid);
                android.util.Slog.i("HwUserManagerService", stringBuilder.toString());
                nativeSendUserChangedNotification(0, userid);
            }
        }
    }

    private void hwRemoveUser(int userid) {
        if (userid > 0) {
            if (isSupportJni) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("native remove user ");
                stringBuilder.append(userid);
                android.util.Slog.i("HwUserManagerService", stringBuilder.toString());
                nativeSendUserChangedNotification(1, userid);
            }
        }
    }

    private void createUserDir(int userId) {
        java.io.File userDir = android.os.Environment.getUserSystemDirectory(userId);
        if (!userDir.exists() && !userDir.mkdir()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Failed to create user directory for ");
            stringBuilder.append(userId);
            android.util.Slog.w("HwUserManagerService", stringBuilder.toString());
        }
    }

    private boolean isStorageLow() {
        boolean isStorageLow = ((com.android.server.pm.PackageManagerService) android.os.ServiceManager.getService("package")).isStorageLow();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("PackageManagerService.isStorageLow() = ");
        stringBuilder.append(isStorageLow);
        android.util.Slog.i("HwUserManagerService", stringBuilder.toString());
        return isStorageLow;
    }

    private void pretreatClonedProfile(com.android.server.pm.PackageManagerService pm, int parentUserId, int clonedProfileUserId) {
        if (com.android.server.am.HwActivityManagerService.IS_SUPPORT_CLONE_APP) {
            long callingId = android.os.Binder.clearCallingIdentity();
            try {
                restoreDataForClone(pm, parentUserId, clonedProfileUserId);
                pm.deleteNonRequiredAppsForClone(clonedProfileUserId);
                pm.flushPackageRestrictionsAsUser(clonedProfileUserId);
                super.setUserRestriction("no_outgoing_calls", false, clonedProfileUserId);
                super.setUserRestriction("no_sms", false, clonedProfileUserId);
                android.provider.Settings.Secure.putIntForUser(this.mContext.getContentResolver(), "user_setup_complete", 1, clonedProfileUserId);
            } finally {
                android.os.Binder.restoreCallingIdentity(callingId);
            }
        }
    }

    private void restoreDataForClone(com.android.server.pm.PackageManagerService pm, int parentUserId, int clonedProfileUserId) {
        if (parentUserId == 0) {
            java.lang.String cloneAppList = android.provider.Settings.Secure.getStringForUser(this.mContext.getContentResolver(), "clone_app_list", parentUserId);
            if (!android.text.TextUtils.isEmpty(cloneAppList)) {
                for (java.lang.String pkg : cloneAppList.split(";")) {
                    if (!android.text.TextUtils.isEmpty(pkg)) {
                        if (pm.getPackageInfo(pkg, 0, parentUserId) != null) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Install existing package [");
                            stringBuilder.append(pkg);
                            stringBuilder.append("] as user ");
                            stringBuilder.append(clonedProfileUserId);
                            android.util.Slog.i("HwUserManagerService", stringBuilder.toString());
                            pm.installExistingPackageAsUser(pkg, clonedProfileUserId, 0, 0);
                            pm.setPackageStoppedState(pkg, false, clonedProfileUserId);
                            pm.restoreAppDataForClone(pkg, parentUserId, clonedProfileUserId);
                        }
                    }
                }
            }
        }
    }

    public boolean isClonedProfile(int userId) {
        if (userId == 0) {
            return false;
        }
        boolean isClonedProfile = false;
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            android.content.pm.UserInfo ui = super.getUserInfo(userId);
            if (ui != null) {
                isClonedProfile = ui.isClonedProfile();
            }
            android.os.Binder.restoreCallingIdentity(ident);
            return isClonedProfile;
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(ident);
        }
    }

    public android.content.pm.UserInfo getUserInfo(int userId) {
        int callingUserId = android.os.UserHandle.getUserId(android.os.Binder.getCallingUid());
        if (!isClonedProfile(userId)) {
            if (!isClonedProfile(callingUserId)) {
                return super.getUserInfo(userId);
            }
        }
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            android.content.pm.UserInfo userInfo = super.getUserInfo(userId);
            return userInfo;
        } finally {
            android.os.Binder.restoreCallingIdentity(ident);
        }
    }
}
