package com.android.server.pm;

public class PackagePublicityUtils {
    private static final java.lang.String HW_PUBLICITY_ALL_DIRS = "/system/etc:/version/etc:cust/etc:product/etc:vendor/etc:preload/etc";
    private static final java.lang.String HW_PUBLICITY_PERMISSION_PATH = "emui/china/xml/publicity_permission.xml";
    private static java.util.Comparator<com.android.server.pm.PackagePublicityInfo> PUBLICITYINFO_COMPARATOR = new java.util.Comparator<com.android.server.pm.PackagePublicityInfo>() {
        private final java.text.Collator sCollator = java.text.Collator.getInstance(java.util.Locale.CHINA);

        public int compare(com.android.server.pm.PackagePublicityInfo object1, com.android.server.pm.PackagePublicityInfo object2) {
            int compareResult = this.sCollator.compare(object1.getLabel(), object2.getLabel());
            if (compareResult != 0) {
                return compareResult;
            }
            return this.sCollator.compare(object1.getPackageName(), object2.getPackageName());
        }
    };
    private static final java.lang.String TAG = "PackagePublicityUtils";
    private static java.util.List<java.lang.String> mHwPlublicityAppList = null;

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private static java.util.List<com.android.server.pm.PackagePublicityInfo> loadPackagePublicityInfo() {
        java.util.ArrayList<java.io.File> publicityFileList = new java.util.ArrayList();
        try {
            publicityFileList = getPublicityFileList("publicity_all.xml");
        } catch (java.lang.NoClassDefFoundError er) {
            android.util.Slog.e("PackagePublicityUtils", er.getMessage());
        }
        java.util.List<com.android.server.pm.PackagePublicityInfo> publicityInfos = new java.util.ArrayList();
        java.util.Iterator it = publicityFileList.iterator();
        while (it.hasNext()) {
            java.io.File file = (java.io.File) it.next();
            if (file != null) {
                if (file.exists()) {
                    publicityInfos.addAll(getPackagePublicityInfoFromCust(file));
                }
            }
        }
        return publicityInfos;
    }

    private static java.util.ArrayList<java.io.File> getPublicityFileList(java.lang.String fileName) {
        java.util.ArrayList<java.io.File> fileList = new java.util.ArrayList();
        if (android.text.TextUtils.isEmpty(fileName)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Error: file = [");
            stringBuilder.append(fileName);
            stringBuilder.append("]");
            android.util.Log.e("PackagePublicityUtils", stringBuilder.toString());
            return fileList;
        }
        java.lang.String[] dirs = "/system/etc:/version/etc:cust/etc:product/etc:vendor/etc:preload/etc".split(":");
        for (java.lang.String file : dirs) {
            java.io.File file2 = new java.io.File(file, fileName);
            if (file2.exists()) {
                fileList.add(file2);
            }
        }
        if (fileList.size() == 0) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("No publicity file found for:");
            stringBuilder2.append(fileName);
            android.util.Log.w("PackagePublicityUtils", stringBuilder2.toString());
        }
        return fileList;
    }

    public static java.util.List<com.android.server.pm.PackagePublicityInfo> getPackagePublicityInfoFromCust(java.io.File file) {
        java.util.List<com.android.server.pm.PackagePublicityInfo> result = new java.util.ArrayList();
        if (file != null) {
            if (file.exists()) {
                java.io.InputStream in = null;
                try {
                    in = new java.io.FileInputStream(file);
                    org.xmlpull.v1.XmlPullParser xml = android.util.Xml.newPullParser();
                    xml.setInput(in, "utf-8");
                    while (true) {
                        int next = xml.next();
                        int xmlEventType = next;
                        if (next == 1) {
                            break;
                        } else if (xmlEventType == 2 && "packageInfo".equals(xml.getName())) {
                            com.android.server.pm.PackagePublicityInfo packagePublicityInfo = new com.android.server.pm.PackagePublicityInfo();
                            java.lang.String mPackage = xml.getAttributeValue(null, "package");
                            packagePublicityInfo.setPackageName(mPackage);
                            java.lang.String label = xml.getAttributeValue(null, "label");
                            if (android.text.TextUtils.isEmpty(label)) {
                                packagePublicityInfo.setLabel(mPackage);
                            } else {
                                packagePublicityInfo.setLabel(label);
                            }
                            packagePublicityInfo.setFeature(xml.getAttributeValue(null, "feature"));
                            packagePublicityInfo.setAuthor(xml.getAttributeValue(null, "author"));
                            packagePublicityInfo.setIsLauncher(xml.getAttributeValue(null, "launcher"));
                            packagePublicityInfo.setIsUninstall(xml.getAttributeValue(null, "uninstall"));
                            packagePublicityInfo.setPackageFileName(xml.getAttributeValue(null, "packageFileName"));
                            packagePublicityInfo.setUsePermission(xml.getAttributeValue(null, "use-permission"));
                            packagePublicityInfo.setCategory(xml.getAttributeValue(null, "app-category"));
                            packagePublicityInfo.setSignature(xml.getAttributeValue(null, "app-signature"));
                            if (!"".equals(mPackage)) {
                                if (mPackage != null) {
                                    result.add(packagePublicityInfo);
                                }
                            }
                        }
                    }
                    try {
                        in.close();
                    } catch (java.io.IOException e) {
                        android.util.Slog.e("PackagePublicityUtils", "close FileInputStram error");
                    }
                } catch (java.io.FileNotFoundException e2) {
                    android.util.Slog.w("PackagePublicityUtils", "Error FileNotFound while trying to read from publicity_all.xml", e2);
                    if (in != null) {
                        in.close();
                    }
                } catch (org.xmlpull.v1.XmlPullParserException e3) {
                    android.util.Slog.e("PackagePublicityUtils", "Error XmlPullParser while trying to read from publicity_all.xml", e3);
                    if (in != null) {
                        in.close();
                    }
                } catch (java.io.IOException e4) {
                    android.util.Slog.e("PackagePublicityUtils", "Error while trying to read from publicity_all.xml", e4);
                    if (in != null) {
                        in.close();
                    }
                } catch (Throwable th) {
                    if (in != null) {
                        try {
                            in.close();
                        } catch (java.io.IOException e5) {
                            android.util.Slog.e("PackagePublicityUtils", "close FileInputStram error");
                        }
                    }
                }
                return result;
            }
        }
        return result;
    }

    public static void writeAllPakcagePublicityInfoIntoFile(android.content.Context context, android.content.pm.ParceledListSlice<android.content.pm.ApplicationInfo> slice) {
        java.io.IOException e;
        java.io.IOException e2;
        java.lang.StringBuilder stringBuilder;
        java.lang.StringBuilder stringBuilder2;
        java.io.File file = getPublicityFile();
        if (file != null) {
            if (!file.exists()) {
                java.util.List<com.android.server.pm.PackagePublicityInfo> allPackagePublicityInfo = loadPackagePublicityInfo();
                if (allPackagePublicityInfo.size() != 0) {
                    handlePublicityInfos(context, slice, allPackagePublicityInfo);
                    java.io.FileOutputStream out = null;
                    java.io.BufferedOutputStream str = null;
                    try {
                        out = new java.io.FileOutputStream(file);
                        str = new java.io.BufferedOutputStream(out);
                        org.xmlpull.v1.XmlSerializer serializer = new com.android.internal.util.FastXmlSerializer();
                        serializer.setOutput(str, "utf-8");
                        serializer.startDocument(null, java.lang.Boolean.valueOf(true));
                        serializer.startTag(null, "packageList");
                        for (com.android.server.pm.PackagePublicityInfo info : allPackagePublicityInfo) {
                            serializer.startTag(null, "packageInfo");
                            serializer.attribute(null, "package", info.getPackageName());
                            serializer.attribute(null, "label", info.getLabel());
                            serializer.attribute(null, "feature", info.getFeature());
                            serializer.attribute(null, "author", info.getAuthor());
                            serializer.attribute(null, "launcher", info.getIsLauncher());
                            serializer.attribute(null, "uninstall", info.getIsUninstall());
                            serializer.attribute(null, "packageFileName", info.getPackageFileName());
                            serializer.attribute(null, "use-permission", info.getUsePermission());
                            serializer.attribute(null, "app-category", info.getCategory());
                            serializer.attribute(null, "app-signature", info.getSignature());
                            serializer.endTag(null, "packageInfo");
                        }
                        serializer.endTag(null, "packageList");
                        serializer.endDocument();
                        str.flush();
                        android.os.FileUtils.sync(out);
                        try {
                            str.close();
                            out.close();
                            android.os.FileUtils.setPermissions(file.toString(), 432, -1, -1);
                        } catch (java.io.IOException e3) {
                            e = e3;
                            e2 = "PackagePublicityUtils";
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Error close writing package manager settings");
                            stringBuilder.append(e.getMessage());
                            android.util.Slog.e(e2, stringBuilder.toString());
                        }
                    } catch (java.io.FileNotFoundException e4) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("File not found when writing pakcagePublicity file: ");
                        stringBuilder2.append(e4.getMessage());
                        android.util.Slog.e("PackagePublicityUtils", stringBuilder2.toString());
                        if (str != null) {
                            try {
                                str.close();
                            } catch (java.io.IOException e5) {
                                e = e5;
                                e2 = "PackagePublicityUtils";
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("Error close writing package manager settings");
                                stringBuilder.append(e.getMessage());
                                android.util.Slog.e(e2, stringBuilder.toString());
                            }
                        }
                        if (out != null) {
                            out.close();
                        }
                        android.os.FileUtils.setPermissions(file.toString(), 432, -1, -1);
                    } catch (java.lang.IllegalArgumentException e6) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("IllegalArgument when writing pakcagePublicity file: ");
                        stringBuilder2.append(e6.getMessage());
                        android.util.Slog.e("PackagePublicityUtils", stringBuilder2.toString());
                        if (str != null) {
                            try {
                                str.close();
                            } catch (java.io.IOException e7) {
                                e = e7;
                                e2 = "PackagePublicityUtils";
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("Error close writing package manager settings");
                                stringBuilder.append(e.getMessage());
                                android.util.Slog.e(e2, stringBuilder.toString());
                            }
                        }
                        if (out != null) {
                            out.close();
                        }
                        android.os.FileUtils.setPermissions(file.toString(), 432, -1, -1);
                    } catch (java.io.IOException e8) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("IOException when writing pakcagePublicity file: ");
                        stringBuilder2.append(e8.getMessage());
                        android.util.Slog.e("PackagePublicityUtils", stringBuilder2.toString());
                        if (str != null) {
                            try {
                                str.close();
                            } catch (java.io.IOException e9) {
                                e8 = e9;
                                e2 = "PackagePublicityUtils";
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("Error close writing package manager settings");
                                stringBuilder.append(e8.getMessage());
                                android.util.Slog.e(e2, stringBuilder.toString());
                            }
                        }
                        if (out != null) {
                            out.close();
                        }
                        android.os.FileUtils.setPermissions(file.toString(), 432, -1, -1);
                    } catch (Throwable th) {
                        if (str != null) {
                            try {
                                str.close();
                            } catch (java.io.IOException e22) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("Error close writing package manager settings");
                                stringBuilder.append(e22.getMessage());
                                android.util.Slog.e("PackagePublicityUtils", stringBuilder.toString());
                            }
                        }
                        if (out != null) {
                            out.close();
                        }
                        android.os.FileUtils.setPermissions(file.toString(), 432, -1, -1);
                    }
                }
            }
        }
    }

    public static java.io.File getPublicityFile() {
        java.io.File publicityFile = null;
        try {
            java.io.File systemDir = new java.io.File(android.os.Environment.getDataDirectory(), "system");
            if (systemDir.exists() || systemDir.mkdirs()) {
                publicityFile = new java.io.File(systemDir, "publicity_all.xml");
                if (publicityFile.exists()) {
                    return null;
                }
                android.util.Slog.i("PackagePublicityUtils", "first boot. init publicity_all.xml");
                return publicityFile;
            }
            android.util.Slog.i("PackagePublicityUtils", "PakcagePublicity file create error");
            return null;
        } catch (java.lang.SecurityException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PakcagePublicity file SecurityException: ");
            stringBuilder.append(e.getMessage());
            android.util.Slog.i("PackagePublicityUtils", stringBuilder.toString());
        }
    }

    public static void deletePublicityFile() {
        try {
            java.io.File publicityFile = new java.io.File(android.os.Environment.getDataDirectory(), "system/publicity_all.xml");
            if (publicityFile.exists() && publicityFile.delete()) {
                android.util.Slog.i("PackagePublicityUtils", "Delete publicity file ...");
            }
        } catch (java.lang.SecurityException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Delete publicity file error: ");
            stringBuilder.append(e.getMessage());
            android.util.Slog.i("PackagePublicityUtils", stringBuilder.toString());
        }
    }

    private static void handlePublicityInfos(android.content.Context context, android.content.pm.ParceledListSlice<android.content.pm.ApplicationInfo> slice, java.util.List<com.android.server.pm.PackagePublicityInfo> pkgPubInfo) {
        filterPublicityInfos(new android.content.pm.HwInvisibleAppsFilter(context), slice, pkgPubInfo, context.getPackageManager());
        sortPackagePublicityInfos(pkgPubInfo);
    }

    private static void initPubPermissions(java.util.List<java.lang.String> pubPermissionGroup, java.util.List<java.lang.String> pubPermission) {
        java.io.File file = new java.io.File("system", "emui/china/xml/publicity_permission.xml");
        if (file.exists()) {
            java.io.InputStream in = null;
            try {
                in = new java.io.FileInputStream(file);
                org.xmlpull.v1.XmlPullParser xml = android.util.Xml.newPullParser();
                xml.setInput(in, "utf-8");
                while (true) {
                    int next = xml.next();
                    int xmlEventType = next;
                    if (next == 1) {
                        break;
                    } else if (xmlEventType == 2 && "permissionInfo".equals(xml.getName())) {
                        java.lang.String group = xml.getAttributeValue(null, "group");
                        java.lang.String name = xml.getAttributeValue(null, "name");
                        if (!(android.text.TextUtils.isEmpty(group) || android.text.TextUtils.isEmpty(name))) {
                            pubPermissionGroup.add(group);
                            pubPermission.add(name);
                        }
                    }
                }
                try {
                    in.close();
                } catch (java.io.IOException e) {
                    android.util.Log.e("PackagePublicityUtils", "close FileInputStram error");
                }
            } catch (java.io.FileNotFoundException e2) {
                android.util.Log.w("PackagePublicityUtils", "Error FileNotFound while trying to read from publicity_permission.xml");
                if (in != null) {
                    in.close();
                }
            } catch (org.xmlpull.v1.XmlPullParserException e3) {
                android.util.Log.e("PackagePublicityUtils", "Error XmlPullParser while trying to read from publicity_permission.xml", e3);
                if (in != null) {
                    in.close();
                }
            } catch (java.io.IOException e4) {
                android.util.Log.e("PackagePublicityUtils", "Error while trying to read from publicity_permission.xml", e4);
                if (in != null) {
                    in.close();
                }
            } catch (Throwable th) {
                if (in != null) {
                    try {
                        in.close();
                    } catch (java.io.IOException e5) {
                        android.util.Log.e("PackagePublicityUtils", "close FileInputStram error");
                    }
                }
            }
        }
    }

    private static void filterPublicityInfos(android.content.pm.HwInvisibleAppsFilter filter, android.content.pm.ParceledListSlice<android.content.pm.ApplicationInfo> slice, java.util.List<com.android.server.pm.PackagePublicityInfo> pkgPubInfo, android.content.pm.PackageManager pm) {
        java.util.List<java.lang.String> pubPermissionGroup = new java.util.ArrayList();
        java.util.List<java.lang.String> pubPermission = new java.util.ArrayList();
        initPubPermissions(pubPermissionGroup, pubPermission);
        java.util.List<java.lang.String> sysWhiteList = com.android.server.pm.AntiMalPreInstallScanner.getInstance().getSysWhiteList();
        if (slice == null) {
            android.util.Slog.w("PackagePublicityUtils", "FiltePublicityInfo: getInstalledApplications is null");
            pkgPubInfo.clear();
            return;
        }
        android.content.pm.HwInvisibleAppsFilter hwInvisibleAppsFilter;
        android.content.pm.PackageManager packageManager;
        java.util.List<java.lang.String> list;
        java.util.List<java.lang.String> list2;
        if (sysWhiteList == null) {
            hwInvisibleAppsFilter = filter;
            packageManager = pm;
            list = pubPermissionGroup;
            list2 = pubPermission;
            pubPermissionGroup = pkgPubInfo;
        } else if (sysWhiteList.size() == 0) {
            hwInvisibleAppsFilter = filter;
            packageManager = pm;
            list = pubPermissionGroup;
            list2 = pubPermission;
            pubPermissionGroup = pkgPubInfo;
        } else {
            java.util.List<android.content.pm.ApplicationInfo> allApps = slice.getList();
            if (allApps == null) {
                hwInvisibleAppsFilter = filter;
                packageManager = pm;
                list = pubPermissionGroup;
                list2 = pubPermission;
                pubPermissionGroup = pkgPubInfo;
            } else if (allApps.size() == 0) {
                hwInvisibleAppsFilter = filter;
                packageManager = pm;
                list = pubPermissionGroup;
                list2 = pubPermission;
                pubPermissionGroup = pkgPubInfo;
            } else {
                allApps = filter.filterHideApp(allApps);
                java.util.List<java.lang.String> allInstallAppName = new java.util.ArrayList();
                for (android.content.pm.ApplicationInfo app : allApps) {
                    allInstallAppName.add(app.packageName);
                }
                java.util.List<com.android.server.pm.PackagePublicityInfo> insatlledPkgs = new java.util.ArrayList();
                java.util.List<java.lang.String> existPkg = new java.util.ArrayList();
                com.android.server.pm.PackageManagerService pms = (com.android.server.pm.PackageManagerService) android.os.ServiceManager.getService("package");
                for (com.android.server.pm.PackagePublicityInfo pubInfo : pkgPubInfo) {
                    java.lang.String pubInfoPkg = pubInfo.getPackageName();
                    if (!existPkg.contains(pubInfoPkg)) {
                        if (allInstallAppName.contains(pubInfoPkg) && sysWhiteList.contains(pubInfoPkg)) {
                            android.content.pm.PackageInfo pkgInfo = pms.getPackageInfo(pubInfoPkg, 4096, 0);
                            pubInfo.setUsePermission(getUsePermission(pkgInfo, pubPermissionGroup, pubPermission));
                            java.lang.String label = pkgInfo.applicationInfo.loadUnsafeLabel(pm).toString();
                            if (android.text.TextUtils.isEmpty(label)) {
                                pubInfo.setLabel(pubInfoPkg);
                            } else {
                                pubInfo.setLabel(label);
                            }
                            list = pubPermissionGroup;
                            list2 = pubPermission;
                            pubPermissionGroup = pms.getPackageInfo(pubInfoPkg, 64, null);
                            if (pubPermissionGroup.signatures != null) {
                                pubInfo.setSignature(getSignatureString(pubPermissionGroup.signatures));
                                insatlledPkgs.add(pubInfo);
                                existPkg.add(pubInfoPkg);
                            }
                        } else {
                            packageManager = pm;
                            list = pubPermissionGroup;
                            list2 = pubPermission;
                        }
                        pubPermissionGroup = list;
                        pubPermission = list2;
                    }
                }
                packageManager = pm;
                list = pubPermissionGroup;
                list2 = pubPermission;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("insatlledPkgs size = ");
                stringBuilder.append(insatlledPkgs.size());
                android.util.Slog.w("PackagePublicityUtils", stringBuilder.toString());
                pkgPubInfo.clear();
                pkgPubInfo.addAll(insatlledPkgs);
                return;
            }
            pkgPubInfo.clear();
            return;
        }
        android.util.Slog.w("PackagePublicityUtils", "FiltePublicityInfo: getSysWhiteList is null or isEmpty");
        pkgPubInfo.clear();
    }

    private static java.lang.String getUsePermission(android.content.pm.PackageInfo pkgInfo, java.util.List<java.lang.String> pubPermissionGroup, java.util.List<java.lang.String> pubPermission) {
        if (pkgInfo == null) {
            return "";
        }
        java.lang.String[] requestedPermissions = pkgInfo.requestedPermissions;
        if (requestedPermissions != null) {
            if (requestedPermissions.length > 0) {
                java.lang.StringBuilder usePermissionBuilder = new java.lang.StringBuilder();
                java.util.List<java.lang.String> usePermissionGroup = new java.util.ArrayList();
                java.util.List<java.lang.String> requestedPermissionList = java.util.Arrays.asList(requestedPermissions);
                for (java.lang.String permission : pubPermission) {
                    if (requestedPermissionList.contains(permission)) {
                        java.lang.String prermissionGroup = (java.lang.String) pubPermissionGroup.get(pubPermission.indexOf(permission));
                        if (!usePermissionGroup.contains(prermissionGroup)) {
                            usePermissionGroup.add(prermissionGroup);
                            usePermissionBuilder.append(prermissionGroup);
                            usePermissionBuilder.append(",");
                        }
                    }
                }
                java.lang.String usePermission = usePermissionBuilder.toString();
                if (!android.text.TextUtils.isEmpty(usePermission) && usePermission.endsWith(",")) {
                    usePermission = usePermission.substring(0, usePermission.length() - 1);
                }
                return usePermission;
            }
        }
        return "";
    }

    private static void sortPackagePublicityInfos(java.util.List<com.android.server.pm.PackagePublicityInfo> pkgPubInfo) {
        if (pkgPubInfo != null && pkgPubInfo.size() > 0 && PUBLICITYINFO_COMPARATOR != null) {
            java.util.Collections.sort(pkgPubInfo, PUBLICITYINFO_COMPARATOR);
            PUBLICITYINFO_COMPARATOR = null;
        }
    }

    public static java.util.List<java.lang.String> getHwPublicityAppList(android.content.Context context) {
        if (mHwPlublicityAppList == null) {
            java.io.File publicityFile = new java.io.File(android.os.Environment.getDataDirectory(), "system/publicity_all.xml");
            if (publicityFile.exists()) {
                mHwPlublicityAppList = new java.util.ArrayList();
                java.util.List<com.android.server.pm.PackagePublicityInfo> readResult = getPackagePublicityInfoFromCust(publicityFile);
                com.android.server.pm.PackageManagerService pms = (com.android.server.pm.PackageManagerService) android.os.ServiceManager.getService("package");
                android.content.pm.PackageManager pm = context.getPackageManager();
                java.util.List<java.lang.String> sysWhiteList = com.android.server.pm.AntiMalPreInstallScanner.getInstance().getSysWhiteList();
                if (sysWhiteList != null) {
                    if (sysWhiteList.size() != 0) {
                        for (com.android.server.pm.PackagePublicityInfo pp : readResult) {
                            java.lang.String pkName = pp.getPackageName();
                            if (sysWhiteList.contains(pkName)) {
                                java.lang.String label = "";
                                java.lang.String info = "";
                                android.content.pm.PackageInfo pkgInfo = pms.getPackageInfo(pkName, 64, 0);
                                if (pkgInfo == null) {
                                    label = pp.getLabel();
                                } else if (pkgInfo.signatures != null) {
                                    if (pkgInfo.applicationInfo != null) {
                                        if (pp.getSignature().equals(getSignatureString(pkgInfo.signatures))) {
                                            label = pkgInfo.applicationInfo.loadUnsafeLabel(pm).toString();
                                            if (android.text.TextUtils.isEmpty(label)) {
                                                label = pkName;
                                            }
                                        }
                                    }
                                }
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append(pkName);
                                stringBuilder.append("+++++");
                                stringBuilder.append(label);
                                mHwPlublicityAppList.add(stringBuilder.toString());
                            }
                        }
                    }
                }
                android.util.Slog.w("PackagePublicityUtils", "FiltePublicityInfo: getSysWhiteList is null or isEmpty");
                return mHwPlublicityAppList;
            }
        }
        return mHwPlublicityAppList;
    }

    private static java.lang.String getSignatureString(android.content.pm.Signature[] signatures) {
        java.lang.StringBuilder signatureStrBuilder = new java.lang.StringBuilder();
        for (android.content.pm.Signature toCharsString : signatures) {
            signatureStrBuilder.append(toCharsString.toCharsString());
            signatureStrBuilder.append(",");
        }
        java.lang.String signatureStr = signatureStrBuilder.toString();
        if (android.text.TextUtils.isEmpty(signatureStr) || !signatureStr.endsWith(",")) {
            return signatureStr;
        }
        return signatureStr.substring(0, signatureStr.length() - 1);
    }

    public static android.os.ParcelFileDescriptor getHwPublicityAppParcelFileDescriptor() {
        android.os.ParcelFileDescriptor plublicityFileDescriptor = null;
        try {
            java.io.File target = new java.io.File(android.os.Environment.getDataDirectory(), "system/publicity_all.xml");
            if (target.exists()) {
                plublicityFileDescriptor = new android.os.ParcelFileDescriptor(libcore.io.Libcore.os.open(target.getAbsolutePath(), android.system.OsConstants.O_RDONLY, 0));
            }
        } catch (android.system.ErrnoException e) {
            android.util.Slog.w("PackagePublicityUtils", "getHwPlublicityAppParcelFileDescriptor file not found .");
        }
        return plublicityFileDescriptor;
    }
}
