package com.android.server.pm.auth.processor;

public class ApkHashProcessor extends com.android.server.pm.auth.processor.BaseProcessor {
    public boolean readCert(java.lang.String line, com.android.server.pm.auth.HwCertification.CertificationData rawCert) {
        if (line != null) {
            if (!line.isEmpty()) {
                if (!line.startsWith("ApkHash")) {
                    return false;
                }
                java.lang.String apkHash = line.substring("ApkHash".length() + 1);
                if (apkHash != null) {
                    if (!apkHash.isEmpty()) {
                        rawCert.mApkHash = apkHash;
                        return true;
                    }
                }
                com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_RC is empty");
                return false;
            }
        }
        return false;
    }

    public boolean parserCert(com.android.server.pm.auth.HwCertification rawCert) {
        com.android.server.pm.auth.HwCertification.CertificationData certData = rawCert.mCertificationData;
        if (certData.mApkHash == null || certData.mApkHash.isEmpty()) {
            com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_PC error");
            return false;
        }
        rawCert.setApkHash(certData.mApkHash);
        return true;
    }

    public boolean verifyCert(android.content.pm.PackageParser.Package pkg, com.android.server.pm.auth.HwCertification cert) {
        if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
            com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", "AH_VC start");
        }
        java.lang.String hashFromcert = cert.getApkHash();
        if (hashFromcert != null) {
            if (!hashFromcert.isEmpty()) {
                if (cert.isReleased()) {
                    if ("*".equals(hashFromcert)) {
                        if (com.android.server.pm.auth.util.HwAuthLogger.getHWDEBUG()) {
                            com.android.server.pm.auth.util.HwAuthLogger.d("HwCertificationManager", "AH_VC is * in released cert");
                        }
                        return true;
                    }
                    try {
                        if (hashFromcert.equals(generateAPKHash(cert))) {
                            if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
                                com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", "AH_VC line ok released cert");
                            }
                            return true;
                        }
                        com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_VC error:not same");
                        return false;
                    } catch (java.lang.Exception e) {
                        com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_VC failed");
                        return false;
                    }
                } else if ("*".equals(hashFromcert)) {
                    if (com.android.server.pm.auth.util.HwAuthLogger.getHWDEBUG()) {
                        com.android.server.pm.auth.util.HwAuthLogger.d("HwCertificationManager", "AH_VC debug cert,line ok");
                    }
                    return true;
                } else {
                    com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_VC error not * in debug cert");
                    return false;
                }
            }
        }
        return false;
    }

    public boolean parseXmlTag(java.lang.String tag, org.xmlpull.v1.XmlPullParser parser, com.android.server.pm.auth.HwCertification cert) {
        if (!"ApkHash".equals(tag)) {
            return false;
        }
        cert.mCertificationData.mApkHash = parser.getAttributeValue(null, "value");
        return true;
    }

    private java.lang.String generateAPKHash(com.android.server.pm.auth.HwCertification rawCert) throws java.lang.Exception {
        if (rawCert == null) {
            com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_G cert is null");
            return "";
        }
        byte[] manifest;
        java.lang.String apkHashFromFile = null;
        java.util.zip.ZipFile zFile = rawCert.getZipFile();
        java.lang.String sfFilePath = null;
        if (zFile != null) {
            try {
                sfFilePath = com.android.server.pm.auth.util.Utils.getSfFileName(zFile);
            } catch (java.security.NoSuchAlgorithmException e) {
                com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "AH_G error");
            } catch (Throwable th) {
                rawCert.resetZipFile();
            }
        }
        if (sfFilePath == null || !com.android.server.pm.auth.util.Utils.isUsingSignatureSchemaV2(zFile, zFile.getEntry(sfFilePath))) {
            com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", " AH_G not V2");
            manifest = com.android.server.pm.auth.util.Utils.getManifestFileWithoutHwCER(rawCert.getApkFile());
        } else {
            com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", "AH_G V2 sort manifest content");
            manifest = com.android.server.pm.auth.util.Utils.getManifestFileWithoutHwCER(zFile, zFile.getEntry("META-INF/MANIFEST.MF"));
        }
        if (manifest != null) {
            if (manifest.length != 0) {
                apkHashFromFile = com.android.server.pm.auth.util.Utils.bytesToString(com.android.server.pm.auth.util.CryptionUtils.sha256(manifest));
                rawCert.resetZipFile();
                return apkHashFromFile;
            }
        }
        rawCert.resetZipFile();
        return null;
    }
}
