package com.android.server.pm.auth.processor;

public class SignatureProcessor extends com.android.server.pm.auth.processor.BaseProcessor {
    private static final java.lang.String SEPARATOR = "\r\n";

    public boolean readCert(java.lang.String line, com.android.server.pm.auth.HwCertification.CertificationData rawCert) {
        if (line != null) {
            if (!line.isEmpty()) {
                if (!line.startsWith("Signature")) {
                    return false;
                }
                java.lang.String key = line.substring("Signature".length() + 1);
                if (key != null) {
                    if (!key.isEmpty()) {
                        rawCert.mSignature = key;
                        return true;
                    }
                }
                com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "SN_RC is empty");
                return false;
            }
        }
        return false;
    }

    public boolean parserCert(com.android.server.pm.auth.HwCertification rawCert) {
        com.android.server.pm.auth.HwCertification.CertificationData certData = rawCert.mCertificationData;
        if (certData.mSignature == null || certData.mSignature.isEmpty()) {
            com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "SN_PC error");
            return false;
        }
        rawCert.setSignature(certData.mSignature);
        return true;
    }

    public boolean verifyCert(android.content.pm.PackageParser.Package pkg, com.android.server.pm.auth.HwCertification cert) {
        if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
            java.lang.String str = "HwCertificationManager";
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("SN_VC start ");
            stringBuilder.append(cert.isReleased() ? "released cert--" : "debugged cert--");
            com.android.server.pm.auth.util.HwAuthLogger.i(str, stringBuilder.toString());
        }
        java.lang.String orginal = cert.mCertificationData.mSignature;
        if (orginal != null) {
            if (!orginal.isEmpty()) {
                boolean result = false;
                try {
                    byte[] digestFromFileText = com.android.server.pm.auth.util.CryptionUtils.sha256(generatePartlyContent(cert.isReleased(), cert).getBytes("UTF-8"));
                    java.security.PublicKey pubKey = com.android.server.pm.auth.DevicePublicKeyLoader.getPublicKey(com.android.server.pm.auth.HwCertificationManager.getIntance().getContext());
                    if (pubKey == null) {
                        return false;
                    }
                    result = com.android.server.pm.auth.util.CryptionUtils.verify(digestFromFileText, pubKey, com.android.server.pm.auth.util.Utils.stringToBytes(orginal));
                    if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
                        java.lang.String str2 = "HwCertificationManager";
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("SN_VC result:");
                        stringBuilder2.append(result ? "OK" : "not the same");
                        com.android.server.pm.auth.util.HwAuthLogger.i(str2, stringBuilder2.toString());
                    }
                    return result;
                } catch (java.lang.RuntimeException e) {
                    com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "SN_VC RuntimeException when encounting");
                    return false;
                } catch (java.lang.Exception e2) {
                    com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "SN_VC exception when encounting");
                    return false;
                }
            }
        }
        return false;
    }

    public boolean parseXmlTag(java.lang.String tag, org.xmlpull.v1.XmlPullParser parser, com.android.server.pm.auth.HwCertification cert) {
        if (!"Signature".equals(tag)) {
            return false;
        }
        cert.mCertificationData.mSignature = parser.getAttributeValue(null, "value");
        return true;
    }

    private java.lang.String generatePartlyContent(boolean isRelease, com.android.server.pm.auth.HwCertification rawCert) {
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        java.lang.String tDelveoperKey = rawCert.getDelveoperKey();
        java.lang.String tPackageName = rawCert.getPackageName();
        java.lang.String tPermissionsString = rawCert.mCertificationData.mPermissionsString;
        java.lang.String tDeviceIdsString = rawCert.mCertificationData.mDeviceIdsString;
        java.lang.String tPeriod = rawCert.mCertificationData.mPeriodString;
        java.lang.String tApkHash = rawCert.getApkHash();
        java.lang.String tCertificate = rawCert.getCertificate();
        java.lang.String tVersion = rawCert.getVersion();
        java.lang.String tExtenstion = rawCert.getExtenstion();
        if (!(tVersion == null || tVersion.isEmpty())) {
            sb.append("Version");
            sb.append(":");
            sb.append(tVersion);
            sb.append("\r\n");
        }
        sb.append("DeveloperKey");
        sb.append(":");
        sb.append(tDelveoperKey == null ? "" : tDelveoperKey);
        sb.append("\r\n");
        sb.append("PackageName");
        sb.append(":");
        sb.append(tPackageName == null ? "" : tPackageName);
        sb.append("\r\n");
        sb.append("Permissions");
        sb.append(":");
        sb.append(tPermissionsString == null ? "" : tPermissionsString);
        sb.append("\r\n");
        if (isRelease) {
            sb.append("DeviceIds");
            sb.append(":*");
            sb.append("\r\n");
        } else {
            sb.append("DeviceIds");
            sb.append(":");
            sb.append(tDeviceIdsString == null ? "" : tDeviceIdsString);
            sb.append("\r\n");
        }
        sb.append("ValidPeriod");
        sb.append(":");
        sb.append(tPeriod);
        sb.append("\r\n");
        if (isRelease) {
            sb.append("ApkHash");
            sb.append(":");
            sb.append(tApkHash == null ? "" : tApkHash);
            sb.append("\r\n");
        } else {
            sb.append("ApkHash");
            sb.append(":*");
            sb.append("\r\n");
        }
        if (!(tCertificate == null || tCertificate.isEmpty())) {
            sb.append("Certificate");
            sb.append(":");
            sb.append(tCertificate);
            sb.append("\r\n");
        }
        if (!(tExtenstion == null || tExtenstion.isEmpty())) {
            sb.append("Extension");
            sb.append(":");
            sb.append(tExtenstion);
            sb.append("\r\n");
        }
        return sb.toString();
    }
}
