package com.android.server.pm.auth.processor;

public class ValidPeriodProcessor extends com.android.server.pm.auth.processor.BaseProcessor {
    public boolean readCert(java.lang.String line, com.android.server.pm.auth.HwCertification.CertificationData rawCert) {
        if (line != null) {
            if (!line.isEmpty()) {
                if (!line.startsWith("ValidPeriod")) {
                    return false;
                }
                java.lang.String key = line.substring("ValidPeriod".length() + 1);
                if (key != null) {
                    if (!key.isEmpty()) {
                        rawCert.mPeriodString = key;
                        return true;
                    }
                }
                com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "VP_RC empty");
                return false;
            }
        }
        return false;
    }

    @android.annotation.SuppressLint({"AvoidMethodInForLoop"})
    public boolean parserCert(com.android.server.pm.auth.HwCertification rawCert) {
        java.lang.String period = rawCert.mCertificationData.mPeriodString;
        if (period == null) {
            com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "VP_PC error time is null ");
            return false;
        }
        java.lang.String dateElem = "(\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2})";
        java.lang.String dateRegx = new java.lang.StringBuilder();
        dateRegx.append("from ");
        dateRegx.append(dateElem);
        dateRegx.append(" ");
        dateRegx.append("to");
        dateRegx.append(" ");
        dateRegx.append(dateElem);
        java.util.regex.Matcher m = java.util.regex.Pattern.compile(dateRegx.toString()).matcher(period);
        int i = 1;
        if (m.matches()) {
            try {
                java.text.SimpleDateFormat dateFormat = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                dateFormat.setTimeZone(java.util.TimeZone.getTimeZone("GMT"));
                rawCert.setFromDate(dateFormat.parse(m.group(1)));
                rawCert.setToDate(dateFormat.parse(m.group(2)));
                return true;
            } catch (java.text.ParseException e) {
                com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "VP_PC time parser exception");
                if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("period:");
                    stringBuilder.append(period);
                    stringBuilder.append("m.groupCount():");
                    stringBuilder.append(m.groupCount());
                    com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", stringBuilder.toString());
                    while (i <= m.groupCount()) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("m.group");
                        stringBuilder.append(i);
                        stringBuilder.append(":");
                        stringBuilder.append(m.group(i));
                        com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", stringBuilder.toString());
                        i++;
                    }
                }
                return false;
            }
        }
        if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
            while (true) {
                int i2 = i;
                if (i2 > m.groupCount()) {
                    break;
                }
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("m.group");
                stringBuilder2.append(i2);
                stringBuilder2.append(":");
                stringBuilder2.append(m.group(i2));
                com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", stringBuilder2.toString());
                i = i2 + 1;
            }
        }
        com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", "VP_PC error");
        return false;
    }

    public boolean verifyCert(android.content.pm.PackageParser.Package pkg, com.android.server.pm.auth.HwCertification cert) {
        if (com.android.server.pm.auth.util.HwAuthLogger.getHWFLOW()) {
            com.android.server.pm.auth.util.HwAuthLogger.i("HwCertificationManager", "VP_VC start");
        }
        java.util.Date fromDate = cert.getFromDate();
        java.util.Date toDate = cert.getToDate();
        if (fromDate != null) {
            if (toDate != null) {
                java.lang.StringBuilder stringBuilder;
                if (!toDate.after(fromDate)) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("VP_VC date error from time is : ");
                    stringBuilder.append(fromDate);
                    stringBuilder.append(", toTime is:");
                    stringBuilder.append(toDate);
                    com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", stringBuilder.toString());
                    return false;
                } else if (!isCurrentDataExpired(toDate)) {
                    return true;
                } else {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("VP_VC date expired ");
                    stringBuilder.append(cert.mCertificationData.mPeriodString);
                    com.android.server.pm.auth.util.HwAuthLogger.e("HwCertificationManager", stringBuilder.toString());
                    return false;
                }
            }
        }
        return false;
    }

    public boolean parseXmlTag(java.lang.String tag, org.xmlpull.v1.XmlPullParser parser, com.android.server.pm.auth.HwCertification cert) {
        if (!"ValidPeriod".equals(tag)) {
            return false;
        }
        cert.mCertificationData.mPeriodString = parser.getAttributeValue(null, "value");
        return true;
    }

    private boolean isCurrentDataExpired(java.util.Date toDate) {
        return java.lang.System.currentTimeMillis() > toDate.getTime();
    }
}
