package com.android.server.pm.permission;

public final class HwDefaultPermissionGrantPolicy extends com.android.server.pm.permission.DefaultPermissionGrantPolicy {
    private static final java.util.Set<java.lang.String> CALENDAR_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> CAMERA_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> CONTACTS_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> LOCATION_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> MICROPHONE_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> PHONE_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> SENSORS_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> SMS_PERMISSIONS = new android.util.ArraySet();
    private static final java.util.Set<java.lang.String> STORAGE_PERMISSIONS = new android.util.ArraySet();
    private static final java.lang.String TAG = "HwDefaultPermissionGrantPolicy";
    private static final java.util.Map<java.lang.String, java.util.Set<java.lang.String>> nameToSet = new java.util.HashMap();
    private static final java.util.Set<java.lang.String> singlePermissionSet = new android.util.ArraySet();
    private android.content.Context mContext = null;

    static {
        PHONE_PERMISSIONS.add("android.permission.READ_PHONE_STATE");
        PHONE_PERMISSIONS.add("android.permission.CALL_PHONE");
        PHONE_PERMISSIONS.add("android.permission.READ_CALL_LOG");
        PHONE_PERMISSIONS.add("android.permission.WRITE_CALL_LOG");
        PHONE_PERMISSIONS.add("com.android.voicemail.permission.ADD_VOICEMAIL");
        PHONE_PERMISSIONS.add("android.permission.USE_SIP");
        PHONE_PERMISSIONS.add("android.permission.PROCESS_OUTGOING_CALLS");
        CONTACTS_PERMISSIONS.add("android.permission.READ_CONTACTS");
        CONTACTS_PERMISSIONS.add("android.permission.WRITE_CONTACTS");
        CONTACTS_PERMISSIONS.add("android.permission.GET_ACCOUNTS");
        LOCATION_PERMISSIONS.add("android.permission.ACCESS_FINE_LOCATION");
        LOCATION_PERMISSIONS.add("android.permission.ACCESS_COARSE_LOCATION");
        CALENDAR_PERMISSIONS.add("android.permission.READ_CALENDAR");
        CALENDAR_PERMISSIONS.add("android.permission.WRITE_CALENDAR");
        SMS_PERMISSIONS.add("android.permission.SEND_SMS");
        SMS_PERMISSIONS.add("android.permission.RECEIVE_SMS");
        SMS_PERMISSIONS.add("android.permission.READ_SMS");
        SMS_PERMISSIONS.add("android.permission.RECEIVE_WAP_PUSH");
        SMS_PERMISSIONS.add("android.permission.RECEIVE_MMS");
        SMS_PERMISSIONS.add("android.permission.READ_CELL_BROADCASTS");
        MICROPHONE_PERMISSIONS.add("android.permission.RECORD_AUDIO");
        CAMERA_PERMISSIONS.add("android.permission.CAMERA");
        SENSORS_PERMISSIONS.add("android.permission.BODY_SENSORS");
        STORAGE_PERMISSIONS.add("android.permission.READ_EXTERNAL_STORAGE");
        STORAGE_PERMISSIONS.add("android.permission.WRITE_EXTERNAL_STORAGE");
        nameToSet.put("android.permission-group.PHONE", PHONE_PERMISSIONS);
        nameToSet.put("android.permission-group.CONTACTS", CONTACTS_PERMISSIONS);
        nameToSet.put("android.permission-group.LOCATION", LOCATION_PERMISSIONS);
        nameToSet.put("android.permission-group.CALENDAR", CALENDAR_PERMISSIONS);
        nameToSet.put("android.permission-group.SMS", SMS_PERMISSIONS);
        nameToSet.put("android.permission-group.MICROPHONE", MICROPHONE_PERMISSIONS);
        nameToSet.put("android.permission-group.CAMERA", CAMERA_PERMISSIONS);
        nameToSet.put("android.permission-group.SENSORS", SENSORS_PERMISSIONS);
        nameToSet.put("android.permission-group.STORAGE", STORAGE_PERMISSIONS);
        singlePermissionSet.addAll(PHONE_PERMISSIONS);
        singlePermissionSet.addAll(CONTACTS_PERMISSIONS);
        singlePermissionSet.addAll(LOCATION_PERMISSIONS);
        singlePermissionSet.addAll(CALENDAR_PERMISSIONS);
        singlePermissionSet.addAll(SMS_PERMISSIONS);
        singlePermissionSet.addAll(MICROPHONE_PERMISSIONS);
        singlePermissionSet.addAll(CAMERA_PERMISSIONS);
        singlePermissionSet.addAll(SENSORS_PERMISSIONS);
        singlePermissionSet.addAll(STORAGE_PERMISSIONS);
    }

    public HwDefaultPermissionGrantPolicy(android.content.Context context, android.os.Looper looper, com.android.server.pm.permission.DefaultPermissionGrantPolicy.DefaultPermissionGrantedCallback callback, com.android.server.pm.permission.PermissionManagerService permissionManager) {
        super(context, looper, callback, permissionManager);
        this.mContext = context;
    }

    public void grantDefaultPermissions(int userId) {
        super.grantDefaultPermissions(userId);
        try {
            grantCustomizedPermissions(userId);
        } catch (java.lang.Exception e) {
            android.util.Slog.e("HwDefaultPermissionGrantPolicy", "Grant customized permission fail. ");
        }
    }

    private void grantCustomizedPermissions(int userId) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Granting customized permissions for user ");
        stringBuilder.append(userId);
        android.util.Log.i("HwDefaultPermissionGrantPolicy", stringBuilder.toString());
        for (com.android.server.pm.permission.DefaultAppPermission perm : com.android.server.pm.permission.DefaultPermissionPolicyParser.parseConfig(this.mContext).values()) {
            try {
                grantCustomizedPermissions(userId, perm);
            } catch (java.lang.Exception e) {
                android.util.Slog.w("HwDefaultPermissionGrantPolicy", "Granting permission fail.");
            }
        }
    }

    private static boolean doesPackageSupportRuntimePermissions(android.content.pm.PackageParser.Package pkg) {
        return pkg.applicationInfo.targetSdkVersion > 22;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private void grantCustomizedPermissions(int userId, com.android.server.pm.permission.DefaultAppPermission perm) {
        java.lang.String pkgName = perm.mPackageName;
        android.content.pm.PackageParser.Package pkg = getSystemPackage(pkgName);
        java.lang.StringBuilder stringBuilder;
        if (pkg == null) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Invalid pkg name or system component :");
            stringBuilder.append(perm.mPackageName);
            android.util.Slog.w("HwDefaultPermissionGrantPolicy", stringBuilder.toString());
        } else if (doesPackageSupportRuntimePermissions(pkg)) {
            java.util.Iterator it = perm.mGrantedGroups.iterator();
            while (it.hasNext()) {
                com.android.server.pm.permission.DefaultAppPermission.DefaultPermissionGroup group = (com.android.server.pm.permission.DefaultAppPermission.DefaultPermissionGroup) it.next();
                if (group.mGrant) {
                    boolean fixed = group.mSystemFixed;
                    java.lang.String groupName = group.mName;
                    java.util.Set<java.lang.String> permSet = (java.util.Set) nameToSet.get(groupName);
                    if (permSet == null) {
                        permSet = new android.util.ArraySet();
                        permSet.add(groupName);
                    }
                    try {
                        grantRuntimePermissions(pkg, permSet, fixed, userId);
                    } catch (java.lang.Exception e) {
                        android.util.Slog.w("HwDefaultPermissionGrantPolicy", "Granting runtime permission failed.");
                    }
                } else {
                    return;
                }
            }
            if (com.android.server.pm.permission.DefaultPermissionPolicyParser.IS_ATT || com.android.server.pm.permission.DefaultPermissionPolicyParser.IS_SINGLE_PERMISSION) {
                java.util.Set<java.lang.String> singlePermSet = new android.util.ArraySet();
                java.util.Iterator it2 = perm.mGrantedSingles.iterator();
                while (it2.hasNext()) {
                    com.android.server.pm.permission.DefaultAppPermission.DefaultPermissionSingle single = (com.android.server.pm.permission.DefaultAppPermission.DefaultPermissionSingle) it2.next();
                    if (single.mGrant) {
                        boolean singlefiexd = single.mSystemFixed;
                        java.lang.String singlePerName = single.mName;
                        java.lang.StringBuilder stringBuilder2;
                        if (singlePermissionSet.contains(singlePerName)) {
                            singlePermSet.add(singlePerName);
                            try {
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("Granting customized permission:");
                                stringBuilder2.append(single);
                                stringBuilder2.append(" to ");
                                stringBuilder2.append(pkgName);
                                android.util.Slog.i("HwDefaultPermissionGrantPolicy", stringBuilder2.toString());
                                grantRuntimePermissions(pkg, singlePermSet, singlefiexd, userId);
                            } catch (java.lang.Exception e2) {
                                android.util.Slog.w("HwDefaultPermissionGrantPolicy", "Granting runtime permission failed.");
                            } finally {
                                singlePermSet.clear();
                            }
                        } else {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("Invalid permission: ");
                            stringBuilder2.append(singlePerName);
                            android.util.Slog.i("HwDefaultPermissionGrantPolicy", stringBuilder2.toString());
                        }
                    }
                }
            }
        } else {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("don't support runtime permission:");
            stringBuilder.append(perm.mPackageName);
            android.util.Slog.d("HwDefaultPermissionGrantPolicy", stringBuilder.toString());
        }
    }

    public void grantCustDefaultPermissions(int uid) {
        for (com.android.server.pm.permission.DefaultAppPermission perm : com.android.server.pm.permission.DefaultPermissionPolicyParser.parseCustConfig(this.mContext).values()) {
            try {
                grantCustomizedPermissions(uid, perm);
            } catch (java.lang.Exception e) {
                android.util.Slog.w("HwDefaultPermissionGrantPolicy", "Granting one application permission fail.");
            }
        }
        grantDefaultPermissionsForGmsCore(uid);
    }

    private void grantDefaultPermissionsForGmsCore(int uid) {
        android.content.pm.PackageParser.Package pkg = getSystemPackage("com.google.android.gms");
        if (pkg != null) {
            java.lang.String groupName = "android.permission-group.LOCATION";
            java.util.Set<java.lang.String> permSet = (java.util.Set) nameToSet.get("android.permission-group.LOCATION");
            if (permSet == null) {
                android.util.Slog.w("HwDefaultPermissionGrantPolicy", "customized invalid group name. must check :android.permission-group.LOCATION");
                permSet = new android.util.ArraySet();
                permSet.add("android.permission-group.LOCATION");
            }
            try {
                grantRuntimePermissions(pkg, permSet, false, uid);
            } catch (java.lang.Exception e) {
                android.util.Slog.w("HwDefaultPermissionGrantPolicy", "Granting runtime permission failed.");
            }
        }
    }
}
