package com.android.server.policy;

public class FingerprintActionsListener implements android.view.WindowManagerPolicyConstants.PointerEventListener {
    private static final boolean ENABLE_MWSWITCH = true;
    private static final java.lang.String FRONT_FINGERPRINT_SWAP_KEY_POSITION = "swap_key_position";
    private static final java.lang.String GSETTINGS_VDRIVE_IS_RUN = "vdrive_is_run_state";
    static final int HIT_REGION_SCALE = 4;
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    private static final int MSG_CLOSE_SEARCH_PANEL = 1;
    private static final java.lang.String TAG = "FingerprintActionsListener";
    private static final java.lang.String TALKBACK_COMPONENT_NAME = "com.google.android.marvin.talkback/com.google.android.marvin.talkback.TalkBackService";
    private static final int VDRIVE_IS_RUN = 1;
    private static final int VDRIVE_IS_UNRUN = 0;
    private static final boolean mDisableMultiWin = android.os.SystemProperties.getBoolean("ro.huawei.disable_multiwindow", false);
    private boolean isCoordinateForPad = android.os.SystemProperties.getBoolean("ro.config.coordinateforpad", false);
    private android.content.Context mContext = null;
    private boolean mDeviceProvisioned = true;
    private android.database.ContentObserver mDisplayDensityObserver;
    private boolean mDriveState = false;
    private boolean mGestureNavEnabled;
    private android.os.Handler mHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            if (msg.what == 1) {
                com.android.server.policy.FingerprintActionsListener.this.hideSearchPanelView();
            }
        }
    };
    private boolean mIsDoubleFlinger = false;
    private boolean mIsNeedHideMultiWindowView = false;
    private boolean mIsSingleFlinger = false;
    private boolean mIsStatusBarExplaned = false;
    private boolean mIsValidGesture = false;
    private boolean mIsValidHiboardGesture = false;
    private boolean mIsValidLazyModeGesture = false;
    private com.android.server.policy.HwSplitScreenArrowView mLandMultiWinArrowView = null;
    private com.android.server.policy.HwSplitScreenArrowView mMultiWinArrowView = null;
    private com.android.server.policy.PhoneWindowManager mPolicy = null;
    private com.android.server.policy.HwSplitScreenArrowView mPortMultiWinArrowView = null;
    private com.android.server.policy.SearchPanelView mSearchPanelView = null;
    private com.android.server.policy.FingerprintActionsListener.SettingsObserver mSettingsObserver;
    private com.android.server.policy.SlideTouchEvent mSlideTouchEvent;
    private boolean mTalkBackOn;
    private int mTrikeyNaviMode = -1;
    private android.view.WindowManager mWindowManager;
    private android.graphics.Point realSize = new android.graphics.Point();

    class SettingsObserver extends android.database.ContentObserver {
        SettingsObserver(android.os.Handler handler) {
            super(handler);
            registerContentObserver(android.os.UserHandle.myUserId());
            updateCurrentSettigns();
        }

        public void registerContentObserver(int userId) {
            com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("swap_key_position"), false, this, userId);
            com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("device_provisioned"), false, this, userId);
            com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("secure_gesture_navigation"), false, this, userId);
            com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("accessibility_enabled"), false, this, userId);
            com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("enabled_accessibility_services"), false, this, userId);
        }

        public void onChange(boolean selfChange) {
            updateCurrentSettigns();
        }

        private void updateCurrentSettigns() {
            boolean z = true;
            com.android.server.policy.FingerprintActionsListener.this.mDeviceProvisioned = android.provider.Settings.Secure.getIntForUser(com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver(), "device_provisioned", 0, android.app.ActivityManager.getCurrentUser()) != 0;
            com.android.server.policy.FingerprintActionsListener.this.mTrikeyNaviMode = android.provider.Settings.System.getIntForUser(com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver(), "swap_key_position", huawei.android.provider.FrontFingerPrintSettings.getDefaultNaviMode(), android.app.ActivityManager.getCurrentUser());
            com.android.server.policy.FingerprintActionsListener.this.mGestureNavEnabled = com.android.server.gesture.GestureNavConst.isGestureNavEnabled(com.android.server.policy.FingerprintActionsListener.this.mContext, -2);
            boolean accessibilityEnabled = android.provider.Settings.Secure.getIntForUser(com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver(), "accessibility_enabled", 0, -2) == 1;
            java.lang.String enabledSerices = android.provider.Settings.Secure.getStringForUser(com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver(), "enabled_accessibility_services", -2);
            boolean isContainsTalkBackService = enabledSerices != null && enabledSerices.contains("com.google.android.marvin.talkback/com.google.android.marvin.talkback.TalkBackService");
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("accessibilityEnabled:");
            stringBuilder.append(accessibilityEnabled);
            stringBuilder.append(",isContainsTalkBackService:");
            stringBuilder.append(isContainsTalkBackService);
            stringBuilder.append(",mGestureNavEnabled:");
            stringBuilder.append(com.android.server.policy.FingerprintActionsListener.this.mGestureNavEnabled);
            android.util.Log.i("FingerprintActionsListener", stringBuilder.toString());
            com.android.server.policy.FingerprintActionsListener fingerprintActionsListener = com.android.server.policy.FingerprintActionsListener.this;
            if (!accessibilityEnabled || !isContainsTalkBackService) {
                z = false;
            }
            fingerprintActionsListener.mTalkBackOn = z;
        }
    }

    private class StatusBarStatesChangedReceiver extends android.content.BroadcastReceiver {
        private StatusBarStatesChangedReceiver() {
        }

        /* synthetic */ StatusBarStatesChangedReceiver(com.android.server.policy.FingerprintActionsListener x0, com.android.server.policy.FingerprintActionsListener.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null && "com.android.systemui.statusbar.visible.change".equals(intent.getAction())) {
                com.android.server.policy.FingerprintActionsListener.this.mIsStatusBarExplaned = java.lang.Boolean.valueOf(intent.getExtras().getString("visible")).booleanValue();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mIsStatusBarExplaned = ");
                stringBuilder.append(com.android.server.policy.FingerprintActionsListener.this.mIsStatusBarExplaned);
                android.util.Log.i("FingerprintActionsListener", stringBuilder.toString());
            }
        }
    }

    public class TouchOutsideListener implements android.view.View.OnTouchListener {
        private int mMsg;

        public TouchOutsideListener(int msg, com.android.server.policy.SearchPanelView panel) {
            this.mMsg = msg;
        }

        public boolean onTouch(android.view.View v, android.view.MotionEvent ev) {
            int action = ev.getAction();
            if (action != 4) {
                if (action != 0) {
                    return false;
                }
            }
            com.android.server.policy.FingerprintActionsListener.this.mHandler.removeMessages(this.mMsg);
            com.android.server.policy.FingerprintActionsListener.this.mHandler.sendEmptyMessage(this.mMsg);
            return true;
        }
    }

    public FingerprintActionsListener(android.content.Context context, com.android.server.policy.PhoneWindowManager policy) {
        this.mContext = context;
        this.mPolicy = policy;
        updateRealSize();
        this.mWindowManager = (android.view.WindowManager) this.mContext.getSystemService("window");
        this.mSlideTouchEvent = new com.android.server.policy.SlideTouchEvent(context);
        initialDensityObserver(this.mHandler);
        this.mSettingsObserver = new com.android.server.policy.FingerprintActionsListener.SettingsObserver(this.mHandler);
        initView();
        initStatusBarReciver();
        initDriveStateReciver();
    }

    private void initialDensityObserver(android.os.Handler handler) {
        this.mDisplayDensityObserver = new android.database.ContentObserver(handler) {
            public void onChange(boolean selfChange) {
                android.util.Log.i("FingerprintActionsListener", "Density has been changed");
                com.android.server.policy.FingerprintActionsListener.this.initView();
                com.android.server.policy.FingerprintActionsListener.this.createSearchPanelView();
                com.android.server.policy.FingerprintActionsListener.this.createMultiWinArrowView();
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("display_density_forced"), false, this.mDisplayDensityObserver, android.os.UserHandle.myUserId());
    }

    private void initDriveStateReciver() {
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Global.getUriFor("vdrive_is_run_state"), false, new android.database.ContentObserver(new android.os.Handler()) {
            public void onChange(boolean selfChange) {
                int state = android.provider.Settings.Global.getInt(com.android.server.policy.FingerprintActionsListener.this.mContext.getContentResolver(), "vdrive_is_run_state", 0);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("mVDriveStateObserver onChange selfChange = ");
                stringBuilder.append(selfChange);
                stringBuilder.append("   state = ");
                stringBuilder.append(state);
                android.util.Log.i("FingerprintActionsListener", stringBuilder.toString());
                if (1 == state) {
                    com.android.server.policy.FingerprintActionsListener.this.mDriveState = true;
                } else {
                    com.android.server.policy.FingerprintActionsListener.this.mDriveState = false;
                }
            }
        });
    }

    private void initStatusBarReciver() {
        if (this.mContext != null) {
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("com.android.systemui.statusbar.visible.change");
            this.mContext.registerReceiver(new com.android.server.policy.FingerprintActionsListener.StatusBarStatesChangedReceiver(this, null), filter, "huawei.android.permission.HW_SIGNATURE_OR_SYSTEM", null);
            android.util.Log.i("FingerprintActionsListener", "initStatusBarReciver completed");
        }
    }

    private void initView() {
        android.graphics.Point screenDims = new android.graphics.Point();
        this.mWindowManager.getDefaultDisplay().getRealSize(screenDims);
        this.mSearchPanelView = (com.android.server.policy.SearchPanelView) android.view.LayoutInflater.from(this.mContext).inflate(34013255, null);
        this.mPortMultiWinArrowView = (com.android.server.policy.HwSplitScreenArrowView) android.view.LayoutInflater.from(this.mContext).inflate(34013263, null);
        if (this.mPortMultiWinArrowView != null) {
            this.mPortMultiWinArrowView.initViewParams(1, screenDims);
        }
        this.mLandMultiWinArrowView = (com.android.server.policy.HwSplitScreenArrowView) android.view.LayoutInflater.from(this.mContext).inflate(34013264, null);
        if (this.mLandMultiWinArrowView != null) {
            this.mLandMultiWinArrowView.initViewParams(2, new android.graphics.Point(screenDims.y, screenDims.x));
        }
    }

    public void createSearchPanelView() {
        if (this.mSearchPanelView != null) {
            this.mSearchPanelView.setOnTouchListener(new com.android.server.policy.FingerprintActionsListener.TouchOutsideListener(1, this.mSearchPanelView));
            this.mSearchPanelView.setVisibility(8);
            addWindowView(this.mWindowManager, this.mSearchPanelView, getSearchLayoutParams(this.mSearchPanelView.getLayoutParams()));
            this.mSearchPanelView.initUI(this.mHandler.getLooper());
        }
    }

    public void destroySearchPanelView() {
        if (this.mSearchPanelView != null) {
            removeWindowView(this.mWindowManager, this.mSearchPanelView, true);
        }
    }

    public void createMultiWinArrowView() {
        if (android.app.ActivityManager.supportsMultiWindow(this.mContext)) {
            if (this.mMultiWinArrowView != null) {
                this.mMultiWinArrowView.removeViewToWindow();
            }
            if (1 == this.mContext.getResources().getConfiguration().orientation) {
                this.mMultiWinArrowView = this.mPortMultiWinArrowView;
            } else {
                this.mMultiWinArrowView = this.mLandMultiWinArrowView;
            }
            this.mMultiWinArrowView.addViewToWindow();
        }
    }

    public void destroyMultiWinArrowView() {
        if (android.app.ActivityManager.supportsMultiWindow(this.mContext) && this.mMultiWinArrowView != null) {
            this.mMultiWinArrowView.removeViewToWindow();
        }
    }

    private void hideSearchPanelView() {
        try {
            if (this.mSearchPanelView != null) {
                this.mSearchPanelView.hideSearchPanelView();
            }
        } catch (java.lang.Exception exp) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("hideSearchPanelView");
            stringBuilder.append(exp.getMessage());
            android.util.Log.e("FingerprintActionsListener", stringBuilder.toString());
        }
    }

    private boolean isSuperPowerSaveMode() {
        return android.os.SystemProperties.getBoolean("sys.super_power_save", false);
    }

    public void setCurrentUser(int newUserId) {
        this.mSettingsObserver.registerContentObserver(newUserId);
        this.mSettingsObserver.onChange(true);
        if (this.mSlideTouchEvent != null) {
            this.mSlideTouchEvent.updateSettings();
        }
    }

    protected android.view.WindowManager.LayoutParams getSearchLayoutParams(android.view.ViewGroup.LayoutParams layoutParams) {
        android.view.WindowManager.LayoutParams lp = new android.view.WindowManager.LayoutParams(-1, -1, 2024, 8519936, -3);
        if (android.app.ActivityManager.isHighEndGfx()) {
            lp.flags |= 16777216;
        }
        lp.gravity = 8388691;
        lp.setTitle("Framework_SearchPanel");
        lp.windowAnimations = 16974590;
        lp.softInputMode = 49;
        return lp;
    }

    public void addWindowView(android.view.WindowManager mWindowManager, android.view.View view, android.view.WindowManager.LayoutParams params) {
        try {
            mWindowManager.addView(view, params);
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("the exception happen in addWindowView, e=");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("FingerprintActionsListener", stringBuilder.toString());
        }
    }

    public void removeWindowView(android.view.WindowManager mWindowManager, android.view.View view, boolean immediate) {
        if (view != null) {
            if (immediate) {
                try {
                    mWindowManager.removeViewImmediate(view);
                } catch (java.lang.IllegalArgumentException e) {
                } catch (java.lang.Exception e2) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("the exception happen in removeWindowView, e=");
                    stringBuilder.append(e2.getMessage());
                    android.util.Log.e("FingerprintActionsListener", stringBuilder.toString());
                    return;
                }
            }
            mWindowManager.removeView(view);
        }
    }

    public void onPointerEvent(android.view.MotionEvent motionEvent) {
        if (this.mDeviceProvisioned) {
            if (motionEvent.getPointerCount() == 1) {
                this.mIsSingleFlinger = true;
                this.mIsDoubleFlinger = false;
            } else if (motionEvent.getPointerCount() == 2) {
                this.mIsDoubleFlinger = true;
                this.mIsSingleFlinger = false;
                this.mIsValidLazyModeGesture = false;
                this.mIsValidHiboardGesture = false;
            } else {
                this.mIsDoubleFlinger = false;
                this.mIsSingleFlinger = false;
                this.mIsNeedHideMultiWindowView = true;
                if (this.mMultiWinArrowView != null && this.mMultiWinArrowView.getVisibility() == 0) {
                    this.mMultiWinArrowView.setVisibility(8);
                }
            }
            if (this.mIsSingleFlinger && !this.mGestureNavEnabled) {
                if (motionEvent.getActionMasked() == 0) {
                    android.util.Log.d("FingerprintActionsListener", "touchDownIsValid MotionEvent.ACTION_DOWN ");
                    touchDownIsValidLazyMode(motionEvent.getRawX(), motionEvent.getRawY());
                }
                if (this.mIsValidLazyModeGesture) {
                    this.mSlideTouchEvent.handleTouchEvent(motionEvent);
                }
                if (!(!this.mIsValidHiboardGesture || isSuperPowerSaveMode() || isInLockTaskMode() || this.mIsStatusBarExplaned || this.mDriveState)) {
                    this.mSearchPanelView.handleGesture(motionEvent);
                }
            }
            if (!(this.mIsValidHiboardGesture || motionEvent.getActionMasked() != 1 || this.mSearchPanelView == null)) {
                this.mSearchPanelView.hideSearchPanelView();
            }
            if (!(!this.mIsDoubleFlinger || this.mIsNeedHideMultiWindowView || this.mTalkBackOn)) {
                if (motionEvent.getActionMasked() == 5) {
                    android.util.Log.d("FingerprintActionsListener", "touchDownIsValidMultiWin MotionEvent.ACTION_DOWN ");
                    this.mIsValidGesture = touchDownIsValidMultiWin(motionEvent);
                }
                if (this.mIsValidGesture && this.mMultiWinArrowView != null) {
                    this.mMultiWinArrowView.handleSplitScreenGesture(motionEvent);
                    if (this.mSearchPanelView != null) {
                        this.mSearchPanelView.hideSearchPanelView();
                    }
                }
            }
            if (motionEvent.getActionMasked() == 1) {
                reset();
            }
            if (motionEvent.getActionMasked() == 6) {
                this.mIsNeedHideMultiWindowView = true;
            }
        }
    }

    private void reset() {
        this.mIsValidGesture = false;
        this.mIsValidLazyModeGesture = false;
        this.mIsValidHiboardGesture = false;
        this.mIsNeedHideMultiWindowView = false;
    }

    private boolean isNaviBarEnable() {
        return huawei.android.provider.FrontFingerPrintSettings.isNaviBarEnabled(this.mContext.getContentResolver());
    }

    private boolean canAssistEnable() {
        android.content.ContentResolver resolver = this.mContext.getContentResolver();
        boolean isNaviBarEnabled = huawei.android.provider.FrontFingerPrintSettings.isNaviBarEnabled(resolver);
        boolean isSingleNavBarAIEnable = huawei.android.provider.FrontFingerPrintSettings.isSingleNavBarAIEnable(resolver);
        boolean isSingleVirtualNavbarEnable = huawei.android.provider.FrontFingerPrintSettings.isSingleVirtualNavbarEnable(resolver);
        boolean isNavShown = android.provider.Settings.Global.getInt(resolver, "navigationbar_is_min", 0) == 0;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("canAssistEnable():isNaviBarEnabled(resolver)=");
        stringBuilder.append(isNaviBarEnabled);
        stringBuilder.append(";---isSingleNavBarAIEnable(resolver)");
        stringBuilder.append(isSingleNavBarAIEnable);
        stringBuilder.append(";isNavShown=");
        stringBuilder.append(isNavShown);
        android.util.Log.i("FingerprintActionsListener", stringBuilder.toString());
        if (isNaviBarEnabled) {
            if (!isSingleVirtualNavbarEnable || isSingleNavBarAIEnable || !isNavShown) {
                return false;
            }
        }
        return true;
    }

    private void touchDownIsValidLazyMode(float pointX, float pointY) {
        if (this.mPolicy.mDisplay != null) {
            if (!this.mPolicy.mKeyguardDelegate.isShowing() || this.mPolicy.mKeyguardDelegate.isOccluded()) {
                int HIT_REGION_TO_MAX_LAZYMODE = this.mContext.getResources().getDimensionPixelSize(17105186);
                int HIT_REGION_TO_MAX_HIBOARD = (int) (((double) this.mContext.getResources().getDimensionPixelSize(17105186)) / 4.0d);
                updateRealSize();
                if (this.isCoordinateForPad) {
                    HIT_REGION_TO_MAX_HIBOARD *= 2;
                }
                boolean z = true;
                boolean z2;
                if (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY == 1) {
                    z2 = true;
                } else {
                    z2 = false;
                }
                int i = this.mPolicy.mNavigationBarPosition;
                com.android.server.policy.PhoneWindowManager phoneWindowManager = this.mPolicy;
                int invalidPointX;
                if (i == 4) {
                    boolean isDistanceValid = pointY > ((float) (this.realSize.y - HIT_REGION_TO_MAX_LAZYMODE)) && (pointX < ((float) HIT_REGION_TO_MAX_LAZYMODE) || pointX > ((float) (this.realSize.x - HIT_REGION_TO_MAX_LAZYMODE)));
                    boolean z3 = isDistanceValid && canAssistEnable();
                    this.mIsValidLazyModeGesture = z3;
                    invalidPointX = this.realSize.x / 2;
                    int invalidPointX2 = this.realSize.y;
                    if (pointY <= ((float) (this.realSize.y - HIT_REGION_TO_MAX_HIBOARD)) || pointX == ((float) invalidPointX) || pointY == ((float) invalidPointX2) || !canAssistEnable() || (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY != 0 && (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY != 1 || this.mTrikeyNaviMode >= 0))) {
                        z = false;
                    }
                    this.mIsValidHiboardGesture = z;
                } else {
                    int invalidPointY = this.realSize.y / 2;
                    invalidPointX = this.realSize.x;
                    this.mIsValidLazyModeGesture = false;
                    if (pointX <= ((float) (this.realSize.x - HIT_REGION_TO_MAX_HIBOARD)) || pointX == ((float) invalidPointX) || pointY == ((float) invalidPointY) || !canAssistEnable() || (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY != 0 && (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY != 1 || this.mTrikeyNaviMode >= 0))) {
                        z = false;
                    }
                    this.mIsValidHiboardGesture = z;
                }
                if (this.mPolicy.isKeyguardLocked()) {
                    this.mIsValidLazyModeGesture = false;
                    this.mIsValidHiboardGesture = false;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("touchDownIsValidLazyMode = ");
                stringBuilder.append(this.mIsValidLazyModeGesture);
                stringBuilder.append("  touchDownIsValidHiBoard = ");
                stringBuilder.append(this.mIsValidHiboardGesture);
                android.util.Log.d("FingerprintActionsListener", stringBuilder.toString());
                return;
            }
        }
        this.mIsValidLazyModeGesture = false;
        this.mIsValidHiboardGesture = false;
    }

    private void updateRealSize() {
        if (this.mPolicy.mDisplay != null) {
            this.mPolicy.mDisplay.getRealSize(this.realSize);
        }
    }

    private boolean touchDownIsValidMultiWin(android.view.MotionEvent event) {
        boolean z = false;
        if (!isNaviBarEnable() && this.mPolicy.mDisplay != null && event.getPointerCount() == 2 && ((!this.mPolicy.mKeyguardDelegate.isShowing() || this.mPolicy.mKeyguardDelegate.isOccluded()) && !isSuperPowerSaveMode())) {
            if (!mDisableMultiWin) {
                boolean ret;
                float pointX0 = event.getX(0);
                float pointY0 = event.getY(0);
                float pointX1 = event.getX(1);
                float pointY1 = event.getY(1);
                int navigation_bar_height = (int) (((double) this.mContext.getResources().getDimensionPixelSize(17105186)) / 4.0d);
                if (this.isCoordinateForPad) {
                    navigation_bar_height *= 2;
                }
                updateRealSize();
                int i = this.mPolicy.mNavigationBarPosition;
                com.android.server.policy.PhoneWindowManager phoneWindowManager = this.mPolicy;
                if (i == 4) {
                    if (pointY0 > ((float) (this.realSize.y - navigation_bar_height)) && pointY1 > ((float) (this.realSize.y - navigation_bar_height))) {
                        z = true;
                    }
                    ret = z;
                } else {
                    if (pointX0 > ((float) (this.realSize.x - navigation_bar_height)) && pointX1 > ((float) (this.realSize.x - navigation_bar_height))) {
                        z = true;
                    }
                    ret = z;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("touchDownIsValidMultiWin ret = ");
                stringBuilder.append(ret);
                android.util.Log.d("FingerprintActionsListener", stringBuilder.toString());
                return ret;
            }
        }
        return false;
    }

    private boolean isInLockTaskMode() {
        return ((android.app.ActivityManager) this.mContext.getSystemService("activity")).isInLockTaskMode();
    }
}
