package com.android.server.policy;

public class HwSplitScreenArrowView extends android.widget.LinearLayout {
    private static final int DISTANCE_THRESHOLD_DIVIDE = 8;
    private static final int DURATION = 400;
    private static final int DURATION_MIN = 200;
    private static final int SCREEN_LARGE_SHORT_SIDE = 600;
    private static final java.lang.String TAG = "HwSplitScreenArrowView";
    private boolean mAdded;
    android.app.ActivityManager mAm = null;
    private float mAnimStartPos;
    private android.widget.ImageView mArrowIcon;
    private android.content.Context mContext;
    private int mDistanceThreshold;
    private boolean mDockedStackExists;
    private float[] mDownPoint = new float[2];
    android.app.IActivityManager mIam = null;
    private android.widget.TextView mInfoText;
    private boolean mIsDisabled;
    private boolean mIsMoving;
    private boolean mIsScreenLarge;
    private boolean mIsshownToast;
    private boolean mLaunchSplitScreen;
    private int mNavBarHeight;
    private int mOrientation;
    private android.view.WindowManager.LayoutParams mParams;
    private android.graphics.Point mScreenDims = new android.graphics.Point();
    private android.view.WindowManager mWindowMgr;

    public HwSplitScreenArrowView(android.content.Context context, android.util.AttributeSet attrs) {
        super(context, attrs);
        this.mContext = context;
        this.mAm = (android.app.ActivityManager) context.getSystemService("activity");
        this.mIam = android.app.ActivityManagerNative.getDefault();
        this.mWindowMgr = (android.view.WindowManager) this.mContext.getSystemService("window");
    }

    protected void onFinishInflate() {
        super.onFinishInflate();
        updateDockedStackFlag();
    }

    public void initViewParams(int orientation, android.graphics.Point screenDims) {
        this.mArrowIcon = (android.widget.ImageView) findViewById(34603137);
        this.mInfoText = (android.widget.TextView) findViewById(34603138);
        android.content.res.Resources res = this.mContext.getResources();
        this.mOrientation = orientation;
        this.mNavBarHeight = res.getDimensionPixelSize(17105186);
        this.mScreenDims = screenDims;
        this.mParams = new android.view.WindowManager.LayoutParams(-1, -1, 2014, 16777736, -3);
        if (this.mOrientation == 2) {
            this.mParams.gravity = 48;
        } else {
            this.mParams.gravity = 1;
        }
        this.mParams.width = this.mScreenDims.x;
        this.mParams.height = this.mScreenDims.y;
        this.mIsScreenLarge = isScreenLarge();
        if (this.mOrientation != 2 || this.mIsScreenLarge) {
            this.mDistanceThreshold = this.mScreenDims.y / 8;
        } else {
            this.mDistanceThreshold = this.mScreenDims.x / 8;
        }
    }

    private void updateDockedStackFlag() {
        try {
            android.view.WindowManagerGlobal.getWindowManagerService().registerDockedStackListener(new android.view.IDockedStackListener.Stub() {
                public void onDividerVisibilityChanged(boolean visible) throws android.os.RemoteException {
                }

                public void onDockedStackExistsChanged(boolean exists) throws android.os.RemoteException {
                    com.android.server.policy.HwSplitScreenArrowView.this.mDockedStackExists = exists;
                }

                public void onDockedStackMinimizedChanged(boolean minimized, long animDuration, boolean isHomeStackResizable) throws android.os.RemoteException {
                }

                public void onAdjustedForImeChanged(boolean adjustedForIme, long animDuration) throws android.os.RemoteException {
                }

                public void onDockSideChanged(int newDockSide) throws android.os.RemoteException {
                }
            });
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwSplitScreenArrowView", "Failed registering docked stack exists listener", e);
        }
    }

    private boolean isScreenLarge() {
        android.util.DisplayMetrics displayMetrics = new android.util.DisplayMetrics();
        this.mWindowMgr.getDefaultDisplay().getMetrics(displayMetrics);
        return ((float) (this.mScreenDims.x < this.mScreenDims.y ? this.mScreenDims.x : this.mScreenDims.y)) / displayMetrics.density >= 600.0f;
    }

    public void addViewToWindow() {
        try {
            if (!this.mAdded) {
                if (this.mOrientation == 2) {
                    this.mParams.x = this.mParams.width;
                } else {
                    this.mParams.y = this.mParams.height;
                }
                this.mWindowMgr.addView(this, this.mParams);
                this.mAdded = true;
            }
        } catch (java.lang.RuntimeException e) {
        }
    }

    public void removeViewToWindow() {
        try {
            if (this.mAdded) {
                this.mWindowMgr.removeView(this);
                this.mAdded = false;
            }
        } catch (java.lang.RuntimeException e) {
        }
    }

    private void moveToPositionY(float aPosY) {
        if (aPosY > ((float) (4 * this.mNavBarHeight))) {
            this.mParams.y = ((int) aPosY) - (3 * this.mNavBarHeight);
            this.mWindowMgr.updateViewLayout(this, this.mParams);
        }
    }

    private void moveToPositionX(float aPosX) {
        if (aPosX > ((float) (4 * this.mNavBarHeight))) {
            this.mParams.x = ((int) aPosX) - (3 * this.mNavBarHeight);
            this.mWindowMgr.updateViewLayout(this, this.mParams);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:21:0x009b  */
    public void handleSplitScreenGesture(android.view.MotionEvent r5) {
        /*
        r4 = this;
        r0 = "fingerTest";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "event.x=:";
        r1.append(r2);
        r2 = r5.getX();
        r1.append(r2);
        r2 = " event.y=:";
        r1.append(r2);
        r2 = r5.getY();
        r1.append(r2);
        r1 = r1.toString();
        android.util.Log.d(r0, r1);
        r0 = r5.getAction();
        r1 = 1;
        r2 = 0;
        if (r0 != 0) goto L_0x004a;
    L_0x002e:
        r0 = "fingerTest";
        r3 = "MotionEvent.ACTION_DOWN";
        android.util.Log.d(r0, r3);
        r0 = r4.mArrowIcon;
        r0.setVisibility(r2);
        r0 = r4.mDownPoint;
        r3 = r5.getX();
        r0[r2] = r3;
        r0 = r4.mDownPoint;
        r3 = r5.getY();
        r0[r1] = r3;
    L_0x004a:
        r0 = r5.getActionMasked();
        r3 = 5;
        if (r0 != r3) goto L_0x006d;
    L_0x0051:
        r0 = "fingerTest";
        r3 = "MotionEvent.ACTION_POINTER_DOWN";
        android.util.Log.d(r0, r3);
        r0 = r4.mArrowIcon;
        r0.setVisibility(r2);
        r0 = r4.mDownPoint;
        r3 = r5.getX();
        r0[r2] = r3;
        r0 = r4.mDownPoint;
        r3 = r5.getY();
        r0[r1] = r3;
    L_0x006d:
        r0 = r5.getAction();
        r3 = 2;
        if (r0 != r3) goto L_0x00a9;
    L_0x0074:
        r0 = r5.getPointerCount();
        if (r0 != r3) goto L_0x00a9;
    L_0x007a:
        r0 = r4.mIsMoving;
        if (r0 != 0) goto L_0x00a5;
    L_0x007e:
        r0 = r4.mDockedStackExists;
        if (r0 != 0) goto L_0x008a;
    L_0x0082:
        r0 = r4.isTopTaskHome();
        if (r0 == 0) goto L_0x0089;
    L_0x0088:
        goto L_0x008a;
    L_0x0089:
        goto L_0x008b;
    L_0x008a:
        r2 = r1;
    L_0x008b:
        r4.mIsDisabled = r2;
        r0 = r4.mInfoText;
        r2 = 33685889; // 0x2020181 float:9.551323E-38 double:1.66430405E-316;
        r0.setText(r2);
        r0 = r4.isTopTaskHome();
        if (r0 == 0) goto L_0x00a3;
    L_0x009b:
        r0 = r4.mContext;
        r2 = 33685923; // 0x20201a3 float:9.551361E-38 double:1.66430573E-316;
        r4.showToastForAllUser(r0, r2);
    L_0x00a3:
        r4.mIsMoving = r1;
    L_0x00a5:
        r4.processFingerMoveEvent(r5);
        goto L_0x00ca;
    L_0x00a9:
        r0 = r5.getActionMasked();
        r1 = 6;
        if (r0 != r1) goto L_0x00bb;
    L_0x00b0:
        r0 = "fingerTest";
        r1 = "MotionEvent.ACTION_UP";
        android.util.Log.d(r0, r1);
        r4.enterSplitScreenMode();
        goto L_0x00ca;
    L_0x00bb:
        r0 = r5.getAction();
        r1 = 3;
        if (r0 != r1) goto L_0x00ca;
    L_0x00c2:
        r4.reset();
        r0 = 8;
        r4.setVisibility(r0);
    L_0x00ca:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.policy.HwSplitScreenArrowView.handleSplitScreenGesture(android.view.MotionEvent):void");
    }

    private void processFingerMoveEvent(android.view.MotionEvent event) {
        if (this.mIsDisabled) {
            android.util.Log.d("fingerTest", "no response for finger move event");
            return;
        }
        float lDistance;
        if (this.mIsScreenLarge || this.mOrientation != 2) {
            lDistance = this.mDownPoint[1] - event.getY();
        } else {
            lDistance = this.mDownPoint[0] - event.getX();
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("lDistance = :");
        stringBuilder.append(lDistance);
        android.util.Log.d("fingerTest", stringBuilder.toString());
        if (lDistance < ((float) this.mNavBarHeight)) {
            android.util.Log.d("fingerTest", "return since swipe distance too closely");
        } else if (isTopTaskSupportMultiWindow()) {
            if (lDistance > ((float) this.mDistanceThreshold)) {
                this.mInfoText.setVisibility(0);
                this.mLaunchSplitScreen = true;
            } else {
                this.mInfoText.setVisibility(4);
                this.mLaunchSplitScreen = false;
            }
            if (1 == this.mOrientation || !this.mIsScreenLarge) {
                setVisibility(0);
            }
            if (this.mIsScreenLarge || this.mOrientation != 2) {
                this.mAnimStartPos = event.getRawY();
                moveToPositionY(this.mAnimStartPos);
            } else {
                this.mAnimStartPos = event.getRawX();
                moveToPositionX(this.mAnimStartPos);
            }
        } else {
            showToast();
        }
    }

    private void reset() {
        this.mLaunchSplitScreen = false;
        this.mIsshownToast = false;
        this.mIsMoving = false;
    }

    public void enterSplitScreenMode() {
        if (getVisibility() == 0) {
            animateView(this.mAnimStartPos, this.mLaunchSplitScreen);
        }
        if (this.mLaunchSplitScreen) {
            toggleSplitScreen();
        }
        reset();
    }

    private void showToast() {
        if (!this.mIsshownToast) {
            showToastForAllUser(this.mContext, 33685924);
            this.mIsshownToast = true;
        }
    }

    private void animateView(float aPos, boolean islaunchingMultiWindow) {
        if (aPos <= 0.0f) {
            setVisibility(8);
            return;
        }
        float aMin = (float) (4 * this.mNavBarHeight);
        float aMax = (float) (this.mOrientation == 2 ? this.mScreenDims.x : this.mScreenDims.y);
        int dividerHeight = this.mContext.getResources().getDimensionPixelSize(34472140);
        if (islaunchingMultiWindow) {
            if (this.mOrientation == 2) {
                aMax = (((float) (this.mScreenDims.x - dividerHeight)) / 2.0f) + ((float) this.mNavBarHeight);
            } else {
                aMax = (((float) (this.mScreenDims.y - dividerHeight)) / 2.0f) + ((float) this.mNavBarHeight);
            }
        }
        android.animation.PropertyValuesHolder animValue = android.animation.PropertyValuesHolder.ofFloat("value", new float[]{aPos > aMin ? aPos : aMin, aMax});
        android.animation.ValueAnimator animation = android.animation.ValueAnimator.ofPropertyValuesHolder(new android.animation.PropertyValuesHolder[]{animValue});
        int duration = (int) (1137180672 * (java.lang.Math.abs(aMax - aPos) / (aMax / 2.0f)));
        int i = 200;
        if (duration > 200) {
            i = duration;
        }
        animation.setDuration((long) i);
        animation.addUpdateListener(new android.animation.ValueAnimator.AnimatorUpdateListener() {
            public void onAnimationUpdate(android.animation.ValueAnimator animation) {
                java.lang.Object object = animation.getAnimatedValue("value");
                if (object != null) {
                    float lValue = ((java.lang.Float) object).floatValue();
                    if (com.android.server.policy.HwSplitScreenArrowView.this.mOrientation == 2) {
                        com.android.server.policy.HwSplitScreenArrowView.this.mParams.x = ((int) lValue) - (3 * com.android.server.policy.HwSplitScreenArrowView.this.mNavBarHeight);
                    } else {
                        com.android.server.policy.HwSplitScreenArrowView.this.mParams.y = ((int) lValue) - (3 * com.android.server.policy.HwSplitScreenArrowView.this.mNavBarHeight);
                    }
                    if (com.android.server.policy.HwSplitScreenArrowView.this.mWindowMgr != null) {
                        try {
                            com.android.server.policy.HwSplitScreenArrowView.this.mWindowMgr.updateViewLayout(com.android.server.policy.HwSplitScreenArrowView.this, com.android.server.policy.HwSplitScreenArrowView.this.mParams);
                        } catch (java.lang.IllegalArgumentException exp) {
                            android.util.Log.e("HwSplitScreenArrowView", exp.getMessage());
                        }
                    }
                }
            }
        });
        animation.addListener(new android.animation.Animator.AnimatorListener() {
            public void onAnimationStart(android.animation.Animator animation) {
                com.android.server.policy.HwSplitScreenArrowView.this.mArrowIcon.setVisibility(4);
                com.android.server.policy.HwSplitScreenArrowView.this.mInfoText.setVisibility(4);
            }

            public void onAnimationRepeat(android.animation.Animator animation) {
            }

            public void onAnimationEnd(android.animation.Animator animation) {
                com.android.server.policy.HwSplitScreenArrowView.this.setVisibility(8);
            }

            public void onAnimationCancel(android.animation.Animator animation) {
                com.android.server.policy.HwSplitScreenArrowView.this.setVisibility(8);
            }
        });
        animation.start();
    }

    private void toggleSplitScreen() {
        android.util.Flog.bdReport(this.mContext, 12);
        android.util.Log.d("fingerTest", "ready to toggle split screen");
        ((com.android.server.statusbar.StatusBarManagerInternal) com.android.server.LocalServices.getService(com.android.server.statusbar.StatusBarManagerInternal.class)).toggleSplitScreen();
    }

    private boolean isTopTaskHome() {
        if (this.mAm == null) {
            return false;
        }
        java.util.List<android.app.ActivityManager.RunningTaskInfo> tasks = this.mAm.getRunningTasks(1);
        if (tasks == null || tasks.isEmpty()) {
            return false;
        }
        return isInHomeStack((android.app.ActivityManager.RunningTaskInfo) tasks.get(0));
    }

    private boolean isTopTaskSupportMultiWindow() {
        android.app.ActivityManager.RunningTaskInfo topTask = getTopMostTask();
        if (topTask == null || isInHomeStack(topTask) || isScreenPinningActive() || !topTask.supportsSplitScreenMultiWindow) {
            return false;
        }
        return true;
    }

    private boolean isScreenPinningActive() {
        if (this.mIam == null) {
            return false;
        }
        try {
            return this.mIam.isInLockTaskMode();
        } catch (android.os.RemoteException e) {
            return false;
        }
    }

    private java.util.List<android.app.ActivityManager.RunningTaskInfo> getRunningTasks(int numTasks) {
        if (this.mAm == null) {
            return null;
        }
        return this.mAm.getRunningTasks(numTasks);
    }

    private android.app.ActivityManager.RunningTaskInfo getTopMostTask() {
        java.util.List<android.app.ActivityManager.RunningTaskInfo> tasks = getRunningTasks(1);
        if (tasks == null || tasks.isEmpty()) {
            return null;
        }
        return (android.app.ActivityManager.RunningTaskInfo) tasks.get(0);
    }

    private boolean isInHomeStack(android.app.ActivityManager.RunningTaskInfo runningTask) {
        boolean z = false;
        if (runningTask == null) {
            return false;
        }
        if (runningTask.configuration.windowConfiguration.getActivityType() == 2) {
            z = true;
        }
        return z;
    }

    private void showToastForAllUser(android.content.Context mContext, int message) {
        if (mContext != null) {
            android.widget.Toast toast = android.widget.Toast.makeText(mContext, message, null);
            android.view.WindowManager.LayoutParams windowParams = toast.getWindowParams();
            windowParams.privateFlags |= 16;
            toast.show();
        }
    }
}
