package com.android.server.policy;

public class NavigationBarPolicy implements android.view.GestureDetector.OnGestureListener {
    static final boolean DEBUG = false;
    private static final boolean FRONT_FINGERPRINT_NAVIGATION = android.os.SystemProperties.getBoolean("ro.config.hw_front_fp_navi", false);
    static final int HIT_REGION_SCALE = 4;
    static int HIT_REGION_TO_MAX = 20;
    static int HIT_REGION_TO_TOP_BOTTOM = 130;
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    private static final java.lang.String TAG = "NavigationBarPolicy";
    private boolean IS_SUPPORT_PRESSURE;
    private android.content.Context mContext = null;
    private android.view.GestureDetector mDetector = null;
    boolean mForceMinNavigationBar;
    private int mHoleHeight;
    private boolean mImmersiveMode;
    private boolean mIsValidGesture;
    boolean mMinNavigationBar;
    private com.android.server.policy.PhoneWindowManager mPolicy = null;
    private android.graphics.Point realSize;

    public NavigationBarPolicy(android.content.Context context, com.android.server.policy.PhoneWindowManager policy) {
        boolean z = false;
        this.mMinNavigationBar = false;
        this.mForceMinNavigationBar = false;
        this.mIsValidGesture = false;
        this.IS_SUPPORT_PRESSURE = false;
        this.mImmersiveMode = false;
        this.realSize = new android.graphics.Point();
        this.mHoleHeight = 0;
        this.mContext = context;
        this.mPolicy = policy;
        this.mDetector = new android.view.GestureDetector(context, this);
        if (android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "navigationbar_is_min", 0) != 0) {
            z = true;
        }
        this.mMinNavigationBar = z;
        updateRealSize();
        this.IS_SUPPORT_PRESSURE = huawei.android.os.HwGeneralManager.getInstance().isSupportForce();
        parseHole();
    }

    public void addPointerEvent(android.view.MotionEvent event) {
        this.mDetector.onTouchEvent(event);
    }

    private void reset() {
        this.mIsValidGesture = false;
    }

    public void setImmersiveMode(boolean mode) {
        this.mImmersiveMode = mode;
    }

    private boolean touchDownIsValid(float pointX, float pointY) {
        boolean z = false;
        if (!(this.mPolicy.mDisplay == null || this.mForceMinNavigationBar)) {
            if (!this.mPolicy.mKeyguardDelegate.isShowing() || this.mPolicy.mKeyguardDelegate.isOccluded()) {
                if (this.IS_SUPPORT_PRESSURE && !IS_CHINA_AREA && !this.mImmersiveMode) {
                    return false;
                }
                boolean ret = false;
                HIT_REGION_TO_MAX = (int) (((double) this.mContext.getResources().getDimensionPixelSize(17105186)) / 3.5d);
                if (this.mMinNavigationBar) {
                    updateRealSize();
                    int i = this.mPolicy.mNavigationBarPosition;
                    com.android.server.policy.PhoneWindowManager phoneWindowManager = this.mPolicy;
                    if (i == 4) {
                        if (pointY > ((float) (this.realSize.y - HIT_REGION_TO_MAX))) {
                            z = true;
                        }
                        ret = z;
                    } else if (isNaviBarNearByHole()) {
                        if (pointX > ((float) ((this.realSize.x - this.mHoleHeight) - HIT_REGION_TO_MAX))) {
                            z = true;
                        }
                        ret = z;
                    } else {
                        if (pointX > ((float) (this.realSize.x - HIT_REGION_TO_MAX))) {
                            z = true;
                        }
                        ret = z;
                    }
                }
                return ret;
            }
        }
        return false;
    }

    private void updateRealSize() {
        if (this.mPolicy.mDisplay != null) {
            this.mPolicy.mDisplay.getRealSize(this.realSize);
        }
    }

    public void updateNavigationBar(boolean minNaviBar) {
        this.mMinNavigationBar = minNaviBar;
        android.provider.Settings.Global.putInt(this.mContext.getContentResolver(), "navigationbar_is_min", minNaviBar);
        this.mPolicy.mWindowManagerFuncs.reevaluateStatusBarSize(true);
    }

    private void sendBroadcast(boolean minNaviBar) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("sendBroadcast minNaviBar = ");
        stringBuilder.append(minNaviBar);
        android.util.HwSlog.d("NavigationBarPolicy", stringBuilder.toString());
        android.content.Intent intent = new android.content.Intent("com.huawei.navigationbar.statuschange");
        intent.putExtra("minNavigationBar", minNaviBar);
        this.mContext.sendBroadcastAsUser(intent, android.os.UserHandle.ALL);
        com.huawei.android.statistical.StatisticalUtils.reportc(this.mContext, 61);
    }

    public boolean onDown(android.view.MotionEvent event) {
        this.mIsValidGesture = touchDownIsValid(event.getRawX(), event.getRawY());
        return false;
    }

    public boolean onFling(android.view.MotionEvent e1, android.view.MotionEvent e2, float velocityX, float velocityY) {
        if (isFlingOnFrontNaviMode() && !isInLockTaskMode()) {
            android.util.HwSlog.d("NavigationBarPolicy", "onFling::FRONT_FINGERPRINT_NAVIGATION, return! ");
            return false;
        } else if (isGestureNavigationEnable()) {
            android.util.HwSlog.d("NavigationBarPolicy", "onFling::Gest_Navigation_Enable, return! ");
            return false;
        } else if (android.hdm.HwDeviceManager.disallowOp(103)) {
            return false;
        } else {
            boolean z = true;
            if (this.IS_SUPPORT_PRESSURE && IS_CHINA_AREA) {
                boolean ret = false;
                if (this.mMinNavigationBar) {
                    float pointX = e2.getX();
                    float pointY = e2.getY();
                    int i = this.mPolicy.mNavigationBarPosition;
                    com.android.server.policy.PhoneWindowManager phoneWindowManager = this.mPolicy;
                    if (i == 4) {
                        ret = pointY < ((float) (this.realSize.y - HIT_REGION_TO_TOP_BOTTOM));
                    } else if (isNaviBarNearByHole()) {
                        ret = pointX < ((float) ((this.realSize.x - this.mHoleHeight) - HIT_REGION_TO_TOP_BOTTOM));
                    } else {
                        ret = pointX < ((float) (this.realSize.x - HIT_REGION_TO_TOP_BOTTOM));
                    }
                }
                if (!ret) {
                    android.util.HwSlog.d("NavigationBarPolicy", "onFling::move distance is not enough, return! ");
                    return false;
                }
            }
            if (this.mIsValidGesture) {
                if (!android.vkey.SettingsHelper.isTouchPlusOn(this.mContext)) {
                    int i2 = this.mPolicy.mNavigationBarPosition;
                    com.android.server.policy.PhoneWindowManager phoneWindowManager2 = this.mPolicy;
                    if (i2 == 4) {
                        if (e1.getRawY() >= e2.getRawY()) {
                            z = false;
                        }
                        sendBroadcast(z);
                    } else {
                        if (e1.getRawX() >= e2.getRawX()) {
                            z = false;
                        }
                        sendBroadcast(z);
                    }
                    reset();
                    return false;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("onFling::not valid gesture or touch plus on, ");
            stringBuilder.append(this.mIsValidGesture);
            stringBuilder.append(", return!");
            android.util.HwSlog.d("NavigationBarPolicy", stringBuilder.toString());
            return false;
        }
    }

    private boolean isFlingOnFrontNaviMode() {
        return "normal".equals(android.os.SystemProperties.get("ro.runmode", "normal")) && FRONT_FINGERPRINT_NAVIGATION && !isNaviBarEnabled();
    }

    private boolean isNaviBarEnabled() {
        if (this.mContext == null) {
            return true;
        }
        boolean isNaviBarEnable = huawei.android.provider.FrontFingerPrintSettings.isNaviBarEnabled(this.mContext.getContentResolver());
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isNaviBarEnable is: ");
        stringBuilder.append(isNaviBarEnable);
        android.util.Log.d("NavigationBarPolicy", stringBuilder.toString());
        return isNaviBarEnable;
    }

    private boolean isGestureNavigationEnable() {
        if (this.mContext != null) {
            return huawei.android.provider.FrontFingerPrintSettings.isGestureNavigationMode(this.mContext.getContentResolver());
        }
        return false;
    }

    private boolean isInLockTaskMode() {
        android.app.ActivityManager mActivityManager = (android.app.ActivityManager) this.mContext.getSystemService("activity");
        if (huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION && huawei.android.provider.FrontFingerPrintSettings.FRONT_FINGERPRINT_NAVIGATION_TRIKEY == 0 && mActivityManager.isInLockTaskMode()) {
            return true;
        }
        return false;
    }

    public void onLongPress(android.view.MotionEvent arg0) {
    }

    public boolean onScroll(android.view.MotionEvent arg0, android.view.MotionEvent arg1, float arg2, float arg3) {
        return false;
    }

    public void onShowPress(android.view.MotionEvent arg0) {
    }

    public boolean onSingleTapUp(android.view.MotionEvent arg0) {
        reset();
        return false;
    }

    private void parseHole() {
        java.lang.String[] props = android.os.SystemProperties.get("ro.config.hw_notch_size", "").split(",");
        if (props != null && props.length == 4) {
            this.mHoleHeight = java.lang.Integer.parseInt(props[1]);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mHoleHeight = ");
            stringBuilder.append(this.mHoleHeight);
            android.util.Log.d("NavigationBarPolicy", stringBuilder.toString());
        }
    }

    private boolean isNaviBarNearByHole() {
        if (this.mHoleHeight <= 0 || this.mPolicy.mScreenRotation != 3) {
            return false;
        }
        return true;
    }
}
