package com.android.server.policy;

public class PickUpWakeScreenManager {
    private static final java.lang.String ACTION_PICKUP_FACEDETECT = "huawei.intent.action.PICKUP_FACEDETECT";
    private static final int CAN_DISABLE_MOTION = 0;
    private static final int CAN_ENBALE_MOTION = 1;
    private static final boolean CHECK_PROXIMITY_SENSOR_ABSENT = true;
    private static final boolean DEBUG;
    private static final android.net.Uri HWMOTIONS_CONTENT_URI = android.net.Uri.parse("content://com.huawei.providers.motions/hwmotions");
    public static final java.lang.String MOTION_PICKUP_WAKEUP_DEVICE = "motion_pickup_wakeup_device";
    private static final int MSG_RECORD_WAKEUP = 2;
    private static final int MSG_WAIT_PROXIMITY_SENSOR_TIMEOUT = 1;
    private static final java.lang.String PERMISSION_PICKUP_FACEDETECT = "com.huawei.services.permission.PICKUP_FACEDETECT";
    private static int SCREEN_OFF_TIME_WITHOUT_TOUCH = 5000;
    private static final java.lang.String TAG = "PickUpWakeScreenManager";
    private static final float TYPICAL_PROXIMITY_THRESHOLD = 5.0f;
    private static final long WAIT_PROXIMITY_SENSOR_TIMEOUT = 500;
    private static final java.lang.String WAKEUP_REASON = "WakeUpReason";
    private static java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.policy.PickUpWakeScreenManager mPickUpWakeScreenManager;
    private static final int[] mSensorsPickup = new int[]{1};
    private static final boolean sSupportFaceRecognition = android.os.SystemProperties.getBoolean("ro.config.face_recognition", false);
    private android.content.Context mContext;
    private boolean mFirstBoot = true;
    private com.huawei.hwextdevice.HWExtDeviceEventListener mHWEDListener = new com.huawei.hwextdevice.HWExtDeviceEventListener() {
        public void onDeviceDataChanged(com.huawei.hwextdevice.HWExtDeviceEvent hwextDeviceEvent) {
            android.util.Slog.d("PickUpWakeScreenManager", "onDeviceDataChanged");
            if (!com.android.server.policy.PickUpWakeScreenManager.this.mIsPickupSupport) {
                android.util.Slog.d("PickUpWakeScreenManager", "mIsPickupSwitchOn is disable");
            } else if (hwextDeviceEvent.getDeviceValues() == null) {
                android.util.Slog.d("PickUpWakeScreenManager", "onDeviceDataChanged  deviceValues is null ");
            } else if (com.android.server.policy.PickUpWakeScreenManager.this.mIsPickupSwitchOn) {
                com.android.server.policy.PickUpWakeScreenManager.this.wakeupScreenOnIfNeeded(com.android.server.policy.PickUpWakeScreenManager.this.mContext);
            } else {
                android.util.Slog.d("PickUpWakeScreenManager", "mIsPickupSwitchOn is off");
            }
        }
    };
    private com.huawei.hwextdevice.HWExtDeviceManager mHWEDManager = null;
    private com.huawei.hwextdevice.devices.HWExtMotion mHWExtMotion = null;
    private android.os.Handler mHandler;
    private boolean mInFastScreenOn = false;
    private boolean mIsPickupSupport = false;
    private boolean mIsPickupSwitchOn = false;
    private com.android.server.policy.keyguard.KeyguardServiceDelegate mKgDelegate;
    private int mMotionRegistState = 1;
    private boolean mNeedControlTurnOff = false;
    private android.database.ContentObserver mPickupEnabledObserver = new android.database.ContentObserver(new android.os.Handler()) {
        public void onChange(boolean selfChange) {
            android.util.Slog.d("PickUpWakeScreenManager", "PickupEnabledObserver");
            com.android.server.policy.PickUpWakeScreenManager.this.observePickupSwitchState();
        }
    };
    public final java.lang.Runnable mPickupMotionTimeoutRunnable = new java.lang.Runnable() {
        public void run() {
            android.os.PowerManager pm = (android.os.PowerManager) com.android.server.policy.PickUpWakeScreenManager.this.mContext.getSystemService("power");
            if (pm != null && pm.isScreenOn()) {
                pm.goToSleep(android.os.SystemClock.uptimeMillis());
                android.util.Slog.d("PickUpWakeScreenManager", "ScreenOff because pickup motion");
            }
        }
    };
    private boolean mPointerListerInitState = false;
    private android.os.Handler mProximityHandler;
    private android.hardware.Sensor mProximitySensor;
    private boolean mProximitySensorEnabled;
    private final android.hardware.SensorEventListener mProximitySensorListener = new android.hardware.SensorEventListener() {
        public void onSensorChanged(android.hardware.SensorEvent event) {
            if (com.android.server.policy.PickUpWakeScreenManager.this.mProximitySensorEnabled) {
                boolean positive = false;
                float distance = event.values[0];
                if (distance >= 0.0f && distance < com.android.server.policy.PickUpWakeScreenManager.this.mProximityThreshold) {
                    positive = true;
                }
                if (com.android.server.policy.PickUpWakeScreenManager.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onSensorChanged distance=");
                    stringBuilder.append(distance);
                    stringBuilder.append(",positive=");
                    stringBuilder.append(positive);
                    stringBuilder.append(",sensorEnabled=");
                    stringBuilder.append(com.android.server.policy.PickUpWakeScreenManager.this.mProximitySensorEnabled);
                    android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
                }
                com.android.server.policy.PickUpWakeScreenManager.this.handleProximitySensorEvent(positive);
            }
        }

        public void onAccuracyChanged(android.hardware.Sensor sensor, int accuracy) {
        }
    };
    private float mProximityThreshold;
    private android.content.ContentResolver mResolver;
    private com.android.server.policy.PickUpWakeScreenManager.ScreenTouchEventListener mScreenTouchEventListener = null;
    private final android.hardware.SensorManager mSensorManager;
    private android.content.BroadcastReceiver mUserSwitchReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            android.util.Slog.d("PickUpWakeScreenManager", "on receive userSwitchReceiver");
            com.android.server.policy.PickUpWakeScreenManager.this.observePickupSwitchState();
        }
    };
    private com.android.server.policy.WindowManagerPolicy.WindowManagerFuncs mWindowManagerFuncs;
    private boolean trunOffTimeOutEnable = false;

    private class ProximityHandler extends android.os.Handler {
        public ProximityHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            switch (msg.what) {
                case 1:
                    android.util.Slog.i("PickUpWakeScreenManager", "wait proximity sensor timeout(more than 500ms).");
                    com.android.server.policy.PickUpWakeScreenManager.this.setProximitySensorEnabled(false);
                    com.android.server.policy.PickUpWakeScreenManager.this.stopWakeUpReady(com.android.server.policy.PickUpWakeScreenManager.this.mContext, true);
                    return;
                case 2:
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Face Dectect wakeUpInternal type:");
                    stringBuilder.append(msg.obj);
                    android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
                    android.provider.Settings.Global.putString(com.android.server.policy.PickUpWakeScreenManager.this.mContext.getContentResolver(), "WakeUpReason", msg.obj == null ? "unknow" : msg.obj.toString());
                    return;
                default:
                    return;
            }
        }
    }

    private class ScreenTouchEventListener implements android.view.WindowManagerPolicyConstants.PointerEventListener {
        private ScreenTouchEventListener() {
        }

        /* synthetic */ ScreenTouchEventListener(com.android.server.policy.PickUpWakeScreenManager x0, com.android.server.policy.PickUpWakeScreenManager.AnonymousClass1 x1) {
            this();
        }

        public void onPointerEvent(android.view.MotionEvent motionEvent) {
            if (com.android.server.policy.PickUpWakeScreenManager.this.mPickupMotionTimeoutRunnable != null && com.android.server.policy.PickUpWakeScreenManager.this.trunOffTimeOutEnable) {
                com.android.server.policy.PickUpWakeScreenManager.this.mHandler.removeCallbacks(com.android.server.policy.PickUpWakeScreenManager.this.mPickupMotionTimeoutRunnable);
                com.android.server.policy.PickUpWakeScreenManager.this.trunOffTimeOutEnable = false;
                android.util.Slog.d("PickUpWakeScreenManager", "ScreenTouchEventListener remove");
            }
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("PickUpWakeScreenManager", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public static com.android.server.policy.PickUpWakeScreenManager getInstance(android.content.Context context, android.os.Handler handler, com.android.server.policy.WindowManagerPolicy.WindowManagerFuncs windowManagerFuncs, com.android.server.policy.keyguard.KeyguardServiceDelegate KeyguardDelegate) {
        com.android.server.policy.PickUpWakeScreenManager pickUpWakeScreenManager;
        synchronized (mLock) {
            if (mPickUpWakeScreenManager == null) {
                mPickUpWakeScreenManager = new com.android.server.policy.PickUpWakeScreenManager(context, handler, windowManagerFuncs, KeyguardDelegate);
            }
            pickUpWakeScreenManager = mPickUpWakeScreenManager;
        }
        return pickUpWakeScreenManager;
    }

    public static com.android.server.policy.PickUpWakeScreenManager getInstance() {
        com.android.server.policy.PickUpWakeScreenManager pickUpWakeScreenManager;
        synchronized (mLock) {
            pickUpWakeScreenManager = mPickUpWakeScreenManager;
        }
        return pickUpWakeScreenManager;
    }

    public void stopTrunOffScrren() {
        if (this.mPickupMotionTimeoutRunnable != null && this.trunOffTimeOutEnable) {
            this.mHandler.removeCallbacks(this.mPickupMotionTimeoutRunnable);
            this.trunOffTimeOutEnable = false;
            android.util.Slog.d("PickUpWakeScreenManager", "stopTrunOffScrren remove mPickupMotionTimeout");
        }
    }

    public PickUpWakeScreenManager(android.content.Context context, android.os.Handler handler, com.android.server.policy.WindowManagerPolicy.WindowManagerFuncs windowManagerFuncs, com.android.server.policy.keyguard.KeyguardServiceDelegate KeyguardDelegate) {
        this.mContext = context;
        this.mHandler = handler;
        this.mWindowManagerFuncs = windowManagerFuncs;
        this.mResolver = this.mContext.getContentResolver();
        this.mProximityHandler = new com.android.server.policy.PickUpWakeScreenManager.ProximityHandler(handler.getLooper());
        this.mSensorManager = (android.hardware.SensorManager) this.mContext.getSystemService("sensor");
        this.mProximitySensor = this.mSensorManager.getDefaultSensor(8);
        if (this.mProximitySensor != null) {
            float f = 5.0f;
            if (this.mProximitySensor.getMaximumRange() < 5.0f) {
                f = this.mProximitySensor.getMaximumRange();
            }
            this.mProximityThreshold = f;
        }
        this.mContext.registerReceiverAsUser(this.mUserSwitchReceiver, android.os.UserHandle.ALL, new android.content.IntentFilter("android.intent.action.USER_SWITCHED"), null, null);
        this.mKgDelegate = KeyguardDelegate;
    }

    public void pickUpWakeScreenInit() {
        this.mIsPickupSupport = getPickupWakeEnabled();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mIsPickupSupport = ");
        stringBuilder.append(this.mIsPickupSupport);
        android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
        this.mNeedControlTurnOff = getSupportFaceDectect() ^ 1;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mNeedControlTurnOff = ");
        stringBuilder.append(this.mNeedControlTurnOff);
        android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
        com.huawei.motiondetection.MRUtils.observerMotionEnableStateChange(this.mContext, this.mPickupEnabledObserver, -1);
        if (this.mIsPickupSupport) {
            this.mHWEDManager = com.huawei.hwextdevice.HWExtDeviceManager.getInstance(this.mContext);
            this.mHWExtMotion = new com.huawei.hwextdevice.devices.HWExtMotion(100);
            this.mScreenTouchEventListener = new com.android.server.policy.PickUpWakeScreenManager.ScreenTouchEventListener(this, null);
        }
    }

    public static boolean isPickupSensorSupport(android.content.Context context) {
        boolean isSensorSupport = true;
        android.hardware.SensorManager mSensorManager = (android.hardware.SensorManager) context.getSystemService("sensor");
        java.util.ArrayList<java.lang.Integer> mSensorTypeList = new java.util.ArrayList();
        java.util.List<android.hardware.Sensor> list = mSensorManager.getSensorList(-1);
        int i = 0;
        for (int i2 = 0; i2 < list.size(); i2++) {
            mSensorTypeList.add(java.lang.Integer.valueOf(((android.hardware.Sensor) list.get(i2)).getType()));
        }
        while (i < mSensorsPickup.length) {
            if (!mSensorTypeList.contains(java.lang.Integer.valueOf(mSensorsPickup[i]))) {
                isSensorSupport = false;
                break;
            }
            i++;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isPickupSensorSupport isSensorSupport = ");
        stringBuilder.append(isSensorSupport);
        android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
        return isSensorSupport;
    }

    public void enablePickupMotionOrNot(boolean isLocked) {
        if (this.mIsPickupSupport) {
            if (this.mFirstBoot) {
                int motionPickUp = com.huawei.motiondetection.MRUtils.getMotionEnableStateAsUser(this.mContext, "motion_pickup_wakeup_device", android.app.ActivityManager.getCurrentUser());
                if (motionPickUp != -1) {
                    boolean z = true;
                    if (motionPickUp != 1) {
                        z = false;
                    }
                    this.mIsPickupSwitchOn = z;
                    this.mFirstBoot = false;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mIsPickupSwitchOn = ");
            stringBuilder.append(this.mIsPickupSwitchOn);
            android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
            if (android.provider.Settings.Secure.getIntForUser(this.mResolver, "device_provisioned", 0, android.app.ActivityManager.getCurrentUser()) == 0) {
                android.util.Slog.d("PickUpWakeScreenManager", "Device is in Provision");
                return;
            } else if (this.mIsPickupSwitchOn) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("isLocked = ");
                stringBuilder2.append(isLocked);
                android.util.Slog.d("PickUpWakeScreenManager", stringBuilder2.toString());
                if (isLocked) {
                    enablePickupMotion(this.mHandler);
                } else {
                    disablePickupMotion();
                }
                return;
            } else {
                return;
            }
        }
        android.util.Slog.d("PickUpWakeScreenManager", "mIsPickupSwitchOn is disable");
    }

    private void enablePickupMotion(android.os.Handler handler) {
        if (this.mMotionRegistState == 0) {
            android.util.Slog.d("PickUpWakeScreenManager", "can not regist twice");
        } else if (this.mHWEDManager != null) {
            this.mHWEDManager.registerDeviceListener(this.mHWEDListener, this.mHWExtMotion, handler);
            android.util.Slog.d("PickUpWakeScreenManager", "regist listener");
            if (this.mScreenTouchEventListener != null) {
                if (this.mPointerListerInitState) {
                    this.mWindowManagerFuncs.unregisterPointerEventListener(this.mScreenTouchEventListener);
                } else {
                    this.mPointerListerInitState = true;
                }
                this.mScreenTouchEventListener = null;
                android.util.Slog.d("PickUpWakeScreenManager", "unregisterPointerEventListener");
                this.mMotionRegistState = 0;
            }
        } else {
            android.util.Slog.d("PickUpWakeScreenManager", "mHWEDManager is null, return");
        }
    }

    private void disablePickupMotion() {
        if (this.mMotionRegistState == 1) {
            android.util.Slog.d("PickUpWakeScreenManager", "can not unregist without regist");
        } else if (this.mHWEDManager != null) {
            if (this.mScreenTouchEventListener == null) {
                this.mScreenTouchEventListener = new com.android.server.policy.PickUpWakeScreenManager.ScreenTouchEventListener(this, null);
            }
            this.mWindowManagerFuncs.registerPointerEventListener(this.mScreenTouchEventListener);
            android.util.Slog.d("PickUpWakeScreenManager", "registerPointerEventListener");
            this.mMotionRegistState = 1;
        } else {
            android.util.Slog.d("PickUpWakeScreenManager", " mHWEDManager is null,return ");
        }
    }

    private void triggerFaceDetect(java.lang.String reason) {
        if (this.mKgDelegate != null) {
            this.mKgDelegate.doFaceRecognize(true, reason);
        }
    }

    private void wakeupScreenOnIfNeeded(android.content.Context context) {
        android.os.PowerManager pm = (android.os.PowerManager) context.getSystemService("power");
        if (pm == null) {
            android.util.Slog.d("PickUpWakeScreenManager", "pm is null");
        } else if (pm.isScreenOn()) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("screen on =");
            stringBuilder.append(pm.isScreenOn());
            android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
            triggerFaceDetect("PICKUP:SC_ON");
        } else {
            triggerFaceDetect("PICKUP:SC_OFF");
            wakeUpWaitForProximity();
            if (this.mNeedControlTurnOff) {
                this.mHandler.removeCallbacks(this.mPickupMotionTimeoutRunnable);
                this.mHandler.postDelayed(this.mPickupMotionTimeoutRunnable, (long) SCREEN_OFF_TIME_WITHOUT_TOUCH);
                this.trunOffTimeOutEnable = true;
            }
        }
    }

    private void setProximitySensorEnabled(boolean enable) {
        if (enable) {
            if (!this.mProximitySensorEnabled) {
                this.mProximitySensorEnabled = true;
                this.mSensorManager.registerListener(this.mProximitySensorListener, this.mProximitySensor, 3, this.mProximityHandler);
                this.mProximityHandler.sendEmptyMessageDelayed(1, 500);
                if (DEBUG) {
                    android.util.Slog.d("PickUpWakeScreenManager", "proximity sensor registered.");
                }
            }
        } else if (this.mProximitySensorEnabled) {
            this.mProximitySensorEnabled = false;
            this.mProximityHandler.removeMessages(1);
            this.mSensorManager.unregisterListener(this.mProximitySensorListener);
            if (DEBUG) {
                android.util.Slog.d("PickUpWakeScreenManager", "proximity sensor unregistered.");
            }
        }
    }

    private void handleProximitySensorEvent(boolean positive) {
        if (this.mProximitySensorEnabled) {
            if (positive) {
                stopWakeUpReady(this.mContext, false);
            } else {
                stopWakeUpReady(this.mContext, true);
            }
            setProximitySensorEnabled(false);
        }
    }

    private void wakeUpWaitForProximity() {
        if (this.mInFastScreenOn) {
            android.util.Slog.d("PickUpWakeScreenManager", "wakeUpWaitForProximity already in processing");
            return;
        }
        startWakeUpReady(this.mContext);
        setProximitySensorEnabled(true);
    }

    private void startWakeUpReady(android.content.Context context) {
        java.lang.StringBuilder stringBuilder;
        android.os.PowerManager power = null;
        if (context != null) {
            power = (android.os.PowerManager) context.getSystemService("power");
        }
        if (power == null) {
            android.util.Slog.w("PickUpWakeScreenManager", "startWakeUpReady powermanager is null");
            return;
        }
        android.util.Slog.w("PickUpWakeScreenManager", "wakeUpWaitForProximity start");
        try {
            power.getClass().getMethod("startWakeUpReady", new java.lang.Class[]{java.lang.Long.TYPE}).invoke(power, new java.lang.Object[]{java.lang.Long.valueOf(android.os.SystemClock.uptimeMillis())});
            this.mInFastScreenOn = true;
        } catch (java.lang.NoSuchMethodException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PowerManager Value: System hasn't startWakeUpReady method ");
            stringBuilder.append(e);
            android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
        } catch (java.lang.IllegalArgumentException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PowerManager Value: startWakeUpReady method has wrong parameter ");
            stringBuilder.append(e2);
            android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
        } catch (java.lang.Exception e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("PowerManager Value: other reflect exception ");
            stringBuilder.append(e3);
            android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
        }
    }

    private void stopWakeUpReady(android.content.Context context, boolean turnOn) {
        java.lang.StringBuilder stringBuilder;
        if (this.mInFastScreenOn) {
            android.os.PowerManager power = null;
            if (context != null) {
                power = (android.os.PowerManager) context.getSystemService("power");
            }
            if (power == null) {
                android.util.Slog.w("PickUpWakeScreenManager", "stopWakeUpReady powermanager is null");
                this.mInFastScreenOn = false;
                return;
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("stopWakeUpReady turnon=");
            stringBuilder2.append(turnOn);
            android.util.Slog.w("PickUpWakeScreenManager", stringBuilder2.toString());
            try {
                power.getClass().getMethod("stopWakeUpReady", new java.lang.Class[]{java.lang.Long.TYPE, java.lang.Boolean.TYPE}).invoke(power, new java.lang.Object[]{java.lang.Long.valueOf(android.os.SystemClock.uptimeMillis()), java.lang.Boolean.valueOf(turnOn)});
            } catch (java.lang.NoSuchMethodException e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PowerManager Value: System hasn't stopWakeUpReady method ");
                stringBuilder.append(e);
                android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
            } catch (java.lang.IllegalArgumentException e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PowerManager Value: stopWakeUpReady method has wrong parameter ");
                stringBuilder.append(e2);
                android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
            } catch (java.lang.Exception e3) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("PowerManager Value: other reflect exception ");
                stringBuilder.append(e3);
                android.util.Slog.e("PickUpWakeScreenManager", stringBuilder.toString());
            }
            this.mInFastScreenOn = false;
            if (turnOn) {
                if (sSupportFaceRecognition) {
                    android.os.Handler handler = this.mProximityHandler;
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("android.policy:HWPICKUP#");
                    stringBuilder3.append(android.os.Binder.getCallingUid());
                    handler.obtainMessage(2, 0, 0, stringBuilder3.toString()).sendToTarget();
                }
                boolean ret = android.util.Flog.bdReport(this.mContext, 500);
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("report no proximity ScreenOn waked by pickup motion. EventId:500 ret:");
                stringBuilder2.append(ret);
                android.util.Slog.d("PickUpWakeScreenManager", stringBuilder2.toString());
                android.util.HwLog.dubaie("DUBAI_TAG_PICKUP_WAKE", "type=1");
            } else {
                android.util.HwLog.dubaie("DUBAI_TAG_PICKUP_WAKE", "type=0");
            }
            return;
        }
        android.util.Slog.w("PickUpWakeScreenManager", "stopWakeUpReady, not in fast screen on");
    }

    private boolean getPickupWakeEnabled() {
        return android.os.SystemProperties.getBoolean("ro.config.hw_wakeup_device", false);
    }

    private boolean getSupportFaceDectect() {
        if (!(1 == android.os.SystemProperties.getInt("ro.config.face_detect", 0) || android.os.SystemProperties.getBoolean("ro.config.face_recognition", false))) {
            if (!android.os.SystemProperties.getBoolean("ro.config.face_smart_keepon", false)) {
                return false;
            }
        }
        return true;
    }

    private boolean getPickupSwitchOn() {
        return com.huawei.motiondetection.MRUtils.getMotionEnableStateAsUser(this.mContext, "motion_pickup_wakeup_device", android.app.ActivityManager.getCurrentUser()) == 1;
    }

    private void observePickupSwitchState() {
        this.mIsPickupSwitchOn = getPickupSwitchOn();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("observePickupSwitchState mIsPickupSwitchOn:");
        stringBuilder.append(this.mIsPickupSwitchOn);
        android.util.Slog.d("PickUpWakeScreenManager", stringBuilder.toString());
        if (this.mIsPickupSupport && !this.mIsPickupSwitchOn && this.mHWEDManager != null) {
            this.mHWEDManager.unregisterDeviceListener(this.mHWEDListener, this.mHWExtMotion);
            android.util.Slog.d("PickUpWakeScreenManager", "unregist listener");
        }
    }
}
