package com.android.server.policy;

public class SlideTouchEvent {
    public static final java.lang.String KEY_SINGLE_HAND_SCREEN_ZOOM = "single_hand_screen_zoom";
    private static final int LAZYMODE_THRESHOLD_DEGREE_MAX = 70;
    private static final int LAZYMODE_THRESHOLD_DEGREE_MIN = 20;
    private static final long LAZYMODE_USE_DURATION = 3600000;
    private static final java.lang.String LEFT = "left";
    private static final java.lang.String RIGHT = "right";
    public static final float SCALE = 0.75f;
    public static final int STATE_LEFT = 1;
    public static final int STATE_MIDDLE = 0;
    public static final int STATE_RIGHT = 2;
    private static final int STOP_SDR_BINDER_ID = 1195;
    private static final int STOP_SDR_CMD = 1;
    private static final java.lang.String TAG = "SlideTouchEvent";
    private android.content.Context mContext;
    private float[] mDownPoint = new float[2];
    private boolean mFirstOverThreshold;
    private android.os.Handler mHandler = new android.os.Handler();
    private boolean mIsSupport = true;
    private boolean mIsValidGuesture;
    private boolean mScreenZoomEnabled = true;
    private long mStartLazyModeTime = 0;
    private float mThreshHoldsLazyMode;
    private boolean mZoomGestureEnabled = false;

    public SlideTouchEvent(android.content.Context context) {
        this.mContext = context;
        init();
    }

    private void init() {
        if (this.mContext != null) {
            this.mIsSupport = isSupportSingleHand();
            if (this.mIsSupport) {
                this.mThreshHoldsLazyMode = (float) this.mContext.getResources().getDimensionPixelSize(17105186);
                boolean z = false;
                this.mScreenZoomEnabled = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "single_hand_screen_zoom", 1, android.app.ActivityManager.getCurrentUser()) == 1;
                if (android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "accessibility_display_magnification_enabled", 0, android.app.ActivityManager.getCurrentUser()) == 1) {
                    z = true;
                }
                this.mZoomGestureEnabled = z;
                registerObserver();
            }
        }
    }

    private void registerObserver() {
        android.database.ContentObserver slideObserver = new android.database.ContentObserver(this.mHandler) {
            public void onChange(boolean selfChange) {
                com.android.server.policy.SlideTouchEvent.this.updateSettings();
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("single_hand_screen_zoom"), false, slideObserver, -1);
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Secure.getUriFor("accessibility_display_magnification_enabled"), false, slideObserver, -1);
    }

    public void updateSettings() {
        boolean z = false;
        this.mScreenZoomEnabled = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "single_hand_screen_zoom", 1, android.app.ActivityManager.getCurrentUser()) == 1;
        if (android.provider.Settings.Secure.getIntForUser(this.mContext.getContentResolver(), "accessibility_display_magnification_enabled", 0, android.app.ActivityManager.getCurrentUser()) == 1) {
            z = true;
        }
        this.mZoomGestureEnabled = z;
        if (!this.mScreenZoomEnabled || this.mZoomGestureEnabled) {
            quitLazyMode();
        }
    }

    public void setGestureResultAtUp(boolean success) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("gestureResultAtUp:");
        stringBuilder.append(success);
        android.util.Log.i("SlideTouchEvent", stringBuilder.toString());
        this.mIsValidGuesture &= success;
    }

    private boolean shouldHandleTouchEvent(android.view.MotionEvent event) {
        boolean should = true;
        if (event == null || event.getPointerCount() > 1) {
            should = false;
        }
        if (this.mIsSupport && this.mScreenZoomEnabled && !this.mZoomGestureEnabled) {
            return should;
        }
        return false;
    }

    public void handleTouchEvent(android.view.MotionEvent event) {
        if (shouldHandleTouchEvent(event)) {
            float x = event.getX();
            float y = event.getY();
            float distanceX = java.lang.Math.abs(this.mDownPoint[0] - x);
            float distanceY = java.lang.Math.abs(this.mDownPoint[1] - y);
            double rotationDegree;
            switch (event.getAction()) {
                case 0:
                    android.util.Log.i("SlideTouchEvent", "MotionEvent.ACTION_DOWN");
                    this.mDownPoint[0] = event.getX();
                    this.mDownPoint[1] = event.getY();
                    this.mIsValidGuesture = false;
                    this.mFirstOverThreshold = false;
                    break;
                case 1:
                    if (!this.mIsValidGuesture) {
                        android.util.Log.i("SlideTouchEvent", "Sliding distance is too short, can not trigger the lazy mode");
                        break;
                    }
                    rotationDegree = (java.lang.Math.atan((double) (distanceY / distanceX)) / 3.141592653589793d) * 180.0d;
                    if (rotationDegree >= 70.0d || rotationDegree <= 20.0d || 1 != this.mContext.getResources().getConfiguration().orientation) {
                        break;
                    }
                    android.util.Log.i("SlideTouchEvent", "preformStartLazyMode");
                    preformStartLazyMode(this.mDownPoint[0] - x);
                    return;
                    break;
                case 2:
                    if (distanceY > this.mThreshHoldsLazyMode && !this.mFirstOverThreshold) {
                        this.mFirstOverThreshold = true;
                        rotationDegree = (java.lang.Math.atan((double) (distanceY / distanceX)) / 3.141592653589793d) * 180.0d;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("rotationDegree=");
                        stringBuilder.append(rotationDegree);
                        stringBuilder.append(",mIsValidGuesture=");
                        stringBuilder.append(this.mIsValidGuesture);
                        android.util.Log.d("SlideTouchEvent", stringBuilder.toString());
                        if (rotationDegree < 70.0d && rotationDegree > 20.0d && !this.mIsValidGuesture) {
                            this.mIsValidGuesture = true;
                        }
                        break;
                    }
                default:
                    break;
            }
        }
    }

    public void preformStartLazyMode(float x) {
        final float distanceX = x;
        new android.os.AsyncTask<java.lang.Void, java.lang.Void, java.lang.Void>() {
            /* JADX WARNING: Missing block: B:7:0x002c, code:
            if (r5 != null) goto L_0x002e;
     */
            protected java.lang.Void doInBackground(java.lang.Void... r11) {
                /*
                r10 = this;
                r0 = "sys.sdr.enter";
                r1 = 0;
                r0 = android.os.SystemProperties.getInt(r0, r1);
                r2 = 1;
                if (r2 != r0) goto L_0x0098;
            L_0x000b:
                r0 = 0;
                r3 = "SurfaceFlinger";
                r3 = android.os.ServiceManager.getService(r3);
                r4 = android.os.Parcel.obtain();
                r5 = android.os.Parcel.obtain();
                r4.writeInt(r2);	 Catch:{ RemoteException -> 0x0034 }
                r6 = "android.ui.ISurfaceComposer";
                r4.writeInterfaceToken(r6);	 Catch:{ RemoteException -> 0x0034 }
                r6 = 1195; // 0x4ab float:1.675E-42 double:5.904E-321;
                r3.transact(r6, r4, r5, r1);	 Catch:{ RemoteException -> 0x0034 }
                if (r4 == 0) goto L_0x002c;
            L_0x0029:
                r4.recycle();
            L_0x002c:
                if (r5 == 0) goto L_0x0058;
            L_0x002e:
                r5.recycle();
                goto L_0x0058;
            L_0x0032:
                r1 = move-exception;
                goto L_0x008d;
            L_0x0034:
                r6 = move-exception;
                r7 = "SlideTouchEvent";
                r8 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0032 }
                r8.<init>();	 Catch:{ all -> 0x0032 }
                r9 = "stop sdr exception. message = ";
                r8.append(r9);	 Catch:{ all -> 0x0032 }
                r9 = r6.getMessage();	 Catch:{ all -> 0x0032 }
                r8.append(r9);	 Catch:{ all -> 0x0032 }
                r8 = r8.toString();	 Catch:{ all -> 0x0032 }
                android.util.Log.e(r7, r8);	 Catch:{ all -> 0x0032 }
                if (r4 == 0) goto L_0x0055;
            L_0x0052:
                r4.recycle();
            L_0x0055:
                if (r5 == 0) goto L_0x0058;
            L_0x0057:
                goto L_0x002e;
            L_0x0058:
                r6 = "APS";
                r7 = "APS: SDR: special: Lazymode process wait begin ";
                android.util.Log.d(r6, r7);
            L_0x005f:
                r6 = "sys.sdr.special";
                r6 = android.os.SystemProperties.getInt(r6, r1);
                if (r2 != r6) goto L_0x0076;
            L_0x0068:
                r6 = 100;
                if (r0 >= r6) goto L_0x0076;
            L_0x006c:
                r6 = 10;
                java.lang.Thread.sleep(r6);	 Catch:{ InterruptedException -> 0x0072 }
                goto L_0x0073;
            L_0x0072:
                r6 = move-exception;
            L_0x0073:
                r0 = r0 + 1;
                goto L_0x005f;
            L_0x0076:
                r1 = "APS";
                r2 = new java.lang.StringBuilder;
                r2.<init>();
                r6 = "APS: SDR: special: Lazymode process wait end, sleepCount=";
                r2.append(r6);
                r2.append(r0);
                r2 = r2.toString();
                android.util.Log.d(r1, r2);
                goto L_0x0098;
            L_0x008d:
                if (r4 == 0) goto L_0x0092;
            L_0x008f:
                r4.recycle();
            L_0x0092:
                if (r5 == 0) goto L_0x0097;
            L_0x0094:
                r5.recycle();
            L_0x0097:
                throw r1;
            L_0x0098:
                r0 = 0;
                return r0;
                */
                throw new UnsupportedOperationException("Method not decompiled: com.android.server.policy.SlideTouchEvent.2.doInBackground(java.lang.Void[]):java.lang.Void");
            }

            protected void onPostExecute(java.lang.Void result) {
                com.android.server.policy.SlideTouchEvent.this.startLazyMode(distanceX);
            }
        }.execute(new java.lang.Void[0]);
    }

    private void startLazyMode(float distanceX) {
        java.lang.String str = android.provider.Settings.Global.getString(this.mContext.getContentResolver(), "single_hand_mode");
        if (distanceX > 0.0f && android.text.TextUtils.isEmpty(str)) {
            android.util.Flog.bdReport(this.mContext, 13);
            android.provider.Settings.Global.putString(this.mContext.getContentResolver(), "single_hand_mode", "right");
            this.mStartLazyModeTime = android.os.SystemClock.uptimeMillis();
        }
        if (distanceX < 0.0f && android.text.TextUtils.isEmpty(str)) {
            android.util.Flog.bdReport(this.mContext, 14);
            android.provider.Settings.Global.putString(this.mContext.getContentResolver(), "single_hand_mode", "left");
            this.mStartLazyModeTime = android.os.SystemClock.uptimeMillis();
        }
        if (distanceX < 0.0f && str != null && str.contains("left")) {
            quitLazyMode();
            reportLazyModeUsingTime();
        }
        if (distanceX > 0.0f && str != null && str.contains("right")) {
            quitLazyMode();
            reportLazyModeUsingTime();
        }
    }

    private void reportLazyModeUsingTime() {
        if (this.mStartLazyModeTime > 0 && android.os.SystemClock.uptimeMillis() - this.mStartLazyModeTime >= 3600000) {
            android.util.Log.i("SlideTouchEvent", "BDReporter.EVENT_ID_SINGLE_HAND_USING_ONEHOUR");
        }
    }

    public static int getLazyState(android.content.Context context) {
        java.lang.String str = android.provider.Settings.Global.getString(context.getContentResolver(), "single_hand_mode");
        if (android.text.TextUtils.isEmpty(str)) {
            return 0;
        }
        if (str.contains("left")) {
            return 1;
        }
        if (str.contains("right")) {
            return 2;
        }
        return 0;
    }

    public static android.graphics.Rect getScreenshotRect(android.content.Context context) {
        android.view.Display display = ((android.view.WindowManager) context.getSystemService("window")).getDefaultDisplay();
        android.util.DisplayMetrics displayMetrics = new android.util.DisplayMetrics();
        display.getRealMetrics(displayMetrics);
        int state = getLazyState(context);
        if (1 == state) {
            return new android.graphics.Rect(0, (int) (((float) displayMetrics.heightPixels) * 0.25f), (int) (((float) displayMetrics.widthPixels) * 0.75f), displayMetrics.heightPixels);
        }
        if (2 == state) {
            return new android.graphics.Rect((int) (((float) displayMetrics.widthPixels) * 0.25f), (int) (((float) displayMetrics.heightPixels) * 0.25f), displayMetrics.widthPixels, displayMetrics.heightPixels);
        }
        return null;
    }

    public static boolean isLazyMode(android.content.Context context) {
        return getLazyState(context) != 0;
    }

    private void quitLazyMode() {
        android.provider.Settings.Global.putString(this.mContext.getContentResolver(), "single_hand_mode", "");
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x00ad  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00b2  */
    /* JADX WARNING: Missing block: B:18:0x005c, code:
            if (r3 != null) goto L_0x005e;
     */
    private boolean isSupportSingleHand() {
        /*
        r9 = this;
        r0 = android.view.WindowManagerGlobal.getWindowManagerService();
        r1 = 0;
        if (r0 != 0) goto L_0x0008;
    L_0x0007:
        return r1;
    L_0x0008:
        r0 = android.view.WindowManagerGlobal.getWindowManagerService();
        r0 = r0.asBinder();
        r2 = 0;
        r3 = 0;
        r4 = 1;
        r5 = android.os.Parcel.obtain();	 Catch:{ RemoteException -> 0x0064 }
        r2 = r5;
        r5 = android.os.Parcel.obtain();	 Catch:{ RemoteException -> 0x0064 }
        r3 = r5;
        if (r0 == 0) goto L_0x0057;
    L_0x001f:
        r5 = "android.view.IWindowManager";
        r2.writeInterfaceToken(r5);	 Catch:{ RemoteException -> 0x0064 }
        r5 = 1991; // 0x7c7 float:2.79E-42 double:9.837E-321;
        r0.transact(r5, r2, r3, r1);	 Catch:{ RemoteException -> 0x0064 }
        r3.readException();	 Catch:{ RemoteException -> 0x0064 }
        r5 = r3.readInt();	 Catch:{ RemoteException -> 0x0064 }
        r6 = "SlideTouchEvent";
        r7 = new java.lang.StringBuilder;	 Catch:{ RemoteException -> 0x0064 }
        r7.<init>();	 Catch:{ RemoteException -> 0x0064 }
        r8 = "single_hand_switch = ";
        r7.append(r8);	 Catch:{ RemoteException -> 0x0064 }
        r7.append(r5);	 Catch:{ RemoteException -> 0x0064 }
        r7 = r7.toString();	 Catch:{ RemoteException -> 0x0064 }
        android.util.Log.i(r6, r7);	 Catch:{ RemoteException -> 0x0064 }
        if (r5 != r4) goto L_0x004b;
    L_0x0049:
        r1 = r4;
        goto L_0x004c;
    L_0x004c:
        if (r2 == 0) goto L_0x0051;
    L_0x004e:
        r2.recycle();
    L_0x0051:
        if (r3 == 0) goto L_0x0056;
    L_0x0053:
        r3.recycle();
    L_0x0056:
        return r1;
    L_0x0057:
        if (r2 == 0) goto L_0x005c;
    L_0x0059:
        r2.recycle();
    L_0x005c:
        if (r3 == 0) goto L_0x00b3;
    L_0x005e:
        r3.recycle();
        goto L_0x00b3;
    L_0x0062:
        r1 = move-exception;
        goto L_0x00b4;
    L_0x0064:
        r1 = move-exception;
        r5 = "SlideTouchEvent";
        r6 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0062 }
        r6.<init>();	 Catch:{ all -> 0x0062 }
        r7 = "read single_hand_switch exception. message = ";
        r6.append(r7);	 Catch:{ all -> 0x0062 }
        r7 = r1.getMessage();	 Catch:{ all -> 0x0062 }
        r6.append(r7);	 Catch:{ all -> 0x0062 }
        r6 = r6.toString();	 Catch:{ all -> 0x0062 }
        android.util.Log.e(r5, r6);	 Catch:{ all -> 0x0062 }
        r5 = r9.mContext;	 Catch:{ all -> 0x0062 }
        r5 = r5.getResources();	 Catch:{ all -> 0x0062 }
        r6 = "single_hand_mode";
        r7 = "bool";
        r8 = "androidhwext";
        r5 = r5.getIdentifier(r6, r7, r8);	 Catch:{ all -> 0x0062 }
        if (r5 == 0) goto L_0x00ab;
    L_0x0092:
        r6 = r9.mContext;	 Catch:{ NotFoundException -> 0x00a7 }
        r6 = r6.getResources();	 Catch:{ NotFoundException -> 0x00a7 }
        r6 = r6.getBoolean(r5);	 Catch:{ NotFoundException -> 0x00a7 }
        if (r2 == 0) goto L_0x00a1;
    L_0x009e:
        r2.recycle();
    L_0x00a1:
        if (r3 == 0) goto L_0x00a6;
    L_0x00a3:
        r3.recycle();
    L_0x00a6:
        return r6;
    L_0x00a7:
        r6 = move-exception;
        r6.printStackTrace();	 Catch:{ all -> 0x0062 }
    L_0x00ab:
        if (r2 == 0) goto L_0x00b0;
    L_0x00ad:
        r2.recycle();
    L_0x00b0:
        if (r3 == 0) goto L_0x00b3;
    L_0x00b2:
        goto L_0x005e;
    L_0x00b3:
        return r4;
    L_0x00b4:
        if (r2 == 0) goto L_0x00b9;
    L_0x00b6:
        r2.recycle();
    L_0x00b9:
        if (r3 == 0) goto L_0x00be;
    L_0x00bb:
        r3.recycle();
    L_0x00be:
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.policy.SlideTouchEvent.isSupportSingleHand():boolean");
    }
}
