package com.android.server.power;

public class HwDisplayPowerController {
    private static final boolean DEBUG;
    private static final int MAX_RETRY_COUNT = 4;
    private static final int MIN_LUX_VALUE = 3;
    private static final java.lang.String TAG = "HwDisplayPowerController";
    private static boolean mCoverClose = false;
    private static final android.util.ArrayMap<java.lang.String, android.os.HwBrightnessProcessor> mHwBrightnessProcessors = new android.util.ArrayMap();
    private static int mSensorCount = 4;

    private static final class PersonalizedBrightnessCurveLevelProcessor extends android.os.HwBrightnessProcessor {
        private com.android.server.display.AutomaticBrightnessController mAutomaticBrightnessController;

        public PersonalizedBrightnessCurveLevelProcessor(com.android.server.display.AutomaticBrightnessController controller) {
            this.mAutomaticBrightnessController = controller;
        }

        public boolean setData(android.os.Bundle data, int[] retValue) {
            if (this.mAutomaticBrightnessController == null) {
                retValue[0] = -1;
                return true;
            }
            this.mAutomaticBrightnessController.setPersonalizedBrightnessCurveLevel(data.getInt("TopApkLevel", 0));
            retValue[0] = 0;
            return true;
        }
    }

    private static final class PersonalizedBrightnessProcessor extends android.os.HwBrightnessProcessor {
        private final boolean DEBUG;
        private java.lang.String TAG = "PersonalizedBrightnessProcessor";
        private com.android.server.display.AutomaticBrightnessController mAutomaticBrightnessController;

        public PersonalizedBrightnessProcessor(com.android.server.display.AutomaticBrightnessController controller) {
            boolean z;
            if (!android.util.Log.HWINFO) {
                if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable(this.TAG, 4)) {
                    z = false;
                    this.DEBUG = z;
                    this.mAutomaticBrightnessController = controller;
                }
            }
            z = true;
            this.DEBUG = z;
            this.mAutomaticBrightnessController = controller;
        }

        public boolean setData(android.os.Bundle data, int[] retValue) {
            if (this.mAutomaticBrightnessController == null) {
                return false;
            }
            int isCurveUpdate = data.getInt("CurveUpdateFlag", 0);
            if (this.DEBUG) {
                java.lang.String str = this.TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("isCurveUpdate = ");
                stringBuilder.append(isCurveUpdate);
                android.util.Slog.i(str, stringBuilder.toString());
            }
            if (isCurveUpdate == 1) {
                this.mAutomaticBrightnessController.updateNewBrightnessCurveTmp();
            }
            retValue[0] = 0;
            return true;
        }

        public boolean getData(android.os.Bundle data, int[] retValue) {
            if (this.mAutomaticBrightnessController == null) {
                return false;
            }
            data.putParcelableArrayList("DefaultCurve", (java.util.ArrayList) this.mAutomaticBrightnessController.getCurrentDefaultNewCurveLine());
            if (this.DEBUG) {
                android.util.Slog.i(this.TAG, "defaultCurve ");
            }
            retValue[0] = 0;
            return true;
        }
    }

    private static final class SceneRecognitionProcessor extends android.os.HwBrightnessProcessor {
        private com.android.server.display.AutomaticBrightnessController mAutomaticBrightnessController;

        public SceneRecognitionProcessor(com.android.server.display.AutomaticBrightnessController controller) {
            this.mAutomaticBrightnessController = controller;
        }

        public boolean getData(android.os.Bundle data, int[] retValue) {
            if (this.mAutomaticBrightnessController == null) {
                retValue[0] = -1;
                return true;
            }
            this.mAutomaticBrightnessController.getUserDragInfo(data);
            retValue[0] = 0;
            return true;
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwDisplayPowerController", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public static void setIfCoverClosed(boolean isClosed) {
        mCoverClose = isClosed;
        mSensorCount = 0;
    }

    public static boolean isCoverClosed() {
        return mCoverClose;
    }

    public static boolean shouldFilteInvalidSensorVal(float lux) {
        if (mCoverClose) {
            return true;
        }
        if (4 <= mSensorCount || lux >= 3.0f) {
            mSensorCount = 4;
            return false;
        }
        mSensorCount++;
        return true;
    }

    public static void setPowerState(int powerState) {
        huawei.android.aod.HwAodManager.getInstance().setPowerState(powerState);
    }

    public static boolean hwBrightnessSetData(java.lang.String name, android.os.Bundle data, int[] result) {
        android.os.HwBrightnessProcessor processor = (android.os.HwBrightnessProcessor) mHwBrightnessProcessors.get(name);
        if (processor != null) {
            return processor.setData(data, result);
        }
        return false;
    }

    public static boolean hwBrightnessGetData(java.lang.String name, android.os.Bundle data, int[] result) {
        android.os.HwBrightnessProcessor processor = (android.os.HwBrightnessProcessor) mHwBrightnessProcessors.get(name);
        if (processor != null) {
            return processor.getData(data, result);
        }
        return false;
    }

    public static void loadHwBrightnessProcessors(com.android.server.display.AutomaticBrightnessController autoController, com.android.server.display.ManualBrightnessController manualController) {
        mHwBrightnessProcessors.put("Cryogenic", new com.android.server.display.CryogenicPowerProcessor(autoController));
        mHwBrightnessProcessors.put("SceneRecognition", new com.android.server.power.HwDisplayPowerController.SceneRecognitionProcessor(autoController));
        mHwBrightnessProcessors.put("PersonalizedBrightnessCurveLevel", new com.android.server.power.HwDisplayPowerController.PersonalizedBrightnessCurveLevelProcessor(autoController));
        mHwBrightnessProcessors.put("PersonalizedBrightness", new com.android.server.power.HwDisplayPowerController.PersonalizedBrightnessProcessor(autoController));
    }
}
