package com.android.server.power;

public class HwPowerManagerService extends com.android.server.power.PowerManagerService {
    private static final java.lang.String COLOR_TEMPERATURE = "color_temperature";
    private static final int COLOR_TEMPERATURE_DEFAULT = 128;
    private static final java.lang.String COLOR_TEMPERATURE_RGB = "color_temperature_rgb";
    private static final java.lang.String DIRECT_CHG_ENABLE_PATH_HISI = "/sys/class/hw_power/charger/direct_charger/enable_charger";
    private static final int INTELLI_DETECT_FACE_PRESENCE = 1;
    private static final int MAXINUM_TEMPERATURE = 255;
    private static final int MODE_COLOR_TEMP_3_DIMENSION = 1;
    private static final java.lang.String NORMAL_CHG_ENABLE_PATH = "/sys/class/hw_power/charger/charge_data/enable_charger";
    private static final java.lang.String POWER_STATE_CHARGE_DISABLE = "0";
    private static final java.lang.String POWER_STATE_CHARGE_ENABLE = "1";
    private static final java.lang.String SERVICE_ACTION = "com.huawei.intelliServer.intelliServer";
    private static final java.lang.String SERVICE_CLASS = "com.huawei.intelliServer.intelliServer.IntelliService";
    private static final java.lang.String SERVICE_PACKAGE = "com.huawei.intelliServer.intelliServer";
    public static final int SUBTYPE_DROP_WAKELOCK = 1;
    public static final int SUBTYPE_PROXY_NO_WORKSOURCE = 2;
    public static final int SUBTYPE_RELEASE_NO_WORKSOURCE = 3;
    private static final java.lang.String TAG = "HwPowerManagerService";
    private static final int TYPE_FACE_STAY_LIT = 3;
    private static boolean mLoadLibraryFailed;
    private android.content.ServiceConnection connection = new android.content.ServiceConnection() {
        public void onServiceConnected(android.content.ComponentName componentName, android.os.IBinder iBinder) {
            if (com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound) {
                if (com.android.server.power.PowerManagerService.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("IntelliService Connected, mShouldFaceDetectLater=");
                    stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mShouldFaceDetectLater);
                    android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                }
                com.android.server.power.HwPowerManagerService.this.mIRemote = com.huawei.IntelliServer.intellilib.IIntelliService.Stub.asInterface(iBinder);
                if (com.android.server.power.HwPowerManagerService.this.mShouldFaceDetectLater) {
                    com.android.server.power.HwPowerManagerService.this.mShouldFaceDetectLater = false;
                    com.android.server.power.HwPowerManagerService.this.registerFaceDetect();
                }
                return;
            }
            android.util.Slog.w("HwPowerManagerService", "IntelliService not bound, ignore.");
        }

        public void onServiceDisconnected(android.content.ComponentName componentName) {
            if (com.android.server.power.PowerManagerService.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("IntelliService Disconnected, mIntelliServiceBound=");
                stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound) {
                com.android.server.power.HwPowerManagerService.this.resetFaceDetect();
            }
        }

        public void onBindingDied(android.content.ComponentName name) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("IntelliService binding died, mIntelliServiceBound=");
            stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound);
            android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
            if (com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound) {
                com.android.server.power.HwPowerManagerService.this.resetFaceDetect();
            }
        }
    };
    private final android.content.Context mContext;
    private com.android.server.display.DisplayEffectMonitor mDisplayEffectMonitor;
    private com.huawei.displayengine.DisplayEngineManager mDisplayEngineManager;
    private int mEyesProtectionMode;
    private boolean mFaceDetecting;
    private com.android.server.power.HwPowerManagerService.FingerSenseObserver mFingerSenseObserver;
    private final java.util.ArrayList<com.android.server.power.PowerManagerService.WakeLock> mForceReleasedWakeLocks = new java.util.ArrayList();
    private boolean mHadSendBrightnessModeToMonitor;
    private boolean mHadSendManualBrightnessToMonitor;
    private final java.util.ArrayList<com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData> mHwBrightnessCallbacks = new java.util.ArrayList();
    private final android.util.ArrayMap<java.lang.String, com.android.server.power.HwPowerManagerService.HwBrightnessInnerProcessor> mHwBrightnessInnerProcessors = new android.util.ArrayMap();
    private com.huawei.IntelliServer.intellilib.IIntelliService mIRemote;
    private android.content.Intent mIntelliIntent;
    private com.huawei.IntelliServer.intellilib.IIntelliListener mIntelliListener = new com.huawei.IntelliServer.intellilib.IIntelliListener.Stub() {
        public void onEvent(com.huawei.IntelliServer.intellilib.IntelliAlgoResult intelliAlgoResult) throws android.os.RemoteException {
            int result = intelliAlgoResult != null ? intelliAlgoResult.getPrecenseStatus() : 0;
            if (com.android.server.power.PowerManagerService.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onEvent result=");
                stringBuilder.append(result);
                stringBuilder.append(",mFaceDetecting=");
                stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mFaceDetecting);
                android.util.Slog.i("HwPowerManagerService", stringBuilder.toString());
            }
            if (result == 1 && com.android.server.power.HwPowerManagerService.this.mFaceDetecting) {
                long ident = android.os.Binder.clearCallingIdentity();
                try {
                    com.android.server.power.HwPowerManagerService.this.userActivityInternal(android.os.SystemClock.uptimeMillis(), 0, 0, 1000);
                } finally {
                    android.os.Binder.restoreCallingIdentity(ident);
                }
            }
        }

        public void onErr(int i) throws android.os.RemoteException {
        }
    };
    private boolean mIntelliServiceBound;
    private boolean mIsGoogleEBS = false;
    private final java.lang.Object mLockHwBrightnessCallbacks = new java.lang.Object();
    private com.android.server.pg.PGManagerInternal mPGManagerInternal;
    private com.android.server.policy.WindowManagerPolicy mPolicy;
    private final java.util.ArrayList<com.android.server.power.HwPowerManagerService.ProxyWLProcessInfo> mProxyWLProcessList = new java.util.ArrayList();
    private final java.util.ArrayList<com.android.server.power.PowerManagerService.WakeLock> mProxyedWakeLocks = new java.util.ArrayList();
    private com.android.server.power.HwPowerManagerService.SettingsObserver mSettingsObserver;
    private boolean mShouldFaceDetectLater;
    private boolean mSupportDisplayEngine3DColorTemperature;
    private boolean mSystemReady = false;
    private int mWaitBrightTimeout = 3000;
    private com.android.server.wm.WindowManagerInternal mWindowManagerInternal;

    private final class BluetoothReceiver extends android.content.BroadcastReceiver {
        private BluetoothReceiver() {
        }

        /* synthetic */ BluetoothReceiver(com.android.server.power.HwPowerManagerService x0, com.android.server.power.HwPowerManagerService.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.Throwable th;
            android.content.Intent intent2 = intent;
            long now = android.os.SystemClock.uptimeMillis();
            android.bluetooth.BluetoothDevice btDevice = (android.bluetooth.BluetoothDevice) intent2.getParcelableExtra("android.bluetooth.device.extra.DEVICE");
            int newState = intent2.getIntExtra("android.bluetooth.profile.extra.STATE", 0);
            int oldState = intent2.getIntExtra("android.bluetooth.profile.extra.PREVIOUS_STATE", 0);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("BluetoothReceiver,btDevice:");
            stringBuilder.append(btDevice);
            stringBuilder.append(",newState:");
            stringBuilder.append(newState);
            stringBuilder.append(",oldState:");
            stringBuilder.append(oldState);
            stringBuilder.append(",intent:");
            stringBuilder.append(intent.getAction());
            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            boolean needWakeUp = false;
            if (btDevice != null && newState == 2 && oldState == 1) {
                android.bluetooth.BluetoothClass btClass = btDevice.getBluetoothClass();
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("BluetoothReceiver btClass.getDeviceClass():");
                stringBuilder2.append(btClass);
                android.util.Slog.d("HwPowerManagerService", stringBuilder2.toString());
                if (btClass != null) {
                    switch (btClass.getDeviceClass()) {
                        case 1024:
                        case 1028:
                        case 1032:
                        case 1040:
                        case 1044:
                        case 1048:
                        case 1052:
                        case 1056:
                        case 1060:
                        case 1064:
                        case 1068:
                        case 1072:
                        case 1076:
                        case 1080:
                        case 1084:
                        case 1088:
                        case 1096:
                            needWakeUp = true;
                            break;
                    }
                    boolean needWakeUp2 = needWakeUp;
                    if (needWakeUp2) {
                        java.lang.Object obj = com.android.server.power.HwPowerManagerService.this.mLock;
                        synchronized (obj) {
                            java.lang.Object obj2;
                            try {
                                obj2 = obj;
                                if (com.android.server.power.HwPowerManagerService.this.wakeUpNoUpdateLocked(now, "bluetooth.connected", 1000, com.android.server.power.HwPowerManagerService.this.mContext.getOpPackageName(), 1000) || com.android.server.power.HwPowerManagerService.this.userActivityNoUpdateLocked(now, 0, 0, 1000)) {
                                    com.android.server.power.HwPowerManagerService.this.updatePowerStateLocked();
                                }
                            } catch (Throwable th2) {
                                th = th2;
                                throw th;
                            }
                        }
                    }
                    needWakeUp = needWakeUp2;
                }
            }
        }
    }

    private static final class FingerSenseObserver extends android.database.ContentObserver {
        private android.content.ContentResolver resolver;

        public FingerSenseObserver(android.os.Handler handler, android.content.ContentResolver resolver) {
            super(handler);
            this.resolver = resolver;
        }

        public void observe() {
            this.resolver.registerContentObserver(android.provider.Settings.Global.getUriFor("fingersense_enabled"), false, this, -1);
        }

        public void onChange(boolean selfChange) {
            boolean z = true;
            if (android.provider.Settings.Global.getInt(this.resolver, "fingersense_enabled", 1) != 1) {
                z = false;
            }
            com.android.server.power.PowerManagerService.nativeSetFsEnable(z);
        }
    }

    private final class HeadsetReceiver extends android.content.BroadcastReceiver {
        private HeadsetReceiver() {
        }

        /* synthetic */ HeadsetReceiver(com.android.server.power.HwPowerManagerService x0, com.android.server.power.HwPowerManagerService.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            synchronized (com.android.server.power.HwPowerManagerService.this.mLock) {
                long now = android.os.SystemClock.uptimeMillis();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("HeadsetReceiver,state:");
                stringBuilder.append(intent.getIntExtra("state", 0));
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                if (intent.getIntExtra("state", 0) == 1 && (com.android.server.power.HwPowerManagerService.this.wakeUpNoUpdateLocked(now, "headset.connected", 1000, com.android.server.power.HwPowerManagerService.this.mContext.getOpPackageName(), 1000) || com.android.server.power.HwPowerManagerService.this.userActivityNoUpdateLocked(now, 0, 0, 1000))) {
                    com.android.server.power.HwPowerManagerService.this.updatePowerStateLocked();
                }
            }
        }
    }

    private static final class HwBrightnessCallbackData {
        private android.os.IHwBrightnessCallback mCB;
        private java.util.List<java.lang.String> mFilter = null;

        public HwBrightnessCallbackData(android.os.IHwBrightnessCallback cb, java.util.List<java.lang.String> filter) {
            if (filter != null) {
                this.mFilter = new java.util.ArrayList(filter);
            }
            this.mCB = cb;
        }

        public java.util.List<java.lang.String> getFilter() {
            return this.mFilter;
        }

        public android.os.IHwBrightnessCallback getCB() {
            return this.mCB;
        }
    }

    public static final class HwBrightnessInnerProcessor {
        public int setData(android.os.Bundle data) {
            android.util.Slog.w("HwPowerManagerService", "Forget to override setData()? Now in default setData(), nothing to do!");
            return -1;
        }

        public int getData(android.os.Bundle data) {
            android.util.Slog.w("HwPowerManagerService", "Forget to override getData()? Now in default getData(), nothing to do!");
            return -1;
        }
    }

    private static final class ProxyWLProcessInfo {
        public int mPid;
        public boolean mProxyWS;
        public int mUid;

        public ProxyWLProcessInfo(int pid, int uid, boolean proxyWS) {
            this.mPid = pid;
            this.mUid = uid;
            this.mProxyWS = proxyWS;
        }

        public boolean isSameProcess(int pid, int uid) {
            if (this.mPid == pid || -1 == pid) {
                if (this.mUid != uid) {
                    if (-1 == uid) {
                    }
                }
                return true;
            }
            return false;
        }
    }

    private final class SettingsObserver extends android.database.ContentObserver {
        public SettingsObserver(android.os.Handler handler) {
            super(handler);
        }

        public void onChange(boolean selfChange, android.net.Uri uri) {
            synchronized (com.android.server.power.HwPowerManagerService.this.mLock) {
                com.android.server.power.HwPowerManagerService.this.setColorTemperatureAccordingToSetting();
            }
        }
    }

    private static native void finalize_native();

    private static native void init_SurfaceComposerClient();

    private static native void init_native();

    private static native int nativeGetDisplayFeatureSupported(int i);

    private static native int nativeGetDisplayPanelType();

    public static native java.lang.String nativeReadColorTemperatureNV();

    private native int nativeSetColorTemperature(int i);

    private native int nativeUpdateRgbGamma(float f, float f2, float f3);

    static {
        mLoadLibraryFailed = false;
        try {
            java.lang.System.loadLibrary("hwpwmanager_jni");
        } catch (java.lang.UnsatisfiedLinkError e) {
            mLoadLibraryFailed = true;
            android.util.Slog.d("HwPowerManagerService", "hwpwmanager_jni library not found!");
        }
    }

    public void init(android.content.Context context, com.android.server.lights.LightsService ls, com.android.server.am.ActivityManagerService am, com.android.server.BatteryService bs, com.android.internal.app.IBatteryStats bss, com.android.internal.app.IAppOpsService appOps, com.android.server.display.DisplayManagerService dm) {
    }

    public HwPowerManagerService(android.content.Context context) {
        super(context);
        this.mContext = context;
        this.mDisplayEffectMonitor = com.android.server.display.DisplayEffectMonitor.getInstance(this.mContext);
        if (this.mDisplayEffectMonitor == null) {
            android.util.Slog.e("HwPowerManagerService", "getDisplayEffectMonitor failed!");
        }
        if (!mLoadLibraryFailed) {
            init_native();
        }
        this.mDisplayEngineManager = new com.huawei.displayengine.DisplayEngineManager();
        loadHwBrightnessInnerProcessors();
    }

    protected void finalize() {
        if (!mLoadLibraryFailed) {
            finalize_native();
        }
        try {
            super.finalize();
        } catch (Throwable th) {
        }
    }

    public boolean setGoogleEBS(boolean isGoogleEBS) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setGoogleEBS:");
        stringBuilder.append(isGoogleEBS);
        android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        this.mIsGoogleEBS = isGoogleEBS;
        return true;
    }

    public int setColorTemperatureInternal(int colorTemper) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setColorTemperature:");
        stringBuilder.append(colorTemper);
        android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        try {
            if (!mLoadLibraryFailed) {
                return nativeSetColorTemperature(colorTemper);
            }
            android.util.Slog.d("HwPowerManagerService", "nativeSetColorTemperature not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwPowerManagerService", "nativeSetColorTemperature not found!");
            return -1;
        }
    }

    public boolean isDisplayFeatureSupported(int feature) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isDisplayFeatureSupported feature:");
        stringBuilder.append(feature);
        android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        boolean z = false;
        try {
            if (mLoadLibraryFailed) {
                android.util.Slog.d("HwPowerManagerService", "Display feature not supported because of library not found!");
                return false;
            }
            if (nativeGetDisplayFeatureSupported(feature) != 0) {
                z = true;
            }
            return z;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwPowerManagerService", "Display feature not supported because of exception!");
            return false;
        }
    }

    private void setColorRGB(float red, float green, float blue) {
        java.lang.StringBuilder stringBuilder;
        if (red >= 0.0f && red <= 1.0f && green >= 0.0f && green <= 1.0f && blue >= 0.0f) {
            if (blue <= 1.0f) {
                try {
                    java.lang.Class clazz = java.lang.Class.forName("com.huawei.android.os.PowerManagerCustEx");
                    clazz.getMethod("updateRgbGamma", new java.lang.Class[]{java.lang.Float.TYPE, java.lang.Float.TYPE, java.lang.Float.TYPE, java.lang.Integer.TYPE, java.lang.Integer.TYPE}).invoke(clazz, new java.lang.Object[]{java.lang.Float.valueOf(red), java.lang.Float.valueOf(green), java.lang.Float.valueOf(blue), java.lang.Integer.valueOf(18), java.lang.Integer.valueOf(7)});
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("setColorTemperatureAccordingToSetting and setColorRGB sucessfully:red=");
                    stringBuilder2.append(red);
                    stringBuilder2.append(", green=");
                    stringBuilder2.append(green);
                    stringBuilder2.append(", blue=");
                    stringBuilder2.append(blue);
                    android.util.Log.i("HwPowerManagerService", stringBuilder2.toString());
                } catch (java.lang.RuntimeException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(": reflection exception is ");
                    stringBuilder.append(e.getMessage());
                    android.util.Log.e("HwPowerManagerService", stringBuilder.toString());
                } catch (java.lang.Exception ex) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(": Exception happend when setColorRGB. Message is: ");
                    stringBuilder.append(ex.getMessage());
                    android.util.Log.e("HwPowerManagerService", stringBuilder.toString());
                }
                return;
            }
        }
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("Parameters invalid: red=");
        stringBuilder3.append(red);
        stringBuilder3.append(", green=");
        stringBuilder3.append(green);
        stringBuilder3.append(", blue=");
        stringBuilder3.append(blue);
        android.util.Slog.w("HwPowerManagerService", stringBuilder3.toString());
    }

    protected void setColorTemperatureAccordingToSetting() {
        java.lang.StringBuilder stringBuilder;
        android.util.Slog.d("HwPowerManagerService", "setColorTemperatureAccordingToSetting");
        float red = 1.0f;
        float green = 1.0f;
        float blue = 1.0f;
        java.lang.String ctNewRGB;
        java.util.List<java.lang.String> rgbarryList;
        int operation;
        if (this.mSupportDisplayEngine3DColorTemperature) {
            android.util.Slog.i("HwPowerManagerService", "setColorTemperatureAccordingToSetting new from displayengine.");
            try {
                this.mEyesProtectionMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "eyes_protection_mode", 0, -2);
                if (this.mEyesProtectionMode == 1) {
                    setColorRGB(1.0f, 1.0f, 1.0f);
                    return;
                }
                ctNewRGB = android.provider.Settings.System.getStringForUser(this.mContext.getContentResolver(), "color_temperature_rgb", -2);
                if (ctNewRGB != null) {
                    rgbarryList = new java.util.ArrayList(java.util.Arrays.asList(ctNewRGB.split(",")));
                    red = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(0)).floatValue();
                    green = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(1)).floatValue();
                    blue = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(2)).floatValue();
                } else {
                    android.util.Slog.w("HwPowerManagerService", "ColorTemperature read from setting failed, and set default values");
                }
                setColorRGB(red, green, blue);
            } catch (java.lang.IndexOutOfBoundsException e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("IndexOutOfBoundsException:");
                stringBuilder.append(e);
                android.util.Slog.e("HwPowerManagerService", stringBuilder.toString());
            } catch (Throwable th) {
                setColorRGB(1.0f, 1.0f, 1.0f);
            }
        } else if (isDisplayFeatureSupported(1)) {
            android.util.Slog.d("HwPowerManagerService", "setColorTemperatureAccordingToSetting new.");
            try {
                ctNewRGB = android.provider.Settings.System.getStringForUser(this.mContext.getContentResolver(), "color_temperature_rgb", -2);
                if (ctNewRGB != null) {
                    rgbarryList = new java.util.ArrayList(java.util.Arrays.asList(ctNewRGB.split(",")));
                    red = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(0)).floatValue();
                    green = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(1)).floatValue();
                    blue = java.lang.Float.valueOf((java.lang.String) rgbarryList.get(2)).floatValue();
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("ColorTemperature read from setting:");
                    stringBuilder.append(ctNewRGB);
                    stringBuilder.append(red);
                    stringBuilder.append(green);
                    stringBuilder.append(blue);
                    android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                    updateRgbGammaInternal(red, green, blue);
                } else {
                    operation = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "color_temperature", 128, -2);
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("ColorTemperature read from old setting:");
                    stringBuilder.append(operation);
                    android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                    setColorTemperatureInternal(operation);
                }
            } catch (java.lang.UnsatisfiedLinkError e2) {
                android.util.Slog.d("HwPowerManagerService", "ColorTemperature read from setting exception!");
                updateRgbGammaInternal(1.0f, 1.0f, 1.0f);
            }
        } else {
            operation = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "color_temperature", 128, -2);
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("setColorTemperatureAccordingToSetting old:");
            stringBuilder2.append(operation);
            android.util.Slog.d("HwPowerManagerService", stringBuilder2.toString());
            setColorTemperatureInternal(operation);
        }
    }

    public int updateRgbGammaInternal(float red, float green, float blue) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateRgbGammaInternal:red=");
        stringBuilder.append(red);
        stringBuilder.append(" green=");
        stringBuilder.append(green);
        stringBuilder.append(" blue=");
        stringBuilder.append(blue);
        android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        try {
            if (!mLoadLibraryFailed) {
                return nativeUpdateRgbGamma(red, green, blue);
            }
            android.util.Slog.d("HwPowerManagerService", "nativeUpdateRgbGamma not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwPowerManagerService", "nativeUpdateRgbGamma not found!");
            return -1;
        }
    }

    private static boolean isMultiSimEnabled() {
        return false;
    }

    private boolean isPhoneInCall() {
        boolean phoneInCall = false;
        if (android.telephony.TelephonyManager.getDefault().isMultiSimEnabled()) {
            int phoneCount = android.telephony.TelephonyManager.getDefault().getPhoneCount();
            for (int i = 0; i < phoneCount; i++) {
                if (android.telephony.TelephonyManager.getDefault().getCallState(i) != 0) {
                    phoneInCall = true;
                    break;
                }
            }
            return phoneInCall;
        } else if (android.telephony.TelephonyManager.getDefault().getCallState(android.telephony.SubscriptionManager.getDefaultSubscriptionId()) != 0) {
            return true;
        } else {
            return false;
        }
    }

    public void systemReady(com.android.internal.app.IAppOpsService appOps) {
        android.content.IntentFilter headsetFilter;
        super.systemReady(appOps);
        init_SurfaceComposerClient();
        this.mPolicy = (com.android.server.policy.WindowManagerPolicy) getLocalService(com.android.server.policy.WindowManagerPolicy.class);
        this.mWindowManagerInternal = (com.android.server.wm.WindowManagerInternal) com.android.server.LocalServices.getService(com.android.server.wm.WindowManagerInternal.class);
        this.mSystemReady = true;
        this.mSupportDisplayEngine3DColorTemperature = this.mDisplayEngineManager.getSupported(18) == 1;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("systemReady mSupportDisplayEngine3DColorTemperature=");
        stringBuilder.append(this.mSupportDisplayEngine3DColorTemperature);
        android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        setColorTemperatureAccordingToSetting();
        this.mSettingsObserver = new com.android.server.power.HwPowerManagerService.SettingsObserver(this.mHandler);
        android.content.ContentResolver resolver = this.mContext.getContentResolver();
        if (!this.mSupportDisplayEngine3DColorTemperature) {
            if (!isDisplayFeatureSupported(1)) {
                resolver.registerContentObserver(android.provider.Settings.System.getUriFor("color_temperature"), false, this.mSettingsObserver, -1);
                this.mFingerSenseObserver = new com.android.server.power.HwPowerManagerService.FingerSenseObserver(this.mHandler, resolver);
                this.mFingerSenseObserver.observe();
                headsetFilter = new android.content.IntentFilter();
                headsetFilter.addAction("android.intent.action.HEADSET_PLUG");
                this.mContext.registerReceiver(new com.android.server.power.HwPowerManagerService.HeadsetReceiver(this, null), headsetFilter, null, this.mHandler);
                headsetFilter = new android.content.IntentFilter();
                headsetFilter.addAction("android.bluetooth.headset.profile.action.CONNECTION_STATE_CHANGED");
                headsetFilter.addAction("android.bluetooth.a2dp.profile.action.CONNECTION_STATE_CHANGED");
                this.mContext.registerReceiver(new com.android.server.power.HwPowerManagerService.BluetoothReceiver(this, null), headsetFilter, null, this.mHandler);
                this.mIntelliIntent = new android.content.Intent("com.huawei.intelliServer.intelliServer");
                this.mIntelliIntent.setClassName("com.huawei.intelliServer.intelliServer", "com.huawei.intelliServer.intelliServer.IntelliService");
            }
        }
        resolver.registerContentObserver(android.provider.Settings.System.getUriFor("color_temperature_rgb"), false, this.mSettingsObserver, -1);
        this.mFingerSenseObserver = new com.android.server.power.HwPowerManagerService.FingerSenseObserver(this.mHandler, resolver);
        this.mFingerSenseObserver.observe();
        headsetFilter = new android.content.IntentFilter();
        headsetFilter.addAction("android.intent.action.HEADSET_PLUG");
        this.mContext.registerReceiver(new com.android.server.power.HwPowerManagerService.HeadsetReceiver(this, null), headsetFilter, null, this.mHandler);
        headsetFilter = new android.content.IntentFilter();
        headsetFilter.addAction("android.bluetooth.headset.profile.action.CONNECTION_STATE_CHANGED");
        headsetFilter.addAction("android.bluetooth.a2dp.profile.action.CONNECTION_STATE_CHANGED");
        this.mContext.registerReceiver(new com.android.server.power.HwPowerManagerService.BluetoothReceiver(this, null), headsetFilter, null, this.mHandler);
        this.mIntelliIntent = new android.content.Intent("com.huawei.intelliServer.intelliServer");
        this.mIntelliIntent.setClassName("com.huawei.intelliServer.intelliServer", "com.huawei.intelliServer.intelliServer.IntelliService");
    }

    public int getAdjustedMaxTimeout(int oldtimeout, int maxv) {
        if (this.mWindowManagerInternal == null || this.mPolicy == null || this.mWindowManagerInternal.isCoverOpen() || this.mPolicy.isKeyguardLocked() || isPhoneInCall()) {
            return 0;
        }
        return 10000;
    }

    public void handleWakeLockDeath(com.android.server.power.PowerManagerService.WakeLock wakeLock) {
        synchronized (this.mLock) {
            int i;
            com.android.server.power.PowerManagerService.WakeLock wl;
            java.lang.StringBuilder stringBuilder;
            if (DEBUG_SPEW) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("handleWakeLockDeath: lock=");
                stringBuilder2.append(java.util.Objects.hashCode(wakeLock.mLock));
                stringBuilder2.append(" [");
                stringBuilder2.append(wakeLock.mTag);
                stringBuilder2.append("]");
                android.util.Slog.d("HwPowerManagerService", stringBuilder2.toString());
            }
            for (i = this.mForceReleasedWakeLocks.size() - 1; i >= 0; i--) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) this.mForceReleasedWakeLocks.get(i);
                if (wl.mLock == wakeLock.mLock) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("remove from forceReleased wl: ");
                    stringBuilder.append(wakeLock);
                    stringBuilder.append(" mForceReleasedWakeLocks:");
                    stringBuilder.append(wl);
                    android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                    this.mForceReleasedWakeLocks.remove(i);
                }
            }
            for (i = this.mProxyedWakeLocks.size() - 1; i >= 0; i--) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) this.mProxyedWakeLocks.get(i);
                if (wl.mLock == wakeLock.mLock) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("remove from proxyed wl: ");
                    stringBuilder.append(wakeLock);
                    stringBuilder.append(" mProxyedWakeLocks:");
                    stringBuilder.append(wl);
                    android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                    this.mProxyedWakeLocks.remove(i);
                }
            }
            super.handleWakeLockDeath(wakeLock);
        }
    }

    private void restoreProxyWakeLockLocked(int pid, int uid) {
        for (int i = this.mProxyedWakeLocks.size() - 1; i >= 0; i--) {
            com.android.server.power.PowerManagerService.WakeLock wakelock = (com.android.server.power.PowerManagerService.WakeLock) this.mProxyedWakeLocks.get(i);
            if (((wakelock.mOwnerUid == uid || -1 == uid) && (wakelock.mOwnerPid == pid || -1 == uid)) || (wakelock.mWorkSource != null && wakelock.mWorkSource.get(0) == uid)) {
                acquireWakeLockInternalLocked(wakelock.mLock, wakelock.mFlags, wakelock.mTag, wakelock.mPackageName, wakelock.mWorkSource, wakelock.mHistoryTag, wakelock.mOwnerUid, wakelock.mOwnerPid);
                this.mProxyedWakeLocks.remove(i);
            }
        }
    }

    private void removeProxyWakeLockProcessLocked(int pid, int uid) {
        for (int i = this.mProxyWLProcessList.size() - 1; i >= 0; i--) {
            if (((com.android.server.power.HwPowerManagerService.ProxyWLProcessInfo) this.mProxyWLProcessList.get(i)).isSameProcess(pid, uid)) {
                if (DEBUG_SPEW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("remove pxy wl, pid: ");
                    stringBuilder.append(pid);
                    stringBuilder.append(", uid: ");
                    stringBuilder.append(uid);
                    stringBuilder.append(" from pxy process list.");
                    android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                }
                this.mProxyWLProcessList.remove(i);
            }
        }
    }

    public void proxyWakeLockByPidUid(int pid, int uid, boolean proxy) {
        proxyWakeLockByPidUid(pid, uid, proxy, true);
    }

    private void proxyWakeLockByPidUid(int pid, int uid, boolean proxy, boolean proxyWS) {
        synchronized (this.mLock) {
            if (true == proxy) {
                try {
                    this.mProxyWLProcessList.add(new com.android.server.power.HwPowerManagerService.ProxyWLProcessInfo(pid, uid, proxyWS));
                } catch (Throwable th) {
                }
            } else {
                restoreProxyWakeLockLocked(pid, uid);
                removeProxyWakeLockProcessLocked(pid, uid);
            }
        }
    }

    /* JADX WARNING: Missing block: B:25:0x006b, code:
            if (DEBUG_SPEW == false) goto L_0x00ba;
     */
    /* JADX WARNING: Missing block: B:28:0x0071, code:
            if (dropLogs(r13, r15) != false) goto L_0x00ba;
     */
    /* JADX WARNING: Missing block: B:29:0x0073, code:
            r0 = "HwPowerManagerService";
            r1 = new java.lang.StringBuilder();
            r1.append("acquire pxy wl : lock=");
     */
    /* JADX WARNING: Missing block: B:32:?, code:
            r1.append(r31);
            r1.append(", uid: ");
            r1.append(r15);
            r1.append(", ws: ");
            r1.append(r14);
            r1.append(", packageName: ");
     */
    /* JADX WARNING: Missing block: B:35:?, code:
            r1.append(r27);
            r1.append(", tag: ");
            r1.append(r13);
            android.util.Log.d(r0, r1.toString());
     */
    /* JADX WARNING: Missing block: B:38:0x00b3, code:
            r0 = th;
     */
    /* JADX WARNING: Missing block: B:39:0x00b4, code:
            r2 = r27;
            r3 = r31;
     */
    /* JADX WARNING: Missing block: B:40:0x00ba, code:
            r2 = r27;
            r3 = r31;
     */
    /* JADX WARNING: Missing block: B:42:0x00c5, code:
            r1 = r1;
            r16 = r4;
            r17 = r5;
            r5 = r13;
            r18 = r6;
            r19 = r7;
            r20 = r8;
            r21 = r9;
            r13 = 0;
     */
    /* JADX WARNING: Missing block: B:45:0x00e4, code:
            r1 = new com.android.server.power.PowerManagerService.WakeLock(r12, r24, r25, r5, r27, r14, r29, r15, r31, new com.android.server.power.PowerManagerService.UidState(r15));
     */
    /* JADX WARNING: Missing block: B:47:?, code:
            r24.linkToDeath(r1, r13);
     */
    /* JADX WARNING: Missing block: B:49:?, code:
            r12.mProxyedWakeLocks.add(r1);
     */
    /* JADX WARNING: Missing block: B:50:0x00f0, code:
            monitor-exit(r21);
     */
    /* JADX WARNING: Missing block: B:52:0x00f2, code:
            return true;
     */
    /* JADX WARNING: Missing block: B:53:0x00f3, code:
            r0 = move-exception;
     */
    /* JADX WARNING: Missing block: B:54:0x00f4, code:
            r3 = r0;
     */
    /* JADX WARNING: Missing block: B:55:0x00fc, code:
            throw new java.lang.IllegalArgumentException("HW Wake lock is already dead.");
     */
    /* JADX WARNING: Missing block: B:56:0x00fd, code:
            r0 = th;
     */
    /* JADX WARNING: Missing block: B:57:0x00fe, code:
            r2 = r24;
     */
    /* JADX WARNING: Missing block: B:66:0x011e, code:
            r0 = th;
     */
    protected boolean acquireProxyWakeLock(android.os.IBinder r24, int r25, java.lang.String r26, java.lang.String r27, android.os.WorkSource r28, java.lang.String r29, int r30, int r31) {
        /*
        r23 = this;
        r12 = r23;
        r13 = r26;
        r14 = r28;
        r15 = r30;
        r0 = r12.mSystemReady;
        r10 = 0;
        if (r0 != 0) goto L_0x0015;
    L_0x000d:
        r0 = "HwPowerManagerService";
        r1 = "acquireProxyWakeLock, mSystemReady is false.";
        android.util.Log.w(r0, r1);
        return r10;
    L_0x0015:
        r9 = r12.mLock;
        monitor-enter(r9);
        r0 = r12.mProxyWLProcessList;	 Catch:{ all -> 0x0117 }
        r0 = r0.size();	 Catch:{ all -> 0x0117 }
        r8 = r0;
        r0 = r10;
    L_0x0020:
        r7 = r0;
        if (r7 >= r8) goto L_0x0110;
    L_0x0023:
        r0 = r31;
        r1 = r15;
        r2 = r12.mProxyWLProcessList;	 Catch:{ all -> 0x0117 }
        r2 = r2.get(r7);	 Catch:{ all -> 0x0117 }
        r2 = (com.android.server.power.HwPowerManagerService.ProxyWLProcessInfo) r2;	 Catch:{ all -> 0x0117 }
        r6 = r2;
        r2 = r6.mProxyWS;	 Catch:{ all -> 0x0117 }
        if (r2 == 0) goto L_0x0061;
    L_0x0033:
        if (r14 == 0) goto L_0x0061;
    L_0x0035:
        r0 = -1;
        r2 = r28.size();	 Catch:{ all -> 0x0117 }
        if (r2 <= 0) goto L_0x0042;
    L_0x003c:
        r2 = r14.get(r10);	 Catch:{ all -> 0x0117 }
        r1 = r2;
        goto L_0x0061;
    L_0x0042:
        r2 = r28.getWorkChains();	 Catch:{ all -> 0x0117 }
        if (r2 == 0) goto L_0x005a;
    L_0x0048:
        r3 = r2.size();	 Catch:{ all -> 0x0117 }
        if (r3 <= 0) goto L_0x005a;
    L_0x004e:
        r3 = r2.get(r10);	 Catch:{ all -> 0x0117 }
        r3 = (android.os.WorkSource.WorkChain) r3;	 Catch:{ all -> 0x0117 }
        r3 = r3.getAttributionUid();	 Catch:{ all -> 0x0117 }
        r1 = r3;
        goto L_0x0061;
    L_0x005a:
        r3 = "HwPowerManagerService";
        r4 = "acquireProxyWakeLock, workChains is empty.";
        android.util.Log.w(r3, r4);	 Catch:{ all -> 0x0117 }
    L_0x0061:
        r5 = r0;
        r4 = r1;
        r0 = r6.isSameProcess(r5, r4);	 Catch:{ all -> 0x0117 }
        if (r0 == 0) goto L_0x0101;
    L_0x0069:
        r0 = DEBUG_SPEW;	 Catch:{ all -> 0x0117 }
        if (r0 == 0) goto L_0x00ba;
    L_0x006d:
        r0 = r12.dropLogs(r13, r15);	 Catch:{ all -> 0x00b3 }
        if (r0 != 0) goto L_0x00ba;
    L_0x0073:
        r0 = "HwPowerManagerService";
        r1 = new java.lang.StringBuilder;	 Catch:{ all -> 0x00b3 }
        r1.<init>();	 Catch:{ all -> 0x00b3 }
        r2 = "acquire pxy wl : lock=";
        r1.append(r2);	 Catch:{ all -> 0x00b3 }
        r3 = r31;
        r1.append(r3);	 Catch:{ all -> 0x00ae }
        r2 = ", uid: ";
        r1.append(r2);	 Catch:{ all -> 0x00ae }
        r1.append(r15);	 Catch:{ all -> 0x00ae }
        r2 = ", ws: ";
        r1.append(r2);	 Catch:{ all -> 0x00ae }
        r1.append(r14);	 Catch:{ all -> 0x00ae }
        r2 = ", packageName: ";
        r1.append(r2);	 Catch:{ all -> 0x00ae }
        r2 = r27;
        r1.append(r2);	 Catch:{ all -> 0x0117 }
        r11 = ", tag: ";
        r1.append(r11);	 Catch:{ all -> 0x0117 }
        r1.append(r13);	 Catch:{ all -> 0x0117 }
        r1 = r1.toString();	 Catch:{ all -> 0x0117 }
        android.util.Log.d(r0, r1);	 Catch:{ all -> 0x0117 }
        goto L_0x00be;
    L_0x00ae:
        r0 = move-exception;
        r2 = r27;
        goto L_0x0118;
    L_0x00b3:
        r0 = move-exception;
        r2 = r27;
        r3 = r31;
        goto L_0x0118;
    L_0x00ba:
        r2 = r27;
        r3 = r31;
    L_0x00be:
        r11 = new com.android.server.power.PowerManagerService$UidState;	 Catch:{ all -> 0x0117 }
        r11.<init>(r15);	 Catch:{ all -> 0x0117 }
        r0 = new com.android.server.power.PowerManagerService$WakeLock;	 Catch:{ all -> 0x0117 }
        r1 = r0;
        r2 = r12;
        r3 = r24;
        r16 = r4;
        r4 = r25;
        r17 = r5;
        r5 = r13;
        r18 = r6;
        r6 = r27;
        r19 = r7;
        r7 = r14;
        r20 = r8;
        r8 = r29;
        r21 = r9;
        r9 = r15;
        r13 = r10;
        r10 = r31;
        r1.<init>(r2, r3, r4, r5, r6, r7, r8, r9, r10, r11);	 Catch:{ all -> 0x00fd }
        r1 = r0;
        r2 = r24;
        r2.linkToDeath(r1, r13);	 Catch:{ RemoteException -> 0x00f3 }
        r0 = r12.mProxyedWakeLocks;	 Catch:{ all -> 0x011e }
        r0.add(r1);	 Catch:{ all -> 0x011e }
        monitor-exit(r21);	 Catch:{ all -> 0x011e }
        r0 = 1;
        return r0;
    L_0x00f3:
        r0 = move-exception;
        r3 = r0;
        r3 = new java.lang.IllegalArgumentException;	 Catch:{ all -> 0x011e }
        r4 = "HW Wake lock is already dead.";
        r3.<init>(r4);	 Catch:{ all -> 0x011e }
        throw r3;	 Catch:{ all -> 0x011e }
    L_0x00fd:
        r0 = move-exception;
        r2 = r24;
        goto L_0x011c;
    L_0x0101:
        r2 = r24;
        r19 = r7;
        r20 = r8;
        r21 = r9;
        r13 = r10;
        r0 = r19 + 1;
        r13 = r26;
        goto L_0x0020;
    L_0x0110:
        r2 = r24;
        r21 = r9;
        r13 = r10;
        monitor-exit(r21);	 Catch:{ all -> 0x011e }
        return r13;
    L_0x0117:
        r0 = move-exception;
    L_0x0118:
        r2 = r24;
        r21 = r9;
    L_0x011c:
        monitor-exit(r21);	 Catch:{ all -> 0x011e }
        throw r0;
    L_0x011e:
        r0 = move-exception;
        goto L_0x011c;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.power.HwPowerManagerService.acquireProxyWakeLock(android.os.IBinder, int, java.lang.String, java.lang.String, android.os.WorkSource, java.lang.String, int, int):boolean");
    }

    private int findProxyWakeLockIndexLocked(android.os.IBinder lock) {
        int count = this.mProxyedWakeLocks.size();
        for (int i = 0; i < count; i++) {
            if (((com.android.server.power.PowerManagerService.WakeLock) this.mProxyedWakeLocks.get(i)).mLock == lock) {
                return i;
            }
        }
        return -1;
    }

    protected boolean updateProxyWakeLockWorkSource(android.os.IBinder lock, android.os.WorkSource ws, java.lang.String historyTag, int callingUid) {
        synchronized (this.mLock) {
            int index = findProxyWakeLockIndexLocked(lock);
            if (index < 0) {
                return false;
            }
            com.android.server.power.PowerManagerService.WakeLock wakeLock = (com.android.server.power.PowerManagerService.WakeLock) this.mProxyedWakeLocks.get(index);
            if (DEBUG_SPEW) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("update ws pxy wl : lock=");
                stringBuilder.append(java.util.Objects.hashCode(lock));
                stringBuilder.append(" [");
                stringBuilder.append(wakeLock.mTag);
                stringBuilder.append("], ws=");
                stringBuilder.append(ws);
                stringBuilder.append(", curr.ws: ");
                stringBuilder.append(wakeLock.mWorkSource);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (!wakeLock.hasSameWorkSource(ws)) {
                wakeLock.mHistoryTag = historyTag;
                wakeLock.updateWorkSource(ws);
            }
            return true;
        }
    }

    private boolean releaseWakeLockFromListLocked(android.os.IBinder lock, java.util.ArrayList<com.android.server.power.PowerManagerService.WakeLock> list) {
        int length = list.size();
        boolean ret = false;
        for (int i = length - 1; i >= 0; i--) {
            com.android.server.power.PowerManagerService.WakeLock wakelock = (com.android.server.power.PowerManagerService.WakeLock) list.get(i);
            if (wakelock.mLock == lock) {
                if (DEBUG_SPEW && !dropLogs(wakelock.mTag, wakelock.mOwnerUid)) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("release ws pxy wl : lock= wl:");
                    stringBuilder.append(wakelock);
                    stringBuilder.append(" from list, length: ");
                    stringBuilder.append(length);
                    android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                }
                try {
                    lock.unlinkToDeath(wakelock, 0);
                } catch (java.util.NoSuchElementException e) {
                    android.util.Log.d("HwPowerManagerService", "release ws pxy wl, no such Element");
                }
                list.remove(i);
                ret = true;
            }
        }
        return ret;
    }

    protected boolean releaseProxyWakeLock(android.os.IBinder lock) {
        if (this.mSystemReady) {
            boolean ret;
            synchronized (this.mLock) {
                ret = (false | releaseWakeLockFromListLocked(lock, this.mProxyedWakeLocks)) | releaseWakeLockFromListLocked(lock, this.mForceReleasedWakeLocks);
            }
            return ret;
        }
        android.util.Log.w("HwPowerManagerService", "releaseProxyWakeLock, mSystemReady is false.");
        return false;
    }

    private void releaseWakeLockInternalLocked(android.os.IBinder lock, int flags) {
        int index = findWakeLockIndexLocked(lock);
        if (index < 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("releaseWakeLockInternalLocked: lock=");
            stringBuilder.append(java.util.Objects.hashCode(lock));
            stringBuilder.append(" [not found], flags=0x");
            stringBuilder.append(java.lang.Integer.toHexString(flags));
            android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
            return;
        }
        com.android.server.power.PowerManagerService.WakeLock wakeLock = (com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(index);
        if (DEBUG_SPEW && !dropLogs(wakeLock.mTag, wakeLock.mOwnerUid)) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("releaseWakeLockInternalLocked: lock=");
            stringBuilder2.append(java.util.Objects.hashCode(lock));
            stringBuilder2.append(", flags=0x");
            stringBuilder2.append(java.lang.Integer.toHexString(flags));
            stringBuilder2.append(", tag=\"");
            stringBuilder2.append(wakeLock.mTag);
            stringBuilder2.append("\", packageName=");
            stringBuilder2.append(wakeLock.mPackageName);
            stringBuilder2.append("\", ws=");
            stringBuilder2.append(wakeLock.mWorkSource);
            stringBuilder2.append(", uid=");
            stringBuilder2.append(wakeLock.mOwnerUid);
            stringBuilder2.append(", pid=");
            stringBuilder2.append(wakeLock.mOwnerPid);
            android.util.Slog.d("HwPowerManagerService", stringBuilder2.toString());
        }
        if ((flags & 1) != 0) {
            this.mRequestWaitForNegativeProximity = true;
        }
        removeWakeLockLocked(wakeLock, index);
    }

    private void acquireWakeLockInternalLocked(android.os.IBinder lock, int flags, java.lang.String tag, java.lang.String packageName, android.os.WorkSource ws, java.lang.String historyTag, int uid, int pid) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String str = tag;
        java.lang.String str2 = packageName;
        android.os.WorkSource workSource = ws;
        int i = uid;
        int i2 = pid;
        boolean dropLogs = dropLogs(str, i);
        if (DEBUG_SPEW && !dropLogs) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("acquireWakeLockInternalLocked: lock=");
            stringBuilder.append(java.util.Objects.hashCode(lock));
            stringBuilder.append(", flags=0x");
            stringBuilder.append(java.lang.Integer.toHexString(flags));
            stringBuilder.append(", tag=\"");
            stringBuilder.append(str);
            stringBuilder.append("\", packageName=");
            stringBuilder.append(str2);
            stringBuilder.append("\", ws=");
            stringBuilder.append(workSource);
            stringBuilder.append(", uid=");
            stringBuilder.append(i);
            stringBuilder.append(", pid=");
            stringBuilder.append(i2);
            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        }
        if (lock.isBinderAlive()) {
            com.android.server.power.PowerManagerService.WakeLock wakeLock;
            int i3;
            com.android.server.power.PowerManagerService.WakeLock wakeLock2;
            int index = findWakeLockIndexLocked(lock);
            if (index >= 0) {
                if (DEBUG_SPEW && !dropLogs) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("acquireWakeLockInternalLocked: lock=");
                    stringBuilder2.append(java.util.Objects.hashCode(lock));
                    stringBuilder2.append(", existing wakelock");
                    android.util.Slog.d("HwPowerManagerService", stringBuilder2.toString());
                }
                com.android.server.power.PowerManagerService.WakeLock wakeLock3 = (com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(index);
                if (wakeLock3.hasSameProperties(flags, str, workSource, i, i2)) {
                } else {
                    notifyWakeLockChangingLocked(wakeLock3, flags, str, str2, i, i2, workSource, historyTag);
                    wakeLock3.updateProperties(flags, str, str2, workSource, historyTag, i, i2);
                }
                wakeLock = null;
                android.os.IBinder iBinder = lock;
                i3 = i;
                wakeLock2 = wakeLock3;
            } else {
                i3 = i;
                wakeLock = new com.android.server.power.PowerManagerService.WakeLock(this, lock, flags, str, str2, workSource, historyTag, i, pid, new com.android.server.power.PowerManagerService.UidState(i));
                try {
                    lock.linkToDeath(wakeLock, 0);
                    this.mWakeLocks.add(wakeLock);
                    setWakeLockDisabledStateLocked(wakeLock);
                    wakeLock2 = wakeLock;
                    wakeLock = 1;
                } catch (android.os.RemoteException ex) {
                    android.os.RemoteException remoteException = ex;
                    throw new java.lang.IllegalArgumentException("Wake lock is already dead.");
                }
            }
            applyWakeLockFlagsOnAcquireLocked(wakeLock2, i3);
            this.mDirty = 1 | this.mDirty;
            updatePowerStateLocked();
            if (wakeLock != null) {
                notifyWakeLockAcquiredLocked(wakeLock2);
            }
            return;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("lock:");
        stringBuilder.append(java.util.Objects.hashCode(lock));
        stringBuilder.append(" is already dead, tag=\"");
        stringBuilder.append(str);
        stringBuilder.append("\", packageName=");
        stringBuilder.append(str2);
        stringBuilder.append(", ws=");
        stringBuilder.append(workSource);
        stringBuilder.append(", uid=");
        stringBuilder.append(i);
        stringBuilder.append(", pid=");
        stringBuilder.append(i2);
        android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
    }

    public boolean proxyedWakeLock(int subType, java.util.List<java.lang.String> value) {
        if (value != null) {
            if (value.size() == 2) {
                boolean ret = true;
                try {
                    int pid = java.lang.Integer.parseInt((java.lang.String) value.get(0));
                    int uid = java.lang.Integer.parseInt((java.lang.String) value.get(1));
                    switch (subType) {
                        case 1:
                            dropProxyedWakeLock(pid, uid);
                            break;
                        case 2:
                            proxyWakeLockByPidUid(pid, uid, true, false);
                            break;
                        case 3:
                            forceReleaseWakeLockByPidUid(pid, uid, false);
                            break;
                        default:
                            ret = false;
                            break;
                    }
                } catch (java.lang.Exception ex) {
                    android.util.Log.e("HwPowerManagerService", "proxyedWakeLock Exception !", ex);
                    ret = false;
                }
                return ret;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("invaild para for :");
        stringBuilder.append(subType);
        stringBuilder.append(" value:");
        stringBuilder.append(value);
        android.util.Log.w("HwPowerManagerService", stringBuilder.toString());
        return false;
    }

    private void dropProxyedWakeLock(int pid, int uid) {
        synchronized (this.mLock) {
            int i;
            com.android.server.power.PowerManagerService.WakeLock wl;
            for (i = this.mForceReleasedWakeLocks.size() - 1; i >= 0; i--) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) this.mForceReleasedWakeLocks.get(i);
                if (((wl.mOwnerUid == uid || -1 == uid) && (wl.mOwnerPid == pid || -1 == pid)) || (-1 == pid && wl.mWorkSource != null && wl.mWorkSource.get(0) == uid)) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("drop from forceReleased wl: ");
                    stringBuilder.append(wl);
                    stringBuilder.append(" mForceReleasedWakeLocks:");
                    stringBuilder.append(wl);
                    android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                    this.mForceReleasedWakeLocks.remove(i);
                    wl.mLock.unlinkToDeath(wl, 0);
                }
            }
            for (i = this.mProxyedWakeLocks.size() - 1; i >= 0; i--) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) this.mProxyedWakeLocks.get(i);
                if ((-1 == uid && -1 == pid) || ((wl.mOwnerUid == uid && (wl.mOwnerPid == pid || -1 == pid)) || (-1 == pid && wl.mWorkSource != null && wl.mWorkSource.get(0) == uid))) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("drop from proxyed wl: ");
                    stringBuilder2.append(wl);
                    stringBuilder2.append(" mProxyedWakeLocks:");
                    stringBuilder2.append(wl);
                    android.util.Log.d("HwPowerManagerService", stringBuilder2.toString());
                    this.mProxyedWakeLocks.remove(i);
                    wl.mLock.unlinkToDeath(wl, 0);
                }
            }
        }
    }

    public void forceReleaseWakeLockByPidUid(int pid, int uid) {
        forceReleaseWakeLockByPidUid(pid, uid, true);
    }

    private void forceReleaseWakeLockByPidUid(int pid, int uid, boolean releaseWS) {
        java.lang.Throwable th;
        int length = pid;
        int i = uid;
        synchronized (this.mLock) {
            int i2;
            int i3;
            try {
                int size = this.mWakeLocks.size();
                int i4 = size - 1;
                while (true) {
                    int i5 = i4;
                    if (i5 >= 0) {
                        int size2;
                        int i6;
                        com.android.server.power.PowerManagerService.WakeLock wakelock = (com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(i5);
                        if (!releaseWS || wakelock.mWorkSource == null) {
                            size2 = size;
                            com.android.server.power.PowerManagerService.WakeLock wakelock2 = wakelock;
                            i6 = i5;
                            if (wakelock2.mWorkSource == null) {
                                i2 = pid;
                                if (wakelock2.mOwnerPid == i2) {
                                    try {
                                        i3 = uid;
                                        if (wakelock2.mOwnerUid == i3) {
                                            if (DEBUG_SPEW) {
                                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                                stringBuilder.append("forceReleaseWakeLockByPidUid, ws null, pid: ");
                                                stringBuilder.append(i2);
                                                stringBuilder.append(", uid: ");
                                                stringBuilder.append(i3);
                                                stringBuilder.append(", wakelock: ");
                                                stringBuilder.append(wakelock2);
                                                android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                                            }
                                            this.mForceReleasedWakeLocks.add(wakelock2);
                                            releaseWakeLockInternalLocked(wakelock2.mLock, wakelock2.mFlags);
                                        }
                                        i4 = i6 - 1;
                                        length = i2;
                                        i = i3;
                                        size = size2;
                                    } catch (Throwable th2) {
                                        th = th2;
                                        throw th;
                                    }
                                }
                                i3 = uid;
                                i4 = i6 - 1;
                                length = i2;
                                i = i3;
                                size = size2;
                            }
                        } else {
                            int length2 = wakelock.mWorkSource.size();
                            i4 = 0;
                            java.lang.StringBuilder stringBuilder2;
                            if (1 == length2) {
                                if (wakelock.mWorkSource.get(0) == i) {
                                    if (DEBUG_SPEW) {
                                        stringBuilder2 = new java.lang.StringBuilder();
                                        stringBuilder2.append("forceReleaseWakeLockByPidUid, last one, wakelock: ");
                                        stringBuilder2.append(wakelock);
                                        android.util.Log.d("HwPowerManagerService", stringBuilder2.toString());
                                    }
                                    this.mForceReleasedWakeLocks.add(wakelock);
                                    releaseWakeLockInternalLocked(wakelock.mLock, wakelock.mFlags);
                                }
                                size2 = size;
                                size = wakelock;
                                i6 = i5;
                            } else if (length2 > 1) {
                                while (true) {
                                    int j = i4;
                                    if (j >= length2) {
                                        break;
                                    }
                                    int j2;
                                    if (wakelock.mWorkSource.get(j) == i) {
                                        android.os.WorkSource workSource;
                                        if (DEBUG_SPEW) {
                                            stringBuilder2 = new java.lang.StringBuilder();
                                            stringBuilder2.append("forceReleaseWakeLockByPidUid, more than one, wakelock: ");
                                            stringBuilder2.append(wakelock);
                                            android.util.Log.d("HwPowerManagerService", stringBuilder2.toString());
                                        }
                                        java.lang.String name = wakelock.mWorkSource.getName(j);
                                        if (name == null) {
                                            workSource = new android.os.WorkSource(i);
                                        } else {
                                            workSource = new android.os.WorkSource(i, name);
                                        }
                                        android.os.WorkSource workSource2 = workSource;
                                        com.android.server.power.PowerManagerService.UidState state = new com.android.server.power.PowerManagerService.UidState(i);
                                        android.os.IBinder iBinder = wakelock.mLock;
                                        int i7 = wakelock.mFlags;
                                        java.lang.String str = wakelock.mTag;
                                        java.lang.String str2 = wakelock.mPackageName;
                                        size2 = size;
                                        size = wakelock.mHistoryTag;
                                        i6 = i5;
                                        try {
                                            java.lang.String str3 = str2;
                                            com.android.server.power.PowerManagerService.WakeLock wakeLock = wakeLock;
                                            android.os.WorkSource workSource3 = workSource2;
                                            name = str3;
                                            j2 = j;
                                            length = length2;
                                            java.lang.String str4 = size;
                                            size = wakelock;
                                            com.android.server.power.PowerManagerService.WakeLock cacheWakelock = new com.android.server.power.PowerManagerService.WakeLock(this, iBinder, i7, str, name, workSource3, str4, wakelock.mOwnerUid, wakelock.mOwnerPid, state);
                                            this.mForceReleasedWakeLocks.add(cacheWakelock);
                                            android.os.WorkSource newWorkSource = new android.os.WorkSource(size.mWorkSource);
                                            android.os.WorkSource workSource4 = workSource3;
                                            newWorkSource.remove(workSource4);
                                            i5 = workSource4;
                                            notifyWakeLockChangingLocked(size, size.mFlags, size.mTag, size.mPackageName, size.mOwnerUid, size.mOwnerPid, newWorkSource, size.mHistoryTag);
                                            size.mWorkSource.remove(i5);
                                        } catch (Throwable th3) {
                                            th = th3;
                                            i2 = pid;
                                            i3 = uid;
                                            throw th;
                                        }
                                    }
                                    size2 = size;
                                    j2 = j;
                                    length = length2;
                                    size = wakelock;
                                    i6 = i5;
                                    i4 = j2 + 1;
                                    wakelock = size;
                                    length2 = length;
                                    size = size2;
                                    i5 = i6;
                                    length = pid;
                                    i = uid;
                                }
                                size2 = size;
                                length = length2;
                                size = wakelock;
                                i6 = i5;
                            } else {
                                size2 = size;
                                length = length2;
                                size = wakelock;
                                i6 = i5;
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("forceReleaseWakeLockByPidUid, length invalid: ");
                                stringBuilder2.append(length);
                                android.util.Log.e("HwPowerManagerService", stringBuilder2.toString());
                            }
                        }
                        i2 = pid;
                        i3 = uid;
                        i4 = i6 - 1;
                        length = i2;
                        i = i3;
                        size = size2;
                    } else {
                        i2 = length;
                        i3 = i;
                        return;
                    }
                }
            } catch (Throwable th4) {
                th = th4;
                i2 = length;
                i3 = i;
                throw th;
            }
        }
    }

    public void forceRestoreWakeLockByPidUid(int pid, int uid) {
        int i = pid;
        int i2 = uid;
        synchronized (this.mLock) {
            int size = this.mForceReleasedWakeLocks.size();
            int i3 = size - 1;
            while (true) {
                int i4 = i3;
                if (i4 >= 0) {
                    int size2;
                    com.android.server.power.PowerManagerService.WakeLock wakelock = (com.android.server.power.PowerManagerService.WakeLock) this.mForceReleasedWakeLocks.get(i4);
                    java.lang.StringBuilder stringBuilder;
                    if (wakelock.mWorkSource == null) {
                        if (wakelock.mOwnerPid != i) {
                            if (-1 == i) {
                            }
                        }
                        if (wakelock.mOwnerUid == i2 || -1 == i2) {
                            if (DEBUG_SPEW) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("forceRestoreWakeLockByPidUid, WorkSource == null, wakelock: ");
                                stringBuilder.append(wakelock);
                                android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                            }
                            acquireWakeLockInternalLocked(wakelock.mLock, wakelock.mFlags, wakelock.mTag, wakelock.mPackageName, wakelock.mWorkSource, wakelock.mHistoryTag, wakelock.mOwnerUid, wakelock.mOwnerPid);
                            this.mForceReleasedWakeLocks.remove(i4);
                        }
                    } else if (wakelock.mWorkSource.get(0) == i2 || -1 == i2) {
                        int index = findWakeLockIndexLocked(wakelock.mLock);
                        if (index < 0) {
                            if (DEBUG_SPEW) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("forceRestoreWakeLockByPidUid, not found base, wakelock: ");
                                stringBuilder.append(wakelock);
                                android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                            }
                            size2 = size;
                            size = index;
                            acquireWakeLockInternalLocked(wakelock.mLock, wakelock.mFlags, wakelock.mTag, wakelock.mPackageName, wakelock.mWorkSource, wakelock.mHistoryTag, wakelock.mOwnerUid, wakelock.mOwnerPid);
                        } else {
                            size2 = size;
                            size = index;
                            if (DEBUG_SPEW) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("forceRestoreWakeLockByPidUid, update exist, wakelock: ");
                                stringBuilder.append(wakelock);
                                android.util.Log.d("HwPowerManagerService", stringBuilder.toString());
                            }
                            android.os.WorkSource newWorkSource = new android.os.WorkSource(((com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(size)).mWorkSource);
                            newWorkSource.add(wakelock.mWorkSource);
                            notifyWakeLockChangingLocked((com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(size), wakelock.mFlags, wakelock.mTag, wakelock.mPackageName, wakelock.mOwnerUid, wakelock.mOwnerPid, newWorkSource, wakelock.mHistoryTag);
                            ((com.android.server.power.PowerManagerService.WakeLock) this.mWakeLocks.get(size)).mWorkSource.add(wakelock.mWorkSource);
                        }
                        this.mForceReleasedWakeLocks.remove(i4);
                        i3 = i4 - 1;
                        size = size2;
                    }
                    size2 = size;
                    i3 = i4 - 1;
                    size = size2;
                }
            }
        }
    }

    /* JADX WARNING: Missing block: B:16:0x0031, code:
            return true;
     */
    public boolean getWakeLockByUid(int r11, int r12) {
        /*
        r10 = this;
        r0 = r10.mLock;
        monitor-enter(r0);
        r1 = r10.mWakeLocks;	 Catch:{ all -> 0x007f }
        r1 = r1.size();	 Catch:{ all -> 0x007f }
        r2 = 0;
        if (r1 > 0) goto L_0x000e;
    L_0x000c:
        monitor-exit(r0);	 Catch:{ all -> 0x007f }
        return r2;
    L_0x000e:
        r1 = r10.mWakeLocks;	 Catch:{ all -> 0x007f }
        r1 = r1.iterator();	 Catch:{ all -> 0x007f }
    L_0x0014:
        r3 = r1.hasNext();	 Catch:{ all -> 0x007f }
        if (r3 == 0) goto L_0x007d;
    L_0x001a:
        r3 = r1.next();	 Catch:{ all -> 0x007f }
        r3 = (com.android.server.power.PowerManagerService.WakeLock) r3;	 Catch:{ all -> 0x007f }
        r4 = r3.mOwnerUid;	 Catch:{ all -> 0x007f }
        r5 = 65535; // 0xffff float:9.1834E-41 double:3.23786E-319;
        r6 = -1;
        r7 = 1;
        if (r4 != r11) goto L_0x0032;
    L_0x0029:
        if (r6 == r12) goto L_0x0030;
    L_0x002b:
        r4 = r3.mFlags;	 Catch:{ all -> 0x007f }
        r4 = r4 & r5;
        if (r4 != r12) goto L_0x007c;
    L_0x0030:
        monitor-exit(r0);	 Catch:{ all -> 0x007f }
        return r7;
    L_0x0032:
        r4 = r3.mWorkSource;	 Catch:{ all -> 0x007f }
        if (r4 == 0) goto L_0x007c;
    L_0x0036:
        r4 = r3.mWorkSource;	 Catch:{ all -> 0x007f }
        r4 = r4.size();	 Catch:{ all -> 0x007f }
        r8 = r2;
    L_0x003d:
        if (r8 >= r4) goto L_0x007c;
    L_0x003f:
        r9 = r3.mWorkSource;	 Catch:{ all -> 0x007f }
        r9 = r9.get(r8);	 Catch:{ all -> 0x007f }
        if (r11 != r9) goto L_0x0079;
    L_0x0047:
        if (r6 == r12) goto L_0x004e;
    L_0x0049:
        r9 = r3.mFlags;	 Catch:{ all -> 0x007f }
        r9 = r9 & r5;
        if (r9 != r12) goto L_0x0079;
    L_0x004e:
        r2 = "HwPowerManagerService";
        r5 = new java.lang.StringBuilder;	 Catch:{ all -> 0x007f }
        r5.<init>();	 Catch:{ all -> 0x007f }
        r6 = "worksource not null, i:";
        r5.append(r6);	 Catch:{ all -> 0x007f }
        r5.append(r8);	 Catch:{ all -> 0x007f }
        r6 = ", size: ";
        r5.append(r6);	 Catch:{ all -> 0x007f }
        r5.append(r4);	 Catch:{ all -> 0x007f }
        r6 = ", flags: ";
        r5.append(r6);	 Catch:{ all -> 0x007f }
        r6 = r3.mFlags;	 Catch:{ all -> 0x007f }
        r5.append(r6);	 Catch:{ all -> 0x007f }
        r5 = r5.toString();	 Catch:{ all -> 0x007f }
        android.util.Log.d(r2, r5);	 Catch:{ all -> 0x007f }
        monitor-exit(r0);	 Catch:{ all -> 0x007f }
        return r7;
    L_0x0079:
        r8 = r8 + 1;
        goto L_0x003d;
    L_0x007c:
        goto L_0x0014;
    L_0x007d:
        monitor-exit(r0);	 Catch:{ all -> 0x007f }
        return r2;
    L_0x007f:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x007f }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.power.HwPowerManagerService.getWakeLockByUid(int, int):boolean");
    }

    public void setLcdRatio(int ratio, boolean autoAdjust) {
        this.mLightsManager.getLight(0).setLcdRatio(ratio, autoAdjust);
    }

    public void configBrightnessRange(int ratioMin, int ratioMax, int autoLimit) {
        this.mLightsManager.getLight(0).configBrightnessRange(ratioMin, ratioMax, autoLimit);
    }

    private void enableBrightnessWaitLocked() {
        if (!this.mBrightnessWaitModeEnabled) {
            this.mBrightnessWaitModeEnabled = true;
            this.mBrightnessWaitRet = false;
            this.mSkipWaitKeyguardDismiss = false;
            this.mDirty |= 16384;
            android.os.Message msg = this.mHandler.obtainMessage(101);
            msg.setAsynchronous(true);
            this.mHandler.sendMessageDelayed(msg, (long) this.mWaitBrightTimeout);
        }
        this.mAuthSucceeded = false;
    }

    protected void disableBrightnessWaitLocked(boolean enableBright) {
        disableBrightnessWaitLocked(enableBright, false);
    }

    protected void disableBrightnessWaitLocked(boolean enableBright, boolean skipWaitKeyguardDismiss) {
        if (this.mBrightnessWaitModeEnabled) {
            this.mHandler.removeMessages(101);
            this.mBrightnessWaitModeEnabled = false;
            this.mBrightnessWaitRet = enableBright;
            this.mSkipWaitKeyguardDismiss = skipWaitKeyguardDismiss;
            this.mDirty |= 16384;
        }
        this.mAuthSucceeded = false;
    }

    protected void setAuthSucceededInternal() {
        synchronized (this.mLock) {
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setAuthSucceededInternal, mBrightnessWaitModeEnabled = ");
                stringBuilder.append(this.mBrightnessWaitModeEnabled);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            this.mAuthSucceeded = true;
        }
    }

    protected void startWakeUpReadyInternal(long eventTime, int uid, java.lang.String opPackageName) {
        synchronized (this.mLock) {
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("UL_Power startWakeUpReadyInternal, mBrightnessWaitModeEnabled = ");
                stringBuilder.append(this.mBrightnessWaitModeEnabled);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (this.mBrightnessWaitModeEnabled) {
                resetWaitBrightTimeoutLocked();
            } else {
                if (!"com.android.systemui".equals(opPackageName)) {
                    this.mPolicy.setPickUpFlag();
                    this.mPolicy.setSyncPowerStateFlag();
                }
                if (wakeUpNoUpdateWithoutInteractiveLocked(eventTime, "startWakeUpReady", uid, opPackageName)) {
                    enableBrightnessWaitLocked();
                    updatePowerStateLocked();
                }
            }
        }
    }

    protected void setPowerStateInternal(boolean state) {
        java.lang.String para = state ? "1" : "0";
        setPowerStateValue("/sys/class/hw_power/charger/charge_data/enable_charger", para);
        setPowerStateValue("/sys/class/hw_power/charger/direct_charger/enable_charger", para);
    }

    public int getDisplayPanelTypeInternal() {
        int type = -1;
        try {
            if (mLoadLibraryFailed) {
                android.util.Slog.d("HwPowerManagerService", "nativeGetDisplayPanelType failed because of library not found!");
            } else {
                type = nativeGetDisplayPanelType();
            }
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwPowerManagerService", "nativeGetDisplayPanelType not found!");
        }
        return type;
    }

    protected int hwBrightnessSetDataInternal(java.lang.String name, android.os.Bundle data) {
        int[] result = new int[]{0};
        if (this.mDisplayManagerInternal.hwBrightnessSetData(name, data, result)) {
            return result[0];
        }
        com.android.server.power.HwPowerManagerService.HwBrightnessInnerProcessor processor = (com.android.server.power.HwPowerManagerService.HwBrightnessInnerProcessor) this.mHwBrightnessInnerProcessors.get(name);
        if (processor != null) {
            return processor.setData(data);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("There is no process to deal with setData(");
        stringBuilder.append(name);
        stringBuilder.append(")");
        android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
        return -1;
    }

    protected int hwBrightnessGetDataInternal(java.lang.String name, android.os.Bundle data) {
        int[] result = new int[]{0};
        if (this.mDisplayManagerInternal.hwBrightnessGetData(name, data, result)) {
            return result[0];
        }
        com.android.server.power.HwPowerManagerService.HwBrightnessInnerProcessor processor = (com.android.server.power.HwPowerManagerService.HwBrightnessInnerProcessor) this.mHwBrightnessInnerProcessors.get(name);
        if (processor != null) {
            return processor.getData(data);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("There is no process to deal with getData(");
        stringBuilder.append(name);
        stringBuilder.append(")");
        android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
        return -1;
    }

    protected int hwBrightnessRegisterCallbackInternal(android.os.IHwBrightnessCallback cb, java.util.List<java.lang.String> filter) {
        synchronized (this.mLockHwBrightnessCallbacks) {
            this.mHwBrightnessCallbacks.add(new com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData(cb, filter));
        }
        return 0;
    }

    protected int hwBrightnessUnregisterCallbackInternal(android.os.IHwBrightnessCallback cb) {
        synchronized (this.mLockHwBrightnessCallbacks) {
            int size = this.mHwBrightnessCallbacks.size();
            for (int i = 0; i < size; i++) {
                if (((com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData) this.mHwBrightnessCallbacks.get(i)).getCB() == cb) {
                    this.mHwBrightnessCallbacks.remove(i);
                    return 0;
                }
            }
            android.util.Slog.i("HwPowerManagerService", "Unknown callback!");
            return -1;
        }
    }

    private boolean needHwBrightnessNotify(java.lang.String what, java.util.List<java.lang.String> filter) {
        boolean need = false;
        if (filter == null) {
            return true;
        }
        int size = filter.size();
        for (int i = 0; i < size; i++) {
            if (what.equals(filter.get(i))) {
                need = true;
                break;
            }
        }
        return need;
    }

    protected void notifyHwBrightnessCallbacks(java.lang.String what, int arg1, int arg2, android.os.Bundle data) {
        java.lang.Throwable th;
        synchronized (this.mLockHwBrightnessCallbacks) {
            java.lang.String str;
            try {
                int size = this.mHwBrightnessCallbacks.size();
                int i = 0;
                while (true) {
                    int i2 = i;
                    if (i2 < size) {
                        com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData d = (com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData) this.mHwBrightnessCallbacks.get(i2);
                        str = what;
                        if (needHwBrightnessNotify(str, d.getFilter())) {
                            final com.android.server.power.HwPowerManagerService.HwBrightnessCallbackData hwBrightnessCallbackData = d;
                            final java.lang.String str2 = str;
                            final int i3 = arg1;
                            final int i4 = arg2;
                            final android.os.Bundle bundle = data;
                            new java.lang.Thread(new java.lang.Runnable() {
                                public void run() {
                                    try {
                                        hwBrightnessCallbackData.getCB().onStatusChanged(str2, i3, i4, bundle);
                                    } catch (android.os.RemoteException e) {
                                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                        stringBuilder.append("Failed to notify callback! Error:");
                                        stringBuilder.append(e.getMessage());
                                        android.util.Slog.w("HwPowerManagerService", stringBuilder.toString());
                                    }
                                }
                            }).start();
                        }
                        i = i2 + 1;
                    } else {
                        str = what;
                        return;
                    }
                }
            } catch (Throwable th2) {
                th = th2;
                throw th;
            }
        }
    }

    private void loadHwBrightnessInnerProcessors() {
    }

    protected void stopPickupTrunOff() {
        if (com.android.server.policy.PickUpWakeScreenManager.isPickupSensorSupport(this.mContext) && com.android.server.policy.PickUpWakeScreenManager.getInstance() != null) {
            com.android.server.policy.PickUpWakeScreenManager.getInstance().stopTrunOffScrren();
        }
    }

    protected void resetWaitBrightTimeoutLocked() {
        this.mHandler.removeMessages(101);
        android.os.Message msg = this.mHandler.obtainMessage(101);
        msg.setAsynchronous(true);
        this.mHandler.sendMessageDelayed(msg, (long) this.mWaitBrightTimeout);
    }

    protected void stopWakeUpReadyInternal(long eventTime, int uid, boolean enableBright, java.lang.String opPackageName) {
        synchronized (this.mLock) {
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("UL_Power stopWakeUpReadyInternal, mBrightnessWaitModeEnabled = ");
                stringBuilder.append(this.mBrightnessWaitModeEnabled);
                stringBuilder.append(" enableBright = ");
                stringBuilder.append(enableBright);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (this.mBrightnessWaitModeEnabled) {
                if (!"com.android.systemui".equals(opPackageName)) {
                    this.mPolicy.setSyncPowerStateFlag();
                }
                if (enableBright) {
                    this.mLastWakeTime = eventTime;
                    setWakefulnessLocked(1, 0);
                    userActivityNoUpdateLocked(eventTime, 0, 0, uid);
                    disableBrightnessWaitLocked(true, "com.android.systemui".equals(opPackageName) ^ 1);
                    updatePowerStateLocked();
                } else {
                    goToSleepNoUpdateLocked(eventTime, 0, 0, uid);
                    updatePowerStateLocked();
                }
            } else if (enableBright) {
                if (DEBUG) {
                    android.util.Slog.d("HwPowerManagerService", "UL_Power stopWakeUpReadyInternal, brightness wait timeout.");
                }
                if (wakeUpNoUpdateLocked(eventTime, "BrightnessWaitTimeout", uid, opPackageName, uid)) {
                    updatePowerStateLocked();
                }
            }
        }
    }

    private boolean wakeUpNoUpdateWithoutInteractiveLocked(long eventTime, java.lang.String reason, int uid, java.lang.String opPackageName) {
        if (DEBUG_SPEW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("UL_Power wakeUpNoUpdateWithoutInteractiveLocked: eventTime=");
            stringBuilder.append(eventTime);
            stringBuilder.append(", uid=");
            stringBuilder.append(uid);
            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        }
        if (eventTime >= this.mLastSleepTime && this.mWakefulness != 1 && this.mBootCompleted && this.mSystemReady) {
            if (!this.mProximityPositive) {
                if (mSupportFaceDetect) {
                    startIntelliService();
                }
                android.os.Trace.traceBegin(131072, "wakeUpWithoutInteractive");
                try {
                    int i = this.mWakefulness;
                    java.lang.StringBuilder stringBuilder2;
                    if (i != 0) {
                        switch (i) {
                            case 2:
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("UL_Power Waking up from dream (uid ");
                                stringBuilder2.append(uid);
                                stringBuilder2.append(")...");
                                android.util.Slog.i("HwPowerManagerService", stringBuilder2.toString());
                                android.util.Jlog.d(6, "JL_PMS_WAKEFULNESS_DREAMING");
                                break;
                            case 3:
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("UL_Power Waking up from dozing (uid ");
                                stringBuilder2.append(uid);
                                stringBuilder2.append(")...");
                                android.util.Slog.i("HwPowerManagerService", stringBuilder2.toString());
                                android.util.Jlog.d(7, "JL_PMS_WAKEFULNESS_NAPPING");
                                break;
                            default:
                                break;
                        }
                    }
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("UL_Power Waking up from sleep (uid ");
                    stringBuilder2.append(uid);
                    stringBuilder2.append(")...");
                    android.util.Slog.i("HwPowerManagerService", stringBuilder2.toString());
                    android.util.Jlog.d(5, "JL_PMS_WAKEFULNESS_ASLEEP");
                    this.mLastWakeTime = eventTime;
                    this.mDirty |= 2;
                    this.mWakefulness = 1;
                    this.mNotifier.onWakeUp(reason, uid, opPackageName, uid);
                    userActivityNoUpdateLocked(eventTime, 0, 0, uid);
                    return true;
                } finally {
                    android.os.Trace.traceEnd(131072);
                }
            }
        }
        notifyWakeupResult(false);
        return false;
    }

    protected void handleWaitBrightTimeout() {
        synchronized (this.mLock) {
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("UL_Power handleWaitBrightTimeout mBrightnessWaitModeEnabled = ");
                stringBuilder.append(this.mBrightnessWaitModeEnabled);
                stringBuilder.append(" mWakefulness = ");
                stringBuilder.append(this.mWakefulness);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (this.mBrightnessWaitModeEnabled) {
                if (!goToSleepNoUpdateLocked(android.os.SystemClock.uptimeMillis(), 101, 0, 1000)) {
                    disableBrightnessWaitLocked(false);
                }
                updatePowerStateLocked();
            }
        }
    }

    public boolean isAppWakeLockFilterTag(int flags, java.lang.String packageName, android.os.WorkSource ws) {
        if (this.mPGManagerInternal == null) {
            this.mPGManagerInternal = (com.android.server.pg.PGManagerInternal) com.android.server.LocalServices.getService(com.android.server.pg.PGManagerInternal.class);
        }
        if (this.mPGManagerInternal != null) {
            return this.mPGManagerInternal.isGmsWakeLockFilterTag(flags, packageName, ws);
        }
        return false;
    }

    public boolean isSkipWakeLockUsing(int uid, java.lang.String tag) {
        synchronized (this.mLock) {
            if (tag == null) {
                try {
                    return false;
                } catch (Throwable th) {
                }
            } else if (this.mWakeLocks.size() <= 0) {
                return false;
            } else {
                java.util.Iterator<com.android.server.power.PowerManagerService.WakeLock> it = this.mWakeLocks.iterator();
                while (it.hasNext()) {
                    com.android.server.power.PowerManagerService.WakeLock wl = (com.android.server.power.PowerManagerService.WakeLock) it.next();
                    if (wl.mOwnerUid == uid) {
                        if (tag.equals(wl.mTag)) {
                            return true;
                        }
                    } else if (wl.mWorkSource != null) {
                        int size = wl.mWorkSource.size();
                        for (int i = 0; i < size; i++) {
                            if (uid == wl.mWorkSource.get(i) && tag.equals(wl.mTag)) {
                                return true;
                            }
                        }
                        continue;
                    } else {
                        continue;
                    }
                }
                return false;
            }
        }
    }

    public void dumpInternal(java.io.PrintWriter pw) {
        super.dumpInternal(pw);
        pw.println("Proxyed WakeLocks State");
        synchronized (this.mLock) {
            com.android.server.power.PowerManagerService.WakeLock wl;
            java.lang.StringBuilder stringBuilder;
            java.util.Iterator it = this.mProxyedWakeLocks.iterator();
            while (it.hasNext()) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) it.next();
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(" Proxyed WakeLocks :");
                stringBuilder.append(wl);
                pw.println(stringBuilder.toString());
            }
            it = this.mForceReleasedWakeLocks.iterator();
            while (it.hasNext()) {
                wl = (com.android.server.power.PowerManagerService.WakeLock) it.next();
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(" Force Released WakeLocks :");
                stringBuilder.append(wl);
                pw.println(stringBuilder.toString());
            }
        }
    }

    protected void sendTempBrightnessToMonitor(java.lang.String paramType, int brightness) {
        if (this.mDisplayEffectMonitor != null) {
            java.lang.String[] packageName = this.mContext.getPackageManager().getNameForUid(android.os.Binder.getCallingUid()).split(":");
            if (packageName.length != 0) {
                android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
                params.put("paramType", paramType);
                params.put("brightness", java.lang.Integer.valueOf(brightness));
                params.put("packageName", packageName[0]);
                this.mDisplayEffectMonitor.sendMonitorParam(params);
            }
        }
    }

    protected void sendBrightnessModeToMonitor(boolean manualMode, java.lang.String packageName) {
        if (this.mDisplayEffectMonitor != null) {
            if (!this.mHadSendBrightnessModeToMonitor) {
                packageName = "android";
                this.mHadSendBrightnessModeToMonitor = true;
            }
            android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
            params.put("paramType", "brightnessMode");
            params.put("brightnessMode", manualMode ? "MANUAL" : "AUTO");
            params.put("packageName", packageName);
            this.mDisplayEffectMonitor.sendMonitorParam(params);
        }
    }

    protected void sendManualBrightnessToMonitor(int brightness, java.lang.String packageName) {
        if (this.mDisplayEffectMonitor != null) {
            if (!this.mHadSendManualBrightnessToMonitor) {
                packageName = "android";
                this.mHadSendManualBrightnessToMonitor = true;
            }
            android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
            params.put("paramType", "manualBrightness");
            params.put("brightness", java.lang.Integer.valueOf(brightness));
            params.put("packageName", packageName);
            this.mDisplayEffectMonitor.sendMonitorParam(params);
        }
    }

    protected void sendBootCompletedToMonitor() {
        if (this.mDisplayEffectMonitor != null) {
            android.util.ArrayMap<java.lang.String, java.lang.Object> params = new android.util.ArrayMap();
            params.put("paramType", "bootCompleted");
            this.mDisplayEffectMonitor.sendMonitorParam(params);
        }
    }

    protected void notifyWakeupResult(boolean isWakenupThisTime) {
        com.android.server.rms.iaware.appmng.AwareFakeActivityRecg.self().notifyWakeupResult(isWakenupThisTime);
    }

    protected void startIntelliService() {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("bind IntelliService, mIntelliServiceBound=");
            stringBuilder.append(this.mIntelliServiceBound);
            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        }
        if (!this.mIntelliServiceBound) {
            this.mHandler.post(new java.lang.Runnable() {
                public void run() {
                    java.lang.StringBuilder stringBuilder;
                    try {
                        com.android.server.power.HwPowerManagerService.this.mIntelliServiceBound = true;
                        boolean success = com.android.server.power.HwPowerManagerService.this.mContext.bindServiceAsUser(com.android.server.power.HwPowerManagerService.this.mIntelliIntent, com.android.server.power.HwPowerManagerService.this.connection, 1, android.os.UserHandle.CURRENT);
                        if (com.android.server.power.PowerManagerService.DEBUG) {
                            stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("bind IntelliService, success=");
                            stringBuilder.append(success);
                            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                        }
                        if (!success) {
                            com.android.server.power.HwPowerManagerService.this.resetFaceDetect();
                        }
                    } catch (java.lang.SecurityException e) {
                        com.android.server.power.HwPowerManagerService.this.resetFaceDetect();
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("unable to start intelli service: ");
                        stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mIntelliIntent);
                        android.util.Slog.e("HwPowerManagerService", stringBuilder.toString(), e);
                    } catch (java.lang.Exception e2) {
                        com.android.server.power.HwPowerManagerService.this.resetFaceDetect();
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("unable to start intelli service: ");
                        stringBuilder.append(com.android.server.power.HwPowerManagerService.this.mIntelliIntent);
                        android.util.Slog.e("HwPowerManagerService", stringBuilder.toString(), e2);
                    }
                }
            });
        }
    }

    protected void stopIntelliService() {
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("unbind IntelliService, mIntelliServiceBound=");
            stringBuilder.append(this.mIntelliServiceBound);
            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
        }
        if (this.mIntelliServiceBound) {
            this.mHandler.post(new java.lang.Runnable() {
                public void run() {
                    try {
                        com.android.server.power.HwPowerManagerService.this.mContext.unbindService(com.android.server.power.HwPowerManagerService.this.connection);
                    } catch (java.lang.Exception e) {
                        android.util.Slog.e("HwPowerManagerService", "unbindService fail: ", e);
                    }
                }
            });
            resetFaceDetect();
        }
    }

    protected int registerFaceDetect() {
        if (this.mIntelliServiceBound) {
            if (this.mIRemote != null) {
                if (!this.mFaceDetecting) {
                    try {
                        int result = this.mIRemote.registListener(3, this.mIntelliListener);
                        if (DEBUG) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("registListener, result=");
                            stringBuilder.append(result);
                            android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
                        }
                        if (result != -1) {
                            this.mFaceDetecting = true;
                        }
                        return result;
                    } catch (android.os.RemoteException e) {
                        android.util.Slog.e("HwPowerManagerService", "registListener exption: ", e);
                        return -1;
                    } catch (java.lang.Exception e2) {
                        android.util.Slog.e("HwPowerManagerService", "registListener exption: ", e2);
                        return -1;
                    }
                }
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("register err, mFaceDetecting=");
            stringBuilder2.append(this.mFaceDetecting);
            android.util.Slog.e("HwPowerManagerService", stringBuilder2.toString());
            return -1;
        }
        android.util.Slog.i("HwPowerManagerService", "IntelliService not started, face detect later");
        this.mShouldFaceDetectLater = true;
        startIntelliService();
        return -1;
    }

    protected int unregisterFaceDetect() {
        if (!this.mFaceDetecting) {
            return -1;
        }
        if (this.mIRemote == null) {
            android.util.Slog.e("HwPowerManagerService", "unregister err mIRemote is null!!");
            return -1;
        }
        try {
            int result = this.mIRemote.unregistListener(3, this.mIntelliListener);
            if (DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("unregistListener, result=");
                stringBuilder.append(result);
                android.util.Slog.d("HwPowerManagerService", stringBuilder.toString());
            }
            if (result != -1) {
                this.mFaceDetecting = false;
            }
            return result;
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("HwPowerManagerService", "unregistListener exption: ", e);
            return -1;
        } catch (java.lang.Exception e2) {
            android.util.Slog.e("HwPowerManagerService", "unregistListener exption: ", e2);
            return -1;
        }
    }

    private void resetFaceDetect() {
        this.mIntelliServiceBound = false;
        this.mFaceDetecting = false;
        this.mShouldFaceDetectLater = false;
        this.mIRemote = null;
    }

    private void setPowerStateValue(java.lang.String path, java.lang.String para) {
        java.io.IOException e;
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        java.io.FileOutputStream fileOutputStream = null;
        try {
            fileOutputStream = new java.io.FileOutputStream(path);
            fileOutputStream.write(para.getBytes(java.nio.charset.Charset.forName("UTF-8")));
            fileOutputStream.flush();
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("setPowerState as ");
            stringBuilder2.append(para);
            stringBuilder2.append(", path:");
            stringBuilder2.append(path);
            android.util.Slog.i("HwPowerManagerService", stringBuilder2.toString());
            try {
                fileOutputStream.close();
            } catch (java.io.IOException e2) {
                e = e2;
                str = "HwPowerManagerService";
                stringBuilder = new java.lang.StringBuilder();
            }
        } catch (java.io.FileNotFoundException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setPowerStateValue:File not found: ");
            stringBuilder.append(e3.toString());
            android.util.Slog.e("HwPowerManagerService", stringBuilder.toString());
            if (fileOutputStream != null) {
                try {
                    fileOutputStream.close();
                } catch (java.io.IOException e4) {
                    e = e4;
                    str = "HwPowerManagerService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (java.io.IOException e5) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setPowerStateValue:Error accessing file: ");
            stringBuilder.append(e5.toString());
            android.util.Slog.e("HwPowerManagerService", stringBuilder.toString());
            if (fileOutputStream != null) {
                try {
                    fileOutputStream.close();
                } catch (java.io.IOException e6) {
                    e5 = e6;
                    str = "HwPowerManagerService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (java.lang.Exception e7) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setPowerStateValue:Exception occur: ");
            stringBuilder.append(e7.toString());
            android.util.Slog.e("HwPowerManagerService", stringBuilder.toString());
            if (fileOutputStream != null) {
                try {
                    fileOutputStream.close();
                } catch (java.io.IOException e8) {
                    e5 = e8;
                    str = "HwPowerManagerService";
                    stringBuilder = new java.lang.StringBuilder();
                }
            }
        } catch (Throwable th) {
            if (fileOutputStream != null) {
                try {
                    fileOutputStream.close();
                } catch (java.io.IOException e9) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("setPowerStateValue:Error closing file: ");
                    stringBuilder.append(e9.toString());
                    android.util.Slog.e("HwPowerManagerService", stringBuilder.toString());
                }
            }
        }
        return;
        stringBuilder.append("setPowerStateValue:Error closing file: ");
        stringBuilder.append(e5.toString());
        android.util.Slog.e(str, stringBuilder.toString());
    }

    private boolean dropLogs(java.lang.String tag, int uid) {
        if ("RILJ".equals(tag) && 1001 == uid) {
            return true;
        }
        return false;
    }

    protected void notifyWakeLockToIAware(int uid, int pid, java.lang.String packageName, java.lang.String Tag) {
        com.android.server.rms.iaware.sysload.SysLoadManager.getInstance().notifyWakeLock(uid, pid, packageName, Tag);
    }

    protected void notifyWakeLockReleaseToIAware(int uid, int pid, java.lang.String packageName, java.lang.String Tag) {
        com.android.server.rms.iaware.sysload.SysLoadManager.getInstance().notifyWakeLockRelease(uid, pid, packageName, Tag);
    }
}
