package com.android.server.power;

public class HwShutdownThreadImpl implements com.android.server.power.IHwShutdownThread {
    private static final boolean DEBUG;
    private static final int MAX_SHUTDOWN_ANIM_WAIT_MSEC = 15000;
    private static final int PHONE_STATE_POLL_SLEEP_MSEC = 500;
    private static final int SCREEN_ROTATION_SETTING = 8002;
    private static final java.lang.String SHUTDOWN_ANIMATION_STATUS_PROPERTY = "sys.shutdown.animationstate";
    private static final int SHUTDOWN_ANIMATION_WAIT_TIME = 2000;
    private static final java.lang.String TAG = "HwShutdownThread";
    public static final java.lang.String mNotchProp = android.os.SystemProperties.get("ro.config.hw_notch_size", "");
    private static java.lang.String mShutdown_path1 = "/data/cust/media/shutdownanimation.zip";
    private static java.lang.String mShutdown_path2 = "/data/local/shutdownanimation.zip";
    private static java.lang.String mShutdown_path3 = "/system/media/shutdownanimation.zip";
    private static android.app.AlertDialog sRootConfirmDialog;
    private boolean isHaveShutdownAnimation = false;
    private boolean mHwShutDownAnimationStart;

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwShutdownThread", 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public boolean isShutDownAnimationAvailable() {
        boolean z;
        boolean doseShutDownAnimationExist = false;
        try {
            if (huawei.cust.HwCfgFilePolicy.getCfgFile("media/shutdownanimation.zip", 0) != null || isMccmncCustZipExist() || isIccidCustZipExist() || isBootCustZipExist() || isDataZipExist()) {
                doseShutDownAnimationExist = true;
            }
        } catch (java.lang.NoClassDefFoundError e) {
            android.util.Log.d("HwShutdownThread", "HwCfgFilePolicy NoClassDefFoundError");
        }
        if (!doseShutDownAnimationExist) {
            if (!(new java.io.File(mShutdown_path1).exists() || new java.io.File(mShutdown_path2).exists())) {
                if (!new java.io.File(mShutdown_path3).exists()) {
                    z = false;
                    doseShutDownAnimationExist = z;
                }
            }
            z = true;
            doseShutDownAnimationExist = z;
        }
        z = android.os.SystemProperties.getBoolean("ro.config.use_shutdown_anim", true);
        if (doseShutDownAnimationExist && z) {
            return true;
        }
        return false;
    }

    public static boolean hasNotchInScreen() {
        return android.text.TextUtils.isEmpty(mNotchProp) ^ 1;
    }

    public boolean isDoShutdownAnimation() {
        if (hasNotchInScreen()) {
            transferSwitchStatusToSurfaceFlinger(0);
        }
        if (!isShutDownAnimationAvailable()) {
            return false;
        }
        try {
            ((com.android.server.wm.WindowManagerService) android.os.ServiceManager.getService("window")).freezeOrThawRotation(0);
        } catch (java.lang.Exception e) {
        }
        this.isHaveShutdownAnimation = true;
        try {
            android.util.Log.d("HwShutdownThread", "ctl.start shutanim service!");
            android.os.SystemProperties.set("ctl.start", "shutanim");
        } catch (java.lang.Exception e2) {
            android.util.Log.e("HwShutdownThread", "run shutdown animation failed", e2);
        }
        this.mHwShutDownAnimationStart = true;
        return true;
    }

    public static void transferSwitchStatusToSurfaceFlinger(int val) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Transfer Switch status to SurfaceFlinger , val = ");
        stringBuilder.append(val);
        android.util.Log.i("HwShutdownThread", stringBuilder.toString());
        android.os.Parcel dataIn = android.os.Parcel.obtain();
        try {
            android.os.IBinder sfBinder = android.os.ServiceManager.getService("SurfaceFlinger");
            dataIn.writeInt(val);
            if (!(sfBinder == null || sfBinder.transact(8002, dataIn, null, 1))) {
                android.util.Log.e("HwShutdownThread", "transferSwitchStatusToSurfaceFlinger error!");
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("HwShutdownThread", "transferSwitchStatusToSurfaceFlinger RemoteException on notify screen rotation animation end");
        } catch (Throwable th) {
            dataIn.recycle();
        }
        dataIn.recycle();
    }

    private static boolean isIccidCustZipExist() {
        java.lang.String iccid = android.os.SystemProperties.get("persist.sys.iccid", "0");
        if (!"0".equals(iccid)) {
            java.lang.String matchPath = new java.lang.StringBuilder();
            matchPath.append("media/shutdownanimation_");
            matchPath.append(iccid);
            matchPath.append(".zip");
            try {
                if (huawei.cust.HwCfgFilePolicy.getCfgFile(matchPath.toString(), 0) != null) {
                    return true;
                }
            } catch (java.lang.NoClassDefFoundError e) {
                android.util.Log.d("HwShutdownThread", "HwCfgFilePolicy Iccid NoClassDefFoundError");
            }
        }
        return false;
    }

    private static boolean isMccmncCustZipExist() {
        java.lang.String mccmnc = android.os.SystemProperties.get("persist.sys.mccmnc", "0");
        if (!"0".equals(mccmnc)) {
            java.lang.String matchPath = new java.lang.StringBuilder();
            matchPath.append("media/shutdownanimation_");
            matchPath.append(mccmnc);
            matchPath.append(".zip");
            try {
                if (huawei.cust.HwCfgFilePolicy.getCfgFile(matchPath.toString(), 0) != null) {
                    return true;
                }
            } catch (java.lang.NoClassDefFoundError e) {
                android.util.Log.d("HwShutdownThread", "HwCfgFilePolicy Mccmnc NoClassDefFoundError");
            }
        }
        return false;
    }

    private static boolean isBootCustZipExist() {
        java.lang.String boot = android.os.SystemProperties.get("persist.sys.boot", "0");
        if (!"0".equals(boot)) {
            java.lang.String matchPath = new java.lang.StringBuilder();
            matchPath.append("media/shutdownanimation_");
            matchPath.append(boot);
            matchPath.append(".zip");
            try {
                if (huawei.cust.HwCfgFilePolicy.getCfgFile(matchPath.toString(), 0) != null) {
                    return true;
                }
            } catch (java.lang.NoClassDefFoundError e) {
                android.util.Log.e("HwShutdownThread", "HwCfgFilePolicy boot NoClassDefFoundError");
            }
        }
        return false;
    }

    private static boolean isDataZipExist() {
        try {
            java.lang.String dataShutdowAnimationFileName;
            java.lang.String[] shutdowAnimationFiles = huawei.cust.HwCfgFilePolicy.getCfgPolicyDir(0);
            java.lang.String matchPath = "media/shutdownanimation.zip";
            for (int i = shutdowAnimationFiles.length - 1; i >= 0; i--) {
                dataShutdowAnimationFileName = new java.lang.StringBuilder();
                dataShutdowAnimationFileName.append("/data/hw_init");
                dataShutdowAnimationFileName.append(shutdowAnimationFiles[i]);
                java.io.File file = new java.io.File(dataShutdowAnimationFileName.toString(), matchPath);
                if (file.exists()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("file name is");
                    stringBuilder.append(file.getPath());
                    android.util.Log.d("HwShutdownThread", stringBuilder.toString());
                    return true;
                }
            }
            java.lang.String boot = android.os.SystemProperties.get("persist.sys.boot", "0");
            if (!"0".equals(boot)) {
                dataShutdowAnimationFileName = new java.lang.StringBuilder();
                dataShutdowAnimationFileName.append("media/shutdownanimation_");
                dataShutdowAnimationFileName.append(boot);
                dataShutdowAnimationFileName.append(".zip");
                dataShutdowAnimationFileName = dataShutdowAnimationFileName.toString();
                for (int i2 = shutdowAnimationFiles.length - 1; i2 >= 0; i2--) {
                    java.lang.String dataShutdowAnimationFileName2 = new java.lang.StringBuilder();
                    dataShutdowAnimationFileName2.append("/data/hw_init");
                    dataShutdowAnimationFileName2.append(shutdowAnimationFiles[i2]);
                    java.io.File file2 = new java.io.File(dataShutdowAnimationFileName2.toString(), dataShutdowAnimationFileName);
                    if (file2.exists()) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("file name is");
                        stringBuilder2.append(file2.getPath());
                        android.util.Log.d("HwShutdownThread", stringBuilder2.toString());
                        return true;
                    }
                }
            }
            dataShutdowAnimationFileName = android.os.SystemProperties.get("persist.sys.mccmnc", "0");
            if (!"0".equals(dataShutdowAnimationFileName)) {
                java.lang.String matchPath_mccmnc = new java.lang.StringBuilder();
                matchPath_mccmnc.append("media/shutdownanimation_");
                matchPath_mccmnc.append(dataShutdowAnimationFileName);
                matchPath_mccmnc.append(".zip");
                matchPath_mccmnc = matchPath_mccmnc.toString();
                for (int i3 = shutdowAnimationFiles.length - 1; i3 >= 0; i3--) {
                    java.lang.String dataShutdowAnimationFileName3 = new java.lang.StringBuilder();
                    dataShutdowAnimationFileName3.append("/data/hw_init");
                    dataShutdowAnimationFileName3.append(shutdowAnimationFiles[i3]);
                    java.io.File file3 = new java.io.File(dataShutdowAnimationFileName3.toString(), matchPath_mccmnc);
                    if (file3.exists()) {
                        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("file name is");
                        stringBuilder3.append(file3.getPath());
                        android.util.Log.d("HwShutdownThread", stringBuilder3.toString());
                        return true;
                    }
                }
            }
        } catch (java.lang.NoClassDefFoundError e) {
            android.util.Log.e("HwShutdownThread", "HwCfgFilePolicy boot NoClassDefFoundError");
        }
        return false;
    }

    public void waitShutdownAnimation() {
        if (this.isHaveShutdownAnimation) {
            try {
                java.lang.Thread.sleep(2000);
            } catch (java.lang.InterruptedException e) {
                android.util.Log.e("HwShutdownThread", "shutdown animation thread sleep 2s failed", e);
            }
        }
    }

    public boolean needRebootDialog(java.lang.String rebootReason, android.content.Context context) {
        if (rebootReason == null || !rebootReason.equals("huawei_reboot")) {
            return false;
        }
        rebootDialog(context);
        return true;
    }

    public boolean needRebootProgressDialog(boolean reboot, android.content.Context context) {
        if (!reboot || com.android.server.policy.HwPolicyFactory.isHwGlobalActionsShowing()) {
            return false;
        }
        rebootProgressDialog(context);
        return true;
    }

    private static synchronized void rebootDialog(final android.content.Context context) {
        synchronized (com.android.server.power.HwShutdownThreadImpl.class) {
            com.android.server.power.ShutdownThread.CloseDialogReceiver closer = new com.android.server.power.ShutdownThread.CloseDialogReceiver(context);
            if (sRootConfirmDialog != null) {
                sRootConfirmDialog.dismiss();
            }
            sRootConfirmDialog = new android.app.AlertDialog.Builder(context, 33947691).setTitle(33685517).setMessage(33685518).setIcon(17301543).setPositiveButton(17039379, new android.content.DialogInterface.OnClickListener() {
                public void onClick(android.content.DialogInterface dialog, int which) {
                    com.android.server.power.ShutdownThread.beginShutdownSequence(context);
                }
            }).setNegativeButton(17039369, null).create();
            closer.dialog = sRootConfirmDialog;
            sRootConfirmDialog.setOnDismissListener(closer);
            sRootConfirmDialog.getWindow().setType(2009);
            sRootConfirmDialog.show();
        }
    }

    private static void rebootProgressDialog(android.content.Context context) {
        android.app.ProgressDialog pd = new android.app.ProgressDialog(context, 33947691);
        pd.setTitle(context.getText(33685515));
        pd.setMessage(context.getText(33685565));
        pd.setIndeterminate(true);
        pd.setCancelable(false);
        pd.getWindow().setType(2009);
        pd.show();
    }

    public void resetValues() {
        this.mHwShutDownAnimationStart = false;
    }

    public void waitShutdownAnimationComplete(android.content.Context context, long shutDownBegin) {
        if (this.mHwShutDownAnimationStart && shutDownBegin > 0) {
            long endTime = 15000 + shutDownBegin;
            long delay = endTime - android.os.SystemClock.elapsedRealtime();
            boolean shutDownAnimationFinish = "true".equals(android.os.SystemProperties.get("sys.shutdown.animationstate", "false"));
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("ShutDown Animation Status delay:");
            stringBuilder.append(delay);
            stringBuilder.append(", shutDownAnimationFinish:");
            stringBuilder.append(shutDownAnimationFinish);
            stringBuilder.append(", shutDownBegin:");
            stringBuilder.append(shutDownBegin);
            stringBuilder.append(", endTime:");
            stringBuilder.append(endTime);
            android.util.Log.i("HwShutdownThread", stringBuilder.toString());
            while (delay > 0 && !shutDownAnimationFinish) {
                android.os.SystemClock.sleep(500);
                delay = endTime - android.os.SystemClock.elapsedRealtime();
                shutDownAnimationFinish = "true".equals(android.os.SystemProperties.get("sys.shutdown.animationstate", "false"));
            }
            android.os.SystemProperties.set("sys.shutdown.animationstate", "false");
        }
    }
}
