package com.android.server.rms;

public class CompactJobService extends android.app.job.JobService {
    private static int COMPACT_PERIOD_INTERVAL = (android.rms.utils.Utils.DEBUG ? android.rms.utils.Utils.getCompactPeriodInterval() : 28800000);
    private static final int FAILED_PERIOD_INTERVAL = (android.rms.utils.Utils.DEBUG ? 30000 : 3600000);
    private static final int JOB_ID = 1684366962;
    static final java.lang.String TAG = "RMS.CompactJobService";
    private static android.content.ComponentName sCompactServiceName = new android.content.ComponentName("android", com.android.server.rms.CompactJobService.class.getName());
    private static final java.util.ArrayList<com.android.server.rms.IDefraggler> sDefragglers = new java.util.ArrayList();
    private static android.util.LocalLog sHistory = new android.util.LocalLog(20);
    private static java.util.concurrent.atomic.AtomicInteger sTimes = new java.util.concurrent.atomic.AtomicInteger(0);
    private final com.android.server.rms.utils.Interrupt mInterrupt = new com.android.server.rms.utils.Interrupt();

    public static void schedule(android.content.Context context) {
        ((android.app.job.JobScheduler) context.getSystemService("jobscheduler")).schedule(new android.app.job.JobInfo.Builder(1684366962, sCompactServiceName).setRequiresDeviceIdle(true).setRequiresCharging(true).build());
    }

    private static void delay_schedule(android.content.Context context, long delay) {
        ((android.app.job.JobScheduler) context.getSystemService("jobscheduler")).schedule(new android.app.job.JobInfo.Builder(1684366962, sCompactServiceName).setRequiresDeviceIdle(true).setRequiresCharging(true).setMinimumLatency(delay).build());
    }

    public boolean onStartJob(android.app.job.JobParameters params) {
        android.util.Log.w("RMS.CompactJobService", "onIdleStart");
        if (sDefragglers.size() <= 0) {
            return false;
        }
        final android.app.job.JobParameters jobParams = params;
        new java.lang.Thread("CompactJobService_Handler") {
            @android.annotation.SuppressLint({"PreferForInArrayList"})
            public void run() {
                boolean bFinished = true;
                java.util.Iterator it = com.android.server.rms.CompactJobService.sDefragglers.iterator();
                while (it.hasNext()) {
                    com.android.server.rms.IDefraggler defraggler = (com.android.server.rms.IDefraggler) it.next();
                    if (com.android.server.rms.CompactJobService.this.mInterrupt.checkInterruptAndReset()) {
                        bFinished = false;
                        break;
                    }
                    defraggler.compact("background compact", null);
                }
                com.android.server.rms.CompactJobService.this.mInterrupt.reset();
                com.android.server.rms.CompactJobService.sTimes.getAndIncrement();
                android.util.LocalLog access$300 = com.android.server.rms.CompactJobService.sHistory;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("do compact ");
                stringBuilder.append(bFinished);
                stringBuilder.append(" times = ");
                stringBuilder.append(com.android.server.rms.CompactJobService.sTimes.get());
                access$300.log(stringBuilder.toString());
                com.android.server.rms.CompactJobService.this.jobFinished(jobParams, false);
                com.android.server.rms.CompactJobService.delay_schedule(com.android.server.rms.CompactJobService.this, (long) (bFinished ? com.android.server.rms.CompactJobService.COMPACT_PERIOD_INTERVAL : com.android.server.rms.CompactJobService.FAILED_PERIOD_INTERVAL));
            }
        }.start();
        return true;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public boolean onStopJob(android.app.job.JobParameters params) {
        android.util.Log.w("RMS.CompactJobService", "onIdleStop");
        this.mInterrupt.trigger();
        java.util.Iterator it = sDefragglers.iterator();
        while (it.hasNext()) {
            ((com.android.server.rms.IDefraggler) it.next()).interrupt();
        }
        return false;
    }

    protected static void dumpLog(java.io.FileDescriptor fd, java.io.PrintWriter pw, java.lang.String[] args) {
        pw.println("CompactJobService dump");
        sHistory.dump(fd, pw, args);
    }

    public static void addDefragglers(com.android.server.rms.IDefraggler defraggler) {
        sDefragglers.add(defraggler);
    }
}
