package com.android.server.rms;

public final class HwSysResManagerService extends com.android.server.SystemService {
    private static final java.lang.String APP_UID = "uid";
    private static long BIGDATAINFOS_UPLOAD_PERIOD = (android.rms.utils.Utils.DEBUG ? (long) android.rms.utils.Utils.getCompactPeriodInterval() : 86400000);
    public static final int MSG_ADD_BIGDATA_INFOS = 12;
    private static final int MSG_CLEAN_MAP = 3;
    private static final int MSG_DISPATCH_PROCESS_LAUNCHER = 8;
    private static final int MSG_INIT = 1;
    private static final int MSG_IO_SERVICE = 6;
    private static final int MSG_NOTIFY_STATUS = 4;
    public static final int MSG_RECHECK_BLOCK_IPC_PROCESS = 13;
    private static final int MSG_REPORT_APPTYPE_DATA = 10;
    private static final int MSG_REPORT_STATUS = 2;
    private static final int MSG_SAMPLE = 5;
    public static final int MSG_UPLOAD_BIGDATA_INFOS = 11;
    private static final int MSG_WHITENAME_FILE_UPDATE = 7;
    private static int RECHECK_BLOCK_IPC_PROCESS_TIME = 10000;
    private static final java.lang.String TAG = "RMS.HwSysResManagerService";
    private static boolean enableIaware = android.os.SystemProperties.getBoolean("persist.sys.enable_iaware", false);
    private static boolean enableRms = android.os.SystemProperties.getBoolean("ro.config.enable_rms", false);
    private static com.android.server.rms.HwSysResManagerService mSelf;
    private com.android.server.rms.record.AppUsageFileRecord mAppUsageFile = null;
    private final java.util.concurrent.atomic.AtomicBoolean mCloudFileUpdate = new java.util.concurrent.atomic.AtomicBoolean(false);
    private com.android.server.rms.config.HwConfigReader mConfig;
    private final android.content.Context mContext;
    private final android.os.Handler mHandler;
    private android.os.Handler.Callback mHandlerCallback = new android.os.Handler.Callback() {
        public boolean handleMessage(android.os.Message msg) {
            if (android.rms.utils.Utils.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("handleMessage /");
                stringBuilder.append(msg.what);
                android.util.Log.d("RMS.HwSysResManagerService", stringBuilder.toString());
            }
            switch (msg.what) {
                case 1:
                    com.android.server.rms.HwSysResManagerService.this.handleInitService();
                    return true;
                case 2:
                    com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.recordResourceOverloadStatus(msg);
                    return true;
                case 3:
                    com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.cleanResourceRecordMap(msg);
                    return true;
                case 4:
                    com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.notifyResourceStatus(msg);
                    return true;
                case 6:
                    if (com.android.server.rms.HwSysResManagerService.enableRms && (android.rms.utils.Utils.RMSVERSION & 1) != 0) {
                        com.android.server.rms.HwSysResManagerService.this.mIOStatsService.startIOStatsService();
                    }
                    return true;
                case 7:
                    com.android.server.rms.HwSysResManagerService.this.mCloudFileUpdate.getAndSet(com.android.server.rms.HwSysResManagerService.this.mConfig.updateResConfig(com.android.server.rms.HwSysResManagerService.this.mContext));
                    return true;
                case 8:
                    com.android.server.rms.HwSysResManagerService.this.handleDispatchMessage(msg);
                    return true;
                case 10:
                    android.os.Bundle args = msg.getData();
                    java.lang.String pkgName = args.getString("pkgName");
                    if ("APPTYPE_INIT_ACTION".equals(pkgName)) {
                        android.rms.iaware.AppTypeRecoManager.getInstance().init(com.android.server.rms.HwSysResManagerService.this.mContext);
                        return true;
                    }
                    int apptype = args.getInt("appType");
                    boolean status = args.getBoolean("appsSatus");
                    int attr = args.getInt("appAttr");
                    if (status) {
                        android.rms.iaware.AppTypeRecoManager.getInstance().addAppType(pkgName, apptype, attr);
                    } else {
                        android.rms.iaware.AppTypeRecoManager.getInstance().removeAppType(pkgName);
                    }
                    return true;
                case 11:
                    com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.uploadBigDataInfos();
                    com.android.server.rms.HwSysResManagerService.this.repeatlyCheckUploadBigDataInfos();
                    return true;
                case 12:
                    com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.createAndCheckUploadBigDataInfos(msg);
                    return true;
                case 13:
                    if (com.android.server.rms.HwSysResManagerService.this.mRecheckIpcMonitor != null) {
                        com.android.server.rms.HwSysResManagerService.this.mRecheckIpcMonitor.recoverBlockingProcess(false);
                    }
                    return true;
                default:
                    return false;
            }
        }
    };
    private com.android.server.rms.io.IOStatsService mIOStatsService = null;
    private final com.android.server.rms.collector.ProcMemInfoReader mProcMemInfoReader = new com.android.server.rms.collector.ProcMemInfoReader();
    private android.app.IProcessObserver mProcessObserver = new android.app.IProcessObserver.Stub() {
        public void onForegroundActivitiesChanged(int pid, int uid, boolean foregroundActivities) {
            if (!(foregroundActivities || com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore == null)) {
                com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.handleOverloadResource(uid, pid, 29, 0);
                com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.handleOverloadResource(uid, pid, 30, 0);
                com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.handleOverloadResource(uid, pid, 13, 0);
            }
            if (android.rms.utils.Utils.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onForegroundActivitiesChanged pid = ");
                stringBuilder.append(pid);
                stringBuilder.append(", uid = ");
                stringBuilder.append(uid);
                stringBuilder.append(", foregroundActivities=");
                stringBuilder.append(foregroundActivities);
                android.util.Log.d("RMS.HwSysResManagerService", stringBuilder.toString());
            }
        }

        public void onProcessDied(int pid, int uid) {
            if (android.rms.utils.Utils.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onProcessDied pid = ");
                stringBuilder.append(pid);
                stringBuilder.append(", uid = ");
                stringBuilder.append(uid);
                android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
            }
            com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.cleanResRecordAppDied(uid, pid);
        }
    };
    private android.os.RemoteCallbackList<android.rms.IProcessStateChangeObserver> mProcessStateChangeObserver = new android.os.RemoteCallbackList();
    private com.android.server.rms.iaware.RDAService mRDAService = null;
    private android.content.BroadcastReceiver mReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            java.lang.String action = intent.getAction();
            if ("android.intent.action.ACTION_SHUTDOWN".equals(action)) {
                if (com.android.server.rms.HwSysResManagerService.this.mAppUsageFile != null) {
                    com.android.server.rms.HwSysResManagerService.this.mAppUsageFile.saveUsageInfo();
                }
            } else if ("android.intent.action.PACKAGE_REMOVED".equals(action) || "android.intent.action.PACKAGE_REPLACED".equals(action)) {
                java.lang.String pkg = intent.getData().getSchemeSpecificPart();
                if (android.rms.utils.Utils.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(" receiver for  ");
                    stringBuilder.append(intent.getAction());
                    stringBuilder.append("  pkg ");
                    stringBuilder.append(pkg);
                    android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
                }
                if (com.android.server.rms.HwSysResManagerService.this.mAppUsageFile != null) {
                    com.android.server.rms.HwSysResManagerService.this.mAppUsageFile.updateUsageInfo(pkg);
                }
                int uid = intent.getIntExtra("android.intent.extra.UID", -1);
                if (android.rms.utils.Utils.DEBUG || android.util.Log.HWLog) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(" remove uid ");
                    stringBuilder2.append(uid);
                    android.util.Log.i("RMS.HwSysResManagerService", stringBuilder2.toString());
                }
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.arg1 = uid;
                msg.arg2 = 18;
                com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.cleanResourceRecordMap(msg);
                synchronized (com.android.server.rms.HwSysResManagerService.this.mThirdAppOverloadRecord) {
                    com.android.server.rms.HwSysResManagerService.this.mThirdAppOverloadRecord.remove(pkg);
                }
            }
        }
    };
    private com.android.server.rms.ipcchecker.HwIpcMonitorImpl mRecheckIpcMonitor;
    private android.os.RemoteCallbackList<android.rms.IUpdateWhiteListCallback> mRegisteredResourceCallback = new android.os.RemoteCallbackList();
    private com.android.server.rms.record.ResourceRecordStore mResourceRecordStore;
    private final android.os.IBinder mService = new android.rms.IHwSysResManager.Stub() {
        public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
            int i = code;
            android.os.Parcel parcel = data;
            int resIDGestureScroll;
            android.os.Bundle bundleArgs;
            long curtime;
            int resIDGestureScroll2;
            int resIDGestureScroll3;
            if (i == 15007) {
                parcel.enforceInterface("android.rms.IHwSysResManager");
                resIDGestureScroll = android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCENE_REC);
                bundleArgs = new android.os.Bundle();
                curtime = java.lang.System.currentTimeMillis();
                bundleArgs.putInt("relationType", 13);
                reportData(new android.rms.iaware.CollectData(resIDGestureScroll, curtime, bundleArgs));
                return true;
            } else if (i == 15009) {
                parcel.enforceInterface("android.rms.IHwSysResManager");
                resIDGestureScroll = data.readInt();
                resIDGestureScroll2 = android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCENE_REC);
                android.os.Bundle bundleArgs2 = new android.os.Bundle();
                long curtime2 = java.lang.System.currentTimeMillis();
                bundleArgs2.putInt("relationType", 15);
                bundleArgs2.putInt("scroll_duration", resIDGestureScroll);
                reportData(new android.rms.iaware.CollectData(resIDGestureScroll2, curtime2, bundleArgs2));
                return true;
            } else if (i == 20017) {
                parcel.enforceInterface("android.rms.IHwSysResManager");
                resIDGestureScroll2 = data.readInt();
                resIDGestureScroll3 = android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_MEDIA_BTN);
                android.os.Bundle bundleArgs3 = new android.os.Bundle();
                long curtime3 = java.lang.System.currentTimeMillis();
                bundleArgs3.putInt("eventid", 20017);
                bundleArgs3.putInt("callUid", resIDGestureScroll2);
                reportData(new android.rms.iaware.CollectData(resIDGestureScroll3, curtime3, bundleArgs3));
                return true;
            } else if (i != 85007) {
                switch (i) {
                    case 15015:
                        parcel.enforceInterface("android.rms.IHwSysResManager");
                        resIDGestureScroll = data.readInt();
                        resIDGestureScroll2 = data.readInt();
                        resIDGestureScroll3 = data.readInt();
                        java.lang.String num = data.readString();
                        java.lang.String time = data.readString();
                        java.lang.String pkgName = data.readString();
                        android.os.Bundle bundle = new android.os.Bundle();
                        bundle.putInt("eventId", 2);
                        bundle.putInt("dexopt_pid", resIDGestureScroll);
                        bundle.putInt("ppid", resIDGestureScroll2);
                        bundle.putInt("status", resIDGestureScroll3);
                        bundle.putString("num", num);
                        bundle.putString("time", time);
                        bundle.putString("package_name", pkgName);
                        reportData(new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_INSTALLER_MANAGER), java.lang.System.currentTimeMillis(), bundle));
                        return true;
                    case 15016:
                        parcel.enforceInterface("android.rms.IHwSysResManager");
                        reportData(new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_INSTALLER_MANAGER), java.lang.System.currentTimeMillis(), data.readBundle()));
                        return true;
                    default:
                        return super.onTransact(code, data, reply, flags);
                }
            } else {
                parcel.enforceInterface("android.rms.IHwSysResManager");
                resIDGestureScroll = android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCENE_REC);
                bundleArgs = new android.os.Bundle();
                curtime = java.lang.System.currentTimeMillis();
                bundleArgs.putInt("relationType", 14);
                reportData(new android.rms.iaware.CollectData(resIDGestureScroll, curtime, bundleArgs));
                return true;
            }
        }

        public android.rms.config.ResourceConfig[] getResourceConfig(int resourceType) throws android.os.RemoteException {
            if (!com.android.server.rms.HwSysResManagerService.this.isServiceReady()) {
                return null;
            }
            int subTypeNum = com.android.server.rms.HwSysResManagerService.this.mConfig.getSubTypeNum(resourceType);
            android.rms.config.ResourceConfig[] config = null;
            if (subTypeNum > 0) {
                config = new android.rms.config.ResourceConfig[subTypeNum];
            }
            if (config != null) {
                for (int i = 0; i < subTypeNum; i++) {
                    config[i] = com.android.server.rms.HwSysResManagerService.this.mConfig.getResConfig(resourceType, i);
                }
            }
            return config;
        }

        public boolean registerResourceUpdateCallback(android.rms.IUpdateWhiteListCallback updateCallback) throws android.os.RemoteException {
            if (updateCallback != null) {
                if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                    synchronized (com.android.server.rms.HwSysResManagerService.this.mRegisteredResourceCallback) {
                        com.android.server.rms.HwSysResManagerService.this.mRegisteredResourceCallback.register(updateCallback);
                    }
                    return true;
                }
            }
            return false;
        }

        public boolean registerSceneCallback(android.os.IBinder callback, int scenes) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return false;
            }
            com.android.server.rms.iaware.sysload.SysLoadManager.getInstance().registerCallback(android.rms.iaware.ISceneCallback.Stub.asInterface(callback), scenes);
            return true;
        }

        public boolean isScene(int scene) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.iaware.sysload.SysLoadManager.getInstance().isScene(scene);
            }
            return false;
        }

        public java.util.List<java.lang.String> getIAwareProtectList(int num) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return null;
            }
            com.android.server.rms.algorithm.AwareUserHabit habit = com.android.server.rms.algorithm.AwareUserHabit.getInstance();
            if (habit != null && habit.isEnable()) {
                return habit.getForceProtectApps(num);
            }
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.HwSysResManagerService", "habit is null or habit is disable");
            }
            return null;
        }

        public boolean isVisibleWindow(int userid, java.lang.String pkg, int type) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return false;
            }
            boolean result = false;
            if (type == 1 || type == 3) {
                result = com.android.server.rms.iaware.appmng.AwareAppAssociate.getInstance().isVisibleWindows(userid, pkg);
            }
            if (type == 2 || (!result && type == 3)) {
                result = com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance().isToastWindows(userid, pkg);
            }
            return result;
        }

        public java.lang.String getWhiteList(int resourceType, int type) throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(resourceType)) {
                return com.android.server.rms.HwSysResManagerService.this.mConfig.getWhiteList(resourceType, type);
            }
            return null;
        }

        public void triggerUpdateWhiteList() throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.updateWhiteList();
            }
        }

        public java.util.List<java.lang.String> getLongTimeRunningApps() {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return null;
            }
            java.util.List<java.lang.String> list = null;
            com.android.server.rms.algorithm.AwareUserHabit habit = com.android.server.rms.algorithm.AwareUserHabit.getInstance();
            if (habit != null && habit.isEnable()) {
                list = habit.recognizeLongTimeRunningApps();
            }
            return list;
        }

        public java.util.List<java.lang.String> getMostFrequentUsedApps(int n, int minCount) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return null;
            }
            java.util.List<java.lang.String> list = null;
            com.android.server.rms.algorithm.AwareUserHabit habit = com.android.server.rms.algorithm.AwareUserHabit.getInstance();
            if (habit != null && habit.isEnable()) {
                list = habit.getMostFrequentUsedApp(n, minCount);
            }
            return list;
        }

        public void reportAppType(java.lang.String pkgName, int appType, boolean status, int attr) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.what = 10;
                android.os.Bundle data = msg.getData();
                data.putString("pkgName", pkgName);
                data.putInt("appType", appType);
                data.putBoolean("appsSatus", status);
                data.putInt("appAttr", attr);
                com.android.server.rms.HwSysResManagerService.this.mHandler.sendMessage(msg);
            }
        }

        public void reportHabitData(android.os.Bundle habitData) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                if (habitData != null) {
                    com.android.server.rms.algorithm.AwareUserHabit habit = com.android.server.rms.algorithm.AwareUserHabit.getInstance();
                    if (habit != null && habit.isEnable()) {
                        habit.reportHabitData(habitData);
                    }
                }
            }
        }

        public void recordResourceOverloadStatus(int uid, java.lang.String pkg, int resourceType, int overloadNum, int speedOverLoadPeriod, int totalNum, android.os.Bundle extra) {
            if (com.android.server.rms.HwSysResManagerService.this.isServiceReady()) {
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.what = 2;
                msg.arg1 = uid;
                msg.arg2 = resourceType;
                com.android.internal.os.SomeArgs args = com.android.internal.os.SomeArgs.obtain();
                args.arg1 = pkg;
                args.argi1 = overloadNum;
                args.argi2 = speedOverLoadPeriod;
                args.argi3 = totalNum;
                msg.obj = args;
                if (extra != null) {
                    if (android.rms.utils.Utils.DEBUG) {
                        android.util.Log.e("RMS.HwSysResManagerService", "recordResourceOverloadStatus has NonNull Bundle");
                    }
                    if (resourceType == 18) {
                        extra.putInt("third_party_app_usetime", com.android.server.rms.HwSysResManagerService.this.mAppUsageFile.getUsageTimeforUpload(pkg));
                    }
                    msg.setData(extra);
                }
                com.android.server.rms.HwSysResManagerService.this.mHandler.sendMessage(msg);
            }
        }

        public void clearResourceStatus(int uid, int resourceType) throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.what = 3;
                msg.arg1 = uid;
                msg.arg2 = resourceType;
                com.android.server.rms.HwSysResManagerService.this.mHandler.sendMessage(msg);
            }
        }

        public void notifyResourceStatus(int resourceType, java.lang.String resourceName, int resourceStatus, android.os.Bundle bd) throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.what = 4;
                msg.arg1 = resourceType;
                msg.arg2 = resourceStatus;
                com.android.internal.os.SomeArgs args = com.android.internal.os.SomeArgs.obtain();
                args.arg1 = resourceName;
                args.arg2 = bd;
                msg.obj = args;
                com.android.server.rms.HwSysResManagerService.this.mHandler.sendMessage(msg);
            }
        }

        public void dispatch(int resourceType, android.app.mtm.MultiTaskPolicy policy) throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.handler.HwSysResHandler resHandler = com.android.server.rms.handler.ResourceDispatcher.dispath(resourceType, com.android.server.rms.HwSysResManagerService.this.mContext);
                if (resHandler != null) {
                    resHandler.execute(policy);
                }
            }
        }

        protected void dump(java.io.FileDescriptor fd, java.io.PrintWriter pw, java.lang.String[] args) {
            if (com.android.server.rms.HwSysResManagerService.this.getContext().checkCallingPermission("android.permission.DUMP") != 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Permission Denial: can't dump HwResourceManager service from from pid=");
                stringBuilder.append(android.os.Binder.getCallingPid());
                stringBuilder.append(", uid=");
                stringBuilder.append(android.os.Binder.getCallingUid());
                pw.println(stringBuilder.toString());
            } else if (android.os.Binder.getCallingUid() > 1000 || !com.android.server.rms.dump.DumpCase.dump(com.android.server.rms.HwSysResManagerService.this.mContext, pw, args)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.dump(fd, pw, args);
                com.android.server.rms.HwSysResManagerService.this.mResourceRecordStore.dumpImpl(pw);
                com.android.server.rms.CompactJobService.dumpLog(fd, pw, args);
            }
        }

        public int acquireSysRes(int resourceType, android.net.Uri uri, android.database.IContentObserver observer, android.os.Bundle args) {
            android.rms.HwSysResource resource = com.android.server.rms.resource.HwSysInnerResImpl.getResource(resourceType);
            int uid = args.getInt("uid");
            if (resource != null) {
                if (com.android.server.rms.record.ResourceUtils.checkAppUidPermission(uid) == 0) {
                    return resource.acquire(uri, observer, args);
                }
            }
            return 2;
        }

        public void reportData(android.rms.iaware.CollectData data) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.reportData(data);
            }
        }

        public void reportDataWithCallback(android.rms.iaware.CollectData data, android.rms.iaware.IReportDataCallback callback) throws android.os.RemoteException {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.reportDataWithCallback(data, callback);
            }
        }

        public void enableFeature(int type) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.enableFeature(type);
            }
        }

        public void disableFeature(int type) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.disableFeature(type);
            }
        }

        public boolean configUpdate() {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.configUpdate();
            }
            return false;
        }

        public boolean custConfigUpdate() {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.custConfigUpdate();
            }
            return false;
        }

        public void requestAppClean(java.util.List<java.lang.String> pkgNameList, int[] userIdArray, int level, java.lang.String reason, int source) {
            if (pkgNameList != null) {
                if (userIdArray != null) {
                    if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10) && android.app.mtm.MultiTaskManager.getInstance() != null) {
                        java.util.List<java.lang.Integer> userIdList = new java.util.ArrayList();
                        for (int valueOf : userIdArray) {
                            userIdList.add(java.lang.Integer.valueOf(valueOf));
                        }
                        android.app.mtm.MultiTaskManager.getInstance().requestAppClean(pkgNameList, userIdList, level, reason, source);
                    }
                }
            }
        }

        public void init(android.os.Bundle args) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.init(args);
            }
        }

        public void dispatchRPolicy(android.rms.iaware.RPolicyData policy) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.iaware.RDMEDispatcher.dispatchRPolicy(policy);
            }
        }

        public boolean isResourceNeeded(int resourceid) {
            if (com.android.server.rms.HwSysResManagerService.this.isServiceReady()) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.isResourceNeeded(resourceid);
            }
            return false;
        }

        public int getDumpData(int time, java.util.List<android.rms.iaware.DumpData> dumpData) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.getDumpData(time, dumpData);
            }
            return 0;
        }

        public int getStatisticsData(java.util.List<android.rms.iaware.StatisticsData> statisticsData) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.getStatisticsData(statisticsData);
            }
            return 0;
        }

        public java.lang.String saveBigData(int featureId, boolean clear) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.saveBigData(featureId, clear);
            }
            return null;
        }

        public java.lang.String fetchBigDataByVersion(int iVer, int fId, boolean beta, boolean clear) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.fetchBigDataByVersion(iVer, fId, beta, clear);
            }
            return null;
        }

        public java.lang.String fetchDFTDataByVersion(int iVer, int fId, boolean beta, boolean clear, boolean betaEncode) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.fetchDFTDataByVersion(iVer, fId, beta, clear, betaEncode);
            }
            return null;
        }

        public void updateFakeForegroundList(java.util.List<java.lang.String> processList) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.HwSysResManagerService.this.mRDAService.updateFakeForegroundList(processList);
            }
        }

        public boolean isFakeForegroundProcess(java.lang.String process) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.isFakeForegroundProcess(process);
            }
            return false;
        }

        public boolean isEnableFakeForegroundControl() {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.HwSysResManagerService.this.mRDAService.isEnableFakeForegroundControl();
            }
            return false;
        }

        public int getPid(java.lang.String procName) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return 0;
            }
            return com.android.server.rms.HwSysResManagerService.this.mProcMemInfoReader.getPidForProcName(new java.lang.String[]{procName});
        }

        public long getPss(int pid) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return 1024 * com.android.server.rms.HwSysResManagerService.this.mProcMemInfoReader.getProcessPssByPID(pid);
            }
            return 0;
        }

        public long getMemAvaliable() {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return 0;
            }
            long memAvaliable = 0;
            com.android.server.rms.iaware.memory.utils.MemoryReader memoryReader = com.android.server.rms.iaware.memory.utils.MemoryReader.getInstance();
            if (memoryReader != null) {
                memAvaliable = memoryReader.getMemAvailable();
            }
            return memAvaliable;
        }

        public boolean registerProcessStateChangeObserver(android.rms.IProcessStateChangeObserver observer) throws android.os.RemoteException {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return false;
            }
            synchronized (com.android.server.rms.HwSysResManagerService.this.mProcessStateChangeObserver) {
                com.android.server.rms.HwSysResManagerService.this.mProcessStateChangeObserver.register(observer);
            }
            return true;
        }

        public boolean unRegisterProcessStateChangeObserver(android.rms.IProcessStateChangeObserver observer) throws android.os.RemoteException {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return false;
            }
            synchronized (com.android.server.rms.HwSysResManagerService.this.mProcessStateChangeObserver) {
                com.android.server.rms.HwSysResManagerService.this.mProcessStateChangeObserver.unregister(observer);
            }
            return true;
        }

        public void noteProcessStart(java.lang.String packageName, java.lang.String processName, int pid, int uid, boolean started, java.lang.String launcherMode, java.lang.String reason) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10) && com.android.server.rms.record.ResourceUtils.getProcessTypeId(uid, packageName, -1) == 0 && "activity".equals(launcherMode)) {
                android.os.Message msg = com.android.server.rms.HwSysResManagerService.this.mHandler.obtainMessage();
                msg.what = 8;
                msg.arg1 = uid;
                msg.arg2 = pid;
                com.android.internal.os.SomeArgs args = com.android.internal.os.SomeArgs.obtain();
                args.arg1 = packageName;
                args.arg2 = processName;
                args.arg3 = java.lang.Boolean.valueOf(started);
                args.arg4 = launcherMode;
                args.arg5 = reason;
                msg.obj = args;
                com.android.server.rms.HwSysResManagerService.this.mHandler.sendMessage(msg);
            }
        }

        public java.util.List<android.rms.iaware.memrepair.MemRepairPkgInfo> getMemRepairProcGroup(int sceneType) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.memrepair.MemRepairPolicy.getInstance().getMemRepairPolicy(sceneType);
            }
            return null;
        }

        public java.util.List<java.lang.String> getFrequentIM(int count) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.iaware.appmng.FreezeDataManager.getInstance().getFrequentIM(count);
            }
            return null;
        }

        public void reportSysWakeUp(java.lang.String reason) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.iaware.appmng.AwareWakeUpManager.getInstance().reportWakeupSystem(reason);
            }
        }

        public android.rms.iaware.NetLocationStrategy getNetLocationStrategy(java.lang.String pkgName, int uid, int type) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10) || checkClientPermission(1001)) {
                return com.android.server.rms.iaware.feature.DevSchedFeatureRT.getNetLocationStrategy(pkgName, uid, type);
            }
            return null;
        }

        private boolean checkClientPermission(int uid) {
            boolean z = false;
            if (com.android.server.rms.HwSysResManagerService.this.isServiceReady()) {
                if (android.os.UserHandle.getAppId(android.os.Binder.getCallingUid()) % 100000 == uid) {
                    z = true;
                }
                return z;
            }
            android.util.Log.e("RMS.HwSysResManagerService", "service not ready!");
            return false;
        }

        public java.util.List<java.lang.String> getHabitTopN(int n) {
            if (!com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return null;
            }
            java.util.List<java.lang.String> list = null;
            com.android.server.rms.algorithm.AwareUserHabit habit = com.android.server.rms.algorithm.AwareUserHabit.getInstance();
            if (habit != null && habit.isEnable()) {
                list = habit.getTopN(n);
            }
            return list;
        }

        public android.os.Bundle getTypeTopN(int[] appTypes) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                return com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance().getTypeTopN(appTypes);
            }
            return null;
        }

        public void registerDevModeMethod(int deviceId, android.rms.iaware.IDeviceSettingCallback callback, android.os.Bundle args) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.iaware.feature.DevSchedFeatureRT.registerDevModeMethod(deviceId, callback, args);
            }
        }

        public void unregisterDevModeMethod(int deviceId, android.rms.iaware.IDeviceSettingCallback callback, android.os.Bundle args) {
            if (com.android.server.rms.HwSysResManagerService.this.checkServiceReadyAndPermission(10)) {
                com.android.server.rms.iaware.feature.DevSchedFeatureRT.unregisterDevModeMethod(deviceId, callback, args);
            }
        }
    };
    private boolean mServiceReady = false;
    private java.util.HashMap<java.lang.String, java.lang.Long> mThirdAppOverloadRecord = new java.util.HashMap();
    private int mThirdAppUploadInterval;

    public HwSysResManagerService(android.content.Context context) {
        super(context);
        this.mContext = context;
        setInstance(this);
        android.os.HandlerThread handlerThread = new android.os.HandlerThread("RMS.HwSysResManagerService");
        handlerThread.start();
        this.mHandler = new android.os.Handler(handlerThread.getLooper(), this.mHandlerCallback);
        this.mResourceRecordStore = com.android.server.rms.record.ResourceRecordStore.getInstance(context);
        this.mResourceRecordStore.setMessageHandler(this.mHandler);
        repeatlyCheckUploadBigDataInfos();
        if (enableRms && (1 & android.rms.utils.Utils.RMSVERSION) != 0) {
            if (android.rms.utils.Utils.HWFLOW) {
                android.util.Log.i("RMS.HwSysResManagerService", "create the IOStatsService instance");
            }
            this.mIOStatsService = com.android.server.rms.io.IOStatsService.getInstance(context, handlerThread.getLooper());
        }
        this.mRDAService = new com.android.server.rms.iaware.RDAService(this.mContext, handlerThread);
        com.android.server.rms.iaware.appmng.AwareWakeUpManager.getInstance().init(this.mHandler, this.mContext);
    }

    private static void setInstance(com.android.server.rms.HwSysResManagerService service) {
        mSelf = service;
    }

    private boolean checkServiceReadyAndPermission(int resourceType) {
        if (isServiceReady()) {
            if (resourceType != 12) {
                if (resourceType != 16) {
                    int pid = android.os.Binder.getCallingPid();
                    int uid = android.os.UserHandle.getAppId(android.os.Binder.getCallingUid());
                    if (com.android.server.rms.record.ResourceUtils.checkSysProcPermission(pid, uid) == 0) {
                        return true;
                    }
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Process Permission error! pid:");
                    stringBuilder.append(pid);
                    stringBuilder.append(" uid:");
                    stringBuilder.append(uid);
                    stringBuilder.append(" Process.myPid:");
                    stringBuilder.append(android.os.Process.myPid());
                    android.util.Log.e("RMS.HwSysResManagerService", stringBuilder.toString());
                    return false;
                }
            }
            return true;
        }
        android.util.Log.e("RMS.HwSysResManagerService", "checkServiceReadyAndPermission service not ready!");
        return false;
    }

    public void onStart() {
        if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
            android.util.Log.i("RMS.HwSysResManagerService", "publishBinderService()");
        }
        publishBinderService("hwsysresmanager", this.mService);
    }

    public void onBootPhase(int phase) {
        if (phase == 550 && this.mHandler != null) {
            this.mHandler.sendEmptyMessage(1);
            this.mHandler.sendEmptyMessage(6);
        }
    }

    public void cloudFileUpate() {
        if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW || android.util.Log.HWLog) {
            android.util.Log.d("RMS.HwSysResManagerService", "cloudFileUpate()");
        }
        android.os.Message msg = this.mHandler.obtainMessage();
        msg.what = 7;
        this.mHandler.sendMessage(msg);
    }

    public android.rms.IHwSysResManager getHwSysResManagerService() {
        if (this.mService != null) {
            return android.rms.IHwSysResManager.Stub.asInterface(this.mService);
        }
        return null;
    }

    public void recheckBlockIpcProcess(com.android.server.rms.ipcchecker.HwIpcMonitorImpl monitor) {
        if (this.mHandler != null) {
            this.mRecheckIpcMonitor = monitor;
            if (!this.mHandler.hasMessages(13)) {
                android.os.Message msg = android.os.Message.obtain();
                msg.what = 13;
                this.mHandler.sendMessageDelayed(msg, (long) RECHECK_BLOCK_IPC_PROCESS_TIME);
            }
        }
    }

    private void repeatlyCheckUploadBigDataInfos() {
        if (!(this.mHandler == null || this.mHandler.hasMessages(11))) {
            android.os.Message msg = android.os.Message.obtain();
            msg.what = 11;
            this.mHandler.sendMessageDelayed(msg, BIGDATAINFOS_UPLOAD_PERIOD);
        }
    }

    private void dispatchProcessDied(java.lang.String packageName, java.lang.String processName, int pid, int uid, boolean started, java.lang.String launcherMode, java.lang.String reason) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("dispatchProcessDied pkg:");
        stringBuilder.append(packageName);
        android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
        synchronized (this.mThirdAppOverloadRecord) {
            java.lang.StringBuilder stringBuilder2;
            java.lang.Long record = (java.lang.Long) this.mThirdAppOverloadRecord.get(packageName);
            long currentTime = android.os.SystemClock.uptimeMillis();
            if (android.rms.utils.Utils.DEBUG && record != null) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("pkg ");
                stringBuilder2.append(packageName);
                stringBuilder2.append(" inteval ");
                stringBuilder2.append(currentTime - record.longValue());
                android.util.Log.d("RMS.HwSysResManagerService", stringBuilder2.toString());
            }
            if ((record != null && currentTime - record.longValue() >= ((long) this.mThirdAppUploadInterval)) || record == null) {
                dispatchProcessLauncher(packageName, processName, pid, uid, started, launcherMode, reason);
                this.mThirdAppOverloadRecord.put(packageName, java.lang.Long.valueOf(currentTime));
                if (android.rms.utils.Utils.DEBUG) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("got it. pkg ");
                    stringBuilder2.append(packageName);
                    stringBuilder2.append(" report time ");
                    stringBuilder2.append(currentTime);
                    android.util.Log.d("RMS.HwSysResManagerService", stringBuilder2.toString());
                }
            }
        }
    }

    private void handleDispatchMessage(android.os.Message msg) {
        android.os.Message message = msg;
        if (message != null) {
            int uid = message.arg1;
            int pid = message.arg2;
            com.android.internal.os.SomeArgs args = message.obj;
            java.lang.String packageName = args.arg1;
            java.lang.String processName = args.arg2;
            boolean started = ((java.lang.Boolean) args.arg3).booleanValue();
            java.lang.String launcherMode = args.arg4;
            java.lang.String reason = args.arg5;
            args.recycle();
            if (this.mResourceRecordStore.isOverloadResourceRecord(uid, pid, 18)) {
                if (android.rms.utils.Utils.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("noteProcessStart -uid =");
                    stringBuilder.append(uid);
                    stringBuilder.append(" should be forbidden!");
                    android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
                }
                uid = 18;
                dispatchProcessDied(packageName, processName, pid, uid, started, launcherMode, reason);
                message.arg2 = uid;
                this.mResourceRecordStore.cleanResourceRecordMap(message);
            }
        }
    }

    public void handleInitService() {
        this.mConfig = new com.android.server.rms.config.HwConfigReader();
        if (this.mConfig.loadResConfig(this.mContext)) {
            this.mServiceReady = true;
        } else {
            android.util.Log.e("RMS.HwSysResManagerService", "handleInitService read xml file error");
        }
        try {
            android.app.ActivityManagerNative.getDefault().registerProcessObserver(this.mProcessObserver);
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("RMS.HwSysResManagerService", "RMS register process observer failed");
        }
        initPidCtrollGroup();
        try {
            java.lang.System.loadLibrary("sysrms_jni");
        } catch (java.lang.UnsatisfiedLinkError e2) {
            this.mServiceReady = false;
            android.util.Slog.e("RMS.HwSysResManagerService", "libsysrms_jni library not found!");
        }
        if (enableRms) {
            com.android.server.rms.CompactJobService.schedule(this.mContext);
        }
        setSRMSFeature();
        setAppStartupFeature();
        monitorUsageInfo();
        this.mThirdAppUploadInterval = this.mConfig.getResourceThreshold(18, 3);
    }

    private void monitorUsageInfo() {
        boolean appUsageFileEnabled = (android.rms.utils.Utils.RMSVERSION & 2) != 0;
        if (appUsageFileEnabled) {
            android.content.IntentFilter pkgFilter = new android.content.IntentFilter();
            pkgFilter.addAction("android.intent.action.ACTION_SHUTDOWN");
            this.mContext.registerReceiver(this.mReceiver, pkgFilter, null, this.mHandler);
            pkgFilter.addAction("android.intent.action.PACKAGE_REMOVED");
            pkgFilter.addAction("android.intent.action.PACKAGE_REPLACED");
            pkgFilter.addDataScheme("package");
            this.mContext.registerReceiver(this.mReceiver, pkgFilter, null, this.mHandler);
        }
        this.mAppUsageFile = new com.android.server.rms.record.AppUsageFileRecord(this.mContext, this.mConfig.getResourceMaxPeroid(18, 3), appUsageFileEnabled);
        if (appUsageFileEnabled) {
            this.mAppUsageFile.loadUsageInfo();
        }
    }

    private void setSRMSFeature() {
        if (this.mRDAService != null) {
            int srmsFeature = this.mRDAService.isFeatureEnabled(android.rms.iaware.AwareConstant.FeatureType.getFeatureId(android.rms.iaware.AwareConstant.FeatureType.FEATURE_RESOURCE));
            if (srmsFeature == 0) {
                android.os.SystemProperties.set("persist.sys.srms.enable", "false");
            } else if (1 == srmsFeature) {
                android.os.SystemProperties.set("persist.sys.srms.enable", "true");
            } else {
                android.util.Log.e("RMS.HwSysResManagerService", "get SRMS feature failed");
            }
        }
    }

    private void setAppStartupFeature() {
        if (this.mRDAService != null) {
            int startupFeature = this.mRDAService.isFeatureEnabled(android.rms.iaware.AwareConstant.FeatureType.getFeatureId(android.rms.iaware.AwareConstant.FeatureType.FEATURE_APPSTARTUP));
            if (startupFeature == 0) {
                android.os.SystemProperties.set("persist.sys.appstart.enable", "false");
            } else if (1 == startupFeature) {
                android.os.SystemProperties.set("persist.sys.appstart.enable", "true");
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setAppStartupFeature: ");
            stringBuilder.append(startupFeature);
            android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
        }
    }

    public void updateWhiteList() {
        java.lang.StringBuilder stringBuilder;
        if (android.rms.utils.Utils.DEBUG || android.util.Log.HWLog) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateWhiteList(), CloudFileUpdate=");
            stringBuilder.append(this.mCloudFileUpdate.get());
            android.util.Log.d("RMS.HwSysResManagerService", stringBuilder.toString());
        }
        if (enableIaware && this.mCloudFileUpdate.get()) {
            int i = 0;
            this.mCloudFileUpdate.getAndSet(false);
            synchronized (this.mRegisteredResourceCallback) {
                int len = this.mRegisteredResourceCallback.beginBroadcast();
                while (i < len) {
                    try {
                        ((android.rms.IUpdateWhiteListCallback) this.mRegisteredResourceCallback.getBroadcastItem(i)).update();
                    } catch (android.os.RemoteException e) {
                        android.util.Log.e("RMS.HwSysResManagerService", "Trigger the rms client registered callback error");
                    }
                    i++;
                }
                if (android.rms.utils.Utils.DEBUG) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("updateWhiteList Compact trigger cloud config update all registered resource  [num:");
                    stringBuilder2.append(len);
                    stringBuilder2.append("]");
                    android.util.Log.d("RMS.HwSysResManagerService", stringBuilder2.toString());
                }
                this.mRegisteredResourceCallback.finishBroadcast();
            }
            return;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Compact trigger cloud config update, get config file failed   isEnable:");
        stringBuilder.append(enableIaware);
        android.util.Log.e("RMS.HwSysResManagerService", stringBuilder.toString());
    }

    public static com.android.server.rms.HwSysResManagerService self() {
        return mSelf;
    }

    private boolean isServiceReady() {
        return this.mServiceReady;
    }

    private void dispatchProcessLauncher(java.lang.String packageName, java.lang.String processName, int pid, int uid, boolean started, java.lang.String launcherMode, java.lang.String reason) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String str = packageName;
        if (android.rms.utils.Utils.DEBUG || android.util.Log.HWINFO) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("begin diapatch Process observer! pkg ");
            stringBuilder.append(str);
            android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
        }
        synchronized (this.mProcessStateChangeObserver) {
            int len = this.mProcessStateChangeObserver.beginBroadcast();
            int i = 0;
            while (true) {
                int i2 = i;
                if (i2 < len) {
                    android.rms.IProcessStateChangeObserver observer = (android.rms.IProcessStateChangeObserver) this.mProcessStateChangeObserver.getBroadcastItem(i2);
                    if (observer != null) {
                        try {
                            if (android.rms.utils.Utils.DEBUG || android.util.Log.HWINFO) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("calling dispatchProcessLauncher, pkg ");
                                stringBuilder.append(str);
                                android.util.Log.d("RMS.HwSysResManagerService", stringBuilder.toString());
                            }
                            observer.onProcessLauncher(str, processName, pid, uid, started, launcherMode, reason);
                        } catch (android.os.RemoteException e) {
                            android.util.Log.e("RMS.HwSysResManagerService", "Trigger the rms client registered observer error");
                        }
                    }
                    i = i2 + 1;
                } else {
                    this.mProcessStateChangeObserver.finishBroadcast();
                }
            }
        }
    }

    public void dispatchProcessDiedOverload(java.lang.String packageName, int uid) {
        if (android.rms.utils.Utils.DEBUG || android.util.Log.HWINFO) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("begin diapatch Process Died Overload! pkg ");
            stringBuilder.append(packageName);
            android.util.Log.i("RMS.HwSysResManagerService", stringBuilder.toString());
        }
        android.os.Bundle data = new android.os.Bundle();
        data.putString("pkg", packageName);
        synchronized (this.mProcessStateChangeObserver) {
            int len = this.mProcessStateChangeObserver.beginBroadcast();
            for (int i = 0; i < len; i++) {
                android.rms.IProcessStateChangeObserver observer = (android.rms.IProcessStateChangeObserver) this.mProcessStateChangeObserver.getBroadcastItem(i);
                if (observer != null) {
                    try {
                        if (android.rms.utils.Utils.DEBUG || android.util.Log.HWINFO) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("calling observer.onProcessDiedOverload, pkg ");
                            stringBuilder2.append(packageName);
                            android.util.Log.d("RMS.HwSysResManagerService", stringBuilder2.toString());
                        }
                        observer.onProcessDiedOverload(data);
                    } catch (android.os.RemoteException e) {
                        android.util.Log.e("RMS.HwSysResManagerService", "Trigger the rms client registered observer error");
                    }
                }
            }
            this.mProcessStateChangeObserver.finishBroadcast();
        }
        dispatchProcessDied(packageName, "", 0, 0, false, "", "");
    }

    private void initPidCtrollGroup() {
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.HwSysResManagerService", "initPidCtrollGroup");
        }
        android.rms.resource.PidsResource pids = (android.rms.resource.PidsResource) android.common.HwFrameworkFactory.getHwResource(15);
        java.lang.String[] thresholds = getPidCgroupConfig();
        if (pids != null && thresholds != null) {
            pids.init(thresholds);
            android.os.StrictMode.ThreadPolicy savedPolicy = android.os.StrictMode.allowThreadDiskReads();
            try {
                pids.acquire(android.os.Process.myPid(), "system_server", 2);
            } finally {
                android.os.StrictMode.setThreadPolicy(savedPolicy);
            }
        }
    }

    private java.lang.String[] getPidCgroupConfig() {
        int subTypeNum = this.mConfig.getSubTypeNum(15);
        java.lang.String[] thresholds = null;
        if (subTypeNum > 0) {
            thresholds = new java.lang.String[subTypeNum];
        }
        if (thresholds != null) {
            for (int i = 0; i < subTypeNum; i++) {
                java.lang.StringBuffer buffer = new java.lang.StringBuffer(java.lang.String.valueOf(this.mConfig.getResourceThreshold(15, i)));
                buffer.append(",");
                buffer.append(java.lang.String.valueOf(this.mConfig.getResourceStrategy(15, i)));
                if (android.rms.utils.Utils.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("handleInitService Pids [%d");
                    stringBuilder.append(i);
                    stringBuilder.append("]=");
                    stringBuilder.append(buffer.toString());
                    android.util.Log.d("RMS.HwSysResManagerService", stringBuilder.toString());
                }
                thresholds[i] = buffer.toString();
            }
        }
        return thresholds;
    }
}
