package com.android.server.rms.algorithm;

public class AwareUserHabitAlgorithm {
    private static final double DECREASE_RATE_PER_TRAINING = 0.9d;
    private static final java.lang.String LRU = "lru";
    private static final int LRU_APP_NUM_LIMITED = 2;
    private static final long LRU_TIME_LIMIT = 1800000;
    private static final int MATCHTYPE_LRU = 2;
    private static final int MATCHTYPE_NONE_LRU = 3;
    private static final int MATCHTYPE_TRANS = 1;
    private static final int MAX_DYNAMIC_TOPN_INDEX_VER1 = 6;
    private static final long MIN_THRESHOLD = -31536000000L;
    private static final java.lang.String NONE_LRU = "nonelru";
    private static final long STAY_IN_BACKGROUND_LIMIT_TIME = 86400000;
    private static final java.lang.String TAG = "AwareUserHabitAlgorithm";
    private static final java.lang.String TRANS = "trans";
    private static final int TRANS_APP_NUM_LIMITED = 2;
    private static final double TRANS_PRO_THRESHOLD = 0.3d;
    private java.util.Map<java.lang.Integer, java.util.ArrayList<java.lang.String>> mAppTypeInfo = new android.util.ArrayMap();
    private android.content.ContentResolver mContentResolver = null;
    private android.content.Context mContext = null;
    private final android.util.ArrayMap<java.lang.String, java.lang.Long> mGCMAppsArrayMap = new android.util.ArrayMap();
    private final java.lang.Object mHabitLock = new java.lang.Object();
    private final java.util.List<com.android.server.rms.algorithm.utils.ProtectApp> mHabitProtectAppsList = new java.util.ArrayList();
    private final android.util.ArrayMap<java.lang.String, java.lang.Long> mHabitProtectArrayMap = new android.util.ArrayMap();
    private final java.util.ArrayList<java.lang.String> mHabitProtectListTopN = new java.util.ArrayList();
    private java.util.LinkedHashMap<java.lang.Integer, java.lang.String> mIdToPkgNameMap = new java.util.LinkedHashMap();
    private android.util.ArraySet<java.lang.String> mInterfaceFilterAppSet = new android.util.ArraySet();
    private final android.util.ArraySet<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.HabitProtectListChangeListener> mListeners = new android.util.ArraySet();
    private android.util.LruCache<java.lang.String, java.lang.Long> mLruCache = new android.util.LruCache(500);
    private android.util.ArraySet<java.lang.String> mNoInterfaceFilterAppSet = new android.util.ArraySet();
    private java.util.LinkedHashMap<java.lang.String, java.lang.Integer> mPkgNameToIdMap = new java.util.LinkedHashMap();
    private java.util.ArrayList<java.util.ArrayList<java.lang.Integer>> mTransProMatrix = new java.util.ArrayList();
    private java.util.LinkedHashMap<java.lang.String, java.lang.Integer> mUsageCount = new java.util.LinkedHashMap();
    private java.util.Map<java.lang.String, com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution> mUsageDistributionMap = new android.util.ArrayMap();
    private final java.util.concurrent.atomic.AtomicInteger mUserId = new java.util.concurrent.atomic.AtomicInteger(0);
    private java.util.LinkedHashMap<java.lang.String, java.lang.Integer> mUserTrackList = new java.util.LinkedHashMap();

    private static class AppCountDescComparator implements java.util.Comparator<java.util.Map.Entry<java.lang.String, java.lang.Integer>>, java.io.Serializable {
        private static final long serialVersionUID = 1;

        private AppCountDescComparator() {
        }

        /* synthetic */ AppCountDescComparator(com.android.server.rms.algorithm.AwareUserHabitAlgorithm.AnonymousClass1 x0) {
            this();
        }

        public int compare(java.util.Map.Entry<java.lang.String, java.lang.Integer> o1, java.util.Map.Entry<java.lang.String, java.lang.Integer> o2) {
            return ((java.lang.Integer) o2.getValue()).compareTo((java.lang.Integer) o1.getValue());
        }
    }

    private static class DoubleAscComparator implements java.util.Comparator<java.util.Map.Entry<java.lang.Integer, java.lang.Double>>, java.io.Serializable {
        private static final long serialVersionUID = 1;

        private DoubleAscComparator() {
        }

        /* synthetic */ DoubleAscComparator(com.android.server.rms.algorithm.AwareUserHabitAlgorithm.AnonymousClass1 x0) {
            this();
        }

        public int compare(java.util.Map.Entry<java.lang.Integer, java.lang.Double> o1, java.util.Map.Entry<java.lang.Integer, java.lang.Double> o2) {
            return ((java.lang.Double) o1.getValue()).compareTo((java.lang.Double) o2.getValue());
        }
    }

    public interface HabitProtectListChangeListener {
        void onListChanged();
    }

    private static class IntDescComparator implements java.util.Comparator<java.util.Map.Entry<java.lang.Integer, java.lang.Integer>>, java.io.Serializable {
        private static final long serialVersionUID = 1;

        private IntDescComparator() {
        }

        /* synthetic */ IntDescComparator(com.android.server.rms.algorithm.AwareUserHabitAlgorithm.AnonymousClass1 x0) {
            this();
        }

        public int compare(java.util.Map.Entry<java.lang.Integer, java.lang.Integer> o1, java.util.Map.Entry<java.lang.Integer, java.lang.Integer> o2) {
            return ((java.lang.Integer) o2.getValue()).compareTo((java.lang.Integer) o1.getValue());
        }
    }

    static class PkgInfo {
        private int hitType;
        private int id;

        public PkgInfo(int index, int type) {
            this.id = index;
            this.hitType = type;
        }

        public int getId() {
            return this.id;
        }

        public int getHitType() {
            return this.hitType;
        }
    }

    public AwareUserHabitAlgorithm(android.content.Context ctx) {
        if (ctx != null) {
            this.mContext = ctx;
            this.mContentResolver = this.mContext.getContentResolver();
        }
    }

    public void deinit() {
        clearHabitProtectList();
        synchronized (this.mHabitLock) {
            clearData();
        }
        synchronized (this.mAppTypeInfo) {
            this.mAppTypeInfo.clear();
        }
    }

    private void initFilterPkg() {
        addDefaultApp();
        addHomeApp();
        addRemovedApp();
    }

    void reloadFilterPkg() {
        clearFilterPkg();
        initFilterPkg();
    }

    void updateAppUsage(java.lang.String pkg) {
        int timeType = com.android.server.rms.algorithm.utils.IAwareHabitUtils.getTimeType(java.lang.System.currentTimeMillis());
        synchronized (this.mHabitLock) {
            if (this.mUsageCount.containsKey(pkg)) {
                this.mUsageCount.put(pkg, java.lang.Integer.valueOf(((java.lang.Integer) this.mUsageCount.get(pkg)).intValue() + 1));
            } else {
                this.mUsageCount.put(pkg, java.lang.Integer.valueOf(1));
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateAppUsage, pkg:");
            stringBuilder.append(pkg);
            stringBuilder.append(", usage total:");
            stringBuilder.append(this.mUsageCount.get(pkg));
            android.rms.iaware.AwareLog.d("AwareUserHabitAlgorithm", stringBuilder.toString());
            com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution historyDis = (com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution) this.mUsageDistributionMap.get(pkg);
            if (historyDis != null) {
                if (timeType == 0) {
                    historyDis.mDay++;
                } else {
                    historyDis.mNight++;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("updateAppUsage, pkg:");
                stringBuilder.append(pkg);
                stringBuilder.append(" cur distribution day:");
                stringBuilder.append(historyDis.mDay);
                stringBuilder.append(" night:");
                stringBuilder.append(historyDis.mNight);
                android.rms.iaware.AwareLog.d("AwareUserHabitAlgorithm", stringBuilder.toString());
            } else {
                com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution usageDistribution;
                if (timeType == 0) {
                    usageDistribution = new com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution(1, 0);
                } else {
                    usageDistribution = new com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution(0, 1);
                }
                this.mUsageDistributionMap.put(pkg, usageDistribution);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("updateAppUsage, pkg:");
                stringBuilder2.append(pkg);
                stringBuilder2.append(" new distribution day:");
                stringBuilder2.append(usageDistribution.mDay);
                stringBuilder2.append(" night:");
                stringBuilder2.append(usageDistribution.mNight);
                android.rms.iaware.AwareLog.d("AwareUserHabitAlgorithm", stringBuilder2.toString());
            }
        }
        int appType = android.rms.iaware.AppTypeRecoManager.getInstance().convertType(android.rms.iaware.AppTypeRecoManager.getInstance().getAppType(pkg));
        if (-1 != appType) {
            synchronized (this.mAppTypeInfo) {
                java.util.ArrayList<java.lang.String> list = (java.util.ArrayList) this.mAppTypeInfo.get(java.lang.Integer.valueOf(appType));
                if (list == null) {
                    list = new java.util.ArrayList();
                    list.add(pkg);
                    this.mAppTypeInfo.put(java.lang.Integer.valueOf(appType), list);
                } else if (!list.contains(pkg)) {
                    list.add(pkg);
                }
            }
        }
    }

    void sortUsageCount() {
        loadAppTypeInfo();
    }

    void addFilterPkg(java.lang.String pkgName) {
        synchronized (this.mNoInterfaceFilterAppSet) {
            this.mNoInterfaceFilterAppSet.add(pkgName);
        }
    }

    private void addDefaultApp() {
        boolean isAdded;
        android.util.ArraySet<java.lang.String> appfilterSet1 = new android.util.ArraySet();
        synchronized (this.mInterfaceFilterAppSet) {
            isAdded = this.mInterfaceFilterAppSet.isEmpty() ^ 1;
        }
        android.util.ArraySet<java.lang.String> appfilterSet2 = null;
        if (!isAdded) {
            appfilterSet2 = new android.util.ArraySet();
        }
        com.android.server.rms.algorithm.utils.IAwareHabitUtils.getHabitFilterListFromCMS(appfilterSet1, appfilterSet2);
        if (!appfilterSet1.isEmpty()) {
            synchronized (this.mNoInterfaceFilterAppSet) {
                this.mNoInterfaceFilterAppSet.addAll(appfilterSet1);
            }
        }
        if (appfilterSet2 != null && !appfilterSet2.isEmpty()) {
            synchronized (this.mInterfaceFilterAppSet) {
                this.mInterfaceFilterAppSet.addAll(appfilterSet2);
            }
        }
    }

    private void addRemovedApp() {
        java.util.Set<java.lang.String> set = com.android.server.rms.algorithm.utils.IAwareHabitUtils.loadRemovedPkg(this.mContentResolver, this.mUserId.get());
        if (set != null) {
            synchronized (this.mNoInterfaceFilterAppSet) {
                this.mNoInterfaceFilterAppSet.addAll(set);
            }
        }
    }

    private void addHomeApp() {
        if (this.mContext != null) {
            android.content.pm.PackageManager pm = this.mContext.getPackageManager();
            if (pm != null) {
                int i = 0;
                java.util.List<android.content.pm.ResolveInfo> applist = pm.queryIntentActivities(new android.content.Intent("android.intent.action.MAIN").addCategory("android.intent.category.HOME").addCategory("android.intent.category.DEFAULT"), 0);
                if (applist != null) {
                    while (i < applist.size()) {
                        java.lang.String homePkg = ((android.content.pm.ResolveInfo) applist.get(i)).activityInfo.packageName;
                        if (homePkg != null) {
                            addFilterPkg(homePkg);
                        }
                        i++;
                    }
                }
            }
        }
    }

    android.util.ArraySet<java.lang.String> getFilterApp() {
        android.util.ArraySet<java.lang.String> filter = new android.util.ArraySet();
        synchronized (this.mNoInterfaceFilterAppSet) {
            filter.addAll(this.mNoInterfaceFilterAppSet);
        }
        return filter;
    }

    protected void removePkgFromLru(java.lang.String pkgName) {
        synchronized (this.mLruCache) {
            this.mLruCache.remove(pkgName);
        }
    }

    protected void addPkgToLru(java.lang.String pkgName, long time) {
        synchronized (this.mLruCache) {
            this.mLruCache.put(pkgName, java.lang.Long.valueOf(time));
        }
    }

    protected java.util.LinkedHashMap<java.lang.String, java.lang.Long> getLruCache() {
        java.util.LinkedHashMap<java.lang.String, java.lang.Long> lru = null;
        synchronized (this.mLruCache) {
            java.util.Map<java.lang.String, java.lang.Long> tmp = this.mLruCache.snapshot();
            if (tmp instanceof java.util.LinkedHashMap) {
                lru = (java.util.LinkedHashMap) tmp;
            }
        }
        return lru;
    }

    void clearLruCache() {
        synchronized (this.mLruCache) {
            this.mLruCache.evictAll();
        }
    }

    protected java.util.List<java.lang.String> getAppPkgNamesFromLRU() {
        java.util.LinkedHashMap<java.lang.String, java.lang.Long> lru = getLruCache();
        if (lru != null) {
            return new java.util.ArrayList(lru.keySet());
        }
        return null;
    }

    protected java.util.List<java.lang.String> getForceProtectAppsFromLRU(java.util.List<java.lang.String> homePkg, int lruCount) {
        if (homePkg == null) {
            return null;
        }
        java.util.List<java.lang.String> lruList = getAppPkgNamesFromLRU();
        if (lruList == null) {
            return null;
        }
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        int lruTmpCount = 0;
        for (int i = lruList.size() - 1; i >= 0; i--) {
            java.lang.String pkg = (java.lang.String) lruList.get(i);
            if (lruCount == lruTmpCount) {
                break;
            }
            if (!(homePkg.contains(pkg) || containsFilterPkg(pkg) || containsFilter2Pkg(pkg))) {
                result.add(pkg);
                lruTmpCount++;
            }
        }
        return result;
    }

    /* JADX WARNING: Missing block: B:12:0x001e, code:
            return false;
     */
    protected boolean isPredictHit(java.lang.String r3, int r4) {
        /*
        r2 = this;
        r0 = r2.mUserTrackList;
        monitor-enter(r0);
        r1 = r2.mUserTrackList;	 Catch:{ all -> 0x001f }
        r1 = r1.containsKey(r3);	 Catch:{ all -> 0x001f }
        if (r1 == 0) goto L_0x001c;
    L_0x000b:
        r1 = r2.mUserTrackList;	 Catch:{ all -> 0x001f }
        r1 = r1.get(r3);	 Catch:{ all -> 0x001f }
        r1 = (java.lang.Integer) r1;	 Catch:{ all -> 0x001f }
        r1 = r1.intValue();	 Catch:{ all -> 0x001f }
        if (r1 > r4) goto L_0x001c;
    L_0x0019:
        r1 = 1;
        monitor-exit(r0);	 Catch:{ all -> 0x001f }
        return r1;
    L_0x001c:
        monitor-exit(r0);	 Catch:{ all -> 0x001f }
        r0 = 0;
        return r0;
    L_0x001f:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x001f }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.algorithm.AwareUserHabitAlgorithm.isPredictHit(java.lang.String, int):boolean");
    }

    private void clearFilterPkg() {
        synchronized (this.mNoInterfaceFilterAppSet) {
            this.mNoInterfaceFilterAppSet.clear();
        }
    }

    void removeFilterPkg(java.lang.String pkgName) {
        synchronized (this.mNoInterfaceFilterAppSet) {
            this.mNoInterfaceFilterAppSet.remove(pkgName);
        }
    }

    boolean containsFilterPkg(java.lang.String pkg) {
        boolean contains;
        synchronized (this.mNoInterfaceFilterAppSet) {
            contains = this.mNoInterfaceFilterAppSet.contains(pkg);
        }
        return contains;
    }

    boolean containsFilter2Pkg(java.lang.String pkg) {
        boolean contains;
        synchronized (this.mInterfaceFilterAppSet) {
            contains = this.mInterfaceFilterAppSet.contains(pkg);
        }
        return contains;
    }

    void init() {
        synchronized (this.mHabitLock) {
            this.mUsageCount.clear();
            this.mUsageDistributionMap.clear();
            loadData();
        }
        loadAppTypeInfo();
    }

    void reloadDataInfo() {
        synchronized (this.mHabitLock) {
            clearData();
            loadData();
        }
        loadAppTypeInfo();
    }

    private void clearData() {
        this.mPkgNameToIdMap.clear();
        this.mIdToPkgNameMap.clear();
        this.mTransProMatrix.clear();
        this.mUsageCount.clear();
        this.mUsageDistributionMap.clear();
        clearFilterPkg();
    }

    private void loadData() {
        int userId = this.mUserId.get();
        com.android.server.rms.algorithm.utils.IAwareHabitUtils.loadPkgInfo(this.mContentResolver, this.mPkgNameToIdMap, this.mIdToPkgNameMap, this.mUsageCount, this.mUsageDistributionMap, userId);
        com.android.server.rms.algorithm.utils.IAwareHabitUtils.loadAppAssociateInfo(this.mContentResolver, this.mPkgNameToIdMap, this.mTransProMatrix, userId);
        initFilterPkg();
    }

    private void loadAppTypeInfo() {
        java.util.Map<java.lang.Integer, java.util.ArrayList<java.lang.String>> tmpAppTypeInfo = new android.util.ArrayMap();
        synchronized (this.mHabitLock) {
            if (this.mUsageCount.size() > 0) {
                java.util.List<java.util.Map.Entry<java.lang.String, java.lang.Integer>> entries = new java.util.ArrayList(this.mUsageCount.entrySet());
                java.util.Collections.sort(entries, new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.AppCountDescComparator());
                for (java.util.Map.Entry<java.lang.String, java.lang.Integer> entry : entries) {
                    java.lang.String name = (java.lang.String) entry.getKey();
                    int appType = android.rms.iaware.AppTypeRecoManager.getInstance().convertType(android.rms.iaware.AppTypeRecoManager.getInstance().getAppType(name));
                    if (appType != -1) {
                        java.util.ArrayList<java.lang.String> list = (java.util.ArrayList) tmpAppTypeInfo.get(java.lang.Integer.valueOf(appType));
                        if (list == null) {
                            list = new java.util.ArrayList();
                            list.add(name);
                            tmpAppTypeInfo.put(java.lang.Integer.valueOf(appType), list);
                        } else {
                            list.add(name);
                        }
                    }
                }
            }
        }
        synchronized (this.mAppTypeInfo) {
            this.mAppTypeInfo.clear();
            this.mAppTypeInfo.putAll(tmpAppTypeInfo);
        }
    }

    void updatePkgNameMap(java.lang.String pkgName) {
        if (!this.mPkgNameToIdMap.containsKey(pkgName)) {
            int size = this.mPkgNameToIdMap.size();
            this.mPkgNameToIdMap.put(pkgName, java.lang.Integer.valueOf(size));
            this.mIdToPkgNameMap.put(java.lang.Integer.valueOf(size), pkgName);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x0073 A:{SYNTHETIC} */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x006e  */
    java.util.List<java.lang.String> getMostFreqAppByType(int r11, int r12) {
        /*
        r10 = this;
        r0 = 0;
        if (r12 > 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = "AwareUserHabitAlgorithm";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "getMostFreqAppByType appType:";
        r2.append(r3);
        r2.append(r11);
        r3 = " appNum:";
        r2.append(r3);
        r2.append(r12);
        r2 = r2.toString();
        android.rms.iaware.AwareLog.d(r1, r2);
        r1 = java.lang.System.currentTimeMillis();
        r3 = r12;
        r4 = r10.mAppTypeInfo;
        monitor-enter(r4);
        r5 = r10.mAppTypeInfo;	 Catch:{ all -> 0x0096 }
        r5 = r5.isEmpty();	 Catch:{ all -> 0x0096 }
        if (r5 == 0) goto L_0x0034;
    L_0x0032:
        monitor-exit(r4);	 Catch:{ all -> 0x0096 }
        return r0;
    L_0x0034:
        r5 = r10.mAppTypeInfo;	 Catch:{ all -> 0x0096 }
        r6 = java.lang.Integer.valueOf(r11);	 Catch:{ all -> 0x0096 }
        r5 = r5.get(r6);	 Catch:{ all -> 0x0096 }
        r5 = (java.util.List) r5;	 Catch:{ all -> 0x0096 }
        if (r5 != 0) goto L_0x0044;
    L_0x0042:
        monitor-exit(r4);	 Catch:{ all -> 0x0096 }
        return r0;
    L_0x0044:
        r0 = new java.util.ArrayList;	 Catch:{ all -> 0x0096 }
        r0.<init>();	 Catch:{ all -> 0x0096 }
        r6 = r5.iterator();	 Catch:{ all -> 0x0096 }
    L_0x004d:
        r7 = r6.hasNext();	 Catch:{ all -> 0x0096 }
        if (r7 == 0) goto L_0x0074;
    L_0x0053:
        r7 = r6.next();	 Catch:{ all -> 0x0096 }
        r7 = (java.lang.String) r7;	 Catch:{ all -> 0x0096 }
        if (r3 > 0) goto L_0x005c;
    L_0x005b:
        goto L_0x0074;
    L_0x005c:
        r8 = r10.containsFilterPkg(r7);	 Catch:{ all -> 0x0096 }
        if (r8 != 0) goto L_0x006b;
    L_0x0062:
        r8 = r10.containsFilter2Pkg(r7);	 Catch:{ all -> 0x0096 }
        if (r8 == 0) goto L_0x0069;
    L_0x0068:
        goto L_0x006b;
    L_0x0069:
        r8 = 0;
        goto L_0x006c;
    L_0x006b:
        r8 = 1;
    L_0x006c:
        if (r8 != 0) goto L_0x0073;
    L_0x006e:
        r0.add(r7);	 Catch:{ all -> 0x0096 }
        r3 = r3 + -1;
    L_0x0073:
        goto L_0x004d;
    L_0x0074:
        r6 = "AwareUserHabitAlgorithm";
        r7 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0096 }
        r7.<init>();	 Catch:{ all -> 0x0096 }
        r8 = "getMostFreqAppByType spend time ";
        r7.append(r8);	 Catch:{ all -> 0x0096 }
        r8 = java.lang.System.currentTimeMillis();	 Catch:{ all -> 0x0096 }
        r8 = r8 - r1;
        r7.append(r8);	 Catch:{ all -> 0x0096 }
        r8 = "ms";
        r7.append(r8);	 Catch:{ all -> 0x0096 }
        r7 = r7.toString();	 Catch:{ all -> 0x0096 }
        android.rms.iaware.AwareLog.d(r6, r7);	 Catch:{ all -> 0x0096 }
        monitor-exit(r4);	 Catch:{ all -> 0x0096 }
        return r0;
    L_0x0096:
        r0 = move-exception;
        monitor-exit(r4);	 Catch:{ all -> 0x0096 }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.algorithm.AwareUserHabitAlgorithm.getMostFreqAppByType(int, int):java.util.List<java.lang.String>");
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x0063  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x006f A:{SYNTHETIC} */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x006a  */
    /* JADX WARNING: Missing block: B:33:0x0071, code:
            return r1;
     */
    java.util.List<java.lang.String> getMostFrequentUsedApp(int r10, int r11, java.util.Set<java.lang.String> r12) {
        /*
        r9 = this;
        r0 = 0;
        if (r10 > 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = new java.util.ArrayList;
        r1.<init>();
        r2 = r10;
        r3 = r9.mHabitLock;
        monitor-enter(r3);
        r4 = r9.mUsageCount;	 Catch:{ all -> 0x0074 }
        r4 = r4.isEmpty();	 Catch:{ all -> 0x0074 }
        if (r4 == 0) goto L_0x0017;
    L_0x0015:
        monitor-exit(r3);	 Catch:{ all -> 0x0074 }
        return r1;
    L_0x0017:
        r4 = new java.util.ArrayList;	 Catch:{ all -> 0x0074 }
        r5 = r9.mUsageCount;	 Catch:{ all -> 0x0074 }
        r5 = r5.entrySet();	 Catch:{ all -> 0x0074 }
        r4.<init>(r5);	 Catch:{ all -> 0x0074 }
        r5 = new com.android.server.rms.algorithm.AwareUserHabitAlgorithm$AppCountDescComparator;	 Catch:{ all -> 0x0074 }
        r5.<init>(r0);	 Catch:{ all -> 0x0074 }
        java.util.Collections.sort(r4, r5);	 Catch:{ all -> 0x0074 }
        r0 = r4.iterator();	 Catch:{ all -> 0x0074 }
    L_0x002e:
        r5 = r0.hasNext();	 Catch:{ all -> 0x0074 }
        if (r5 == 0) goto L_0x0072;
    L_0x0034:
        r5 = r0.next();	 Catch:{ all -> 0x0074 }
        r5 = (java.util.Map.Entry) r5;	 Catch:{ all -> 0x0074 }
        if (r2 <= 0) goto L_0x0070;
    L_0x003c:
        r6 = r5.getValue();	 Catch:{ all -> 0x0074 }
        r6 = (java.lang.Integer) r6;	 Catch:{ all -> 0x0074 }
        r6 = r6.intValue();	 Catch:{ all -> 0x0074 }
        if (r6 > r11) goto L_0x0049;
    L_0x0048:
        goto L_0x0070;
    L_0x0049:
        r6 = r5.getKey();	 Catch:{ all -> 0x0074 }
        r6 = (java.lang.String) r6;	 Catch:{ all -> 0x0074 }
        r7 = r9.containsFilterPkg(r6);	 Catch:{ all -> 0x0074 }
        r8 = 0;
        if (r7 != 0) goto L_0x005f;
    L_0x0056:
        r7 = r9.containsFilter2Pkg(r6);	 Catch:{ all -> 0x0074 }
        if (r7 == 0) goto L_0x005d;
    L_0x005c:
        goto L_0x005f;
    L_0x005d:
        r7 = r8;
        goto L_0x0060;
    L_0x005f:
        r7 = 1;
    L_0x0060:
        if (r12 != 0) goto L_0x0063;
    L_0x0062:
        goto L_0x0067;
    L_0x0063:
        r8 = r12.contains(r6);	 Catch:{ all -> 0x0074 }
    L_0x0067:
        r7 = r7 | r8;
        if (r7 != 0) goto L_0x006f;
    L_0x006a:
        r1.add(r6);	 Catch:{ all -> 0x0074 }
        r2 = r2 + -1;
    L_0x006f:
        goto L_0x002e;
    L_0x0070:
        monitor-exit(r3);	 Catch:{ all -> 0x0074 }
        return r1;
    L_0x0072:
        monitor-exit(r3);	 Catch:{ all -> 0x0074 }
        return r1;
    L_0x0074:
        r0 = move-exception;
        monitor-exit(r3);	 Catch:{ all -> 0x0074 }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.algorithm.AwareUserHabitAlgorithm.getMostFrequentUsedApp(int, int, java.util.Set):java.util.List<java.lang.String>");
    }

    private java.util.List<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> getTopMove(java.lang.String lastPkgName, java.util.Set<java.lang.Integer> topMoveSet) {
        java.util.Set<java.lang.Integer> set;
        java.lang.String str = lastPkgName;
        java.util.ArrayList<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> topMoveList = new java.util.ArrayList();
        if (this.mPkgNameToIdMap.containsKey(str)) {
            if (((java.lang.Integer) this.mPkgNameToIdMap.get(str)).intValue() < this.mTransProMatrix.size()) {
                int i;
                int id = ((java.lang.Integer) this.mPkgNameToIdMap.get(str)).intValue();
                java.util.ArrayList<java.lang.Integer> appmovelist = (java.util.ArrayList) this.mTransProMatrix.get(id);
                java.util.ArrayList<java.util.Map.Entry<java.lang.Integer, java.lang.Integer>> slist = new java.util.ArrayList();
                double sum = 0.0d;
                for (i = 0; i < appmovelist.size(); i++) {
                    if (i != id) {
                        sum += (double) ((java.lang.Integer) appmovelist.get(i)).intValue();
                        slist.add(new java.util.AbstractMap.SimpleEntry(java.lang.Integer.valueOf(i), appmovelist.get(i)));
                    }
                }
                java.util.Collections.sort(slist, new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.IntDescComparator());
                i = 0;
                java.util.Iterator<java.util.Map.Entry<java.lang.Integer, java.lang.Integer>> it = slist.iterator();
                while (it.hasNext()) {
                    java.util.Map.Entry<java.lang.Integer, java.lang.Integer> entry = (java.util.Map.Entry) it.next();
                    if (((double) ((java.lang.Integer) entry.getValue()).intValue()) / sum < 0.3d || i >= 2) {
                        break;
                    }
                    topMoveList.add(new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo(((java.lang.Integer) entry.getKey()).intValue(), 1));
                    topMoveSet.add(entry.getKey());
                    i++;
                }
                set = topMoveSet;
                return topMoveList;
            }
        }
        set = topMoveSet;
        return topMoveList;
    }

    private java.util.List<java.lang.Integer> getLRUAppList(java.util.Map<java.lang.String, java.lang.Long> lruCache, long curTime, java.lang.String realCurapp, java.util.Set<java.lang.Integer> topMoveSet) {
        java.util.List<java.lang.Integer> lrulist = new java.util.ArrayList();
        java.util.List<java.lang.String> sortedlru = getAppPkgNamesFromLRU();
        if (sortedlru == null) {
            return lrulist;
        }
        int lruMaxNums = 2;
        if (this.mUsageCount.isEmpty()) {
            lruMaxNums = sortedlru.size();
        }
        for (int i = sortedlru.size() - 1; i >= 0; i--) {
            java.lang.String lruappname = (java.lang.String) sortedlru.get(i);
            if (!(lruappname == null || lruappname.equals(realCurapp) || containsFilterPkg(lruappname) || topMoveSet.contains(this.mPkgNameToIdMap.get(lruappname)) || !this.mPkgNameToIdMap.containsKey(lruappname))) {
                if (lruCache.containsKey(lruappname)) {
                    if (java.lang.Math.abs(curTime - ((java.lang.Long) lruCache.get(lruappname)).longValue()) >= 1800000 || lrulist.size() >= lruMaxNums) {
                        break;
                    }
                    lrulist.add(this.mPkgNameToIdMap.get(lruappname));
                }
            }
        }
        return lrulist;
    }

    private java.util.List<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> getUsePatternList(java.lang.String lastPkgName, java.util.Map<java.lang.String, java.lang.Long> lruCache, long curTime, java.lang.String realCurapp) {
        int distributionType;
        int realCurappID;
        com.android.server.rms.algorithm.AwareUserHabitAlgorithm awareUserHabitAlgorithm = this;
        java.util.Map<java.lang.String, java.lang.Long> map = lruCache;
        java.lang.String str = realCurapp;
        android.util.ArraySet<java.lang.Integer> topMoveSet = new android.util.ArraySet();
        java.util.List<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> topList = awareUserHabitAlgorithm.getTopMove(lastPkgName, topMoveSet);
        java.util.ArrayList<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> patternList = new java.util.ArrayList();
        patternList.addAll(topList);
        java.util.List<java.lang.Integer> lrulist = awareUserHabitAlgorithm.getLRUAppList(map, curTime, str, topMoveSet);
        java.util.ArrayList<java.util.Map.Entry<java.lang.Integer, java.lang.Double>> notinlrulist = new java.util.ArrayList();
        int distributionType2 = com.android.server.rms.algorithm.utils.IAwareHabitUtils.getTimeType(java.lang.System.currentTimeMillis());
        for (java.lang.Integer appID : lrulist) {
            patternList.add(new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo(appID.intValue(), 2));
        }
        int realCurappID2 = awareUserHabitAlgorithm.mPkgNameToIdMap.size();
        if (awareUserHabitAlgorithm.mPkgNameToIdMap.containsKey(str)) {
            realCurappID2 = ((java.lang.Integer) awareUserHabitAlgorithm.mPkgNameToIdMap.get(str)).intValue();
        }
        int i = 0;
        while (i < awareUserHabitAlgorithm.mPkgNameToIdMap.size()) {
            java.util.List<java.lang.Integer> lrulist2;
            if (topMoveSet.contains(java.lang.Integer.valueOf(i)) || lrulist.contains(java.lang.Integer.valueOf(i)) || i == realCurappID2) {
                lrulist2 = lrulist;
                distributionType = distributionType2;
                realCurappID = realCurappID2;
            } else {
                java.lang.String name = (java.lang.String) awareUserHabitAlgorithm.mIdToPkgNameMap.get(java.lang.Integer.valueOf(i));
                com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution curDistribution = (com.android.server.rms.algorithm.utils.IAwareHabitUtils.UsageDistribution) awareUserHabitAlgorithm.mUsageDistributionMap.get(name);
                int curUsage = 0;
                if (curDistribution != null) {
                    curUsage = distributionType2 == 0 ? curDistribution.mDay : curDistribution.mNight;
                }
                if (curUsage != 0) {
                    lrulist2 = lrulist;
                    distributionType = distributionType2;
                    realCurappID = realCurappID2;
                    notinlrulist.add(new java.util.AbstractMap.SimpleEntry(java.lang.Integer.valueOf(i), java.lang.Double.valueOf(0.0d - ((double) curUsage))));
                } else {
                    lrulist2 = lrulist;
                    distributionType = distributionType2;
                    realCurappID = realCurappID2;
                    long lastTime = -31536000000L;
                    if (map.containsKey(name)) {
                        lastTime = ((java.lang.Long) map.get(name)).longValue();
                    }
                    notinlrulist.add(new java.util.AbstractMap.SimpleEntry(java.lang.Integer.valueOf(i), java.lang.Double.valueOf((double) java.lang.Math.abs(curTime - lastTime))));
                }
            }
            i++;
            lrulist = lrulist2;
            distributionType2 = distributionType;
            realCurappID2 = realCurappID;
            awareUserHabitAlgorithm = this;
        }
        distributionType = distributionType2;
        realCurappID = realCurappID2;
        java.util.Collections.sort(notinlrulist, new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.DoubleAscComparator());
        java.util.Iterator<java.util.Map.Entry<java.lang.Integer, java.lang.Double>> it = notinlrulist.iterator();
        while (it.hasNext()) {
            patternList.add(new com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo(((java.lang.Integer) ((java.util.Map.Entry) it.next()).getKey()).intValue(), 3));
        }
        return patternList;
    }

    protected java.util.Map<java.lang.String, java.lang.String> getUserTrackPredictDumpInfo(java.lang.String lastPkgName, java.util.Map<java.lang.String, java.lang.Long> lruCache, long curTime, java.lang.String realCurapp) {
        java.util.LinkedHashMap<java.lang.String, java.lang.String> userTrackList = null;
        synchronized (this.mHabitLock) {
            if (!(lastPkgName == null || realCurapp == null || lruCache == null)) {
                java.util.List<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> dumpList = getUsePatternList(lastPkgName, lruCache, curTime, realCurapp);
                userTrackList = new java.util.LinkedHashMap();
                for (com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo info : dumpList) {
                    java.lang.String appName = (java.lang.String) this.mIdToPkgNameMap.get(java.lang.Integer.valueOf(info.getId()));
                    if (!(appName == null || containsFilterPkg(appName))) {
                        if (1 == info.getHitType()) {
                            userTrackList.put(appName, "trans");
                        } else if (2 == info.getHitType()) {
                            userTrackList.put(appName, "lru");
                        } else {
                            userTrackList.put(appName, "nonelru");
                        }
                    }
                }
            }
        }
        return userTrackList;
    }

    void triggerUserTrackPredict(java.lang.String lastPkgName, java.util.Map<java.lang.String, java.lang.Long> lruCache, long curTime, java.lang.String realCurapp) {
        if (!(lastPkgName == null || realCurapp == null)) {
            if (lruCache != null) {
                synchronized (this.mHabitLock) {
                    predict(lastPkgName, lruCache, curTime, realCurapp);
                }
            }
        }
    }

    private void predict(java.lang.String lastPkgName, java.util.Map<java.lang.String, java.lang.Long> lruCache, long curTime, java.lang.String realCurapp) {
        updatePkgNameMap(realCurapp);
        java.util.List<com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo> numList = getUsePatternList(lastPkgName, lruCache, curTime, realCurapp);
        int order = 1;
        synchronized (this.mUserTrackList) {
            int i;
            this.mUserTrackList.clear();
            java.util.ArrayList<java.lang.String> filterAppList = new java.util.ArrayList();
            java.util.Iterator it = numList.iterator();
            while (true) {
                i = 0;
                if (!it.hasNext()) {
                    break;
                }
                java.lang.String appName = (java.lang.String) this.mIdToPkgNameMap.get(java.lang.Integer.valueOf(((com.android.server.rms.algorithm.AwareUserHabitAlgorithm.PkgInfo) it.next()).getId()));
                if (!(appName == null || containsFilterPkg(appName))) {
                    if (order < 6 && containsFilter2Pkg(appName)) {
                        filterAppList.add(appName);
                    } else if (order != 6 || filterAppList.isEmpty()) {
                        this.mUserTrackList.put(appName, java.lang.Integer.valueOf(order));
                        order++;
                    } else {
                        while (i < filterAppList.size()) {
                            this.mUserTrackList.put(filterAppList.get(i), java.lang.Integer.valueOf(order));
                            order++;
                            i++;
                        }
                    }
                }
            }
            if (this.mUserTrackList.size() < 6 && !filterAppList.isEmpty()) {
                while (true) {
                    int i2 = i;
                    if (i2 >= filterAppList.size()) {
                        break;
                    }
                    this.mUserTrackList.put(filterAppList.get(i2), java.lang.Integer.valueOf(order));
                    order++;
                    i = i2 + 1;
                }
            }
        }
    }

    protected java.util.Map<java.lang.String, java.lang.Integer> getUserTrackList() {
        java.util.LinkedHashMap<java.lang.String, java.lang.Integer> result = new java.util.LinkedHashMap();
        synchronized (this.mUserTrackList) {
            result.putAll(this.mUserTrackList);
        }
        return result;
    }

    java.util.List<java.lang.String> getTopN(int n) {
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        java.util.Iterator<java.util.Map.Entry<java.lang.String, java.lang.Integer>> iterator = getUserTrackList().entrySet().iterator();
        int num = n;
        while (iterator.hasNext() && num != 0) {
            result.add(((java.util.Map.Entry) iterator.next()).getKey());
            num--;
        }
        return result;
    }

    protected java.util.Map<java.lang.String, java.lang.Long> getLongTimePkgsFromLru(long bgtime) {
        java.util.LinkedHashMap<java.lang.String, java.lang.Long> lru = getLruCache();
        if (lru == null) {
            return null;
        }
        java.util.Map<java.lang.String, java.lang.Long> lruPkgList = new android.util.ArrayMap();
        long now = android.os.SystemClock.elapsedRealtime();
        for (java.util.Map.Entry entry : lru.entrySet()) {
            java.lang.String pkg = (java.lang.String) entry.getKey();
            long time = ((java.lang.Long) entry.getValue()).longValue();
            if (now - time >= bgtime) {
                lruPkgList.put(pkg, java.lang.Long.valueOf(time));
            }
        }
        return lruPkgList;
    }

    protected java.lang.String getLastPkgNameExcludeLauncher(java.lang.String curApp, java.util.List<java.lang.String> homePkg) {
        if (curApp != null) {
            if (homePkg != null) {
                java.util.List<java.lang.String> infoPkg = getAppPkgNamesFromLRU();
                if (infoPkg == null) {
                    return null;
                }
                java.lang.String lastPkgName = null;
                for (int i = infoPkg.size() - 1; i >= 0; i--) {
                    java.lang.String pkg = (java.lang.String) infoPkg.get(i);
                    if (!homePkg.contains(pkg) && !pkg.equals(curApp)) {
                        lastPkgName = pkg;
                        break;
                    }
                }
                return lastPkgName;
            }
        }
        return null;
    }

    void initHabitProtectList() {
        synchronized (this.mHabitProtectAppsList) {
            this.mHabitProtectAppsList.clear();
            com.android.server.rms.algorithm.utils.IAwareHabitUtils.loadHabitProtectList(this.mContentResolver, this.mHabitProtectAppsList, this.mUserId.get());
        }
        java.util.List<java.lang.String> topN = getHabitProtectAppList(1, 3, null, true);
        synchronized (this.mHabitProtectListTopN) {
            this.mHabitProtectListTopN.clear();
            this.mHabitProtectListTopN.addAll(topN);
        }
    }

    private void clearHabitProtectList() {
        synchronized (this.mHabitProtectListTopN) {
            this.mHabitProtectListTopN.clear();
        }
        synchronized (this.mHabitProtectAppsList) {
            this.mHabitProtectAppsList.clear();
        }
    }

    protected java.util.List<java.lang.String> queryHabitProtectAppList(int imCount, int emailCount) {
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        int curImCount = 0;
        int curEmailCount = 0;
        synchronized (this.mHabitProtectListTopN) {
            java.util.Iterator it = this.mHabitProtectListTopN.iterator();
            while (it.hasNext()) {
                java.lang.String pkgName = (java.lang.String) it.next();
                int appType = android.rms.iaware.AppTypeRecoManager.getInstance().getAppType(pkgName);
                if (appType != 0) {
                    if (appType != 311) {
                        if ((appType == 1 || appType == 303) && curEmailCount < emailCount) {
                            result.add(pkgName);
                            curEmailCount++;
                        }
                        if (curImCount != imCount && curEmailCount == emailCount) {
                            break;
                        }
                    }
                }
                if (curImCount < imCount) {
                    result.add(pkgName);
                    curImCount++;
                }
                if (curImCount != imCount) {
                }
            }
        }
        return result;
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x0050 A:{SYNTHETIC} */
    protected void foregroundUpdateHabitProtectList(java.lang.String r9) {
        /*
        r8 = this;
        r0 = 1;
        r1 = 0;
        r2 = r8.mHabitProtectAppsList;
        monitor-enter(r2);
        r3 = r8.mHabitProtectAppsList;	 Catch:{ all -> 0x0079 }
        r3 = r3.iterator();	 Catch:{ all -> 0x0079 }
    L_0x000b:
        r4 = r3.hasNext();	 Catch:{ all -> 0x0079 }
        r5 = 0;
        r6 = 1;
        if (r4 == 0) goto L_0x0030;
    L_0x0013:
        r4 = r3.next();	 Catch:{ all -> 0x0079 }
        r4 = (com.android.server.rms.algorithm.utils.ProtectApp) r4;	 Catch:{ all -> 0x0079 }
        r7 = r4.getAppPkgName();	 Catch:{ all -> 0x0079 }
        r7 = r7.equals(r9);	 Catch:{ all -> 0x0079 }
        if (r7 == 0) goto L_0x002f;
    L_0x0023:
        r0 = 0;
        r3 = r4.getDeletedTag();	 Catch:{ all -> 0x0079 }
        if (r3 != r6) goto L_0x0030;
    L_0x002a:
        r4.setDeletedTag(r5);	 Catch:{ all -> 0x0079 }
        r1 = 1;
        goto L_0x0030;
    L_0x002f:
        goto L_0x000b;
    L_0x0030:
        monitor-exit(r2);	 Catch:{ all -> 0x0079 }
        if (r0 == 0) goto L_0x0060;
    L_0x0033:
        r2 = android.rms.iaware.AppTypeRecoManager.getInstance();
        r2 = r2.getAppType(r9);
        if (r2 == 0) goto L_0x004c;
    L_0x003d:
        r3 = 311; // 0x137 float:4.36E-43 double:1.537E-321;
        if (r2 != r3) goto L_0x0042;
    L_0x0041:
        goto L_0x004c;
    L_0x0042:
        if (r2 == r6) goto L_0x004a;
    L_0x0044:
        r3 = 303; // 0x12f float:4.25E-43 double:1.497E-321;
        if (r2 != r3) goto L_0x0049;
    L_0x0048:
        goto L_0x004a;
    L_0x0049:
        return;
    L_0x004a:
        r2 = 1;
        goto L_0x004d;
    L_0x004c:
        r2 = 0;
    L_0x004d:
        r3 = r8.mHabitProtectAppsList;
        monitor-enter(r3);
        r4 = r8.mHabitProtectAppsList;	 Catch:{ all -> 0x005d }
        r6 = new com.android.server.rms.algorithm.utils.ProtectApp;	 Catch:{ all -> 0x005d }
        r7 = 0;
        r6.<init>(r9, r2, r5, r7);	 Catch:{ all -> 0x005d }
        r4.add(r6);	 Catch:{ all -> 0x005d }
        monitor-exit(r3);	 Catch:{ all -> 0x005d }
        goto L_0x0060;
    L_0x005d:
        r4 = move-exception;
        monitor-exit(r3);	 Catch:{ all -> 0x005d }
        throw r4;
    L_0x0060:
        if (r0 != 0) goto L_0x0064;
    L_0x0062:
        if (r1 == 0) goto L_0x0075;
    L_0x0064:
        r3 = r8.mHabitProtectListTopN;
        monitor-enter(r3);
        r2 = r8.mHabitProtectListTopN;	 Catch:{ all -> 0x0076 }
        r2 = r2.contains(r9);	 Catch:{ all -> 0x0076 }
        if (r2 != 0) goto L_0x0074;
    L_0x006f:
        r2 = r8.mHabitProtectListTopN;	 Catch:{ all -> 0x0076 }
        r2.add(r9);	 Catch:{ all -> 0x0076 }
    L_0x0074:
        monitor-exit(r3);	 Catch:{ all -> 0x0076 }
    L_0x0075:
        return;
    L_0x0076:
        r2 = move-exception;
        monitor-exit(r3);	 Catch:{ all -> 0x0076 }
        throw r2;
    L_0x0079:
        r3 = move-exception;
        monitor-exit(r2);	 Catch:{ all -> 0x0079 }
        throw r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.algorithm.AwareUserHabitAlgorithm.foregroundUpdateHabitProtectList(java.lang.String):void");
    }

    protected void backgroundActivityChangedEvent(java.lang.String pkgName, java.lang.Long time) {
        if (pkgName != null) {
            int type = android.rms.iaware.AppTypeRecoManager.getInstance().getAppType(pkgName);
            boolean isNeedUpdate = false;
            if (type == 0 || type == 1 || type == 311 || type == 303) {
                synchronized (this.mHabitProtectArrayMap) {
                    if (!this.mHabitProtectArrayMap.containsKey(pkgName)) {
                        isNeedUpdate = true;
                    }
                    this.mHabitProtectArrayMap.put(pkgName, time);
                }
            }
            synchronized (this.mGCMAppsArrayMap) {
                boolean isGcm = this.mGCMAppsArrayMap.containsKey(pkgName);
                if (!isGcm) {
                    isGcm = com.android.server.rms.algorithm.utils.IAwareHabitUtils.isGCMApp(this.mContext, pkgName);
                    isNeedUpdate |= isGcm;
                }
                if (isGcm) {
                    this.mGCMAppsArrayMap.put(pkgName, time);
                }
            }
            if (isNeedUpdate) {
                updateHabitProtectList();
            }
        }
    }

    protected void trainedUpdateHabitProtectList() {
        boolean isNeedNotifyUpdate = false;
        synchronized (this.mHabitProtectAppsList) {
            this.mHabitProtectAppsList.clear();
            com.android.server.rms.algorithm.utils.IAwareHabitUtils.loadHabitProtectList(this.mContentResolver, this.mHabitProtectAppsList, this.mUserId.get());
        }
        synchronized (this.mHabitProtectArrayMap) {
            java.util.Iterator<java.util.Map.Entry<java.lang.String, java.lang.Long>> it = this.mHabitProtectArrayMap.entrySet().iterator();
            while (it.hasNext()) {
                if (android.os.SystemClock.elapsedRealtime() - ((java.lang.Long) ((java.util.Map.Entry) it.next()).getValue()).longValue() > 86400000) {
                    it.remove();
                    if (!isNeedNotifyUpdate) {
                        isNeedNotifyUpdate = true;
                    }
                }
            }
        }
        synchronized (this.mGCMAppsArrayMap) {
            java.util.Iterator<java.util.Map.Entry<java.lang.String, java.lang.Long>> it2 = this.mGCMAppsArrayMap.entrySet().iterator();
            while (it2.hasNext()) {
                if (android.os.SystemClock.elapsedRealtime() - ((java.lang.Long) ((java.util.Map.Entry) it2.next()).getValue()).longValue() > 86400000) {
                    it2.remove();
                    if (!isNeedNotifyUpdate) {
                        isNeedNotifyUpdate = true;
                    }
                }
            }
        }
        java.util.List<java.lang.String> topNList = getHabitProtectAppList(1, 3, null, true);
        synchronized (this.mHabitProtectListTopN) {
            int size = topNList.size();
            boolean changed = false;
            if (size == this.mHabitProtectListTopN.size()) {
                for (int i = 0; i < size; i++) {
                    java.lang.String dstPkg = (java.lang.String) this.mHabitProtectListTopN.get(i);
                    java.lang.String srcPkg = (java.lang.String) topNList.get(i);
                    if (dstPkg != null && !dstPkg.equals(srcPkg)) {
                        changed = true;
                        break;
                    }
                }
            } else {
                changed = true;
            }
            if (changed) {
                this.mHabitProtectListTopN.clear();
                this.mHabitProtectListTopN.addAll(topNList);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("new habitProtectList topN:");
                stringBuilder.append(this.mHabitProtectListTopN);
                android.rms.iaware.AwareLog.d("AwareUserHabitAlgorithm", stringBuilder.toString());
            }
        }
        if (isNeedNotifyUpdate) {
            updateHabitProtectList();
        }
    }

    private void updateHabitProtectList() {
        com.android.internal.os.BackgroundThread.getHandler().post(new java.lang.Runnable() {
            public void run() {
                synchronized (com.android.server.rms.algorithm.AwareUserHabitAlgorithm.this.mListeners) {
                    if (com.android.server.rms.algorithm.AwareUserHabitAlgorithm.this.mListeners.isEmpty()) {
                        return;
                    }
                    java.util.Iterator it = com.android.server.rms.algorithm.AwareUserHabitAlgorithm.this.mListeners.iterator();
                    while (it.hasNext()) {
                        ((com.android.server.rms.algorithm.AwareUserHabitAlgorithm.HabitProtectListChangeListener) it.next()).onListChanged();
                    }
                }
            }
        });
    }

    protected void uninstallUpdateHabitProtectList(java.lang.String pkgName) {
        boolean isProtectApp = false;
        boolean isNeedNotifyUpdate = false;
        synchronized (this.mHabitProtectAppsList) {
            for (com.android.server.rms.algorithm.utils.ProtectApp app : this.mHabitProtectAppsList) {
                if (app.getAppPkgName().equals(pkgName)) {
                    isProtectApp = true;
                    if (app.getDeletedTag() == 0) {
                        app.setDeletedTag(1);
                    }
                }
            }
        }
        if (isProtectApp) {
            synchronized (this.mHabitProtectListTopN) {
                if (this.mHabitProtectListTopN.contains(pkgName)) {
                    this.mHabitProtectListTopN.remove(pkgName);
                    java.util.List<java.lang.String> result = getHabitProtectAppList(1, 3, null, true);
                    if (result.size() > 0) {
                        for (int i = 0; i < result.size(); i++) {
                            java.lang.String pkgNameStr = (java.lang.String) result.get(i);
                            if (!this.mHabitProtectListTopN.contains(pkgNameStr)) {
                                this.mHabitProtectListTopN.add(pkgNameStr);
                                break;
                            }
                        }
                    }
                }
            }
        }
        synchronized (this.mHabitProtectArrayMap) {
            if (this.mHabitProtectArrayMap.containsKey(pkgName)) {
                java.util.Iterator<java.util.Map.Entry<java.lang.String, java.lang.Long>> it = this.mHabitProtectArrayMap.entrySet().iterator();
                while (it.hasNext()) {
                    if (((java.lang.String) ((java.util.Map.Entry) it.next()).getKey()).equals(pkgName)) {
                        it.remove();
                        isNeedNotifyUpdate = true;
                        break;
                    }
                }
            }
        }
        synchronized (this.mGCMAppsArrayMap) {
            if (this.mGCMAppsArrayMap.containsKey(pkgName)) {
                java.util.Iterator<java.util.Map.Entry<java.lang.String, java.lang.Long>> it2 = this.mGCMAppsArrayMap.entrySet().iterator();
                while (it2.hasNext()) {
                    if (((java.lang.String) ((java.util.Map.Entry) it2.next()).getKey()).equals(pkgName)) {
                        it2.remove();
                        if (!isNeedNotifyUpdate) {
                            isNeedNotifyUpdate = true;
                        }
                    }
                }
            }
        }
        if (isNeedNotifyUpdate) {
            updateHabitProtectList();
        }
    }

    protected java.util.List<java.lang.String> getForceProtectAppsFromHabitProtect(int emailCount, int imCount, java.util.Set<java.lang.String> filterSet) {
        return getHabitProtectAppList(emailCount, imCount, filterSet, true);
    }

    private java.util.List<java.lang.String> getHabitProtectAppList(int emailCount, int imCount, java.util.Set<java.lang.String> filterSet, boolean flag) {
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        synchronized (this.mHabitProtectAppsList) {
            int imTmpCount = 0;
            int emailTmpCount = 0;
            for (com.android.server.rms.algorithm.utils.ProtectApp app : this.mHabitProtectAppsList) {
                java.lang.String pkg = app.getAppPkgName();
                if (app.getDeletedTag() != 1) {
                    if (flag) {
                        if (!(app.getAvgUsedFrequency() <= 0.5f || containsFilterPkg(pkg) || containsFilter2Pkg(pkg))) {
                            if (filterSet != null && filterSet.contains(pkg)) {
                            }
                        }
                    }
                    if (app.getAppType() == 0) {
                        if (imTmpCount < imCount) {
                            imTmpCount++;
                            result.add(pkg);
                        }
                    } else if (app.getAppType() == 1 && emailTmpCount < emailCount) {
                        emailTmpCount++;
                        result.add(pkg);
                    }
                    if (imTmpCount == imCount && emailTmpCount == emailCount) {
                        break;
                    }
                }
            }
        }
        return result;
    }

    public void dumpHabitProtectList(java.io.PrintWriter pw) {
        if (pw != null) {
            pw.println("dump user habit protect list.");
            synchronized (this.mHabitProtectListTopN) {
                java.util.Iterator it = this.mHabitProtectListTopN.iterator();
                while (it.hasNext()) {
                    pw.println((java.lang.String) it.next());
                }
            }
        }
    }

    protected void registHabitProtectListChangeListener(com.android.server.rms.algorithm.AwareUserHabitAlgorithm.HabitProtectListChangeListener listener) {
        if (listener != null) {
            synchronized (this.mListeners) {
                this.mListeners.add(listener);
            }
        }
    }

    protected void unregistHabitProtectListChangeListener(com.android.server.rms.algorithm.AwareUserHabitAlgorithm.HabitProtectListChangeListener listener) {
        if (listener != null) {
            synchronized (this.mListeners) {
                this.mListeners.remove(listener);
            }
        }
    }

    protected java.util.List<java.lang.String> getHabitProtectAppsAll(int emailCount, int imCount) {
        return getHabitProtectAppList(emailCount, imCount, null, false);
    }

    protected java.util.List<java.lang.String> getHabitProtectList(int emailCount, int imCount) {
        java.util.List<java.lang.String> result = getHabitProtectAppList(emailCount, imCount, null, true);
        int total = emailCount + imCount;
        synchronized (this.mHabitProtectArrayMap) {
            if (result.size() < total) {
                for (int i = 0; i < this.mHabitProtectArrayMap.size(); i++) {
                    java.lang.String str = (java.lang.String) this.mHabitProtectArrayMap.keyAt(i);
                    if (!result.contains(str)) {
                        result.add(str);
                    }
                    if (result.size() >= total) {
                        break;
                    }
                }
            }
        }
        return result;
    }

    protected java.util.List<java.lang.String> getGCMAppsList() {
        java.util.ArrayList arrayList;
        synchronized (this.mGCMAppsArrayMap) {
            arrayList = new java.util.ArrayList(this.mGCMAppsArrayMap.keySet());
        }
        return arrayList;
    }

    void setUserId(int userId) {
        this.mUserId.set(userId);
    }

    void clearHabitProtectApps() {
        synchronized (this.mGCMAppsArrayMap) {
            this.mGCMAppsArrayMap.clear();
        }
        synchronized (this.mHabitProtectArrayMap) {
            this.mHabitProtectArrayMap.clear();
        }
        updateHabitProtectList();
    }
}
