package com.android.server.rms.handler;

public final class AppHandler implements com.android.server.rms.handler.HwSysResHandler {
    private static final java.lang.String ACTION_NOTIFY_CRASHINFO_SYSAPP = "com.android.server.rms.handler.AppHandler.ACTION_NOTIFY_CRASHINFO_SYSAPP";
    private static final java.lang.String PERMISSION_NOTIFY_CRASHINFO_SYSAPP = "com.android.server.rms.handler.AppHandler.PERMISSION_NOTIFY_CRASHINFO_SYSAPP";
    private static final java.lang.String TAG = "RMS.AppHandler";
    private static final int TYPE_CLEAR_DATA = 1;
    private static final int TYPE_DISABLE_APP = 2;
    private static final int TYPE_NOTIFY_CRASHINFO = 3;
    private static final int TYPE_NOTIFY_CRASHINFO_SYSAPP = 4;
    private static com.android.server.rms.handler.AppHandler mAppHandler;
    private android.content.Context mContext;

    private AppHandler(android.content.Context context) {
        this.mContext = context;
    }

    public static synchronized com.android.server.rms.handler.AppHandler getInstance(android.content.Context context) {
        com.android.server.rms.handler.AppHandler appHandler;
        synchronized (com.android.server.rms.handler.AppHandler.class) {
            if (mAppHandler == null) {
                mAppHandler = new com.android.server.rms.handler.AppHandler(context);
                if (android.rms.utils.Utils.DEBUG) {
                    android.util.Log.d("RMS.AppHandler", "Create new AppHandler");
                }
            }
            appHandler = mAppHandler;
        }
        return appHandler;
    }

    public boolean execute(android.app.mtm.MultiTaskPolicy policy) {
        boolean result = false;
        if (policy == null) {
            return false;
        }
        int callingUid = policy.getPolicyData().getInt("callingUid");
        java.lang.String pkg = policy.getPolicyData().getString("pkg");
        if (callingUid > 0) {
            if (pkg != null) {
                if (android.rms.utils.Utils.DEBUG || android.util.Log.HWINFO) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("execute: pkg ");
                    stringBuilder.append(pkg);
                    stringBuilder.append(" policy ");
                    stringBuilder.append(policy.getPolicy());
                    android.util.Log.d("RMS.AppHandler", stringBuilder.toString());
                }
                switch (policy.getPolicy()) {
                    case 1:
                        result = clearUserData(callingUid, pkg);
                        break;
                    case 2:
                        result = disableApp(callingUid, pkg);
                        break;
                    case 3:
                        if (com.android.server.rms.HwSysResManagerService.self() != null) {
                            com.android.server.rms.HwSysResManagerService.self().dispatchProcessDiedOverload(pkg, callingUid);
                            break;
                        }
                        break;
                    case 4:
                        result = notifySysAppCrashInfo(pkg);
                        break;
                    default:
                        if (android.rms.utils.Utils.DEBUG) {
                            android.util.Log.i("RMS.AppHandler", "Do not execute any operation, since there is no matching policy");
                            break;
                        }
                        break;
                }
                return result;
            }
        }
        return false;
    }

    public void interrupt() {
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.i("RMS.AppHandler", "interrupt---");
        }
    }

    private boolean clearUserData(int callingUid, java.lang.String pkg) {
        boolean result = ((android.app.ActivityManager) this.mContext.getSystemService("activity")).clearApplicationUserData(pkg, null);
        java.lang.StringBuilder stringBuilder;
        if (result) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Successfully clearUserData of ");
            stringBuilder.append(pkg);
            stringBuilder.append("/");
            stringBuilder.append(callingUid);
            android.util.Log.i("RMS.AppHandler", stringBuilder.toString());
        } else {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Failed to clearUserData of ");
            stringBuilder.append(pkg);
            stringBuilder.append("/");
            stringBuilder.append(callingUid);
            android.util.Log.i("RMS.AppHandler", stringBuilder.toString());
        }
        return result;
    }

    private boolean disableApp(int callingUid, java.lang.String pkg) {
        this.mContext.getPackageManager().setApplicationEnabledSetting(pkg, 3, 0);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Successfully disableApp of ");
        stringBuilder.append(pkg);
        stringBuilder.append("/");
        stringBuilder.append(callingUid);
        android.util.Log.i("RMS.AppHandler", stringBuilder.toString());
        return true;
    }

    private boolean notifySysAppCrashInfo(java.lang.String pkg) {
        if (pkg == null) {
            return false;
        }
        android.content.Intent intent = new android.content.Intent("com.android.server.rms.handler.AppHandler.ACTION_NOTIFY_CRASHINFO_SYSAPP");
        intent.addFlags(1073741824);
        intent.putExtra("android.intent.extra.PACKAGES", pkg);
        this.mContext.sendBroadcast(intent, "com.android.server.rms.handler.AppHandler.PERMISSION_NOTIFY_CRASHINFO_SYSAPP");
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.i("RMS.AppHandler", "notifyCrashInfoSysApp send broadcast successfully!");
        }
        return true;
    }
}
