package com.android.server.rms.iaware;

public class RDAService {
    private static final int DEFAULT_MAX_TIME = 60;
    private static final java.lang.String TAG = "RDAService";
    private static java.lang.String TARGET_APP_FILE_PATH = "/data/app_acc";
    private java.util.ArrayList<java.lang.String> mFakeForegroundList = new java.util.ArrayList();
    private final java.util.concurrent.locks.ReentrantReadWriteLock mPreRecogLock = new java.util.concurrent.locks.ReentrantReadWriteLock();
    private com.android.server.rms.iaware.RFeatureManager mRFeatureManager = null;
    private boolean rdaInitStatus = false;

    private boolean getRDAInitStatus() {
        return this.rdaInitStatus;
    }

    private void setRDAInitStatus(boolean initStatus) {
        this.rdaInitStatus = initStatus;
    }

    public RDAService(android.content.Context context, android.os.HandlerThread handlerThread) {
        android.rms.iaware.AwareLog.d("RDAService", "RDAService construct!");
        this.mRFeatureManager = new com.android.server.rms.iaware.RFeatureManager(context, handlerThread);
        com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().setHandler(handlerThread);
        ensureAppAccDirectoryCreated();
        prepareCloudDownloading();
    }

    public void reportData(android.rms.iaware.CollectData data) {
        if (data != null) {
            if (android.rms.iaware.AwareConstant.ResourceType.getResourceType(data.getResId()) != android.rms.iaware.AwareConstant.ResourceType.RESOURCE_INVALIDE_TYPE) {
                this.mRFeatureManager.reportData(data);
                return;
            }
        }
        android.rms.iaware.AwareLog.e("RDAService", "Reporting error data!");
    }

    public void reportDataWithCallback(android.rms.iaware.CollectData data, android.rms.iaware.IReportDataCallback callback) {
        if (data != null) {
            if (callback != null) {
                this.mRFeatureManager.reportDataWithCallback(data, callback);
                return;
            }
        }
        android.rms.iaware.AwareLog.e("RDAService", "reportDataWithCallback parameters error!");
    }

    public void enableFeature(int type) {
        if (android.rms.iaware.AwareConstant.FeatureType.getFeatureType(type) == android.rms.iaware.AwareConstant.FeatureType.FEATURE_INVALIDE_TYPE) {
            android.rms.iaware.AwareLog.e("RDAService", "Enabling error feature type!");
        } else {
            this.mRFeatureManager.enableFeature(type);
        }
    }

    public void disableFeature(int type) {
        if (android.rms.iaware.AwareConstant.FeatureType.getFeatureType(type) == android.rms.iaware.AwareConstant.FeatureType.FEATURE_INVALIDE_TYPE) {
            android.rms.iaware.AwareLog.e("RDAService", "Disabling error feature type!");
        } else {
            this.mRFeatureManager.disableFeature(type);
        }
    }

    public void init(android.os.Bundle bundle) {
        if (bundle == null) {
            android.rms.iaware.AwareLog.e("RDAService", "init error bundle data!");
            return;
        }
        if (getRDAInitStatus()) {
            android.rms.iaware.AwareLog.d("RDAService", "RDA update iaware feature switch status from config file");
            syncFeatureStatus(bundle);
        } else {
            this.mRFeatureManager.init(bundle);
            setRDAInitStatus(true);
        }
    }

    public boolean isResourceNeeded(int resourceid) {
        android.rms.iaware.AwareConstant.ResourceType resourceType = android.rms.iaware.AwareConstant.ResourceType.getResourceType(resourceid);
        if (resourceType != android.rms.iaware.AwareConstant.ResourceType.RESOURCE_INVALIDE_TYPE) {
            return this.mRFeatureManager.isResourceNeeded(resourceType);
        }
        android.rms.iaware.AwareLog.e("RDAService", "isResourceNeeded error resource type!");
        return false;
    }

    public int isFeatureEnabled(int featureId) {
        return this.mRFeatureManager.isFeatureEnabled(featureId);
    }

    public boolean configUpdate() {
        return this.mRFeatureManager.configUpdate();
    }

    public boolean custConfigUpdate() {
        return this.mRFeatureManager.custConfigUpdate();
    }

    public int getDumpData(int time, java.util.List<android.rms.iaware.DumpData> dumpData) {
        int dumpDataTime = time;
        if (dumpDataTime <= 0 || dumpDataTime > 60) {
            android.rms.iaware.AwareLog.e("RDAService", "getDumpData parameter error: use default time!");
            dumpDataTime = 60;
        }
        if (dumpData != null) {
            return this.mRFeatureManager.getDumpData(dumpDataTime, dumpData);
        }
        android.rms.iaware.AwareLog.e("RDAService", "getDumpData parameter error: null list!");
        return 0;
    }

    public int getStatisticsData(java.util.List<android.rms.iaware.StatisticsData> statisticsData) {
        if (statisticsData != null) {
            return this.mRFeatureManager.getStatisticsData(statisticsData);
        }
        android.rms.iaware.AwareLog.e("RDAService", "statisticsData parameter error: null list!");
        return 0;
    }

    public java.lang.String saveBigData(int featureId, boolean clear) {
        return this.mRFeatureManager.saveBigData(featureId, clear);
    }

    public java.lang.String fetchBigDataByVersion(int iVer, int fId, boolean beta, boolean clear) {
        return this.mRFeatureManager.fetchBigDataByVersion(iVer, fId, beta, clear);
    }

    public java.lang.String fetchDFTDataByVersion(int iVer, int fId, boolean beta, boolean clear, boolean betaEncode) {
        return this.mRFeatureManager.fetchDFTDataByVersion(iVer, fId, beta, clear, betaEncode);
    }

    public void updateFakeForegroundList(java.util.List<java.lang.String> processList) {
        java.util.concurrent.locks.ReentrantReadWriteLock.WriteLock writeLock = this.mPreRecogLock.writeLock();
        writeLock.lock();
        try {
            if (!this.mFakeForegroundList.isEmpty()) {
                this.mFakeForegroundList.clear();
            }
            if (processList != null) {
                if (!processList.isEmpty()) {
                    this.mFakeForegroundList.addAll(processList);
                    writeLock.unlock();
                    return;
                }
            }
            writeLock.unlock();
        } catch (Throwable th) {
            writeLock.unlock();
        }
    }

    public boolean isFakeForegroundProcess(java.lang.String process) {
        if (process != null) {
            if (process.length() != 0) {
                if (this.mPreRecogLock.isWriteLocked()) {
                    android.rms.iaware.AwareLog.w("RDAService", "The fake list is updating!");
                    return false;
                }
                java.util.concurrent.locks.ReentrantReadWriteLock.ReadLock readLock = this.mPreRecogLock.readLock();
                readLock.lock();
                try {
                    if (this.mFakeForegroundList.isEmpty()) {
                        return false;
                    }
                    java.util.Iterator it = this.mFakeForegroundList.iterator();
                    while (it.hasNext()) {
                        if (process.equals((java.lang.String) it.next())) {
                            readLock.unlock();
                            return true;
                        }
                    }
                    readLock.unlock();
                    return false;
                } finally {
                    readLock.unlock();
                }
            }
        }
        android.rms.iaware.AwareLog.e("RDAService", "isFakeForegroundProcess parameter is null!");
        return false;
    }

    public boolean isEnableFakeForegroundControl() {
        if (this.mPreRecogLock.isWriteLocked()) {
            android.rms.iaware.AwareLog.w("RDAService", "The fake list is updating!");
            return false;
        }
        java.util.concurrent.locks.ReentrantReadWriteLock.ReadLock readLock = this.mPreRecogLock.readLock();
        readLock.lock();
        try {
            if (this.mFakeForegroundList.isEmpty()) {
                return false;
            }
            readLock.unlock();
            return true;
        } finally {
            readLock.unlock();
        }
    }

    public void dump(java.io.FileDescriptor fd, java.io.PrintWriter pw, java.lang.String[] args) {
        com.android.server.rms.iaware.memory.utils.MemoryDumpsys.doDumpsys(this.mRFeatureManager.getRegisteredFeature(android.rms.iaware.AwareConstant.FeatureType.FEATURE_MEMORY), fd, pw, args);
        com.android.server.rms.iaware.feature.DevSchedFeatureRT.doDumpsys(this.mRFeatureManager.getRegisteredFeature(android.rms.iaware.AwareConstant.FeatureType.FEATURE_DEVSCHED), fd, pw, args);
    }

    private void ensureAppAccDirectoryCreated() {
        java.io.File appDir = new java.io.File(TARGET_APP_FILE_PATH);
        if (!appDir.exists()) {
            if (appDir.mkdirs()) {
                try {
                    android.system.Os.chmod(TARGET_APP_FILE_PATH, 457);
                } catch (android.system.ErrnoException e) {
                    android.rms.iaware.AwareLog.e("RDAService", "ensureAppAccDirectoryCreated chmod error!");
                }
                return;
            }
            android.rms.iaware.AwareLog.e("RDAService", "ensureAppAccDirectoryCreated mkdir error");
        }
    }

    private void syncFeatureStatus(android.os.Bundle bundle) {
        android.rms.iaware.AwareConstant.FeatureType[] featureTypes = this.mRFeatureManager.getFeatureTypes();
        int featureNum = featureTypes.length;
        boolean featureEnabled = false;
        for (int index = 0; index < featureNum; index++) {
            int[] featureInfo = this.mRFeatureManager.getFeatureInfoFromBundle(bundle, featureTypes[index].name());
            int i = featureInfo[0];
            com.android.server.rms.iaware.RFeatureManager rFeatureManager = this.mRFeatureManager;
            boolean z = true;
            if (i != 1) {
                z = false;
            }
            featureEnabled = z;
            if (this.mRFeatureManager.getFeatureStatus(featureTypes[index].ordinal()) != featureInfo[0]) {
                android.rms.iaware.AwareLog.d("RDAService", "xml != real status");
                if (featureEnabled) {
                    this.mRFeatureManager.enableFeature(featureTypes[index].ordinal());
                } else {
                    this.mRFeatureManager.disableFeature(featureTypes[index].ordinal());
                }
            } else {
                android.rms.iaware.AwareLog.d("RDAService", "xml == real status");
            }
        }
    }

    private void prepareCloudDownloading() {
        java.lang.StringBuilder stringBuilder;
        java.lang.String filePath = android.rms.iaware.AwareConstant.getConfigFilesPath();
        java.io.File fileDir = new java.io.File(filePath);
        if (!fileDir.exists()) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Create ");
            stringBuilder.append(filePath);
            android.rms.iaware.AwareLog.i("RDAService", stringBuilder.toString());
            if (fileDir.mkdir()) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setPermissions ");
                stringBuilder.append(filePath);
                android.rms.iaware.AwareLog.i("RDAService", stringBuilder.toString());
                if (android.os.FileUtils.setPermissions(filePath, 504, -1, -1) != 0) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Failed to setPermissions ");
                    stringBuilder.append(filePath);
                    android.rms.iaware.AwareLog.e("RDAService", stringBuilder.toString());
                }
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Failed to create ");
                stringBuilder.append(filePath);
                android.rms.iaware.AwareLog.e("RDAService", stringBuilder.toString());
                return;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Reflash SELinux lable for ");
        stringBuilder.append(filePath);
        android.rms.iaware.AwareLog.i("RDAService", stringBuilder.toString());
        if (!android.os.SELinux.restoreconRecursive(fileDir)) {
            android.rms.iaware.AwareLog.e("RDAService", "Failed to reflash SELinux lable");
        }
    }
}
