package com.android.server.rms.iaware.appmng;

public class AwareAppMngDfxData {
    public static final int DFX_DATA_TYPE_KILLINFO = 1;
    public static final int DFX_DATA_TYPE_STARTINFO = 2;
    private static final int MASK_CLASSRATE = 983040;
    private static final int MASK_CLEANRES = 1;
    private static final int MASK_RESTART = 2;
    private static final int MASK_SUBCLASS = 3840;
    private static final java.lang.String SEPARATOR = "#";
    private static final java.lang.String TAG = "AwareAppMngDfxData";
    public long mAppColdStartCount;
    public long mAppTotalStartCount;
    public long mAwareBigMemForceStop;
    public long mAwareBigMemKill;
    public long mAwareLowMemForceStop;
    public long mAwareLowMemKill;
    public int mHwAdj;
    public java.lang.String mName;

    public AwareAppMngDfxData(java.lang.String packageName, java.lang.String processName) {
        java.lang.StringBuffer buf = new java.lang.StringBuffer();
        buf.append(packageName == null ? "" : packageName);
        buf.append("#");
        if (processName != null) {
            buf.append(processName);
        }
        this.mName = buf.toString();
        this.mHwAdj = 0;
    }

    public AwareAppMngDfxData(java.util.List<java.lang.String> packageName, java.lang.String processName, int subClsRate, int clsRate, boolean restart, boolean cleanRes) {
        if (packageName != null) {
            java.lang.StringBuffer buf = new java.lang.StringBuffer();
            for (java.lang.String pkg : packageName) {
                buf.append(pkg);
                buf.append("#");
            }
            if (processName != null) {
                buf.append(processName);
            }
            this.mName = buf.toString();
            this.mHwAdj = 0;
            if (cleanRes) {
                this.mHwAdj = 1;
            }
            if (restart) {
                this.mHwAdj += 2;
            }
            this.mHwAdj += subClsRate << 8;
            this.mHwAdj += clsRate << 16;
        }
    }

    public java.lang.String toString() {
        boolean restart = true;
        boolean cleanRes = (this.mHwAdj & 1) != 0;
        if ((this.mHwAdj & 2) == 0) {
            restart = false;
        }
        int subClass = (this.mHwAdj & 3840) >> 8;
        int classRate = (this.mHwAdj & 983040) >> 16;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("name:");
        stringBuilder.append(this.mName);
        stringBuilder.append(",cleanRes:");
        stringBuilder.append(cleanRes);
        stringBuilder.append(",restart:");
        stringBuilder.append(restart);
        stringBuilder.append(",classRate:");
        stringBuilder.append(classRate);
        stringBuilder.append(",subClass:");
        stringBuilder.append(subClass);
        return stringBuilder.toString();
    }

    public org.json.JSONObject makeJson(boolean killInfo) {
        org.json.JSONObject jsonObj = new org.json.JSONObject();
        if (killInfo) {
            try {
                jsonObj.put("AppName", this.mName);
                jsonObj.put("hwAdj", this.mHwAdj);
                jsonObj.put("bmk", this.mAwareBigMemKill);
                jsonObj.put("bmf", this.mAwareBigMemForceStop);
                jsonObj.put("lmk", this.mAwareLowMemKill);
                jsonObj.put("lmf", this.mAwareLowMemForceStop);
            } catch (org.json.JSONException e) {
                android.rms.iaware.AwareLog.e("AwareAppMngDfxData", "makeJson error!");
            }
        } else {
            jsonObj.put("AppName", this.mName);
            jsonObj.put("cNum", this.mAppColdStartCount);
            jsonObj.put("hNum", this.mAppTotalStartCount > this.mAppColdStartCount ? this.mAppTotalStartCount - this.mAppColdStartCount : 0);
        }
        return jsonObj;
    }

    public java.lang.String getKey() {
        java.lang.String hash = new java.lang.StringBuilder();
        hash.append(this.mName == null ? "" : this.mName);
        hash.append(this.mHwAdj);
        return hash.toString();
    }

    public int hashCode() {
        return super.hashCode();
    }

    public boolean equals(java.lang.Object obj) {
        boolean z = false;
        if (obj == null || !(obj instanceof com.android.server.rms.iaware.appmng.AwareAppMngDfxData)) {
            return false;
        }
        com.android.server.rms.iaware.appmng.AwareAppMngDfxData data = (com.android.server.rms.iaware.appmng.AwareAppMngDfxData) obj;
        if (this.mName != null && this.mName.equals(data.mName) && this.mHwAdj == data.mHwAdj) {
            z = true;
        }
        return z;
    }

    public void addTrackeKillInfo(int type) {
        switch (type) {
            case 0:
                this.mAwareBigMemKill++;
                return;
            case 1:
                this.mAwareBigMemForceStop++;
                return;
            case 2:
                this.mAwareLowMemKill++;
                return;
            case 3:
                this.mAwareLowMemForceStop++;
                return;
            default:
                return;
        }
    }

    public void trackeAppStartInfo(int type) {
        switch (type) {
            case 10:
                this.mAppColdStartCount++;
                return;
            case 11:
                this.mAppTotalStartCount++;
                return;
            default:
                return;
        }
    }
}
