package com.android.server.rms.iaware.appmng;

public final class AwareAppPreloadResourceManager {
    private static final java.lang.String CONFIG_SUB_SWITCH = "PreloadResourcesubSwitch";
    private static final java.lang.String FEATURE_BITMAP_DECODE_VALUE = "bitmap_decode_cache_value";
    private static final java.lang.String FEATURE_ITEM = "feature";
    private static final java.lang.String FEATURE_NAME = "PreloadResourceFeature";
    private static final java.lang.String LABEL_CACHE_SIZE = "cache_size";
    private static final java.lang.String LABEL_SWITCH = "switch";
    private static final java.lang.String TAG = "AwareAppPreloadResourceManager";
    private static java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.rms.iaware.appmng.AwareAppPreloadResourceManager sInstance = null;
    private int mSizeOfBitmapDeocodeCache = 0;
    private boolean mSwitchOfBitmapDeocodeCache = false;

    private AwareAppPreloadResourceManager() {
        getPreloadResourceSwitch();
    }

    public static com.android.server.rms.iaware.appmng.AwareAppPreloadResourceManager getInstance() {
        com.android.server.rms.iaware.appmng.AwareAppPreloadResourceManager awareAppPreloadResourceManager;
        synchronized (mLock) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.appmng.AwareAppPreloadResourceManager();
            }
            awareAppPreloadResourceManager = sInstance;
        }
        return awareAppPreloadResourceManager;
    }

    private void parseAllSwitch(java.lang.String data, java.lang.String featureName) {
        if (data != null && "bitmap_decode_cache_value".equals(featureName)) {
            try {
                if (1 == java.lang.Integer.parseInt(data)) {
                    this.mSwitchOfBitmapDeocodeCache = true;
                }
            } catch (java.lang.NumberFormatException e) {
                android.rms.iaware.AwareLog.w("AwareAppPreloadResourceManager", "parseAllSwitch parseInt FEATURE_BITMAP_DECODE_VALUE failed!");
            }
        }
    }

    private void parseAllCacheSize(java.lang.String data, java.lang.String featureName) {
        if (data != null && "bitmap_decode_cache_value".equals(featureName)) {
            try {
                this.mSizeOfBitmapDeocodeCache = java.lang.Integer.parseInt(data);
            } catch (java.lang.NumberFormatException e) {
                android.rms.iaware.AwareLog.w("AwareAppPreloadResourceManager", "parseAllCacheSize  parseInt failed!");
            }
        }
    }

    private void parseSwitchValue(android.rms.iaware.AwareConfig.Item item, java.lang.String featureName) {
        java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = item.getSubItemList();
        if (subItemList == null) {
            android.rms.iaware.AwareLog.w("AwareAppPreloadResourceManager", "get sub switch config item failed!");
            return;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            if (subItem != null) {
                java.lang.String itemName = subItem.getName();
                java.lang.String itemValue = subItem.getValue();
                if ("switch".equals(itemName)) {
                    parseAllSwitch(itemValue, featureName);
                }
                if ("cache_size".equals(itemName)) {
                    parseAllCacheSize(itemValue, featureName);
                }
            }
        }
    }

    private void getSwitchConfig(android.rms.iaware.AwareConfig awareConfig) {
        if (awareConfig == null) {
            android.rms.iaware.AwareLog.w("AwareAppPreloadResourceManager", "get cust aware config failed!");
            return;
        }
        java.util.List<android.rms.iaware.AwareConfig.Item> itemList = awareConfig.getConfigList();
        if (itemList != null) {
            for (android.rms.iaware.AwareConfig.Item item : itemList) {
                if (item != null) {
                    java.util.Map<java.lang.String, java.lang.String> configProperties = item.getProperties();
                    if (configProperties != null) {
                        java.lang.String featureName = (java.lang.String) configProperties.get("feature");
                        if (featureName == null) {
                            break;
                        }
                        parseSwitchValue(item, featureName);
                    }
                }
            }
        }
    }

    private void getPreloadResourceSwitch() {
        try {
            android.os.IBinder awareservice = android.rms.iaware.IAwareCMSManager.getICMSManager();
            if (awareservice != null) {
                getSwitchConfig(android.rms.iaware.IAwareCMSManager.getCustConfig(awareservice, "PreloadResourceFeature", "PreloadResourcesubSwitch"));
            } else {
                android.rms.iaware.AwareLog.w("AwareAppPreloadResourceManager", "getAwareConfig can not find service awareService.");
            }
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.e("AwareAppPreloadResourceManager", "getAwareConfig RemoteException");
        }
    }

    public void enable() {
        android.os.SystemProperties.set("persist.sys.iaware.switch.BitmapDeocodeCache", java.lang.Boolean.toString(this.mSwitchOfBitmapDeocodeCache));
        android.os.SystemProperties.set("persist.sys.iaware.size.BitmapDeocodeCache", java.lang.Integer.toString(this.mSizeOfBitmapDeocodeCache));
    }

    public void disable() {
        android.os.SystemProperties.set("persist.sys.iaware.switch.BitmapDeocodeCache", java.lang.Boolean.toString(false));
        android.os.SystemProperties.set("persist.sys.iaware.size.BitmapDeocodeCache", java.lang.Integer.toString(0));
    }
}
