package com.android.server.rms.iaware.cpu;

public class CPUAppRecogMngProxy {
    private static final int CONNECT_PG_DELAYED = 5000;
    private static final int CYCLE_MAX_NUM = 6;
    private static final int MSG_PG_CONNECT = 1;
    private static final java.lang.String TAG = "CPUAppRecogMngProxy";
    private com.android.server.rms.iaware.cpu.CPUAppRecogMngProxy.CPUAppRecogMngProxyHandler mCPUAppRecogMngProxyHandler;
    private android.content.Context mContext;
    private int mCycleNum = 0;
    private com.huawei.pgmng.plug.PGSdk mPGSdk = null;
    private java.util.concurrent.atomic.AtomicBoolean mRegistered = new java.util.concurrent.atomic.AtomicBoolean(false);
    private com.huawei.pgmng.plug.PGSdk.Sink mSink = null;

    private class CPUAppRecogMngProxyHandler extends android.os.Handler {
        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            if (msg.what != 1) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("msg.what = ");
                stringBuilder.append(msg.what);
                stringBuilder.append("  is Invalid !");
                android.rms.iaware.AwareLog.w("CPUAppRecogMngProxy", stringBuilder.toString());
                return;
            }
            com.android.server.rms.iaware.cpu.CPUAppRecogMngProxy.this.getPGSdk();
        }
    }

    public CPUAppRecogMngProxy(android.content.Context context) {
        this.mContext = context;
        this.mCPUAppRecogMngProxyHandler = new com.android.server.rms.iaware.cpu.CPUAppRecogMngProxy.CPUAppRecogMngProxyHandler();
        getPGSdk();
    }

    private void callPGRegisterListener() {
        if (!this.mRegistered.get()) {
            if (this.mPGSdk != null) {
                if (this.mSink != null) {
                    try {
                        this.mPGSdk.enableStateEvent(this.mSink, 10011);
                        this.mPGSdk.enableStateEvent(this.mSink, 10002);
                        this.mPGSdk.enableStateEvent(this.mSink, 10015);
                        this.mPGSdk.enableStateEvent(this.mSink, 10016);
                        this.mRegistered.set(true);
                    } catch (android.os.RemoteException e) {
                        this.mPGSdk = null;
                        this.mCycleNum = 0;
                        android.rms.iaware.AwareLog.e("CPUAppRecogMngProxy", "mPGSdk registerSink && enableStateEvent happend RemoteException!");
                    }
                    return;
                }
            }
            android.rms.iaware.AwareLog.e("CPUAppRecogMngProxy", "callPGregisterListener null == mPGSdk");
        }
    }

    private void callPGUnregisterListener() {
        if (this.mPGSdk != null) {
            if (this.mRegistered.get()) {
                try {
                    this.mPGSdk.disableStateEvent(this.mSink, 10011);
                    this.mPGSdk.disableStateEvent(this.mSink, 10002);
                    this.mPGSdk.disableStateEvent(this.mSink, 10015);
                    this.mPGSdk.disableStateEvent(this.mSink, 10016);
                    this.mRegistered.set(false);
                } catch (android.os.RemoteException e) {
                    android.rms.iaware.AwareLog.e("CPUAppRecogMngProxy", "callPGUnregisterListener happend RemoteException!");
                }
            }
        }
    }

    private void getPGSdk() {
        if (this.mPGSdk == null) {
            this.mPGSdk = com.huawei.pgmng.plug.PGSdk.getInstance();
            if (this.mPGSdk != null || this.mCycleNum >= 6) {
                callPGRegisterListener();
                return;
            }
            this.mCycleNum++;
            this.mCPUAppRecogMngProxyHandler.removeMessages(1);
            this.mCPUAppRecogMngProxyHandler.sendEmptyMessageDelayed(1, 5000);
        }
    }

    private int queryStateType(java.lang.String pkgName) {
        int pkgType = -1;
        if (this.mPGSdk == null) {
            return -1;
        }
        try {
            pkgType = this.mPGSdk.getPkgType(this.mContext, pkgName);
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.w("CPUAppRecogMngProxy", "queryStateType catch RemoteException!");
        }
        return pkgType;
    }

    public boolean isGameType(java.lang.String pkgName) {
        return isGameType(queryStateType(pkgName));
    }

    public boolean isGameType(int stateType) {
        if (stateType != 10011) {
            if (stateType != 10002) {
                return false;
            }
        }
        return true;
    }

    public boolean isVideoType(int stateType) {
        if (stateType != 10015) {
            if (stateType != 10016) {
                return false;
            }
        }
        return true;
    }

    public void register(com.huawei.pgmng.plug.PGSdk.Sink sink) {
        if (this.mSink == null) {
            if (sink != null) {
                this.mSink = sink;
                callPGRegisterListener();
            }
        }
    }

    public void unregister(com.huawei.pgmng.plug.PGSdk.Sink sink) {
        if (this.mSink == sink) {
            if (sink != null) {
                callPGUnregisterListener();
                this.mSink = null;
            }
        }
    }
}
