package com.android.server.rms.iaware.cpu;

public class CPUFeatureAMSCommunicator {
    private static final int APP_START_DURATION = 1500;
    private static final int INIT_DURATION = -1;
    private static final int MAX_TOP_APP_DURATION = 10000;
    private static final java.lang.String TAG = "CPUFeatureAMSCommunicator";
    private static final int UNIPERF_BOOST_OFF = 4;
    private static final int WINDOW_SWITCH_DURATION = 500;
    private static com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator sInstance;
    private com.android.server.rms.iaware.cpu.CPUFeature mCPUFeatureInstance;
    private int mDelayOffTime = 200;
    private com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.CPUFeatureAMSCommunicatorHandler mHandler;
    private int mLastSetTopDuration = -1;
    private long mLastSetTopTimeStamp = android.os.SystemClock.uptimeMillis();
    private java.lang.String mLaunchingPkg;
    private java.util.concurrent.atomic.AtomicBoolean mOnDemandBoostEnable = new java.util.concurrent.atomic.AtomicBoolean(false);
    private java.util.Map<java.lang.String, java.lang.Integer> mSpecialAppMap = new android.util.ArrayMap();
    private java.util.concurrent.atomic.AtomicBoolean mTopAppBoostEnable = new java.util.concurrent.atomic.AtomicBoolean(false);
    private java.util.ArrayList<java.lang.Integer> mUniperfCmdIds = new java.util.ArrayList();

    private class CPUFeatureAMSCommunicatorHandler extends android.os.Handler {
        private CPUFeatureAMSCommunicatorHandler() {
        }

        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            switch (msg.what) {
                case 116:
                    com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.this.setTopAppCpuSet(msg.arg1);
                    return;
                case 117:
                    com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.this.resetTopAppCpuSet();
                    return;
                case 118:
                    com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.this.dealUniperfOnEvent(msg);
                    return;
                case 119:
                    com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.this.dealUniperfOffEvent(msg);
                    return;
                case 120:
                    com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.this.sendUniperfOffEvent();
                    return;
                default:
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("handleMessage default msg what = ");
                    stringBuilder.append(msg.what);
                    android.rms.iaware.AwareLog.w("CPUFeatureAMSCommunicator", stringBuilder.toString());
                    return;
            }
        }
    }

    private CPUFeatureAMSCommunicator() {
    }

    public static synchronized com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator getInstance() {
        com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator cPUFeatureAMSCommunicator;
        synchronized (com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator();
            }
            cPUFeatureAMSCommunicator = sInstance;
        }
        return cPUFeatureAMSCommunicator;
    }

    public void start(com.android.server.rms.iaware.cpu.CPUFeature feature) {
        initHandler();
        this.mCPUFeatureInstance = feature;
    }

    private void initHandler() {
        if (this.mHandler == null) {
            this.mHandler = new com.android.server.rms.iaware.cpu.CPUFeatureAMSCommunicator.CPUFeatureAMSCommunicatorHandler();
        }
    }

    public void stop() {
        removeAllMsg();
        resetTopAppCpuSet();
    }

    public void setTopAppBoostEnable(boolean enable) {
        this.mTopAppBoostEnable.set(enable);
    }

    public void setOnDemandBoostEnable(boolean enable) {
        this.mOnDemandBoostEnable.set(enable);
    }

    public void setTopAppToBoost(int type, java.lang.String pkgNameExtra) {
        int duration = 0;
        java.lang.String pkgName = pkgNameExtra;
        boolean isUniperfOn = false;
        if (pkgNameExtra != null) {
            java.lang.String[] strings = pkgNameExtra.split(":");
            pkgName = strings[0];
            if (strings.length >= 2 && "on".equals(strings[1])) {
                isUniperfOn = true;
            }
        }
        switch (type) {
            case 1:
                duration = 1500;
                if (isUniperfOn) {
                    doUniperfOnEvent(pkgName, 4099);
                }
                startSpecialApp(pkgName);
                break;
            case 2:
                duration = 500;
                if (isUniperfOn) {
                    doUniperfOnEvent(pkgName, 4098);
                    break;
                }
                break;
            case 3:
                com.android.server.rms.iaware.cpu.CPUAppStartOnFire.getInstance().setOnFire();
                return;
            case 4:
                doUniperfOffEvent(pkgName);
                break;
            default:
                android.rms.iaware.AwareLog.e("CPUFeatureAMSCommunicator", "set app boost but type is unknown");
                return;
        }
        if (pkgName != null && isValidTopDuration(duration)) {
            if (isTopAppBoostEnable()) {
                if (this.mHandler != null) {
                    android.os.Message msg = this.mHandler.obtainMessage(116);
                    msg.arg1 = duration;
                    this.mHandler.sendMessage(msg);
                }
            }
        }
    }

    private void setTopAppCpuSet(int duration) {
        int pastTimeFromLast = (int) (android.os.SystemClock.uptimeMillis() - this.mLastSetTopTimeStamp);
        if (this.mLastSetTopDuration == -1 || pastTimeFromLast > this.mLastSetTopDuration || pastTimeFromLast + duration > this.mLastSetTopDuration) {
            this.mHandler.removeMessages(117);
            sendPacketByMsgCode(116);
            this.mHandler.sendEmptyMessageDelayed(117, (long) duration);
            updateLastTop(duration);
        }
    }

    private void updateLastTop(int duration) {
        this.mLastSetTopTimeStamp = android.os.SystemClock.uptimeMillis();
        this.mLastSetTopDuration = duration;
    }

    private boolean isValidTopDuration(int duration) {
        return duration > 0 && duration <= 10000;
    }

    private void resetTopAppCpuSet() {
        sendPacketByMsgCode(117);
    }

    private void removeAllMsg() {
        this.mHandler.removeMessages(116);
        this.mHandler.removeMessages(117);
    }

    private void sendPacketByMsgCode(int msg) {
        if (this.mCPUFeatureInstance != null) {
            java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(4);
            buffer.putInt(msg);
            int resCode = this.mCPUFeatureInstance.sendPacket(buffer);
            if (resCode != 1) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("sendPacketByMsgCode sendPacket failed, msg:");
                stringBuilder.append(msg);
                stringBuilder.append(",send error code:");
                stringBuilder.append(resCode);
                android.rms.iaware.AwareLog.e("CPUFeatureAMSCommunicator", stringBuilder.toString());
            }
        }
    }

    private boolean isTopAppBoostEnable() {
        return this.mTopAppBoostEnable.get() && com.android.server.rms.iaware.cpu.CPUPowerMode.isPerformanceMode();
    }

    private void sendUniperfOffEvent() {
        int size = this.mUniperfCmdIds.size();
        for (int i = 0; i < size; i++) {
            int cmdId = getCmdId((java.lang.Integer) this.mUniperfCmdIds.get(i));
            if (cmdId > 0) {
                android.iawareperf.UniPerf.getInstance().uniPerfEvent(cmdId, "", new int[]{-1});
            }
        }
        this.mUniperfCmdIds.clear();
    }

    private int getCmdId(java.lang.Integer cmdId) {
        if (cmdId != null) {
            return cmdId.intValue();
        }
        return -1;
    }

    private void doUniperfOnEvent(java.lang.String pkgName, int uniperfCmdId) {
        if (this.mOnDemandBoostEnable.get() && this.mHandler != null) {
            android.os.Message msg = this.mHandler.obtainMessage(118);
            msg.obj = pkgName;
            msg.arg1 = uniperfCmdId;
            this.mHandler.sendMessage(msg);
        }
    }

    private void dealUniperfOnEvent(android.os.Message msg) {
        java.lang.String pkgName = msg.obj;
        int uniperfCmdId = msg.arg1;
        if (pkgName != null) {
            if (this.mHandler != null) {
                this.mHandler.removeMessages(120);
            }
            this.mUniperfCmdIds.add(java.lang.Integer.valueOf(uniperfCmdId));
            this.mLaunchingPkg = pkgName;
            if (uniperfCmdId == 4099) {
                this.mDelayOffTime = com.android.server.rms.iaware.cpu.OnDemandBoost.getInstance().getColdStartOffDelay();
            } else {
                this.mDelayOffTime = com.android.server.rms.iaware.cpu.OnDemandBoost.getInstance().getWinSwitchOffDelay();
            }
        }
    }

    private void doUniperfOffEvent(java.lang.String pkgName) {
        if (this.mOnDemandBoostEnable.get() && this.mHandler != null) {
            android.os.Message msg = this.mHandler.obtainMessage(119);
            msg.obj = pkgName;
            this.mHandler.sendMessage(msg);
        }
    }

    private void dealUniperfOffEvent(android.os.Message msg) {
        java.lang.String pkgName = msg.obj;
        if (!(pkgName == null || this.mLaunchingPkg == null)) {
            if (this.mLaunchingPkg.length() > 0) {
                if (pkgName.startsWith(this.mLaunchingPkg)) {
                    this.mLaunchingPkg = "";
                    if (this.mHandler != null) {
                        this.mHandler.removeMessages(120);
                        this.mHandler.sendEmptyMessageDelayed(120, (long) this.mDelayOffTime);
                    }
                    return;
                }
                this.mLaunchingPkg = "";
            }
        }
    }

    public void updateSpecilaAppMap(java.lang.String pkgName, int cmdId) {
        if (pkgName != null) {
            this.mSpecialAppMap.put(pkgName, java.lang.Integer.valueOf(cmdId));
        }
    }

    private void startSpecialApp(java.lang.String pkgName) {
        if (isInSpecialAppMap(pkgName)) {
            doSpecialAppStart(pkgName);
        }
    }

    private boolean isInSpecialAppMap(java.lang.String pkgName) {
        if (pkgName != null) {
            return this.mSpecialAppMap.containsKey(pkgName);
        }
        android.rms.iaware.AwareLog.d("CPUFeatureAMSCommunicator", "pkgName is null!");
        return false;
    }

    private void doSpecialAppStart(java.lang.String pkgName) {
        int cmdId = getCmdId((java.lang.Integer) this.mSpecialAppMap.get(pkgName));
        if (cmdId > 0) {
            android.iawareperf.UniPerf.getInstance().uniPerfEvent(cmdId, "", new int[0]);
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("invalid cmdid ");
        stringBuilder.append(cmdId);
        android.rms.iaware.AwareLog.d("CPUFeatureAMSCommunicator", stringBuilder.toString());
    }
}
