package com.android.server.rms.iaware.cpu;

public class CPUHighFgControl {
    private static final java.lang.String CGROUP_CPUACCT = ":cpuacct";
    private static final java.lang.String CGROUP_CPUSET = ":cpuset";
    private static final java.lang.String CGROUP_CPUSET_BG = "background";
    private static final java.lang.String CPUCTL_LIMIT_PROC_PATH = "/dev/cpuctl/limit/cgroup.procs";
    private static final java.lang.String CPUCTL_PROC_PATH = "/dev/cpuctl/cgroup.procs";
    private static final java.lang.String CPUSET_FG_PROC_PATH = "/dev/cpuset/foreground/cgroup.procs";
    private static final java.lang.String CPUSET_TA_PROC_PATH = "/dev/cpuset/top-app/cgroup.procs";
    private static final int CPU_FG_LOAD_LIMIT_DEFAULT = 60;
    private static final int CPU_FG_LOAD_THRESHOLD_DEFAULT = 80;
    private static final int CPU_HIGHLOAD_POLLING_INTERVAL_DEFAULT = 1000;
    private static final int CPU_LOAD_LOW_THRESHOLD_DEFAULT = 60;
    private static final int CPU_LOAD_THRESHOLD_MAX = 100;
    private static final int CPU_LOAD_THRESHOLD_MIN = 20;
    private static final int CPU_POLLING_INTERVAL_MAX_VALUE = 5000;
    private static final int CPU_POLLING_INTERVAL_MIN_VALUE = 100;
    private static final java.lang.String CPU_STAT_PATH = "/proc/stat";
    private static final int CPU_TA_LOAD_REGULAR_THRESHOLD_DEFAULT = 75;
    private static final int CPU_TA_LOAD_THRESHOLD_DEFAULT = 90;
    private static final long INVALID_VALUE = -1;
    private static final java.lang.String ITEM_CPU_FG_LOAD_LIMIT = "cpu_fg_load_limit";
    private static final java.lang.String ITEM_CPU_FG_LOAD_THRESHOLD = "cpu_fg_load_threshold";
    private static final java.lang.String ITEM_CPU_HIGHLOAD_POLLING_INTERVAL = "cpu_highload_polling_interval";
    private static final java.lang.String ITEM_CPU_LOAD_LOW_THRESHOLD = "cpu_load_low_threshold";
    private static final java.lang.String ITEM_CPU_TA_LOAD_THRESHOLD = "cpu_ta_load_threshold";
    private static final int LOAD_DETCTOR_DELAY = 10000;
    private static final int LOAD_STATUS_DETECTOR = 4;
    private static final int LOAD_STATUS_HIGH = 2;
    private static final int LOAD_STATUS_IDLE = 3;
    private static final int LOAD_STATUS_LOW = 1;
    private static final int MSG_LOAD_DETCTOR = 1;
    private static final java.lang.String PATH_COMM = "/comm";
    private static final java.lang.String PATH_STAT = "/stat";
    private static final java.lang.String PTAH_CGROUP = "/cgroup";
    private static final java.lang.String PTAH_PROC_INFO = "/proc/";
    private static final java.lang.String SYSTEMUI_NAME = "com.android.systemui";
    private static final java.lang.String TAG = "CPUHighFgControl";
    private static final java.lang.String UID_PTAH = "uid_";
    private static com.android.server.rms.iaware.cpu.CPUHighFgControl sInstance;
    private com.android.server.rms.iaware.cpu.CPUFeature mCPUFeatureInstance;
    private com.android.server.rms.iaware.cpu.CPUZRHungLog mCPUZRHung;
    private int mCpuFgLoadLimit = 60;
    private int mCpuFgLoadThreshold = 80;
    private int mCpuLoadLowThreshold = 60;
    private int mCpuTaLoadThreshold = 90;
    private volatile boolean mIsStart = false;
    private com.android.server.rms.iaware.cpu.CPUHighFgControl.CpuLoadDetectorHandler mLoadDetectorHandler;
    private java.lang.Thread mLoadDetectorThread;
    private int mLoadStatus = 3;
    private java.lang.Object mLock = new java.lang.Object();
    private int mPollingInterval = 1000;
    private com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadComparator mProcLoadComparator;
    private com.android.server.rms.iaware.cpu.CPUHighFgControl.TALoadDetectorThread mTaLoadDetectorThread;

    private class CpuLoadDetectorHandler extends android.os.Handler {
        private CpuLoadDetectorHandler() {
        }

        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            int what = msg.what;
            if (what != 1) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("CpuLoadDetectorHandler msg = ");
                stringBuilder.append(what);
                stringBuilder.append(" not support!");
                android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                return;
            }
            com.android.server.rms.iaware.cpu.CPUHighFgControl.this.notifyLoadChange(4);
        }
    }

    private static class ProcLoadComparator implements java.util.Comparator<com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair>, java.io.Serializable {
        private static final long serialVersionUID = 1;

        private ProcLoadComparator() {
        }

        public int compare(com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair lhs, com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair rhs) {
            return java.lang.Integer.compare(rhs.load, lhs.load);
        }
    }

    private static class ProcLoadPair {
        public int load;
        public int pid;

        public ProcLoadPair(int pid, int load) {
            this.pid = pid;
            this.load = load;
        }
    }

    private static class ProcessStatInfo {
        public long idle;
        public long iowait;
        public long irq;
        public long nice;
        public long softIrq;
        public long system;
        public long userTime;

        private ProcessStatInfo() {
        }

        public long getWallTime() {
            return (((((this.userTime + this.nice) + this.system) + this.idle) + this.iowait) + this.irq) + this.softIrq;
        }

        public long getRunningTime() {
            return (this.userTime + this.nice) + this.system;
        }
    }

    private class TALoadDetectorThread implements java.lang.Runnable {
        private TALoadDetectorThread() {
        }

        public void run() {
            java.lang.Thread.currentThread().setPriority(10);
            while (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mIsStart) {
                synchronized (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLock) {
                    while (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus == 3) {
                        try {
                            com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLock.wait();
                        } catch (java.lang.InterruptedException e) {
                            android.rms.iaware.AwareLog.e("CPUHighFgControl", "TALoadDetectorThread InterruptedException return");
                        }
                    }
                    if (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus == 4) {
                        android.rms.iaware.AwareLog.d("CPUHighFgControl", "DetectorThread run for load detector!");
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.startLoadDetector();
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus = 3;
                    } else if (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus == 2) {
                        android.rms.iaware.AwareLog.d("CPUHighFgControl", "DetectorThread run for high load!");
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.setHighLoadPid();
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus = 3;
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.rotateStatus(2);
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.sendMessageForLoadDetector();
                    } else if (com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus == 1) {
                        android.rms.iaware.AwareLog.d("CPUHighFgControl", "DetectorThread run for low load!");
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.setLowLoad();
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.mLoadStatus = 3;
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.rotateStatus(1);
                        com.android.server.rms.iaware.cpu.CPUHighFgControl.this.sendMessageForLoadDetector();
                    }
                }
            }
        }
    }

    private CPUHighFgControl() {
        initXml();
        this.mCPUZRHung = new com.android.server.rms.iaware.cpu.CPUZRHungLog();
        this.mProcLoadComparator = new com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadComparator();
        this.mLoadDetectorHandler = new com.android.server.rms.iaware.cpu.CPUHighFgControl.CpuLoadDetectorHandler();
    }

    public static synchronized com.android.server.rms.iaware.cpu.CPUHighFgControl getInstance() {
        com.android.server.rms.iaware.cpu.CPUHighFgControl cPUHighFgControl;
        synchronized (com.android.server.rms.iaware.cpu.CPUHighFgControl.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.CPUHighFgControl();
            }
            cPUHighFgControl = sInstance;
        }
        return cPUHighFgControl;
    }

    private boolean isValidValue(java.lang.Integer value, int min, int max) {
        if (value == null || value.intValue() <= min || value.intValue() >= max) {
            return false;
        }
        return true;
    }

    private void initXml() {
        java.util.Map<java.lang.String, java.lang.Integer> cpuCtlFGValueMap = new com.android.server.rms.iaware.cpu.CpuCtlLimitConfig().getCpuCtlFGValueMap();
        if (!cpuCtlFGValueMap.isEmpty()) {
            java.lang.Integer value = (java.lang.Integer) cpuCtlFGValueMap.get("cpu_highload_polling_interval");
            if (isValidValue(value, 100, 5000)) {
                this.mPollingInterval = value.intValue();
            }
            value = (java.lang.Integer) cpuCtlFGValueMap.get("cpu_ta_load_threshold");
            if (isValidValue(value, 20, 100)) {
                this.mCpuTaLoadThreshold = value.intValue();
            }
            value = (java.lang.Integer) cpuCtlFGValueMap.get("cpu_fg_load_threshold");
            if (isValidValue(value, 20, 100)) {
                this.mCpuFgLoadThreshold = value.intValue();
            }
            value = (java.lang.Integer) cpuCtlFGValueMap.get("cpu_fg_load_limit");
            if (isValidValue(value, 20, 100)) {
                this.mCpuFgLoadLimit = value.intValue();
            }
            value = (java.lang.Integer) cpuCtlFGValueMap.get("cpu_load_low_threshold");
            if (isValidValue(value, 20, 100)) {
                this.mCpuLoadLowThreshold = value.intValue();
            }
        }
    }

    public void start(com.android.server.rms.iaware.cpu.CPUFeature feature) {
        this.mCPUFeatureInstance = feature;
        if (this.mTaLoadDetectorThread == null) {
            this.mTaLoadDetectorThread = new com.android.server.rms.iaware.cpu.CPUHighFgControl.TALoadDetectorThread();
        }
        if (this.mLoadDetectorThread == null || !this.mLoadDetectorThread.isAlive()) {
            this.mLoadDetectorThread = new java.lang.Thread(this.mTaLoadDetectorThread, "taLoadDetectorThread");
        }
        this.mIsStart = true;
        this.mLoadDetectorThread.start();
    }

    public void stop() {
        this.mLoadDetectorHandler.removeMessages(1);
        if (this.mLoadDetectorThread != null && this.mLoadDetectorThread.isAlive()) {
            this.mIsStart = false;
            this.mLoadDetectorThread.interrupt();
        }
        this.mLoadDetectorThread = null;
    }

    public void notifyLoadChange(int cpuLoadStatus) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("notifyLoadChange cpuLoadStatus ");
        stringBuilder.append(cpuLoadStatus);
        android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
        synchronized (this.mLock) {
            this.mLoadStatus = cpuLoadStatus;
            this.mLock.notifyAll();
        }
    }

    private int taLoadCompute() {
        long totalCpuTimeLocal = getCpuLoad();
        int pid = getFileContent("/dev/cpuset/top-app/cgroup.procs");
        if (pid == -1) {
            return 0;
        }
        long processCpuTimeLocal = getProcessLoad(pid);
        if (totalCpuTimeLocal != -1) {
            if (processCpuTimeLocal != -1) {
                try {
                    java.lang.Thread.sleep((long) this.mPollingInterval);
                } catch (java.lang.InterruptedException e) {
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", "taLoadCompute InterruptedException");
                }
                int tempPid = getFileContent("/dev/cpuset/top-app/cgroup.procs");
                if (pid != tempPid) {
                    return 0;
                }
                long nextProcessLoad = getProcessLoad(pid);
                long nextCpuLoad = getCpuLoad();
                if (nextCpuLoad == -1) {
                } else if (nextProcessLoad == -1) {
                    int i = tempPid;
                } else {
                    long totalDeltaCpuTime = nextCpuLoad - totalCpuTimeLocal;
                    long totalDeltaProcessTime = nextProcessLoad - processCpuTimeLocal;
                    if (totalDeltaCpuTime == 0) {
                        return 0;
                    }
                    return (int) ((100 * totalDeltaProcessTime) / totalDeltaCpuTime);
                }
                return 0;
            }
        }
        return 0;
    }

    private int computeFgProcLoad(java.util.List<com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair> fgProcLoadArray) {
        if (fgProcLoadArray == null) {
            return 0;
        }
        long totalCpuTime = getCpuLoad();
        if (-1 == totalCpuTime) {
            return 0;
        }
        android.util.SparseArray<java.lang.Long> pidLoadList = new android.util.SparseArray();
        getFgCpuloadPidArray(pidLoadList);
        try {
            java.lang.Thread.sleep((long) this.mPollingInterval);
        } catch (java.lang.InterruptedException e) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "computeFgProcLoad InterruptedException");
        }
        android.util.SparseArray<java.lang.Long> nextPidLoadList = new android.util.SparseArray();
        getFgCpuloadPidArray(nextPidLoadList);
        long nextTotalCpuTime = getCpuLoad();
        if (-1 == nextTotalCpuTime) {
            return 0;
        }
        long totalCpuRuntime = nextTotalCpuTime - totalCpuTime;
        if (totalCpuRuntime == 0) {
            return 0;
        }
        return computeProcsLoad(pidLoadList, nextPidLoadList, totalCpuRuntime, fgProcLoadArray);
    }

    private int computeProcsLoad(android.util.SparseArray<java.lang.Long> prevArray, android.util.SparseArray<java.lang.Long> currArray, long totalTime, java.util.List<com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair> fgProcLoadArray) {
        int i = 0;
        if (!(prevArray == null || currArray == null || totalTime == 0)) {
            if (fgProcLoadArray != null) {
                int totalLoad = 0;
                int currArraySize = currArray.size();
                while (i < currArraySize) {
                    int procPid = currArray.keyAt(i);
                    if (prevArray.indexOfKey(procPid) >= 0) {
                        int procLoad = (int) ((100 * (((java.lang.Long) currArray.get(procPid)).longValue() - ((java.lang.Long) prevArray.get(procPid)).longValue())) / totalTime);
                        if (procLoad == 0) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("pid ");
                            stringBuilder.append(procPid);
                            stringBuilder.append(" cpuload is 0 ");
                            android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
                        } else {
                            fgProcLoadArray.add(new com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair(procPid, procLoad));
                            totalLoad += procLoad;
                        }
                    }
                    i++;
                }
                if (!fgProcLoadArray.isEmpty()) {
                    java.util.Collections.sort(fgProcLoadArray, this.mProcLoadComparator);
                }
                return totalLoad;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "computeProcsLoad invalid params");
        return 0;
    }

    private void getFgProcsloadPidArray(java.lang.String filePath, android.util.SparseArray<java.lang.Long> pidList) {
        java.util.List<java.lang.String> procsList = getProcsList(filePath);
        if (procsList != null) {
            int size = procsList.size();
            for (int i = 0; i < size; i++) {
                int pid = parseInt((java.lang.String) procsList.get(i));
                if (pid >= 0 && isFgProc(pid)) {
                    if (isLimitProc(pid)) {
                        long tempLoad = getProcessLoad(pid);
                        if (-1 != tempLoad) {
                            pidList.put(pid, java.lang.Long.valueOf(tempLoad));
                        }
                    }
                }
            }
        }
    }

    private java.util.List<java.lang.String> getProcsList(java.lang.String filePath) {
        java.io.File file = new java.io.File(filePath);
        if (file.exists()) {
            if (file.canRead()) {
                java.lang.String groupProcs = null;
                int i = 0;
                try {
                    groupProcs = android.os.FileUtils.readTextFile(file, 0, null);
                } catch (java.io.IOException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("IOException + ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                }
                if (groupProcs != null) {
                    if (groupProcs.length() != 0) {
                        java.lang.String[] procs = groupProcs.split("\n");
                        java.util.List<java.lang.String> procsList = new java.util.ArrayList();
                        int length = procs.length;
                        while (i < length) {
                            java.lang.String strProc = procs[i].trim();
                            if (strProc.length() != 0) {
                                procsList.add(strProc);
                            }
                            i++;
                        }
                        return procsList;
                    }
                }
                return null;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getProcsList file not exists or canot read!");
        return null;
    }

    private void getLimitFgProcsLoadArray(java.lang.String filePath, android.util.SparseArray<java.lang.Long> pidList) {
        java.util.List<java.lang.String> procsList = getProcsList(filePath);
        if (procsList != null) {
            int size = procsList.size();
            for (int i = 0; i < size; i++) {
                int pid = parseInt((java.lang.String) procsList.get(i));
                if (pid >= 0) {
                    long tempLoad = getProcessLoad(pid);
                    if (-1 != tempLoad) {
                        pidList.put(pid, java.lang.Long.valueOf(tempLoad));
                    }
                }
            }
        }
    }

    private void getFgCpuloadPidArray(android.util.SparseArray<java.lang.Long> pidList) {
        getFgProcsloadPidArray("/dev/cpuset/foreground/cgroup.procs", pidList);
    }

    private void getLimitFgCpuloadPidArray(android.util.SparseArray<java.lang.Long> pidList) {
        getLimitFgProcsLoadArray("/dev/cpuctl/limit/cgroup.procs", pidList);
    }

    private int computeLoad(long deltaTotaltime, long deltaRuntime) {
        if (deltaTotaltime != 0) {
            return (int) ((100 * deltaRuntime) / deltaTotaltime);
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "computeLoad deltaTotaltime is zero!");
        return -1;
    }

    private void startLoadDetector() {
        com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo prevCpuStatInfo = getCpuStatInfo();
        if (prevCpuStatInfo == null) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "startLoadDetector prevStatInfo is null!");
            return;
        }
        android.util.SparseArray<java.lang.Long> prevLimFgArray = new android.util.SparseArray();
        getLimitFgCpuloadPidArray(prevLimFgArray);
        try {
            java.lang.Thread.sleep((long) (3 * this.mPollingInterval));
        } catch (java.lang.InterruptedException e) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "startLoadDetector InterruptedException");
        }
        android.util.SparseArray<java.lang.Long> currLimFgArray = new android.util.SparseArray();
        getLimitFgCpuloadPidArray(currLimFgArray);
        com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo currCpuStatInfo = getCpuStatInfo();
        if (currCpuStatInfo == null) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "startLoadDetector currStatInfo is null!");
            return;
        }
        long deltaTotalCpuRuntime = currCpuStatInfo.getWallTime() - prevCpuStatInfo.getWallTime();
        int cpuLoad = computeLoad(deltaTotalCpuRuntime, currCpuStatInfo.getRunningTime() - prevCpuStatInfo.getRunningTime());
        if (cpuLoad == -1) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "startLoadDetector computeLoad maybe error!");
            return;
        }
        loadDetectorPolicy(cpuLoad, deltaTotalCpuRuntime, prevLimFgArray, currLimFgArray);
        if (cpuLoad >= this.mCpuTaLoadThreshold) {
            loadZRHungPolicy();
        }
    }

    private boolean isLimitGroupHasPid() {
        java.util.List<java.lang.String> limitPidList = getProcsList("/dev/cpuctl/limit/cgroup.procs");
        if (limitPidList == null || limitPidList.size() <= 0) {
            return false;
        }
        return true;
    }

    private void loadDetectorPolicy(int cpuLoad, long cpuTotalTime, android.util.SparseArray<java.lang.Long> prevArray, android.util.SparseArray<java.lang.Long> currArray) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loadDetectorPolicy cpu_total_Load = ");
        stringBuilder.append(cpuLoad);
        android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
        if (cpuLoad >= this.mCpuTaLoadThreshold) {
            int totalLimitFgLoad = computeProcsLoad(prevArray, currArray, cpuTotalTime, new java.util.ArrayList());
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("loadDetectorPolicy limit totalLoad = ");
            stringBuilder2.append(totalLimitFgLoad);
            android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder2.toString());
            if (totalLimitFgLoad >= this.mCpuTaLoadThreshold) {
                android.rms.iaware.AwareLog.d("CPUHighFgControl", "loadDetectorPolicy limit + ta load high, and a new high load process may be add in the system, so continue detector!");
            } else {
                android.rms.iaware.AwareLog.d("CPUHighFgControl", "limit low, need to find another high load pid to control");
                setHighLoadPid();
            }
        } else if (cpuLoad <= this.mCpuLoadLowThreshold) {
            android.rms.iaware.AwareLog.d("CPUHighFgControl", "loadDetectorPolicy setLowLoad");
            setLowLoad();
        }
        if (isLimitGroupHasPid()) {
            android.rms.iaware.AwareLog.d("CPUHighFgControl", "loadDetectorPolicy limit group has pid, so continue detector!");
            sendMessageForLoadDetector();
        }
    }

    private void loadZRHungPolicy() {
        this.mCPUZRHung.loadPolicy();
    }

    private void rotateStatus(int loadStatus) {
        this.mCPUZRHung.rotateStatus(loadStatus);
    }

    private void chgProcessGroup(int pid, java.lang.String groupPath) {
        if (pid > 0) {
            setGroup(pid, groupPath);
        }
    }

    private void chgProcessGroup(java.util.List<com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair> procLoadArray, java.lang.String groupPath) {
        if (procLoadArray != null) {
            int currLoad = 0;
            int size = procLoadArray.size();
            for (int i = 0; i < size; i++) {
                com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair pair = (com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair) procLoadArray.get(i);
                if (pair != null) {
                    if (currLoad >= this.mCpuFgLoadLimit) {
                        break;
                    }
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("chgProcessGroup list pid = ");
                    stringBuilder.append(pair.pid);
                    stringBuilder.append(" load = ");
                    stringBuilder.append(pair.load);
                    android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
                    currLoad += pair.load;
                    chgProcessGroup(pair.pid, groupPath);
                }
            }
        }
    }

    private int getFileContent(java.lang.String filePath) {
        java.lang.StringBuilder stringBuilder;
        if (filePath == null) {
            return -1;
        }
        java.io.File file = new java.io.File(filePath);
        if (file.exists()) {
            if (file.canRead()) {
                int pid = 0;
                java.io.FileInputStream input = null;
                java.io.InputStreamReader inputStreamReader = null;
                java.io.BufferedReader bufReader = null;
                try {
                    input = new java.io.FileInputStream(filePath);
                    inputStreamReader = new java.io.InputStreamReader(input, "UTF-8");
                    bufReader = new java.io.BufferedReader(inputStreamReader);
                    while (true) {
                        java.lang.String readLine = bufReader.readLine();
                        java.lang.String content = readLine;
                        if (readLine == null) {
                            break;
                        }
                        pid = java.lang.Integer.parseInt(content.trim());
                        if (isFgProc(pid)) {
                            break;
                        }
                        pid = 0;
                    }
                } catch (java.lang.NumberFormatException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("NumberFormatException ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                } catch (java.io.FileNotFoundException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("exception file not found, file path: ");
                    stringBuilder.append(filePath);
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                } catch (java.io.UnsupportedEncodingException e3) {
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", "UnsupportedEncodingException ");
                } catch (java.io.IOException e4) {
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", "IOException");
                } catch (Throwable th) {
                    com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(null);
                }
                com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(bufReader);
                com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(inputStreamReader);
                com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(input);
                return pid;
            }
        }
        return -1;
    }

    private void setHighLoadPid() {
        int taLoad = taLoadCompute();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setHighLoadPid taLoadCompute = ");
        stringBuilder.append(taLoad);
        android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
        setHightLoad(taLoad);
    }

    private void setHightLoad(int taLoad) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setHighLoad taLoad is ");
        stringBuilder.append(taLoad);
        android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder.toString());
        if (taLoad >= this.mCpuTaLoadThreshold) {
            chgProcessGroup(getFileContent("/dev/cpuset/top-app/cgroup.procs"), "/dev/cpuctl/limit/cgroup.procs");
            return;
        }
        java.util.List procLoadArray = new java.util.ArrayList();
        int totalProcLoad = computeFgProcLoad(procLoadArray);
        int procLoadArraySize = procLoadArray.size();
        for (int i = 0; i < procLoadArraySize; i++) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("fg the i= ");
            stringBuilder2.append(i);
            stringBuilder2.append(" load is ");
            stringBuilder2.append(((com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair) procLoadArray.get(i)).load);
            stringBuilder2.append(" pid is ");
            stringBuilder2.append(((com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcLoadPair) procLoadArray.get(i)).pid);
            android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder2.toString());
        }
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("setHighLoadPid computeFgProcLoad = ");
        stringBuilder3.append(totalProcLoad);
        android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder3.toString());
        if (totalProcLoad < this.mCpuFgLoadThreshold) {
            if (taLoad + totalProcLoad < this.mCpuTaLoadThreshold) {
                if (taLoad >= 75) {
                    chgProcessGroup(getFileContent("/dev/cpuset/top-app/cgroup.procs"), "/dev/cpuctl/limit/cgroup.procs");
                }
                return;
            }
        }
        chgProcessGroup(procLoadArray, "/dev/cpuctl/limit/cgroup.procs");
    }

    private void setLowLoad() {
        java.io.File file = new java.io.File("/dev/cpuctl/limit/cgroup.procs");
        if (file.exists()) {
            if (file.canRead()) {
                java.lang.String groupProcs = null;
                int i = 0;
                try {
                    groupProcs = android.os.FileUtils.readTextFile(file, 0, null);
                } catch (java.io.IOException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("IOException + ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                }
                if (groupProcs != null) {
                    if (groupProcs.length() != 0) {
                        java.lang.String[] procs = groupProcs.split("\n");
                        int length = procs.length;
                        while (i < length) {
                            java.lang.String strProc = procs[i].trim();
                            if (strProc.length() != 0) {
                                int pid = parseInt(strProc);
                                if (pid != -1) {
                                    setGroup(pid, "/dev/cpuctl/cgroup.procs");
                                }
                            }
                            i++;
                        }
                        return;
                    }
                }
                android.rms.iaware.AwareLog.d("CPUHighFgControl", "setLowLoad readTextFile null procs!");
                return;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "setLowLoad file not exists or canot read!");
    }

    private void setGroup(int pid, java.lang.String file) {
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
        if ("/dev/cpuctl/limit/cgroup.procs".equals(file)) {
            buffer.putInt(137);
        } else if ("/dev/cpuctl/cgroup.procs".equals(file)) {
            buffer.putInt(139);
        } else {
            return;
        }
        buffer.putInt(pid);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setGroup pid = ");
        stringBuilder.append(pid);
        stringBuilder.append(" processgroup = ");
        stringBuilder.append(file);
        android.rms.iaware.AwareLog.i("CPUHighFgControl", stringBuilder.toString());
        if (this.mCPUFeatureInstance != null) {
            this.mCPUFeatureInstance.sendPacket(buffer);
        }
    }

    private boolean isLimitProc(int pid) {
        java.lang.StringBuilder path = new java.lang.StringBuilder();
        path.append("/proc/");
        path.append(pid);
        path.append("/comm");
        java.io.File file = new java.io.File(path.toString());
        if (file.exists()) {
            if (file.canRead()) {
                java.lang.String procname = null;
                try {
                    procname = android.os.FileUtils.readTextFile(file, 0, null);
                } catch (java.io.IOException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("isLimitProc IOException + ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                }
                if (procname == null) {
                    return false;
                }
                java.lang.String procname2 = procname.trim();
                if (!"com.android.systemui".contains(procname2)) {
                    return true;
                }
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("procname:");
                stringBuilder2.append(procname2);
                stringBuilder2.append("is limit");
                android.rms.iaware.AwareLog.d("CPUHighFgControl", stringBuilder2.toString());
                return false;
            }
        }
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("isLimitProc file not exists or canot read!");
        stringBuilder3.append(path.toString());
        android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder3.toString());
        return false;
    }

    private boolean isFgProc(int pid) {
        java.lang.StringBuilder targetPath = new java.lang.StringBuilder();
        targetPath.append("/proc/");
        targetPath.append(pid);
        targetPath.append("/cgroup");
        return isFgThirdPartProc(targetPath.toString());
    }

    private boolean isThirdPartyUid(java.lang.String line) {
        if (line != null) {
            if (line.contains(":cpuacct")) {
                boolean flag = false;
                int indexOf = line.indexOf("uid_");
                int index = indexOf;
                if (indexOf != -1) {
                    indexOf = line.indexOf(47, index);
                    java.lang.String strUid = null;
                    if (indexOf != -1) {
                        strUid = line.substring("uid_".length() + index, indexOf);
                    }
                    if (android.os.UserHandle.getAppId(parseInt(strUid)) > 10000) {
                        flag = true;
                    }
                }
                return flag;
            }
        }
        return false;
    }

    private boolean isFgThirdPartProc(java.lang.String path) {
        java.lang.StringBuilder stringBuilder;
        java.io.FileInputStream fis = null;
        java.io.InputStreamReader isr = null;
        java.io.BufferedReader br = null;
        try {
            fis = new java.io.FileInputStream(path);
            isr = new java.io.InputStreamReader(fis, "UTF-8");
            br = new java.io.BufferedReader(isr);
            java.lang.String line = "";
            boolean flag = false;
            while (true) {
                java.lang.String readLine = br.readLine();
                line = readLine;
                if (readLine == null) {
                    break;
                }
                if (line.contains(":cpuset")) {
                    if (line.contains("background")) {
                        com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
                        com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
                        com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
                        return false;
                    }
                    flag = true;
                }
                if (flag) {
                    if (isThirdPartyUid(line)) {
                        com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
                        com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
                        com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
                        return true;
                    }
                }
            }
        } catch (java.lang.NumberFormatException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("NumberFormatException ");
            stringBuilder.append(e.getMessage());
            android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
        } catch (java.io.FileNotFoundException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("FileNotFoundException ");
            stringBuilder.append(e2.getMessage());
            android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
        } catch (java.io.UnsupportedEncodingException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("UnsupportedEncodingException ");
            stringBuilder.append(e3.getMessage());
            android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
        } catch (java.io.IOException e4) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("IOException ");
            stringBuilder.append(e4.getMessage());
            android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
        } catch (Throwable th) {
            com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
            com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
            com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
        }
        com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
        com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
        com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
        return false;
    }

    private long getCpuLoad() {
        java.lang.String strContent = getContentWithOneLine("/proc/stat", "cpu ");
        if (strContent == null) {
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "getCpuLoad null content!");
            return -1;
        }
        com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo info = getCpuStatInfo(strContent);
        if (info == null) {
            return -1;
        }
        return info.getWallTime();
    }

    private com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo getCpuStatInfo() {
        java.lang.String strContent = getContentWithOneLine("/proc/stat", "cpu ");
        if (strContent != null) {
            return getCpuStatInfo(strContent);
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getProcessLoad null content!");
        return null;
    }

    private java.util.List<java.lang.String> getProcStatInfo(java.lang.String content) {
        if (content != null) {
            if (content.length() != 0) {
                java.lang.String[] conts = content.split(" ");
                java.util.List<java.lang.String> listTemp = new java.util.ArrayList();
                for (java.lang.String str : conts) {
                    if (!"".equals(str)) {
                        listTemp.add(str);
                    }
                }
                return listTemp;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getWallTime null content!");
        return null;
    }

    private com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo getCpuStatInfo(java.lang.String content) {
        com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo processStatInfo;
        java.util.List<java.lang.String> listTemp = getProcStatInfo(content);
        java.util.List<java.lang.String> list;
        if (listTemp == null) {
            processStatInfo = null;
        } else if (listTemp.size() < 10) {
            list = listTemp;
            processStatInfo = null;
        } else {
            java.lang.String strUserTime = (java.lang.String) listTemp.get(1);
            java.lang.String strNice = (java.lang.String) listTemp.get(2);
            java.lang.String strSystem = (java.lang.String) listTemp.get(3);
            java.lang.String strIdle = (java.lang.String) listTemp.get(4);
            java.lang.String strIoWait = (java.lang.String) listTemp.get(5);
            java.lang.String strIrq = (java.lang.String) listTemp.get(6);
            java.lang.String strSoftIrq = (java.lang.String) listTemp.get(7);
            long userTime = parseLong(strUserTime);
            long nice = parseLong(strNice);
            long system = parseLong(strSystem);
            long idle = parseLong(strIdle);
            long iowait = parseLong(strIoWait);
            long irq = parseLong(strIrq);
            long softIrq = parseLong(strSoftIrq);
            long j;
            if (userTime == -1 || nice == -1 || system == -1 || idle == -1 || iowait == -1 || irq == -1) {
                j = idle;
                listTemp = irq;
            } else if (softIrq == -1) {
                list = listTemp;
                j = idle;
                listTemp = irq;
            } else {
                processStatInfo = new com.android.server.rms.iaware.cpu.CPUHighFgControl.ProcessStatInfo();
                processStatInfo.idle = idle;
                processStatInfo.iowait = iowait;
                processStatInfo.irq = irq;
                processStatInfo.nice = nice;
                processStatInfo.softIrq = softIrq;
                processStatInfo.system = system;
                processStatInfo.userTime = userTime;
                return processStatInfo;
            }
            android.rms.iaware.AwareLog.e("CPUHighFgControl", "getWallTime inalid value!");
            return null;
        }
        return processStatInfo;
    }

    private long parseLong(java.lang.String str) {
        long value = -1;
        if (str != null) {
            if (str.length() != 0) {
                try {
                    value = java.lang.Long.parseLong(str);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("parseLong NumberFormatException e = ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                }
                return value;
            }
        }
        return -1;
    }

    private int parseInt(java.lang.String str) {
        int value = -1;
        if (str != null) {
            if (str.length() != 0) {
                try {
                    value = java.lang.Integer.parseInt(str);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("parseInt NumberFormatException e = ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                }
                return value;
            }
        }
        return -1;
    }

    private long getProcessLoad(int pid) {
        java.lang.StringBuilder targetPath = new java.lang.StringBuilder();
        targetPath.append("/proc/");
        targetPath.append(pid);
        targetPath.append("/stat");
        java.lang.String content = getContentWithOneLine(targetPath.toString(), java.lang.String.valueOf(pid));
        if (content != null) {
            return getPorcseeTime(content);
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getProcessLoad null content!");
        return -1;
    }

    private long getPorcseeTime(java.lang.String content) {
        java.lang.String[] conts = content.split(" ");
        if (conts.length < 15) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getIdleTime content inalid = ");
            stringBuilder.append(content);
            android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
            return -1;
        }
        java.lang.String strUTime = conts[13];
        java.lang.String strSTime = conts[14];
        long utime = parseLong(strUTime);
        long stime = parseLong(strSTime);
        if (utime != -1) {
            if (stime != -1) {
                return utime + stime;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getPorcseeTime inalid value!");
        return -1;
    }

    private java.lang.String getContentWithOneLine(java.lang.String filePath, java.lang.String keyword) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String line = null;
        if (filePath == null) {
            return null;
        }
        java.io.File file = new java.io.File(filePath);
        if (file.exists()) {
            if (file.canRead()) {
                java.io.FileInputStream fis = null;
                java.io.InputStreamReader isr = null;
                java.io.BufferedReader br = null;
                try {
                    fis = new java.io.FileInputStream(filePath);
                    isr = new java.io.InputStreamReader(fis, "UTF-8");
                    br = new java.io.BufferedReader(isr);
                    do {
                        java.lang.String readLine = br.readLine();
                        line = readLine;
                        if (readLine == null || keyword == null) {
                            break;
                        }
                    } while (!line.contains(keyword));
                } catch (java.io.FileNotFoundException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("FileNotFoundException ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                } catch (java.io.UnsupportedEncodingException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("UnsupportedEncodingException ");
                    stringBuilder.append(e2.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                } catch (java.io.IOException e3) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("IOException ");
                    stringBuilder.append(e3.getMessage());
                    android.rms.iaware.AwareLog.e("CPUHighFgControl", stringBuilder.toString());
                } catch (Throwable th) {
                    com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(null);
                }
                com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
                com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
                com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
                return line;
            }
        }
        android.rms.iaware.AwareLog.e("CPUHighFgControl", "getContentWithOneLine file not exists or canot read!");
        return null;
    }

    private void sendMessageForLoadDetector() {
        this.mLoadDetectorHandler.removeMessages(1);
        this.mLoadDetectorHandler.sendEmptyMessageDelayed(1, 10000);
    }
}
