package com.android.server.rms.iaware.cpu;

public class CPUNetLink {
    private static final int BUFF_SIZE = 8192;
    private static final int CPU_HIGH_LOAD_MSG = 1;
    private static final int MAX_LENGTH = 1024;
    private static final int PROC_COMM_MSG = 3;
    private static final int PROC_FORK_MSG = 2;
    private static final int SOCKET_PORT = 33;
    private static final java.lang.String TAG = "CPUNetLink";
    private static final long TIMEOUT = 0;
    private static java.io.FileDescriptor mFileDescriptor;
    private volatile boolean mIsStart;
    private android.net.netlink.NetlinkSocket mLocalNetlinkSocket = null;
    private com.android.server.rms.iaware.cpu.CPUNetLink.ReceiveKernelThread mReceviveKernelThread;
    private java.lang.Thread mThread;

    class ReceiveKernelThread implements java.lang.Runnable {
        ReceiveKernelThread() {
        }

        public void run() {
            java.lang.Thread.currentThread().setPriority(10);
            while (com.android.server.rms.iaware.cpu.CPUNetLink.this.mIsStart) {
                try {
                    com.android.server.rms.iaware.cpu.CPUNetLink.this.mLocalNetlinkSocket;
                    java.nio.ByteBuffer response = android.net.netlink.NetlinkSocket.recvMessage(com.android.server.rms.iaware.cpu.CPUNetLink.mFileDescriptor, 8192, 0);
                    if (response != null) {
                        if (android.net.netlink.StructNlMsgHdr.hasAvailableSpace(response)) {
                            com.android.server.rms.iaware.cpu.CPUNetLink.this.parse(response);
                        }
                    } else {
                        return;
                    }
                } catch (android.system.ErrnoException e) {
                    android.rms.iaware.AwareLog.e("CPUNetLink", "ReceiveKernelThread ErrnoException");
                    return;
                } catch (java.io.InterruptedIOException e2) {
                    android.rms.iaware.AwareLog.e("CPUNetLink", "ReceiveKernelThread InterruptedIOException");
                    return;
                } catch (java.lang.IllegalArgumentException e3) {
                    android.rms.iaware.AwareLog.e("CPUNetLink", "ReceiveKernelThread IllegalArgumentException");
                    return;
                }
            }
        }
    }

    private static class RecvData {
        java.util.List<java.lang.Integer> data;
        int len;
        int what;

        private RecvData() {
        }
    }

    private byte[] newMsgStruct(int seqNo) {
        byte[] bytes = new byte[28];
        java.nio.ByteBuffer byteBuffer = java.nio.ByteBuffer.wrap(bytes);
        byteBuffer.order(java.nio.ByteOrder.nativeOrder());
        android.net.netlink.StructNlMsgHdr nlmsghdr = new android.net.netlink.StructNlMsgHdr();
        nlmsghdr.nlmsg_len = 28;
        nlmsghdr.nlmsg_type = (short) 30;
        nlmsghdr.nlmsg_flags = (short) 769;
        nlmsghdr.nlmsg_seq = seqNo;
        nlmsghdr.nlmsg_pid = android.os.Process.myPid();
        nlmsghdr.pack(byteBuffer);
        new android.net.netlink.StructNdMsg().pack(byteBuffer);
        return bytes;
    }

    private void parse(java.nio.ByteBuffer byteBuffer) {
        if (android.net.netlink.StructNlMsgHdr.parse(byteBuffer) != null && byteBuffer.remaining() >= 8) {
            com.android.server.rms.iaware.cpu.CPUNetLink.RecvData recvData = new com.android.server.rms.iaware.cpu.CPUNetLink.RecvData();
            recvData.what = byteBuffer.getInt();
            recvData.len = byteBuffer.getInt();
            int len = recvData.len;
            if (len > 0 && len <= 1024) {
                if (byteBuffer.remaining() >= 4 * len) {
                    recvData.data = new java.util.ArrayList(len);
                    for (int i = 0; i < len; i++) {
                        recvData.data.add(java.lang.Integer.valueOf(byteBuffer.getInt()));
                    }
                    handleData(recvData);
                }
            }
        }
    }

    private void handleData(com.android.server.rms.iaware.cpu.CPUNetLink.RecvData recvData) {
        java.lang.StringBuilder stringBuilder;
        switch (recvData.what) {
            case 1:
                if (recvData.len == 1) {
                    com.android.server.rms.iaware.cpu.CPUHighFgControl.getInstance().notifyLoadChange(((java.lang.Integer) recvData.data.get(0)).intValue());
                    break;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("err data num:");
                stringBuilder.append(recvData.len);
                stringBuilder.append(" for cpu high load, expect 1");
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                return;
            case 2:
                if (recvData.len == 2) {
                    com.android.server.rms.iaware.cpu.VipCgroupControl.getInstance().notifyForkChange(((java.lang.Integer) recvData.data.get(0)).intValue(), ((java.lang.Integer) recvData.data.get(1)).intValue());
                    break;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("err data num:");
                stringBuilder.append(recvData.len);
                stringBuilder.append(" for proc fork connector, expect 2");
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                return;
            case 3:
                if (recvData.len == 2) {
                    com.android.server.rms.iaware.cpu.CpuThreadBoost.getInstance().notifyCommChange(((java.lang.Integer) recvData.data.get(0)).intValue(), ((java.lang.Integer) recvData.data.get(1)).intValue());
                    break;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("err data num:");
                stringBuilder.append(recvData.len);
                stringBuilder.append(" for proc comm connector, expect 2");
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                return;
            default:
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("error msg what = ");
                stringBuilder.append(recvData.what);
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                break;
        }
    }

    public void start() {
        java.lang.StringBuilder stringBuilder;
        if (createImpl()) {
            try {
                android.system.Os.bind(mFileDescriptor, new android.system.NetlinkSocketAddress(android.os.Process.myPid(), 0));
                try {
                    byte[] request = newMsgStruct(0);
                    android.net.netlink.NetlinkSocket netlinkSocket = this.mLocalNetlinkSocket;
                    if (android.net.netlink.NetlinkSocket.sendMessage(mFileDescriptor, request, 0, request.length, 0) == -1) {
                        destroyImpl();
                        return;
                    }
                    if (this.mReceviveKernelThread == null) {
                        this.mReceviveKernelThread = new com.android.server.rms.iaware.cpu.CPUNetLink.ReceiveKernelThread();
                    }
                    if (this.mThread == null || !this.mThread.isAlive()) {
                        this.mThread = new java.lang.Thread(this.mReceviveKernelThread, "mReceviveKernelThread");
                    }
                    this.mIsStart = true;
                    this.mThread.start();
                    return;
                } catch (android.system.ErrnoException e) {
                    destroyImpl();
                    return;
                } catch (java.io.InterruptedIOException e2) {
                    destroyImpl();
                    return;
                } catch (java.lang.IllegalArgumentException e3) {
                    destroyImpl();
                    return;
                }
            } catch (android.system.ErrnoException e4) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("start ErrnoException msg: ");
                stringBuilder.append(e4.getMessage());
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                destroyImpl();
                return;
            } catch (java.net.SocketException e5) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("start SocketException msg: ");
                stringBuilder.append(e5.getMessage());
                android.rms.iaware.AwareLog.e("CPUNetLink", stringBuilder.toString());
                destroyImpl();
                return;
            }
        }
        android.rms.iaware.AwareLog.e("CPUNetLink", "Failed to create netlink connection");
    }

    public void stop() {
        if (this.mThread != null && this.mThread.isAlive()) {
            this.mIsStart = false;
            this.mThread.interrupt();
        }
        destroyImpl();
        this.mThread = null;
    }

    private boolean createImpl() {
        if (this.mLocalNetlinkSocket != null) {
            return true;
        }
        try {
            this.mLocalNetlinkSocket = new android.net.netlink.NetlinkSocket();
            android.net.netlink.NetlinkSocket netlinkSocket = this.mLocalNetlinkSocket;
            mFileDescriptor = android.net.netlink.NetlinkSocket.forProto(33);
            return true;
        } catch (android.system.ErrnoException e) {
            android.rms.iaware.AwareLog.e("CPUNetLink", "Failed to create connection, ErrnoException");
            destroyImpl();
            return false;
        }
    }

    private void destroyImpl() {
        if (this.mLocalNetlinkSocket != null) {
            this.mLocalNetlinkSocket = null;
        }
        libcore.io.IoUtils.closeQuietly(mFileDescriptor);
    }
}
