package com.android.server.rms.iaware.cpu;

class CPUPowerMode {
    private static final java.lang.String ACTION_ENTER_SUPER_SAVE_MODE = "huawei.intent.action.HWSYSTEMMANAGER_CHANGE_POWERMODE";
    private static final java.lang.String ACTION_POWER_MODE_CHANGE = "huawei.intent.action.POWER_MODE_CHANGED_ACTION";
    private static final java.lang.String ACTION_QUIT_SUPER_SAVE_MODE = "huawei.intent.action.HWSYSTEMMANAGER_SHUTDOWN_LIMIT_POWERMODE";
    private static final int EXTRA_NONSAVE_STATE = 2;
    private static final int EXTRA_SAVE_STATE = 1;
    private static final int NON_SAVE_POWER_MODE = 1;
    private static final int SAVE_POWER_MODE = 2;
    private static final int SETTING_NONSAVE_POWER_MODE = 1;
    private static final int SETTING_SAVE_POWER_MODE = 4;
    private static final int SUPER_SAVE_POWER_MODE = 3;
    private static final java.lang.String SYSTEM_MANAGER_PERMISSION = "com.huawei.systemmanager.permission.ACCESS_INTERFACE";
    private static final java.lang.String TAG = "CPUPowerMode";
    private static java.util.concurrent.atomic.AtomicBoolean mIsFeatureEnable = new java.util.concurrent.atomic.AtomicBoolean(false);
    private static java.util.concurrent.atomic.AtomicBoolean mIsSaveMode = new java.util.concurrent.atomic.AtomicBoolean(false);
    private static java.util.concurrent.atomic.AtomicBoolean mIsSuperSaveMode = new java.util.concurrent.atomic.AtomicBoolean(false);
    private static com.android.server.rms.iaware.cpu.CPUPowerMode sInstance;
    private android.content.Context mContext;
    private int mPowerMode = 1;
    private com.android.server.rms.iaware.cpu.CPUPowerMode.PowerStateChangeReceiver mPowerStateChangeReceiver;
    private int mTempPowerMode = 1;

    private class PowerStateChangeReceiver extends android.content.BroadcastReceiver {
        private PowerStateChangeReceiver() {
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent == null) {
                android.rms.iaware.AwareLog.e("CPUPowerMode", "PowerStateChangeReceiver onReceive intent null!");
            } else if (com.android.server.rms.iaware.cpu.CPUPowerMode.mIsFeatureEnable.get()) {
                java.lang.String action = intent.getAction();
                if ("huawei.intent.action.POWER_MODE_CHANGED_ACTION".equals(action)) {
                    int powerMode = intent.getIntExtra("state", 0);
                    if (powerMode == 1) {
                        com.android.server.rms.iaware.cpu.CPUPowerMode.this.mPowerMode = 2;
                        com.android.server.rms.iaware.cpu.CPUPowerMode.mIsSaveMode.set(true);
                    } else if (powerMode == 2) {
                        com.android.server.rms.iaware.cpu.CPUPowerMode.this.mPowerMode = 1;
                        com.android.server.rms.iaware.cpu.CPUPowerMode.mIsSaveMode.set(false);
                    }
                } else if ("huawei.intent.action.HWSYSTEMMANAGER_CHANGE_POWERMODE".equals(action)) {
                    com.android.server.rms.iaware.cpu.CPUPowerMode.this.mTempPowerMode = com.android.server.rms.iaware.cpu.CPUPowerMode.this.mPowerMode;
                    com.android.server.rms.iaware.cpu.CPUPowerMode.this.mPowerMode = 3;
                    com.android.server.rms.iaware.cpu.CPUPowerMode.mIsSuperSaveMode.set(true);
                } else if ("huawei.intent.action.HWSYSTEMMANAGER_SHUTDOWN_LIMIT_POWERMODE".equals(action)) {
                    com.android.server.rms.iaware.cpu.CPUPowerMode.this.mPowerMode = com.android.server.rms.iaware.cpu.CPUPowerMode.this.mTempPowerMode;
                    com.android.server.rms.iaware.cpu.CPUPowerMode.mIsSuperSaveMode.set(false);
                }
                android.os.SystemProperties.set("persist.sys.performance", com.android.server.rms.iaware.cpu.CPUPowerMode.isPerformanceMode() ? "true" : "false");
            } else {
                android.rms.iaware.AwareLog.e("CPUPowerMode", "PowerStateChangeReceiver disable, return!");
            }
        }
    }

    public void enable(android.content.Context context) {
        if (mIsFeatureEnable.get()) {
            android.rms.iaware.AwareLog.e("CPUPowerMode", "CPUPowerMode has already enabled!");
            return;
        }
        mIsFeatureEnable.set(true);
        this.mContext = context;
        registerPowerStateReceiver();
        int powermode = android.provider.Settings.System.getInt(this.mContext.getContentResolver(), "SmartModeStatus", 1);
        if (powermode == 1) {
            this.mPowerMode = 1;
            mIsSaveMode.set(false);
        } else if (powermode == 4) {
            this.mPowerMode = 2;
            mIsSaveMode.set(true);
        }
        if (isSuperPowerSave()) {
            mIsSuperSaveMode.set(true);
        } else {
            mIsSuperSaveMode.set(false);
        }
        android.os.SystemProperties.set("persist.sys.performance", isPerformanceMode() ? "true" : "false");
    }

    public void disable() {
        if (mIsFeatureEnable.get()) {
            mIsFeatureEnable.set(false);
            unregisterPowerStateReceiver();
            return;
        }
        android.rms.iaware.AwareLog.e("CPUPowerMode", "CPUPowerMode has already disabled!");
    }

    public static synchronized com.android.server.rms.iaware.cpu.CPUPowerMode getInstance() {
        com.android.server.rms.iaware.cpu.CPUPowerMode cPUPowerMode;
        synchronized (com.android.server.rms.iaware.cpu.CPUPowerMode.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.CPUPowerMode();
            }
            cPUPowerMode = sInstance;
        }
        return cPUPowerMode;
    }

    public boolean isSuperPowerSave() {
        return "true".equals(android.os.SystemProperties.get("sys.super_power_save", "false"));
    }

    private void registerPowerStateReceiver() {
        if (this.mContext != null && this.mPowerStateChangeReceiver == null) {
            this.mPowerStateChangeReceiver = new com.android.server.rms.iaware.cpu.CPUPowerMode.PowerStateChangeReceiver();
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("huawei.intent.action.POWER_MODE_CHANGED_ACTION");
            filter.addAction("huawei.intent.action.HWSYSTEMMANAGER_CHANGE_POWERMODE");
            this.mContext.registerReceiver(this.mPowerStateChangeReceiver, filter);
            android.content.IntentFilter filterSuper = new android.content.IntentFilter();
            filterSuper.addAction("huawei.intent.action.HWSYSTEMMANAGER_SHUTDOWN_LIMIT_POWERMODE");
            this.mContext.registerReceiver(this.mPowerStateChangeReceiver, filterSuper, "com.huawei.systemmanager.permission.ACCESS_INTERFACE", null);
        }
    }

    private void unregisterPowerStateReceiver() {
        if (!(this.mContext == null || this.mPowerStateChangeReceiver == null)) {
            this.mContext.unregisterReceiver(this.mPowerStateChangeReceiver);
            this.mPowerStateChangeReceiver = null;
        }
    }

    public static boolean isPerformanceMode() {
        return (mIsSaveMode.get() || mIsSuperSaveMode.get()) ? false : true;
    }
}
