package com.android.server.rms.iaware.cpu;

public class CPUProcessInherit {
    private static final int GROUP_FOREGROUP = 1;
    private static final int INIT_PROC_PID = 1;
    private static final int MAX_TRY_FORK_TIMES = 5;
    private static final int MSG_APP_BACKGROUND = 2;
    private static final int MSG_APP_DIED = 3;
    private static final int MSG_APP_FOREGROUND = 1;
    private static final java.lang.String PATH_GROUPPROCS = "cgroup.procs";
    private static final java.lang.String PATH_UID_INFO = "/acct/uid_";
    private static final java.lang.String TAG = "CPUProcessInherit";
    private android.util.SparseArray<com.android.server.rms.iaware.cpu.InheritInfo> mForkList = new android.util.SparseArray();
    private com.android.server.rms.iaware.cpu.CPUProcessInherit.ProcessHandler mProcessHandler = new com.android.server.rms.iaware.cpu.CPUProcessInherit.ProcessHandler();
    private com.android.server.rms.iaware.cpu.CPUProcessInherit.MyIProcessObserver mProcessObserver = new com.android.server.rms.iaware.cpu.CPUProcessInherit.MyIProcessObserver();

    class MyIProcessObserver extends android.app.IProcessObserver.Stub {
        MyIProcessObserver() {
        }

        public void onForegroundActivitiesChanged(int pid, int uid, boolean foregroundActivities) {
            if (com.android.server.rms.iaware.cpu.CPUFeature.isCpusetEnable()) {
                android.os.Message observerMsg = com.android.server.rms.iaware.cpu.CPUProcessInherit.this.mProcessHandler.obtainMessage();
                observerMsg.arg1 = pid;
                observerMsg.arg2 = uid;
                if (foregroundActivities) {
                    observerMsg.what = 1;
                    com.android.server.rms.iaware.cpu.NetManager.getInstance().sendMsgToNetMng(pid, uid, 0);
                } else {
                    observerMsg.what = 2;
                    com.android.server.rms.iaware.cpu.NetManager.getInstance().sendMsgToNetMng(pid, uid, 1);
                }
                com.android.server.rms.iaware.cpu.CPUProcessInherit.this.mProcessHandler.sendMessage(observerMsg);
            }
        }

        public void onProcessDied(int pid, int uid) {
            com.android.server.rms.iaware.cpu.NetManager.getInstance().sendMsgToNetMng(pid, uid, 2, 1000);
            android.os.Message observerMsg = com.android.server.rms.iaware.cpu.CPUProcessInherit.this.mProcessHandler.obtainMessage();
            observerMsg.arg1 = pid;
            observerMsg.arg2 = uid;
            observerMsg.what = 3;
            com.android.server.rms.iaware.cpu.CPUProcessInherit.this.mProcessHandler.sendMessage(observerMsg);
        }
    }

    private class ProcessHandler extends android.os.Handler {
        private ProcessHandler() {
        }

        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            int pid = msg.arg1;
            int uid = msg.arg2;
            switch (msg.what) {
                case 1:
                    com.android.server.rms.iaware.cpu.CPUProcessInherit.this.handleProcessFork(pid, uid, true);
                    com.android.server.rms.iaware.cpu.SchedLevelBoost.getInstance().onFgActivitiesChanged(pid, uid, true);
                    return;
                case 2:
                    com.android.server.rms.iaware.cpu.CPUProcessInherit.this.handleProcessFork(pid, uid, false);
                    com.android.server.rms.iaware.cpu.SchedLevelBoost.getInstance().onFgActivitiesChanged(pid, uid, false);
                    return;
                case 3:
                    com.android.server.rms.iaware.cpu.CPUProcessInherit.this.handleProcessDie(pid, uid);
                    com.android.server.rms.iaware.cpu.SchedLevelBoost.getInstance().onProcessDied(pid, uid);
                    return;
                default:
                    return;
            }
        }
    }

    public void registerPorcessObserver() {
        try {
            android.app.ActivityManagerNative.getDefault().registerProcessObserver(this.mProcessObserver);
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.e("CPUProcessInherit", "CPUProcessInherit register process observer failed");
        }
    }

    public void unregisterPorcessObserver() {
        try {
            android.app.ActivityManagerNative.getDefault().unregisterProcessObserver(this.mProcessObserver);
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.e("CPUProcessInherit", "CPUProcessInherit unregister process observer failed");
        }
    }

    private int setHeriPidGroup(int pid, int heriPid) {
        java.lang.StringBuilder stringBuilder;
        long oldId = android.os.Binder.clearCallingIdentity();
        int curSchedGroup = Integer.MIN_VALUE;
        int heriPidcurSchedGroup = Integer.MIN_VALUE;
        try {
            curSchedGroup = android.os.Process.getProcessGroup(pid);
            heriPidcurSchedGroup = android.os.Process.getProcessGroup(heriPid);
        } catch (java.lang.IllegalArgumentException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getProcessGroup pid ");
            stringBuilder.append(heriPid);
            stringBuilder.append(" or ppid ");
            stringBuilder.append(pid);
            stringBuilder.append(" has illegal argument");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.SecurityException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getProcessGroup pid ");
            stringBuilder.append(heriPid);
            stringBuilder.append(" or ppid ");
            stringBuilder.append(pid);
            stringBuilder.append(" has no permission");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.RuntimeException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getProcessGroup pid");
            stringBuilder.append(heriPid);
            stringBuilder.append(" is not existed");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(oldId);
        }
        android.os.Binder.restoreCallingIdentity(oldId);
        if (curSchedGroup != Integer.MIN_VALUE) {
            if (heriPidcurSchedGroup != Integer.MIN_VALUE) {
                boolean isForkOk = false;
                boolean isGroupSet = false;
                if (1 == pid) {
                    if (heriPidcurSchedGroup != 0) {
                        isForkOk = setProcessGroup(heriPid, 0);
                        isGroupSet = true;
                    } else if (com.android.server.rms.iaware.cpu.CPUKeyBackground.getInstance().checkIsTargetGroup(heriPid, "/key-background")) {
                        com.android.server.rms.iaware.cpu.CPUKeyBackground.getInstance().sendSwitchGroupMessage(heriPid, 105);
                    }
                } else if (curSchedGroup != heriPidcurSchedGroup) {
                    if (curSchedGroup == 1) {
                        curSchedGroup = -1;
                    }
                    isForkOk = setProcessGroup(heriPid, curSchedGroup);
                    isGroupSet = true;
                } else if (curSchedGroup == 0 && getThreadPriority(heriPid) >= 10) {
                    isForkOk = setProcessGroup(heriPid, curSchedGroup);
                    isGroupSet = true;
                }
                if (isForkOk || !isGroupSet) {
                    return 0;
                }
                return -1;
            }
        }
        return -1;
    }

    private int getThreadPriority(int pid) {
        java.lang.StringBuilder stringBuilder;
        long oldId1 = android.os.Binder.clearCallingIdentity();
        int prio = Integer.MIN_VALUE;
        try {
            prio = android.os.Process.getThreadPriority(pid);
        } catch (java.lang.IllegalArgumentException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getThreadPriority pid ");
            stringBuilder.append(pid);
            stringBuilder.append(" has illegal argument");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.SecurityException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getThreadPriority pid");
            stringBuilder.append(pid);
            stringBuilder.append(" has no permission");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.RuntimeException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getThreadPriority pid ");
            stringBuilder.append(pid);
            stringBuilder.append(" is not existed");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(oldId1);
        }
        android.os.Binder.restoreCallingIdentity(oldId1);
        return prio;
    }

    private boolean setProcessGroup(int pid, int schedGroup) {
        java.lang.StringBuilder stringBuilder;
        long oldId1 = android.os.Binder.clearCallingIdentity();
        boolean isSuccess = false;
        if (schedGroup == 10) {
            schedGroup = 5;
        }
        try {
            android.os.Process.setProcessGroup(pid, schedGroup);
            isSuccess = true;
        } catch (java.lang.IllegalArgumentException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setProcessGroup pid");
            stringBuilder.append(pid);
            stringBuilder.append(" has illegal argument");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.SecurityException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setProcessGroup pid");
            stringBuilder.append(pid);
            stringBuilder.append(" has no permission");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.lang.RuntimeException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setProcessGroup pid");
            stringBuilder.append(pid);
            stringBuilder.append(" is not existed");
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(oldId1);
        }
        android.os.Binder.restoreCallingIdentity(oldId1);
        return isSuccess;
    }

    private boolean isValidHeriPid(int pid, int ppid, int recordPPid, int uid) {
        int pid_uid = android.os.Process.getUidForPid(pid);
        if (pid_uid > 0) {
            if (ppid > 0) {
                if (1 != ppid) {
                    int ppid_uid = android.os.Process.getUidForPid(ppid);
                    if (ppid_uid > 0 && pid_uid == uid && ppid_uid == uid) {
                        if (ppid != recordPPid) {
                        }
                    }
                    return false;
                } else if (pid_uid != uid) {
                    return false;
                }
                return true;
            }
        }
        return false;
    }

    private void changeProcessGroupFromList(int pid, int uid, com.android.server.rms.iaware.cpu.InheritInfo info) {
        if (info != null) {
            int i = 0;
            while (i < info.getListSize()) {
                int heriPid = info.getPidFromList(i);
                int recordPPid = info.getPPidFromList(i);
                int parentPid = android.os.Process.getParentPid(heriPid);
                if (!isValidHeriPid(heriPid, parentPid, recordPPid, uid)) {
                    info.removeFromPidList(heriPid);
                } else if (setHeriPidGroup(parentPid, heriPid) < 0) {
                    info.removeFromPidList(heriPid);
                } else {
                    i++;
                }
            }
        }
    }

    private void handleProcessFork(int pid, int uid, boolean foregroundActivities) {
        com.android.server.rms.iaware.cpu.InheritInfo info = (com.android.server.rms.iaware.cpu.InheritInfo) this.mForkList.get(pid);
        if (foregroundActivities) {
            changeProcessGroupFromList(pid, uid, info);
            return;
        }
        if (info == null) {
            info = new com.android.server.rms.iaware.cpu.InheritInfo();
        } else if (info.getComputeCount() >= 5) {
            changeProcessGroupFromList(pid, uid, info);
            return;
        } else {
            info.clearPidList();
        }
        info.addComputeCount();
        java.lang.StringBuilder str = new java.lang.StringBuilder();
        str.append("/acct/uid_");
        str.append(uid);
        java.io.File[] files = new java.io.File(str.toString()).listFiles();
        if (files == null) {
            android.rms.iaware.AwareLog.e("CPUProcessInherit", "files null ");
            return;
        }
        for (java.io.File dir : files) {
            if (dir.isDirectory() && -1 != dir.getName().indexOf("pid_")) {
                java.lang.String[] a = dir.getName().split("_");
                if (a.length > 1) {
                    java.lang.StringBuilder targetPath = new java.lang.StringBuilder();
                    targetPath.append("/acct/uid_");
                    targetPath.append(uid);
                    targetPath.append('/');
                    targetPath.append(dir.getName());
                    targetPath.append('/');
                    targetPath.append("cgroup.procs");
                    getForkPidList(a[1], targetPath.toString(), info);
                }
            }
        }
        this.mForkList.put(pid, info);
    }

    private void closeBufferedReader(java.io.BufferedReader br) {
        if (br != null) {
            try {
                br.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeBufferedReader exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
            }
        }
    }

    private void closeInputStreamReader(java.io.InputStreamReader isr) {
        if (isr != null) {
            try {
                isr.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeInputStreamReader exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
            }
        }
    }

    private void closeFileInputStream(java.io.FileInputStream fis) {
        if (fis != null) {
            try {
                fis.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeFileInputStream exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
            }
        }
    }

    private void getForkPidList(java.lang.String pid, java.lang.String path, com.android.server.rms.iaware.cpu.InheritInfo info) {
        java.lang.StringBuilder stringBuilder;
        java.io.FileInputStream fis = null;
        java.io.InputStreamReader isr = null;
        java.io.BufferedReader br = null;
        try {
            fis = new java.io.FileInputStream(path);
            isr = new java.io.InputStreamReader(fis, "UTF-8");
            br = new java.io.BufferedReader(isr);
            java.lang.String line = "";
            while (true) {
                java.lang.String readLine = br.readLine();
                line = readLine;
                if (readLine == null) {
                    break;
                } else if (line.indexOf(pid) == -1) {
                    int heriPid = java.lang.Integer.parseInt(line.trim());
                    int parentPid = android.os.Process.getParentPid(heriPid);
                    setHeriPidGroup(parentPid, heriPid);
                    info.addToPidList(heriPid, parentPid);
                }
            }
        } catch (java.lang.NumberFormatException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("NumberFormatException ");
            stringBuilder.append(e.getMessage());
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.io.FileNotFoundException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("FileNotFoundException ");
            stringBuilder.append(e2.getMessage());
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.io.UnsupportedEncodingException e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("UnsupportedEncodingException ");
            stringBuilder.append(e3.getMessage());
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (java.io.IOException e4) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("IOException ");
            stringBuilder.append(e4.getMessage());
            android.rms.iaware.AwareLog.e("CPUProcessInherit", stringBuilder.toString());
        } catch (Throwable th) {
            closeBufferedReader(null);
            closeInputStreamReader(null);
            closeFileInputStream(null);
        }
        closeBufferedReader(br);
        closeInputStreamReader(isr);
        closeFileInputStream(fis);
    }

    private void handleProcessDie(int pid, int uid) {
        if (this.mForkList.get(pid) != null) {
            this.mForkList.remove(pid);
        }
    }
}
