package com.android.server.rms.iaware.cpu;

public class CPUResourceConfigControl {
    private static final java.lang.String CONFIG_CONTROL_GROUP = "control_group";
    private static final java.lang.String CONFIG_GROUP_TYPE = "type";
    private static final java.lang.String FEATURENAME = "CPU";
    private static final int GET_CMS_RETRY_TIME = 5;
    private static final int GET_CMS_SLEEP_TIME = 200;
    private static final java.lang.String GROUP_BG_TYPE = "group_bg";
    public static final int GROUP_BG_VALUE = 1;
    private static final java.lang.String GROUP_WHITELIST = "whitelist";
    private static final java.lang.String SEPARATOR = ";";
    private static final java.lang.String TAG = "CPUResourceConfigControl";
    private static com.android.server.rms.iaware.cpu.CPUResourceConfigControl sInstance;
    private android.os.IBinder mCMSManager;
    private boolean mHasReadXml = false;
    private final java.util.Map<java.lang.String, java.lang.Integer> mProcessWhiteListMap = new android.util.ArrayMap();

    private CPUResourceConfigControl() {
    }

    public static synchronized com.android.server.rms.iaware.cpu.CPUResourceConfigControl getInstance() {
        com.android.server.rms.iaware.cpu.CPUResourceConfigControl cPUResourceConfigControl;
        synchronized (com.android.server.rms.iaware.cpu.CPUResourceConfigControl.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.CPUResourceConfigControl();
            }
            cPUResourceConfigControl = sInstance;
        }
        return cPUResourceConfigControl;
    }

    private void initialize() {
        setWhiteListFromXml();
    }

    private void deInitialize() {
        synchronized (this) {
            this.mHasReadXml = false;
            this.mProcessWhiteListMap.clear();
        }
    }

    public android.rms.iaware.AwareConfig getAwareCustConfig(java.lang.String featureName, java.lang.String configName) {
        android.rms.iaware.AwareConfig awareConfig = null;
        try {
            if (this.mCMSManager == null) {
                int retry = 5;
                do {
                    this.mCMSManager = android.rms.iaware.IAwareCMSManager.getICMSManager();
                    if (this.mCMSManager != null) {
                        break;
                    }
                    retry--;
                    try {
                        java.lang.Thread.sleep(200);
                        continue;
                    } catch (java.lang.InterruptedException e) {
                        android.rms.iaware.AwareLog.e("CPUResourceConfigControl", "InterruptedException occured");
                        continue;
                    }
                } while (retry > 0);
            }
            if (this.mCMSManager != null) {
                awareConfig = android.rms.iaware.IAwareCMSManager.getCustConfig(this.mCMSManager, featureName, configName);
            } else {
                android.rms.iaware.AwareLog.i("CPUResourceConfigControl", "getAwareCustConfig can not find service awareservice.");
            }
        } catch (android.os.RemoteException e2) {
            android.rms.iaware.AwareLog.e("CPUResourceConfigControl", "getAwareCustConfig RemoteException");
            this.mCMSManager = null;
        }
        return awareConfig;
    }

    private android.rms.iaware.AwareConfig getAwareConfig(java.lang.String featureName, java.lang.String configName) {
        android.rms.iaware.AwareConfig awareConfig = null;
        try {
            android.os.IBinder awareservice = android.rms.iaware.IAwareCMSManager.getICMSManager();
            if (awareservice != null) {
                awareConfig = android.rms.iaware.IAwareCMSManager.getConfig(awareservice, featureName, configName);
            } else {
                android.rms.iaware.AwareLog.i("CPUResourceConfigControl", "getAwareConfig can not find service awareservice.");
            }
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.e("CPUResourceConfigControl", "getAwareConfig RemoteException");
        }
        return awareConfig;
    }

    private java.lang.String getWhiteListItem(android.rms.iaware.AwareConfig.Item item) {
        java.lang.String whiteList = null;
        java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = item.getSubItemList();
        if (subItemList == null) {
            return null;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if ("whitelist".equals(itemName)) {
                whiteList = itemValue;
                break;
            }
        }
        return whiteList;
    }

    /* JADX WARNING: Missing block: B:7:0x0008, code:
            r0 = getAwareConfig("CPU", "control_group");
     */
    /* JADX WARNING: Missing block: B:8:0x0010, code:
            if (r0 != null) goto L_0x0013;
     */
    /* JADX WARNING: Missing block: B:9:0x0012, code:
            return;
     */
    /* JADX WARNING: Missing block: B:10:0x0013, code:
            r1 = r0.getConfigList();
     */
    /* JADX WARNING: Missing block: B:11:0x0017, code:
            if (r1 != null) goto L_0x001a;
     */
    /* JADX WARNING: Missing block: B:12:0x0019, code:
            return;
     */
    /* JADX WARNING: Missing block: B:13:0x001a, code:
            r2 = new android.util.ArrayMap();
            r3 = r1.iterator();
     */
    /* JADX WARNING: Missing block: B:15:0x0028, code:
            if (r3.hasNext() == false) goto L_0x0056;
     */
    /* JADX WARNING: Missing block: B:16:0x002a, code:
            r4 = (android.rms.iaware.AwareConfig.Item) r3.next();
            r6 = r4.getProperties();
     */
    /* JADX WARNING: Missing block: B:17:0x0034, code:
            if (r6 != null) goto L_0x0037;
     */
    /* JADX WARNING: Missing block: B:20:0x0046, code:
            if ("group_bg".equals((java.lang.String) r6.get("type")) == false) goto L_0x0055;
     */
    /* JADX WARNING: Missing block: B:21:0x0048, code:
            r8 = getWhiteListItem(r4);
     */
    /* JADX WARNING: Missing block: B:22:0x004c, code:
            if (r8 == null) goto L_0x0055;
     */
    /* JADX WARNING: Missing block: B:23:0x004e, code:
            r2.put(java.lang.Integer.valueOf(1), r8);
     */
    /* JADX WARNING: Missing block: B:25:0x0056, code:
            monitor-enter(r14);
     */
    /* JADX WARNING: Missing block: B:28:0x0059, code:
            if (r14.mHasReadXml == false) goto L_0x005d;
     */
    /* JADX WARNING: Missing block: B:29:0x005b, code:
            monitor-exit(r14);
     */
    /* JADX WARNING: Missing block: B:30:0x005c, code:
            return;
     */
    /* JADX WARNING: Missing block: B:31:0x005d, code:
            r3 = r2.size();
            r6 = 0;
     */
    /* JADX WARNING: Missing block: B:32:0x0063, code:
            if (r6 >= r3) goto L_0x009a;
     */
    /* JADX WARNING: Missing block: B:33:0x0065, code:
            r7 = (java.lang.String) r2.valueAt(r6);
     */
    /* JADX WARNING: Missing block: B:34:0x006f, code:
            if (r7.isEmpty() == false) goto L_0x0072;
     */
    /* JADX WARNING: Missing block: B:36:0x0072, code:
            r8 = (java.lang.Integer) r2.keyAt(r6);
            r9 = r7.split(";");
            r10 = r9.length;
            r11 = 0;
     */
    /* JADX WARNING: Missing block: B:37:0x0080, code:
            if (r11 >= r10) goto L_0x0097;
     */
    /* JADX WARNING: Missing block: B:38:0x0082, code:
            r12 = r9[r11].trim();
     */
    /* JADX WARNING: Missing block: B:39:0x008d, code:
            if (r12.isEmpty() != false) goto L_0x0094;
     */
    /* JADX WARNING: Missing block: B:40:0x008f, code:
            r14.mProcessWhiteListMap.put(r12, r8);
     */
    /* JADX WARNING: Missing block: B:41:0x0094, code:
            r11 = r11 + 1;
     */
    /* JADX WARNING: Missing block: B:42:0x0097, code:
            r6 = r6 + 1;
     */
    /* JADX WARNING: Missing block: B:43:0x009a, code:
            r14.mHasReadXml = true;
     */
    /* JADX WARNING: Missing block: B:44:0x009c, code:
            monitor-exit(r14);
     */
    /* JADX WARNING: Missing block: B:45:0x009d, code:
            return;
     */
    private void setWhiteListFromXml() {
        /*
        r14 = this;
        monitor-enter(r14);
        r0 = r14.mHasReadXml;	 Catch:{ all -> 0x00a1 }
        if (r0 == 0) goto L_0x0007;
    L_0x0005:
        monitor-exit(r14);	 Catch:{ all -> 0x00a1 }
        return;
    L_0x0007:
        monitor-exit(r14);	 Catch:{ all -> 0x00a1 }
        r0 = "CPU";
        r1 = "control_group";
        r0 = r14.getAwareConfig(r0, r1);
        if (r0 != 0) goto L_0x0013;
    L_0x0012:
        return;
    L_0x0013:
        r1 = r0.getConfigList();
        if (r1 != 0) goto L_0x001a;
    L_0x0019:
        return;
    L_0x001a:
        r2 = new android.util.ArrayMap;
        r2.<init>();
        r3 = r1.iterator();
    L_0x0023:
        r4 = r3.hasNext();
        r5 = 1;
        if (r4 == 0) goto L_0x0056;
    L_0x002a:
        r4 = r3.next();
        r4 = (android.rms.iaware.AwareConfig.Item) r4;
        r6 = r4.getProperties();
        if (r6 != 0) goto L_0x0037;
    L_0x0036:
        goto L_0x0023;
    L_0x0037:
        r7 = "type";
        r7 = r6.get(r7);
        r7 = (java.lang.String) r7;
        r8 = "group_bg";
        r8 = r8.equals(r7);
        if (r8 == 0) goto L_0x0055;
    L_0x0048:
        r8 = r14.getWhiteListItem(r4);
        if (r8 == 0) goto L_0x0055;
    L_0x004e:
        r5 = java.lang.Integer.valueOf(r5);
        r2.put(r5, r8);
    L_0x0055:
        goto L_0x0023;
    L_0x0056:
        monitor-enter(r14);
        r3 = r14.mHasReadXml;	 Catch:{ all -> 0x009e }
        if (r3 == 0) goto L_0x005d;
    L_0x005b:
        monitor-exit(r14);	 Catch:{ all -> 0x009e }
        return;
    L_0x005d:
        r3 = r2.size();	 Catch:{ all -> 0x009e }
        r4 = 0;
        r6 = r4;
    L_0x0063:
        if (r6 >= r3) goto L_0x009a;
    L_0x0065:
        r7 = r2.valueAt(r6);	 Catch:{ all -> 0x009e }
        r7 = (java.lang.String) r7;	 Catch:{ all -> 0x009e }
        r8 = r7.isEmpty();	 Catch:{ all -> 0x009e }
        if (r8 == 0) goto L_0x0072;
    L_0x0071:
        goto L_0x0097;
    L_0x0072:
        r8 = r2.keyAt(r6);	 Catch:{ all -> 0x009e }
        r8 = (java.lang.Integer) r8;	 Catch:{ all -> 0x009e }
        r9 = ";";
        r9 = r7.split(r9);	 Catch:{ all -> 0x009e }
        r10 = r9.length;	 Catch:{ all -> 0x009e }
        r11 = r4;
    L_0x0080:
        if (r11 >= r10) goto L_0x0097;
    L_0x0082:
        r12 = r9[r11];	 Catch:{ all -> 0x009e }
        r13 = r12.trim();	 Catch:{ all -> 0x009e }
        r12 = r13;
        r13 = r12.isEmpty();	 Catch:{ all -> 0x009e }
        if (r13 != 0) goto L_0x0094;
    L_0x008f:
        r13 = r14.mProcessWhiteListMap;	 Catch:{ all -> 0x009e }
        r13.put(r12, r8);	 Catch:{ all -> 0x009e }
    L_0x0094:
        r11 = r11 + 1;
        goto L_0x0080;
    L_0x0097:
        r6 = r6 + 1;
        goto L_0x0063;
    L_0x009a:
        r14.mHasReadXml = r5;	 Catch:{ all -> 0x009e }
        monitor-exit(r14);	 Catch:{ all -> 0x009e }
        return;
    L_0x009e:
        r3 = move-exception;
        monitor-exit(r14);	 Catch:{ all -> 0x009e }
        throw r3;
    L_0x00a1:
        r0 = move-exception;
        monitor-exit(r14);	 Catch:{ all -> 0x00a1 }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.iaware.cpu.CPUResourceConfigControl.setWhiteListFromXml():void");
    }

    public void enable() {
        initialize();
    }

    public void disable() {
        deInitialize();
    }

    public int isWhiteList(java.lang.String processName) {
        if (processName == null) {
            return -1;
        }
        synchronized (this) {
            java.lang.Integer groupType = (java.lang.Integer) this.mProcessWhiteListMap.get(processName);
            if (groupType != null) {
                int intValue = groupType.intValue();
                return intValue;
            }
            return -1;
        }
    }
}
