package com.android.server.rms.iaware.cpu;

public class CPUZRHungLog {
    private static final int CPU_HIGHLOAD_POLLING_INTERVAL_DEFAULT = 1000;
    private static final int CPU_LOAD_APP_ARRAY_SIZE_DEFAULT = 10;
    private static final java.lang.String CPU_STAT_PATH = "/proc/stat";
    private static final long INVALID_VALUE = -1;
    private static final int LOAD_STATUS_HIGH = 2;
    private static final int LOAD_STATUS_LOW = 1;
    private static final java.lang.String PATH_CMDLINE = "/cmdline";
    private static final java.lang.String PATH_STAT = "/stat";
    private static final java.lang.String PROC_NAME_MATCHER = "^[\\d]+$";
    private static final java.lang.String PTAH_CGROUP = "/cgroup";
    private static final java.lang.String PTAH_PROC_INFO = "/proc/";
    private static final java.lang.String TAG = "CPUZRHungLog";
    private int mCfgEnable = -1;
    private int mCfgSize = 10;
    private int mCurrStatus = 1;
    private int mPrevStatus = 1;
    private com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadComparator mProcLoadComparator = new com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadComparator();
    private boolean mUploadFlag = true;

    private static class ProcLoadComparator implements java.util.Comparator<com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair>, java.io.Serializable {
        private static final long serialVersionUID = 1;

        private ProcLoadComparator() {
        }

        public int compare(com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair lhs, com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair rhs) {
            return java.lang.Integer.compare(rhs.load, lhs.load);
        }
    }

    private static class ProcLoadPair {
        public int load;
        public int pid;

        public ProcLoadPair(int pid, int load) {
            this.pid = pid;
            this.load = load;
        }
    }

    private static class ProcessStatInfo {
        public long idle;
        public long iowait;
        public long irq;
        public long nice;
        public long softIrq;
        public long system;
        public long userTime;

        private ProcessStatInfo() {
        }

        public long getWallTime() {
            return (((((this.userTime + this.nice) + this.system) + this.idle) + this.iowait) + this.irq) + this.softIrq;
        }

        public long getRunningTime() {
            return this.userTime + this.nice;
        }
    }

    private void setUploadFlag(boolean value) {
        this.mUploadFlag = value;
    }

    private int computeProcsLoad(android.util.SparseArray<java.lang.Long> prevArray, android.util.SparseArray<java.lang.Long> currArray, long totalTime, java.util.List<com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair> fgProcLoadArray) {
        int i = 0;
        if (!(prevArray == null || currArray == null || totalTime == 0)) {
            if (fgProcLoadArray != null) {
                int totalLoad = 0;
                int currArraySize = currArray.size();
                while (i < currArraySize) {
                    int procPid = currArray.keyAt(i);
                    if (prevArray.indexOfKey(procPid) >= 0) {
                        int procLoad = (int) ((100 * (((java.lang.Long) currArray.get(procPid)).longValue() - ((java.lang.Long) prevArray.get(procPid)).longValue())) / totalTime);
                        fgProcLoadArray.add(new com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair(procPid, procLoad));
                        totalLoad += procLoad;
                    }
                    i++;
                }
                if (!fgProcLoadArray.isEmpty()) {
                    java.util.Collections.sort(fgProcLoadArray, this.mProcLoadComparator);
                }
                return totalLoad;
            }
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "computeProcsLoad invalid params");
        return 0;
    }

    private java.util.List<java.lang.String> getAllProcsList() {
        java.util.List<java.lang.String> procsList = new java.util.ArrayList();
        java.io.File procDir = new java.io.File("/proc/");
        if (!procDir.isDirectory()) {
            return procsList;
        }
        java.io.File[] dirList = procDir.listFiles();
        if (dirList != null) {
            if (dirList.length != 0) {
                for (java.io.File dir : dirList) {
                    java.lang.String dirName = dir.getName();
                    if (dir.isDirectory() && dirName.matches("^[\\d]+$")) {
                        procsList.add(dirName);
                    }
                }
                return procsList;
            }
        }
        return procsList;
    }

    private void getLimitProcsLoadArray(android.util.SparseArray<java.lang.Long> pidList) {
        java.util.List<java.lang.String> procsList = getAllProcsList();
        int size = procsList.size();
        for (int i = 0; i < size; i++) {
            int pid = parseInt((java.lang.String) procsList.get(i));
            if (pid >= 0) {
                long tempLoad = getProcessLoad(pid);
                if (-1 != tempLoad) {
                    pidList.put(pid, java.lang.Long.valueOf(tempLoad));
                }
            }
        }
    }

    private void getLimitCpuloadPidArray(android.util.SparseArray<java.lang.Long> pidList) {
        getLimitProcsLoadArray(pidList);
    }

    private boolean isTimeToUpload() {
        return this.mPrevStatus == 1 && this.mCurrStatus == 2 && this.mUploadFlag;
    }

    private boolean isEnabledToUpload() {
        boolean z = true;
        if (this.mCfgEnable != -1) {
            if (this.mCfgEnable != 1) {
                z = false;
            }
            return z;
        }
        try {
            android.util.ZRHung.HungConfig cfg = android.util.ZRHung.getHungConfig((short) 7);
            if (cfg.status != 0) {
                android.rms.iaware.AwareLog.e("CPUZRHungLog", "isEnabledToUpload ZRHung.getHungConfig failed!");
                return false;
            }
            java.lang.String[] values = cfg.value.split(",");
            this.mCfgEnable = parseInt(values[0].trim());
            this.mCfgSize = parseInt(values[3].trim());
            this.mCfgSize = this.mCfgSize > 0 ? this.mCfgSize : 10;
            if (this.mCfgEnable != 1) {
                z = false;
            }
            return z;
        } catch (java.lang.Exception e) {
            android.rms.iaware.AwareLog.e("CPUZRHungLog", "isEnabledToUpload ZRHung.getHungConfig exception!");
            return false;
        }
    }

    private void assembleMessage(java.lang.StringBuilder command, java.lang.StringBuilder message, java.util.List<com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair> pairArray) {
        int pairArraySize = pairArray.size();
        int i = 0;
        while (i < this.mCfgSize && i < pairArraySize) {
            com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair pair = (com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcLoadPair) pairArray.get(i);
            message.append(getProcessName(pair.pid));
            message.append(",");
            message.append(pair.pid);
            message.append(",");
            message.append(pair.load);
            message.append("\n");
            if (i == 0) {
                command.append("p=");
                command.append(pair.pid);
            }
            i++;
        }
    }

    public void loadPolicy() {
        android.rms.iaware.AwareLog.d("CPUZRHungLog", "loadZRHungDetectorPolicy");
        if (isTimeToUpload() && isEnabledToUpload()) {
            com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo prevCpuStatInfo = getCpuStatInfo();
            if (prevCpuStatInfo == null) {
                android.rms.iaware.AwareLog.e("CPUZRHungLog", "loadZRHungDetectorPolicy prevCpuStatInfo is null!");
                return;
            }
            android.util.SparseArray<java.lang.Long> prevLimArray = new android.util.SparseArray();
            getLimitCpuloadPidArray(prevLimArray);
            try {
                java.lang.Thread.sleep(1000);
            } catch (java.lang.InterruptedException e) {
                android.rms.iaware.AwareLog.e("CPUZRHungLog", "loadZRHungDetectorPolicy InterruptedException");
            }
            android.util.SparseArray<java.lang.Long> currLimArray = new android.util.SparseArray();
            getLimitCpuloadPidArray(currLimArray);
            com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo currCpuStatInfo = getCpuStatInfo();
            if (currCpuStatInfo == null) {
                android.rms.iaware.AwareLog.e("CPUZRHungLog", "loadZRHungDetectorPolicy currCpuStatInfo is null!");
                return;
            }
            long deltaTotalCpuRuntime = currCpuStatInfo.getWallTime() - prevCpuStatInfo.getWallTime();
            java.util.List totalProcLoadArray = new java.util.ArrayList();
            int totalLimitLoad = computeProcsLoad(prevLimArray, currLimArray, deltaTotalCpuRuntime, totalProcLoadArray);
            java.lang.StringBuilder command = new java.lang.StringBuilder();
            java.lang.StringBuilder message = new java.lang.StringBuilder();
            assembleMessage(command, message, totalProcLoadArray);
            try {
                if (!android.util.ZRHung.sendHungEvent(true, command.toString(), message.toString())) {
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", "loadZRHungDetectorPolicy ZRHung.sendHungEvent failed!");
                }
            } catch (java.lang.Exception e2) {
                android.rms.iaware.AwareLog.e("CPUZRHungLog", "loadZRHungDetectorPolicy ZRHung.sendHungEvent exception!");
            }
            setUploadFlag(false);
        }
    }

    public void rotateStatus(int loadStatus) {
        this.mPrevStatus = this.mCurrStatus;
        this.mCurrStatus = loadStatus;
        if (loadStatus == 1) {
            setUploadFlag(true);
        }
    }

    private com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo getCpuStatInfo() {
        java.lang.String strContent = getContentWithOneLine("/proc/stat", "cpu ");
        if (strContent != null) {
            return getCpuStatInfo(strContent);
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "getProcessLoad null content!");
        return null;
    }

    private java.util.List<java.lang.String> getProcStatInfo(java.lang.String content) {
        if (content != null) {
            if (content.length() != 0) {
                java.lang.String[] conts = content.split(" ");
                java.util.List<java.lang.String> listTemp = new java.util.ArrayList();
                for (java.lang.String str : conts) {
                    if (!"".equals(str)) {
                        listTemp.add(str);
                    }
                }
                return listTemp;
            }
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "getWallTime null content!");
        return null;
    }

    private com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo getCpuStatInfo(java.lang.String content) {
        com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo processStatInfo;
        java.util.List<java.lang.String> listTemp = getProcStatInfo(content);
        java.util.List<java.lang.String> list;
        if (listTemp == null) {
            processStatInfo = null;
        } else if (listTemp.size() < 10) {
            list = listTemp;
            processStatInfo = null;
        } else {
            java.lang.String strUserTime = (java.lang.String) listTemp.get(1);
            java.lang.String strNice = (java.lang.String) listTemp.get(2);
            java.lang.String strSystem = (java.lang.String) listTemp.get(3);
            java.lang.String strIdle = (java.lang.String) listTemp.get(4);
            java.lang.String strIoWait = (java.lang.String) listTemp.get(5);
            java.lang.String strIrq = (java.lang.String) listTemp.get(6);
            java.lang.String strSoftIrq = (java.lang.String) listTemp.get(7);
            long userTime = parseLong(strUserTime);
            long nice = parseLong(strNice);
            long system = parseLong(strSystem);
            long idle = parseLong(strIdle);
            long iowait = parseLong(strIoWait);
            long irq = parseLong(strIrq);
            long softIrq = parseLong(strSoftIrq);
            long j;
            if (userTime == -1 || nice == -1 || system == -1 || idle == -1 || iowait == -1 || irq == -1) {
                j = idle;
                listTemp = irq;
            } else if (softIrq == -1) {
                list = listTemp;
                j = idle;
                listTemp = irq;
            } else {
                processStatInfo = new com.android.server.rms.iaware.cpu.CPUZRHungLog.ProcessStatInfo();
                processStatInfo.idle = idle;
                processStatInfo.iowait = iowait;
                processStatInfo.irq = irq;
                processStatInfo.nice = nice;
                processStatInfo.softIrq = softIrq;
                processStatInfo.system = system;
                processStatInfo.userTime = userTime;
                return processStatInfo;
            }
            android.rms.iaware.AwareLog.e("CPUZRHungLog", "getWallTime inalid value!");
            return null;
        }
        return processStatInfo;
    }

    private long parseLong(java.lang.String str) {
        long value = -1;
        if (str != null) {
            if (str.length() != 0) {
                try {
                    value = java.lang.Long.parseLong(str);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("parseLong NumberFormatException e = ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
                }
                return value;
            }
        }
        return -1;
    }

    private int parseInt(java.lang.String str) {
        int value = -1;
        if (str != null) {
            if (str.length() != 0) {
                try {
                    value = java.lang.Integer.parseInt(str);
                } catch (java.lang.NumberFormatException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("parseInt NumberFormatException e = ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
                }
                return value;
            }
        }
        return -1;
    }

    private java.lang.String getProcessName(int pid) {
        java.lang.StringBuilder targetPath = new java.lang.StringBuilder();
        targetPath.append("/proc/");
        targetPath.append(pid);
        targetPath.append("/cmdline");
        java.lang.String content = getContentWithOneLine(targetPath.toString(), null);
        if (content == null) {
            android.rms.iaware.AwareLog.e("CPUZRHungLog", "getProcessName null content!");
            content = "";
        }
        return content.trim();
    }

    private long getProcessLoad(int pid) {
        java.lang.StringBuilder targetPath = new java.lang.StringBuilder();
        targetPath.append("/proc/");
        targetPath.append(pid);
        targetPath.append("/stat");
        java.lang.String content = getContentWithOneLine(targetPath.toString(), java.lang.String.valueOf(pid));
        if (content != null) {
            return getPorcseeTime(content);
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "getProcessLoad null content!");
        return -1;
    }

    private long getPorcseeTime(java.lang.String content) {
        java.lang.String[] conts = content.split(" ");
        if (conts.length < 15) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getIdleTime content inalid = ");
            stringBuilder.append(content);
            android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
            return -1;
        }
        java.lang.String strUTime = conts[13];
        java.lang.String strSTime = conts[14];
        long utime = parseLong(strUTime);
        long stime = parseLong(strSTime);
        if (utime != -1) {
            if (stime != -1) {
                return utime + stime;
            }
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "getPorcseeTime inalid value!");
        return -1;
    }

    private java.lang.String getContentWithOneLine(java.lang.String filePath, java.lang.String keyword) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String line = null;
        if (filePath == null) {
            return null;
        }
        java.io.File file = new java.io.File(filePath);
        if (file.exists()) {
            if (file.canRead()) {
                java.io.FileInputStream fis = null;
                java.io.InputStreamReader isr = null;
                java.io.BufferedReader br = null;
                try {
                    fis = new java.io.FileInputStream(filePath);
                    isr = new java.io.InputStreamReader(fis, "UTF-8");
                    br = new java.io.BufferedReader(isr);
                    do {
                        java.lang.String readLine = br.readLine();
                        line = readLine;
                        if (readLine == null || keyword == null) {
                            break;
                        }
                    } while (!line.contains(keyword));
                } catch (java.io.FileNotFoundException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("FileNotFoundException ");
                    stringBuilder.append(e.getMessage());
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
                } catch (java.io.UnsupportedEncodingException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("UnsupportedEncodingException ");
                    stringBuilder.append(e2.getMessage());
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
                } catch (java.io.IOException e3) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("IOException ");
                    stringBuilder.append(e3.getMessage());
                    android.rms.iaware.AwareLog.e("CPUZRHungLog", stringBuilder.toString());
                } catch (Throwable th) {
                    com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(null);
                    com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(null);
                }
                com.android.server.rms.iaware.cpu.FileContent.closeBufferedReader(br);
                com.android.server.rms.iaware.cpu.FileContent.closeInputStreamReader(isr);
                com.android.server.rms.iaware.cpu.FileContent.closeFileInputStream(fis);
                return line;
            }
        }
        android.rms.iaware.AwareLog.e("CPUZRHungLog", "getContentWithOneLine file not exists or canot read!");
        return null;
    }
}
