package com.android.server.rms.iaware.cpu;

public class CpuThreadBoost {
    private static final java.lang.String STR_SYSTEM_SERVER_PROC_NAME = "system_server";
    private static final java.lang.String TAG = "CpuThreadBoost";
    private static com.android.server.rms.iaware.cpu.CpuThreadBoost sInstance;
    private java.util.List<java.lang.String> mBoostThreadsList = new java.util.ArrayList();
    private com.android.server.rms.iaware.cpu.CPUFeature.CPUFeatureHandler mCPUFeatureHandler;
    private com.android.server.rms.iaware.cpu.CPUFeature mCPUFeatureInstance;
    private boolean mEnable = false;
    private int mMyPid = 0;

    private CpuThreadBoost() {
    }

    public static synchronized com.android.server.rms.iaware.cpu.CpuThreadBoost getInstance() {
        com.android.server.rms.iaware.cpu.CpuThreadBoost cpuThreadBoost;
        synchronized (com.android.server.rms.iaware.cpu.CpuThreadBoost.class) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.CpuThreadBoost();
            }
            cpuThreadBoost = sInstance;
        }
        return cpuThreadBoost;
    }

    public void setBoostThreadsList(java.lang.String[] threadsBoostInfo) {
        if (threadsBoostInfo == null) {
            android.rms.iaware.AwareLog.i("CpuThreadBoost", "threadBootInfo is empty");
            return;
        }
        int len = threadsBoostInfo.length;
        this.mBoostThreadsList.clear();
        int i = 0;
        while (i < len) {
            if ("!@#$".equals(threadsBoostInfo[i])) {
                i = obtainBoostProcInfo(threadsBoostInfo, i + 1, len);
            }
            i++;
        }
    }

    public void notifyCommChange(int pid, int tgid) {
        if (this.mEnable) {
            int isBoost = 0;
            if (tgid == this.mMyPid) {
                isBoost = 1;
            }
            java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(16);
            buffer.putInt(151);
            buffer.putInt(tgid);
            buffer.putInt(pid);
            buffer.putInt(isBoost);
            if (this.mCPUFeatureInstance != null) {
                this.mCPUFeatureInstance.sendPacket(buffer);
            }
        }
    }

    private int obtainBoostProcInfo(java.lang.String[] threadsBoostInfo, int start, int len) {
        int i = start;
        if (i >= len) {
            return i;
        }
        if ("system_server".equals(threadsBoostInfo[i])) {
            i++;
            while (i < len && !"!@#$".equals(threadsBoostInfo[i])) {
                int i2 = i + 1;
                this.mBoostThreadsList.add(threadsBoostInfo[i]);
                i = i2;
            }
        }
        return i - 1;
    }

    public void start(com.android.server.rms.iaware.cpu.CPUFeature feature, com.android.server.rms.iaware.cpu.CPUFeature.CPUFeatureHandler handler) {
        this.mEnable = true;
        this.mCPUFeatureInstance = feature;
        this.mCPUFeatureHandler = handler;
        this.mMyPid = android.os.Process.myPid();
        java.util.List<java.lang.String> tidStrArray = new java.util.ArrayList();
        getSystemThreads(this.mMyPid, tidStrArray);
        sendPacket(tidStrArray);
    }

    public void stop() {
        this.mEnable = false;
    }

    private void closeBufferedReader(java.io.BufferedReader br) {
        if (br != null) {
            try {
                br.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeBufferedReader exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CpuThreadBoost", stringBuilder.toString());
            }
        }
    }

    private void closeInputStreamReader(java.io.InputStreamReader isr) {
        if (isr != null) {
            try {
                isr.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeInputStreamReader exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CpuThreadBoost", stringBuilder.toString());
            }
        }
    }

    private void closeFileInputStream(java.io.FileInputStream fis) {
        if (fis != null) {
            try {
                fis.close();
            } catch (java.io.IOException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("closeFileInputStream exception ");
                stringBuilder.append(e.getMessage());
                android.rms.iaware.AwareLog.e("CpuThreadBoost", stringBuilder.toString());
            }
        }
    }

    private java.lang.String getThreadName(java.lang.String tidPath) {
        java.lang.String commFilePath = new java.lang.StringBuilder();
        commFilePath.append(tidPath);
        commFilePath.append("/comm");
        commFilePath = commFilePath.toString();
        java.io.FileInputStream input = null;
        java.io.InputStreamReader inputStreamReader = null;
        java.io.BufferedReader bufReader = null;
        java.lang.String tidName = null;
        try {
            input = new java.io.FileInputStream(commFilePath);
            inputStreamReader = new java.io.InputStreamReader(input, "UTF-8");
            bufReader = new java.io.BufferedReader(inputStreamReader);
            tidName = bufReader.readLine();
        } catch (java.io.FileNotFoundException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("exception file not found, file path: ");
            stringBuilder.append(commFilePath);
            android.rms.iaware.AwareLog.e("CpuThreadBoost", stringBuilder.toString());
        } catch (java.io.UnsupportedEncodingException e2) {
            android.rms.iaware.AwareLog.e("CpuThreadBoost", "UnsupportedEncodingException ");
        } catch (java.io.IOException e3) {
            android.rms.iaware.AwareLog.e("CpuThreadBoost", "getSystemServerThreads failed!");
        } catch (Throwable th) {
            closeBufferedReader(bufReader);
            closeInputStreamReader(inputStreamReader);
            closeFileInputStream(input);
        }
        closeBufferedReader(bufReader);
        closeInputStreamReader(inputStreamReader);
        closeFileInputStream(input);
        return tidName;
    }

    private void getSystemThreads(int pid, java.util.List<java.lang.String> tidStrArray) {
        java.lang.String filePath = new java.lang.StringBuilder();
        filePath.append("/proc/");
        filePath.append(pid);
        filePath.append("/task/");
        java.io.File[] subFiles = new java.io.File(filePath.toString()).listFiles();
        if (subFiles != null) {
            for (java.io.File eachTidFile : subFiles) {
                java.lang.String tidPath = "";
                try {
                    tidPath = eachTidFile.getCanonicalPath();
                    java.lang.String tidName = getThreadName(tidPath);
                    if (tidName != null) {
                        int boostThreadsListSize = this.mBoostThreadsList.size();
                        java.lang.String tidStr = null;
                        for (int i = 0; i < boostThreadsListSize; i++) {
                            if (tidName.contains((java.lang.CharSequence) this.mBoostThreadsList.get(i))) {
                                tidStr = getTidStr(tidPath);
                                if (tidStr != null) {
                                    tidStrArray.add(tidStr);
                                }
                            }
                        }
                    }
                } catch (java.io.IOException e) {
                }
            }
        }
    }

    private java.lang.String getTidStr(java.lang.String tidPath) {
        java.lang.String[] subStr = tidPath.split("task/");
        if (subStr.length == 2) {
            return subStr[1];
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getTid failed, error path is ");
        stringBuilder.append(tidPath);
        android.rms.iaware.AwareLog.e("CpuThreadBoost", stringBuilder.toString());
        return null;
    }

    private void sendPacket(java.util.List<java.lang.String> tidStrArray) {
        int num = tidStrArray.size();
        int[] tids = new int[num];
        int i = 0;
        int i2 = 0;
        while (i2 < num) {
            try {
                tids[i2] = java.lang.Integer.parseInt((java.lang.String) tidStrArray.get(i2));
                i2++;
            } catch (java.lang.NumberFormatException e) {
                android.rms.iaware.AwareLog.e("CpuThreadBoost", "parseInt failed!");
                return;
            }
        }
        i2 = tids.length;
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(4 * (i2 + 2));
        buffer.putInt(115);
        buffer.putInt(i2);
        while (i < i2) {
            buffer.putInt(tids[i]);
            i++;
        }
        if (this.mCPUFeatureInstance != null) {
            this.mCPUFeatureInstance.sendPacket(buffer);
        }
    }

    private void removeCpusMsg() {
        if (this.mCPUFeatureHandler != null) {
            this.mCPUFeatureHandler.removeMessages(135);
            this.mCPUFeatureHandler.removeMessages(136);
        }
    }

    public void setBoostCpus() {
        if (this.mEnable) {
            if (this.mCPUFeatureHandler != null) {
                removeCpusMsg();
                this.mCPUFeatureHandler.sendEmptyMessage(135);
            }
        }
    }

    public void resetBoostCpus() {
        if (this.mEnable) {
            if (this.mCPUFeatureHandler != null) {
                removeCpusMsg();
                this.mCPUFeatureHandler.sendEmptyMessage(136);
            }
        }
    }
}
