package com.android.server.rms.iaware.cpu;

public class IAwareMode {
    private static final java.lang.String BOOST_TAG = "boost";
    private static final int ENTER_GAME = 0;
    private static final int EXIT_GAME = 1;
    public static final int GAME_ENTER_TAG = 1;
    private static final java.lang.String GAME_EXIT_TAG = "isGameExit";
    public static final int GAME_SCENE_TAG = 0;
    public static final int INVALID_INT = -1;
    private static final int LEVEL_EXIT = 0;
    private static final java.lang.String LEVEL_TYPE_BCPU = "bcpu";
    private static final java.lang.String LEVEL_TYPE_DDR = "ddr";
    private static final java.lang.String LEVEL_TYPE_EAS = "eas";
    private static final java.lang.String LEVEL_TYPE_GOV = "gov";
    private static final java.lang.String LEVEL_TYPE_GPU = "gpu";
    private static final java.lang.String LEVEL_TYPE_LCPU = "lcpu";
    private static final java.lang.String TAG = "IAwareMode";
    private static final java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.rms.iaware.cpu.IAwareMode sInstance = null;
    private boolean mEasEnable = false;
    private java.util.Map<java.lang.String, com.android.server.rms.iaware.cpu.IAwareMode.LevelMng> mGameEnterLevelMngs = new android.util.ArrayMap();
    private java.util.Map<java.lang.String, com.android.server.rms.iaware.cpu.IAwareMode.LevelMng> mGameSceneLevelMngs = new android.util.ArrayMap();

    public static class LevelCmdId {
        public int mBoostCmdId = -1;
        public int mLongTermCmdId = -1;
    }

    private static class LevelInfo {
        public boolean isBoosted;
        public int mLevel;

        private LevelInfo() {
            this.mLevel = -1;
            this.isBoosted = false;
        }
    }

    private class LevelMng {
        protected android.os.Bundle mCurConfig;
        java.util.Map<java.lang.Integer, com.android.server.rms.iaware.cpu.IAwareMode.LevelCmdId> mLevelMap;
        protected java.lang.String mType;

        private LevelMng() {
            this.mType = "";
        }

        protected void initConfig(java.util.Map<java.lang.Integer, com.android.server.rms.iaware.cpu.IAwareMode.LevelCmdId> levelMap) {
            this.mLevelMap = levelMap;
        }

        protected com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo getLevelInfo(java.lang.String str) {
            if (str == null) {
                return null;
            }
            com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo levelInfo = new com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo();
            if (str.contains("boost")) {
                java.lang.String[] strParts = str.split("\\|");
                if (strParts.length != 2) {
                    return null;
                }
                levelInfo.mLevel = parseInt(strParts[0]);
                levelInfo.isBoosted = true;
            } else {
                levelInfo.mLevel = parseInt(str);
            }
            return levelInfo;
        }

        protected int parseInt(java.lang.String intStr) {
            try {
                return java.lang.Integer.parseInt(intStr);
            } catch (java.lang.NumberFormatException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("parse level failed:");
                stringBuilder.append(intStr);
                android.rms.iaware.AwareLog.e("IAwareMode", stringBuilder.toString());
                return -1;
            }
        }

        protected void doConfig(android.os.Bundle bundle) {
            if (bundle == null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("bundle is null, type:");
                stringBuilder.append(this.mType);
                android.rms.iaware.AwareLog.w("IAwareMode", stringBuilder.toString());
                return;
            }
            com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo levelInfo = getLevelInfo(bundle.getString(this.mType));
            if (levelInfo != null) {
                int level = levelInfo.mLevel;
                if (level == 0) {
                    if (this.mCurConfig != null) {
                        applyConfig(getLevelInfo(this.mCurConfig.getString(this.mType)), false);
                        this.mCurConfig = null;
                    }
                } else if (level > 0) {
                    if (this.mCurConfig != null) {
                        applyConfig(getLevelInfo(this.mCurConfig.getString(this.mType)), false);
                    }
                    applyConfig(levelInfo, true);
                    this.mCurConfig = bundle;
                } else {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("level ");
                    stringBuilder2.append(level);
                    stringBuilder2.append(" is invalid for type:");
                    stringBuilder2.append(this.mType);
                    android.rms.iaware.AwareLog.e("IAwareMode", stringBuilder2.toString());
                }
            }
        }

        protected void applyConfig(com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo levelInfo, boolean enter) {
            if (levelInfo != null) {
                int cmdId = getCmdId(levelInfo.mLevel, levelInfo.isBoosted);
                int i = -1;
                if (cmdId == -1) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("can not find cmdId for type ");
                    stringBuilder.append(this.mType);
                    stringBuilder.append(" and level ");
                    stringBuilder.append(levelInfo.mLevel);
                    android.rms.iaware.AwareLog.w("IAwareMode", stringBuilder.toString());
                    return;
                }
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("game level ");
                stringBuilder2.append(levelInfo.mLevel);
                stringBuilder2.append(",cmdid:");
                stringBuilder2.append(cmdId);
                stringBuilder2.append(",type:");
                stringBuilder2.append(this.mType);
                stringBuilder2.append(",enter:");
                stringBuilder2.append(enter);
                android.rms.iaware.AwareLog.d("IAwareMode", stringBuilder2.toString());
                android.iawareperf.UniPerf instance = android.iawareperf.UniPerf.getInstance();
                java.lang.String str = "";
                int[] iArr = new int[1];
                if (enter) {
                    i = 0;
                }
                iArr[0] = i;
                instance.uniPerfEvent(cmdId, str, iArr);
            }
        }

        protected int getCmdId(int level, boolean isBoosted) {
            int i = -1;
            if (this.mLevelMap == null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("levelmap is not initialized for type:");
                stringBuilder.append(this.mType);
                android.rms.iaware.AwareLog.e("IAwareMode", stringBuilder.toString());
                return -1;
            }
            com.android.server.rms.iaware.cpu.IAwareMode.LevelCmdId cmdId = (com.android.server.rms.iaware.cpu.IAwareMode.LevelCmdId) this.mLevelMap.get(java.lang.Integer.valueOf(level));
            if (cmdId != null) {
                i = isBoosted ? cmdId.mBoostCmdId : cmdId.mLongTermCmdId;
            }
            return i;
        }
    }

    private class BigCPULevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public BigCPULevelMng() {
            super();
            this.mType = "bcpu";
        }
    }

    private class DDRLevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public DDRLevelMng() {
            super();
            this.mType = "ddr";
        }
    }

    private class EASLevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public EASLevelMng() {
            super();
            this.mType = "eas";
        }

        public void doConfig(android.os.Bundle bundle) {
            if (com.android.server.rms.iaware.cpu.IAwareMode.this.mEasEnable) {
                super.doConfig(bundle);
            }
            java.lang.String levelStr = bundle.getString(this.mType);
            com.android.server.rms.iaware.cpu.IAwareMode.LevelInfo levelInfo = getLevelInfo(levelStr);
            if (levelStr != null) {
                if (levelInfo.mLevel == 0 && com.android.server.rms.iaware.cpu.SchedLevelBoost.getInstance().mIsLcpuLimited.get()) {
                    if (bundle.getInt("isGameExit", -1) == 0) {
                        android.rms.iaware.AwareLog.w("IAwareMode", "proc level0 but little cpu is limited");
                        com.android.server.rms.iaware.cpu.SchedLevelBoost.getInstance().enterSchedLevelBoost();
                    }
                    return;
                }
                if (levelInfo.mLevel != -1) {
                    int i = 0;
                    int cmdId = getCmdId(levelInfo.mLevel, false);
                    if (cmdId != -1) {
                        int pid = bundle.getInt("pid", -1);
                        if (pid <= 0) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("pid is invalid:");
                            stringBuilder.append(pid);
                            android.rms.iaware.AwareLog.w("IAwareMode", stringBuilder.toString());
                            return;
                        }
                        java.util.ArrayList<java.lang.Integer> tids = parseTid(bundle.getString("tid"));
                        if (tids != null) {
                            int tidSize = tids.size();
                            java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(20 + (tidSize * 4));
                            buffer.putInt(157);
                            buffer.putInt(levelInfo.mLevel);
                            buffer.putInt(cmdId);
                            buffer.putInt(pid);
                            buffer.putInt(tidSize);
                            while (i < tidSize) {
                                buffer.putInt(((java.lang.Integer) tids.get(i)).intValue());
                                i++;
                            }
                            sendToIawared(buffer);
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("game level ");
                            stringBuilder2.append(levelInfo.mLevel);
                            stringBuilder2.append(",cmdid:");
                            stringBuilder2.append(cmdId);
                            stringBuilder2.append("type:");
                            stringBuilder2.append(this.mType);
                            stringBuilder2.append(",pid:");
                            stringBuilder2.append(pid);
                            stringBuilder2.append(",tid:");
                            stringBuilder2.append(tids);
                            android.rms.iaware.AwareLog.d("IAwareMode", stringBuilder2.toString());
                        }
                    }
                }
            }
        }

        private java.util.ArrayList<java.lang.Integer> parseTid(java.lang.String tidStr) {
            if (tidStr == null) {
                return null;
            }
            java.util.ArrayList<java.lang.Integer> tids = new java.util.ArrayList();
            for (java.lang.String part : tidStr.split("\\|")) {
                int tidInt = parseInt(part);
                if (tidInt > 0) {
                    tids.add(java.lang.Integer.valueOf(tidInt));
                }
            }
            return tids;
        }

        private void sendToIawared(java.nio.ByteBuffer buffer) {
            if (!(buffer == null || android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array(), 0, buffer.position()))) {
                android.rms.iaware.AwareLog.e("IAwareMode", "send to iawared failed");
            }
        }
    }

    private class GPULevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public GPULevelMng() {
            super();
            this.mType = "gpu";
        }
    }

    private class GovLevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public GovLevelMng() {
            super();
            this.mType = "gov";
        }
    }

    private class LittleCPULevelMng extends com.android.server.rms.iaware.cpu.IAwareMode.LevelMng {
        public LittleCPULevelMng() {
            super();
            this.mType = "lcpu";
        }
    }

    public static com.android.server.rms.iaware.cpu.IAwareMode getInstance() {
        com.android.server.rms.iaware.cpu.IAwareMode iAwareMode;
        synchronized (mLock) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.IAwareMode();
            }
            iAwareMode = sInstance;
        }
        return iAwareMode;
    }

    private IAwareMode() {
        this.mGameSceneLevelMngs.put("bcpu", new com.android.server.rms.iaware.cpu.IAwareMode.BigCPULevelMng());
        this.mGameSceneLevelMngs.put("lcpu", new com.android.server.rms.iaware.cpu.IAwareMode.LittleCPULevelMng());
        this.mGameSceneLevelMngs.put("gpu", new com.android.server.rms.iaware.cpu.IAwareMode.GPULevelMng());
        this.mGameSceneLevelMngs.put("ddr", new com.android.server.rms.iaware.cpu.IAwareMode.DDRLevelMng());
        this.mGameSceneLevelMngs.put("gov", new com.android.server.rms.iaware.cpu.IAwareMode.GovLevelMng());
        this.mGameSceneLevelMngs.put("eas", new com.android.server.rms.iaware.cpu.IAwareMode.EASLevelMng());
        this.mGameEnterLevelMngs.put("gov", new com.android.server.rms.iaware.cpu.IAwareMode.GovLevelMng());
    }

    void enable(int mode) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("enable curmode=");
        stringBuilder.append(mode);
        android.rms.iaware.AwareLog.d("IAwareMode", stringBuilder.toString());
    }

    void modeChange(int mode) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("modeChange curmode=");
        stringBuilder.append(mode);
        android.rms.iaware.AwareLog.d("IAwareMode", stringBuilder.toString());
    }

    public void initLevelMap(int mapTag, java.lang.String type, java.util.Map<java.lang.Integer, com.android.server.rms.iaware.cpu.IAwareMode.LevelCmdId> levelMap) {
        if (type != null) {
            if (levelMap != null) {
                com.android.server.rms.iaware.cpu.IAwareMode.LevelMng levelMng;
                if (mapTag == 0) {
                    levelMng = (com.android.server.rms.iaware.cpu.IAwareMode.LevelMng) this.mGameSceneLevelMngs.get(type);
                    if (levelMng != null) {
                        levelMng.initConfig(levelMap);
                    }
                } else if (mapTag == 1) {
                    levelMng = (com.android.server.rms.iaware.cpu.IAwareMode.LevelMng) this.mGameEnterLevelMngs.get(type);
                    if (levelMng != null) {
                        levelMng.initConfig(levelMap);
                    }
                }
                return;
            }
        }
        android.rms.iaware.AwareLog.e("IAwareMode", "type or levelmap is null");
    }

    private void doLevelConfig(java.util.Map<java.lang.String, com.android.server.rms.iaware.cpu.IAwareMode.LevelMng> levelMngs, android.os.Bundle bundle) {
        for (java.util.Map.Entry<java.lang.String, com.android.server.rms.iaware.cpu.IAwareMode.LevelMng> entry : levelMngs.entrySet()) {
            com.android.server.rms.iaware.cpu.IAwareMode.LevelMng levelMng = (com.android.server.rms.iaware.cpu.IAwareMode.LevelMng) entry.getValue();
            if (levelMng != null) {
                levelMng.doConfig(bundle);
            }
        }
    }

    private void doSceneLevelConfig(android.os.Bundle bundle) {
        doLevelConfig(this.mGameSceneLevelMngs, bundle);
    }

    private void doGameEnterLevelConfig(android.os.Bundle bundle) {
        doLevelConfig(this.mGameEnterLevelMngs, bundle);
    }

    public void gameLevel(android.os.Bundle bundle) {
        if (bundle == null) {
            android.rms.iaware.AwareLog.e("IAwareMode", "game level bundle is null");
            return;
        }
        android.rms.iaware.AwareLog.d("IAwareMode", "adjust game level");
        doSceneLevelConfig(bundle);
    }

    public void gameEnter(android.os.Bundle bundle, boolean isEasEnable) {
        this.mEasEnable = isEasEnable;
        if (bundle == null) {
            android.rms.iaware.AwareLog.e("IAwareMode", "game enter bundle is null");
            return;
        }
        android.rms.iaware.AwareLog.d("IAwareMode", "adjust game enter");
        doGameEnterLevelConfig(bundle);
    }
}
