package com.android.server.rms.iaware.cpu;

public class OnDemandBoost {
    private static final java.lang.String COLD_START = "cold_start_duration_max";
    private static final java.lang.String COLD_START_OFF_DELAY = "cold_start_off_delay";
    private static final int INVALID_TIME = -1;
    private static final int MAX_DURATION_TIME = 60000;
    private static final int MAX_OFF_DELAY_TIME = 10000;
    private static final java.lang.String TAG = "OnDemandBoost";
    private static final java.lang.String WINDOW_SWITCH = "window_switch_duration_max";
    private static final java.lang.String WIN_SWITCH_OFF_DELAY = "window_switch_off_delay";
    private static com.android.server.rms.iaware.cpu.OnDemandBoost sInstance;
    private static java.lang.Object sLock = new java.lang.Object();
    private int mColdStartDuration = 1500;
    private int mColdStartOffDelay = 200;
    private int mWinSwitchoffDelay = 200;
    private int mWindowSwitchDuration = 400;

    private OnDemandBoost() {
    }

    public static com.android.server.rms.iaware.cpu.OnDemandBoost getInstance() {
        com.android.server.rms.iaware.cpu.OnDemandBoost onDemandBoost;
        synchronized (sLock) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.cpu.OnDemandBoost();
            }
            onDemandBoost = sInstance;
        }
        return onDemandBoost;
    }

    public void setParams(java.util.Map<java.lang.String, java.lang.Integer> onDemandParaMap) {
        if (onDemandParaMap != null) {
            int coldStartTime = getDurationTime("cold_start_duration_max", onDemandParaMap);
            if (coldStartTime != -1) {
                this.mColdStartDuration = coldStartTime;
            }
            int windowSwitchTime = getDurationTime("window_switch_duration_max", onDemandParaMap);
            if (windowSwitchTime != -1) {
                this.mWindowSwitchDuration = windowSwitchTime;
            }
            int coldStartOffDelayTime = getOffDelayTime("cold_start_off_delay", onDemandParaMap);
            if (coldStartOffDelayTime != -1) {
                this.mColdStartOffDelay = coldStartOffDelayTime;
            }
            int windowSwitchOffDelayTime = getOffDelayTime("window_switch_off_delay", onDemandParaMap);
            if (windowSwitchOffDelayTime != -1) {
                this.mWinSwitchoffDelay = windowSwitchOffDelayTime;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setParms:");
            stringBuilder.append(this.mColdStartDuration);
            stringBuilder.append(" ");
            stringBuilder.append(this.mWindowSwitchDuration);
            stringBuilder.append(" ");
            stringBuilder.append(this.mColdStartOffDelay);
            stringBuilder.append(" ");
            stringBuilder.append(this.mWinSwitchoffDelay);
            android.rms.iaware.AwareLog.d("OnDemandBoost", stringBuilder.toString());
        }
    }

    private int getDurationTime(java.lang.String durationType, java.util.Map<java.lang.String, java.lang.Integer> onDemandParaMap) {
        java.lang.Integer time = (java.lang.Integer) onDemandParaMap.get(durationType);
        if (time != null) {
            int durationTime = time.intValue();
            if (durationTime > 0 && durationTime < 60000) {
                return durationTime;
            }
        }
        return -1;
    }

    private int getOffDelayTime(java.lang.String delayType, java.util.Map<java.lang.String, java.lang.Integer> onDemandParaMap) {
        java.lang.Integer time = (java.lang.Integer) onDemandParaMap.get(delayType);
        if (time != null) {
            int durationTime = time.intValue();
            if (durationTime >= 0 && durationTime < 10000) {
                return durationTime;
            }
        }
        return -1;
    }

    public int getColdStartDuration() {
        return this.mColdStartDuration;
    }

    public int getWindowSwitchDuration() {
        return this.mWindowSwitchDuration;
    }

    public int getColdStartOffDelay() {
        return this.mColdStartOffDelay;
    }

    public int getWinSwitchOffDelay() {
        return this.mWinSwitchoffDelay;
    }
}
