package com.android.server.rms.iaware.cpu;

/* compiled from: CPUXmlConfiguration */
class SubSwitchConfig extends com.android.server.rms.iaware.cpu.CPUCustBaseConfig {
    private static final int BIT_POS_MAX = 31;
    private static final int BIT_POS_MIN = 0;
    private static final java.lang.String CONFIG_SUBSWITCH = "sub_switch";
    private static final int DEFAULT_SUBSWITCH = 0;
    private static final java.lang.String ITEM_PROP_TYPE = "type";
    private static final java.lang.String ITEM_TYPE_SWITCH = "switch";
    private static final java.lang.String PROP_SUBSWITCH = "persist.sys.cpuset.subswitch";
    private static final java.lang.String SUBITEM_PROP_BIT = "bit";
    private static final java.lang.String TAG = "SubSwitchConfig";
    private int mSubSwitch;

    public SubSwitchConfig() {
        this.mSubSwitch = 0;
        this.mSubSwitch = getSubSwitch();
    }

    public void setConfig(com.android.server.rms.iaware.cpu.CPUFeature feature) {
        try {
            android.os.SystemProperties.set("persist.sys.cpuset.subswitch", java.lang.Integer.toString(this.mSubSwitch));
        } catch (java.lang.IllegalArgumentException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("set subswitch failed,");
            stringBuilder.append(e.toString());
            android.rms.iaware.AwareLog.e("SubSwitchConfig", stringBuilder.toString());
        }
    }

    private int getSubSwitch() {
        java.util.List<android.rms.iaware.AwareConfig.Item> awareConfigItemList = getItemList("sub_switch");
        if (awareConfigItemList == null) {
            android.rms.iaware.AwareLog.d("SubSwitchConfig", "can not get subswitch config");
            return 0;
        }
        for (android.rms.iaware.AwareConfig.Item item : awareConfigItemList) {
            java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
            if (configPropertries != null) {
                java.lang.String itemType = (java.lang.String) configPropertries.get("type");
                if (itemType != null) {
                    if (itemType.equals("switch")) {
                        return getSubSwitchFromSubItem(item);
                    }
                }
            }
        }
        return 0;
    }

    private int getSubSwitchFromSubItem(android.rms.iaware.AwareConfig.Item item) {
        java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = getSubItem(item);
        if (subItemList == null) {
            android.rms.iaware.AwareLog.d("SubSwitchConfig", "can not get subswitch config subitem");
            return 0;
        }
        int subSwitch = 0;
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            java.lang.String itemValue = subItem.getValue();
            if (itemValue != null) {
                java.util.Map<java.lang.String, java.lang.String> subItemProps = subItem.getProperties();
                if (subItemProps != null) {
                    java.lang.String bitPosStr = (java.lang.String) subItemProps.get("bit");
                    if (bitPosStr != null) {
                        try {
                            int bitPos = java.lang.Integer.parseInt(bitPosStr);
                            if (isInBitPosRange(bitPos)) {
                                subSwitch = setBit(subSwitch, itemValue, bitPos);
                            }
                        } catch (java.lang.NumberFormatException e) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("parse bitpos failed:");
                            stringBuilder.append(bitPosStr);
                            android.rms.iaware.AwareLog.d("SubSwitchConfig", stringBuilder.toString());
                        }
                    }
                }
            }
        }
        return subSwitch;
    }

    private int setBit(int subSwitch, java.lang.String bitValue, int bitPos) {
        if (bitValue.equals("1")) {
            return subSwitch | (1 << bitPos);
        }
        if (bitValue.equals("0")) {
            return subSwitch & (~(1 << bitPos));
        }
        return subSwitch;
    }

    private boolean isInBitPosRange(int bitPos) {
        return bitPos >= 0 && bitPos <= 31;
    }
}
