package com.android.server.rms.iaware.cpu;

/* compiled from: CPUXmlConfiguration */
class ThreadBoostConfig extends com.android.server.rms.iaware.cpu.CPUCustBaseConfig {
    private static final java.lang.String CONFIG_KEYTHREAD_NAME = "boost_key_thread_list";
    public static final java.lang.String GAP_IDENTIFIER = "!@#$";
    private static final java.lang.String ITEM_PROP_PROCNAME = "process_name";
    private static final java.lang.String TAG = "ThreadBoostConfig";
    private static final int THREAD_INFO_MAX_SIZE = 2048;
    private int mThreadInfoSize = 0;
    private java.util.ArrayList<java.lang.String> mthreadNameList = new java.util.ArrayList();

    public ThreadBoostConfig() {
        init();
    }

    public void setConfig(com.android.server.rms.iaware.cpu.CPUFeature feature) {
        if (this.mthreadNameList != null) {
            if (this.mthreadNameList.size() != 0) {
                if (this.mThreadInfoSize > 2048) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(" thread capacity size is too large:");
                    stringBuilder.append(this.mThreadInfoSize);
                    android.rms.iaware.AwareLog.w("ThreadBoostConfig", stringBuilder.toString());
                    return;
                }
                java.lang.String[] threadNameList = (java.lang.String[]) this.mthreadNameList.toArray(new java.lang.String[this.mthreadNameList.size()]);
                android.os.Process.setThreadBoostInfo(threadNameList);
                com.android.server.rms.iaware.cpu.CpuThreadBoost.getInstance().setBoostThreadsList(threadNameList);
                return;
            }
        }
        android.rms.iaware.AwareLog.i("ThreadBoostConfig", "thread name is not set");
    }

    private void init() {
        obtainKeyThreadNameArray();
    }

    private void obtainKeyThreadNameArray() {
        int totalLen = 0;
        java.util.List<android.rms.iaware.AwareConfig.Item> awareConfigItemList = getItemList("boost_key_thread_list");
        if (awareConfigItemList == null) {
            android.rms.iaware.AwareLog.d("ThreadBoostConfig", "can not get threadboost info");
            return;
        }
        if (this.mthreadNameList == null) {
            this.mthreadNameList = new java.util.ArrayList();
        }
        for (android.rms.iaware.AwareConfig.Item item : awareConfigItemList) {
            java.util.Map<java.lang.String, java.lang.String> itemProp = item.getProperties();
            if (itemProp != null) {
                java.lang.String procname = (java.lang.String) itemProp.get("process_name");
                if (procname != null) {
                    this.mthreadNameList.add("!@#$");
                    this.mthreadNameList.add(procname);
                    totalLen += ("!@#$".length() + procname.length()) + obtainThreadList(item, this.mthreadNameList);
                }
            }
        }
        this.mThreadInfoSize = totalLen;
    }

    private int obtainThreadList(android.rms.iaware.AwareConfig.Item item, java.util.ArrayList<java.lang.String> boostList) {
        int totalLen = 0;
        java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = getSubItem(item);
        if (subItemList == null) {
            return 0;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            java.lang.String itemValue = subItem.getValue();
            if (itemValue != null) {
                boostList.add(itemValue);
                totalLen += itemValue.length();
            }
        }
        return totalLen;
    }
}
