package com.android.server.rms.iaware.dev;

public class DevRemoteCallbackList {
    private static final java.lang.String TAG = "DevRemoteCallbackList";
    private final android.os.RemoteCallbackList<android.rms.iaware.IDeviceSettingCallback> mDevCallbacks = new android.os.RemoteCallbackList();
    private int mDeviceId;

    public DevRemoteCallbackList(int deviceId) {
        this.mDeviceId = deviceId;
    }

    public void registerDevModeMethod(android.rms.iaware.IDeviceSettingCallback callback, android.os.Bundle args) {
        synchronized (this.mDevCallbacks) {
            this.mDevCallbacks.register(callback);
        }
    }

    public void unregisterDevModeMethod(android.rms.iaware.IDeviceSettingCallback callback, android.os.Bundle args) {
        synchronized (this.mDevCallbacks) {
            this.mDevCallbacks.unregister(callback);
        }
    }

    public void sendDeviceMode(java.lang.String packageName, int uid, int mode, android.os.Bundle bundle) {
        synchronized (this.mDevCallbacks) {
            int i = this.mDevCallbacks.beginBroadcast();
            while (i > 0) {
                i--;
                android.rms.iaware.IDeviceSettingCallback callback = (android.rms.iaware.IDeviceSettingCallback) this.mDevCallbacks.getBroadcastItem(i);
                if (callback != null) {
                    try {
                        callback.onDevSceneChanged(packageName, uid, mode, bundle);
                    } catch (android.os.RemoteException e) {
                        android.rms.iaware.AwareLog.e("DevRemoteCallbackList", "onDevSceneChanged remoteException");
                    }
                }
            }
            this.mDevCallbacks.finishBroadcast();
        }
    }

    public int getDeviceId() {
        return this.mDeviceId;
    }

    public int getCount() {
        int registeredCallbackCount;
        synchronized (this.mDevCallbacks) {
            registeredCallbackCount = this.mDevCallbacks.getRegisteredCallbackCount();
        }
        return registeredCallbackCount;
    }

    public java.lang.String toString() {
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        sb.append("mDeviceId :");
        sb.append(this.mDeviceId);
        sb.append(", RemoteCallbackList num :");
        sb.append(getCount());
        return sb.toString();
    }
}
