package com.android.server.rms.iaware.dev;

public class SceneInfo {
    public static final int INVALID_VALUE = -1;
    private static final java.lang.String ITEM_RULE = "rule";
    public static final java.lang.String ITEM_RULE_ALLOW = "allow";
    private static final java.lang.String ITEM_RULE_DEFAULT = "Default";
    private static final java.lang.String ITEM_RULE_IS_HOME = "IsHome";
    public static final java.lang.String ITEM_RULE_NOT_ALLOW = "not_allow";
    private static final java.lang.String ITEM_RULE_PRE_RECOG = "Pre_Recog";
    public static final java.lang.String ITEM_RULE_SERVICE = "Service_Rule";
    private static final java.lang.String TAG = "SceneInfo";
    private static final java.util.Map<java.lang.String, java.lang.Class<?>> mRuleObjMap = new android.util.ArrayMap();
    private com.android.server.rms.iaware.dev.RuleBase mDefaultRule = null;
    private final java.util.Map<java.lang.String, java.lang.String> mItemValues = new android.util.ArrayMap();
    private final java.util.List<com.android.server.rms.iaware.dev.RuleBase> mRulesList = new java.util.ArrayList();
    private int mSceneId;
    private java.lang.String mSceneName;

    static {
        mRuleObjMap.put("allow", com.android.server.rms.iaware.dev.RuleAllow.class);
        mRuleObjMap.put("Service_Rule", com.android.server.rms.iaware.dev.RuleService.class);
        mRuleObjMap.put("not_allow", com.android.server.rms.iaware.dev.RuleNotAllow.class);
        mRuleObjMap.put("Pre_Recog", com.android.server.rms.iaware.dev.RulePreRecog.class);
        mRuleObjMap.put("IsHome", com.android.server.rms.iaware.dev.RuleIsHome.class);
        mRuleObjMap.put("Default", com.android.server.rms.iaware.dev.RuleDefault.class);
    }

    public SceneInfo(java.lang.String sceneName, int sceneId) {
        this.mSceneName = sceneName;
        this.mSceneId = sceneId;
    }

    public SceneInfo(android.rms.iaware.AwareConfig.Item item) {
        init(item);
    }

    private void init(android.rms.iaware.AwareConfig.Item item) {
        if (item != null) {
            java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
            if (configPropertries != null) {
                this.mItemValues.putAll(configPropertries);
            }
            java.util.List<android.rms.iaware.AwareConfig.SubItem> ruleItemList = item.getSubItemList();
            if (ruleItemList != null) {
                parseRuleList(ruleItemList);
            }
            this.mSceneName = (java.lang.String) this.mItemValues.get("scenename");
            this.mSceneId = getSceneId();
        }
    }

    public boolean fillSceneInfo(java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList, java.util.List<java.lang.String> ruleList) {
        if (subItemList == null) {
            return false;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            if (subItem == null) {
                android.rms.iaware.AwareLog.e("SceneInfo", "WifiSchedFeature subItem null");
                return false;
            }
            java.util.Map<java.lang.String, java.lang.String> properties = subItem.getProperties();
            if (properties != null) {
                if (!properties.isEmpty()) {
                    java.lang.String rule = (java.lang.String) properties.get("rule");
                    if (rule != null) {
                        if (ruleList.contains(rule)) {
                            com.android.server.rms.iaware.dev.RuleBase ruleObj = createRuleBaseObj(rule);
                            if (ruleObj == null) {
                                android.rms.iaware.AwareLog.e("SceneInfo", "WifiSchedFeature createRuleBaseObj error");
                                return false;
                            } else if (ruleObj.fillRuleInfo(subItem)) {
                                insertRuleList(ruleObj);
                            } else {
                                android.rms.iaware.AwareLog.e("SceneInfo", "WifiSchedFeature fillRuleInfo error");
                                return false;
                            }
                        }
                    }
                    android.rms.iaware.AwareLog.e("SceneInfo", "WifiSchedFeature ruleList not contains");
                    return false;
                }
            }
            android.rms.iaware.AwareLog.e("SceneInfo", "WifiSchedFeature properties null");
            return false;
        }
        return true;
    }

    private void insertRuleList(com.android.server.rms.iaware.dev.RuleBase ruleObj) {
        int prio = ruleObj.getPriority();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("prio is ");
        stringBuilder.append(prio);
        android.rms.iaware.AwareLog.d("SceneInfo", stringBuilder.toString());
        int size = this.mRulesList.size();
        int i = 0;
        while (i < size && ((com.android.server.rms.iaware.dev.RuleBase) this.mRulesList.get(i)).mPriority <= prio) {
            i++;
        }
        this.mRulesList.add(i, ruleObj);
    }

    public int isMatch(java.lang.Object... obj) {
        if (obj == null) {
            return -1;
        }
        int size = this.mRulesList.size();
        for (int i = 0; i < size; i++) {
            if (((com.android.server.rms.iaware.dev.RuleBase) this.mRulesList.get(i)).isMatch(obj)) {
                return i;
            }
        }
        return -1;
    }

    public long getMode(int index) {
        if (index >= 0) {
            if (index < this.mRulesList.size()) {
                com.android.server.rms.iaware.dev.RuleBase rule = (com.android.server.rms.iaware.dev.RuleBase) this.mRulesList.get(index);
                if (rule == null) {
                    return -1;
                }
                return rule.getMode();
            }
        }
        return -1;
    }

    private com.android.server.rms.iaware.dev.RuleBase createRuleBaseObj(java.lang.String rule) {
        if (rule == null) {
            return null;
        }
        java.lang.Class<?> classObj = (java.lang.Class) mRuleObjMap.get(rule);
        if (classObj == null) {
            return null;
        }
        com.android.server.rms.iaware.dev.RuleBase sceneObj = null;
        try {
            return (com.android.server.rms.iaware.dev.RuleBase) classObj.newInstance();
        } catch (java.lang.InstantiationException e) {
            android.rms.iaware.AwareLog.e("SceneInfo", " InstantiationException, createRuleBaseObj error!");
            return null;
        } catch (java.lang.IllegalAccessException e2) {
            android.rms.iaware.AwareLog.e("SceneInfo", " IllegalAccessException, createRuleBaseObj error!");
            return null;
        }
    }

    public boolean parseRuleList(java.util.List<android.rms.iaware.AwareConfig.SubItem> ruleItemList) {
        if (ruleItemList == null) {
            return false;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : ruleItemList) {
            if (subItem != null) {
                java.util.Map<java.lang.String, java.lang.String> properties = subItem.getProperties();
                if (properties != null) {
                    java.lang.String rule = (java.lang.String) properties.get("rule");
                    if (rule != null) {
                        com.android.server.rms.iaware.dev.RuleBase ruleObj = createRuleBaseObj(rule);
                        if (ruleObj != null) {
                            if (ruleObj.fillRuleInfo(subItem)) {
                                if (rule.equals("Default")) {
                                    this.mDefaultRule = ruleObj;
                                } else {
                                    this.mRulesList.add(ruleObj);
                                }
                            }
                        }
                    }
                }
            }
        }
        if (this.mDefaultRule != null) {
            this.mRulesList.add(this.mDefaultRule);
            this.mDefaultRule = null;
        }
        return true;
    }

    public com.android.server.rms.iaware.dev.RuleBase getRuleBase(int index) {
        if (index >= 0) {
            if (index < this.mRulesList.size()) {
                return (com.android.server.rms.iaware.dev.RuleBase) this.mRulesList.get(index);
            }
        }
        return null;
    }

    public java.lang.String toString() {
        java.lang.StringBuilder s = new java.lang.StringBuilder();
        s.append("scene name : ");
        s.append(this.mSceneName);
        s.append(", scene id : ");
        s.append(this.mSceneId);
        s.append(", rule num : ");
        s.append(this.mRulesList.size());
        s.append(",mItemValues [ ");
        s.append(this.mItemValues.toString());
        s.append(" ]");
        s.append(",mRulesList [ ");
        s.append(this.mRulesList.toString());
        s.append(" ]");
        return s.toString();
    }

    public int getSceneId() {
        java.lang.String sceneIdOrg = (java.lang.String) this.mItemValues.get("scene_id");
        try {
            return java.lang.Integer.parseInt(sceneIdOrg);
        } catch (java.lang.NumberFormatException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("NumberFormatException, scene id :");
            stringBuilder.append(sceneIdOrg);
            android.rms.iaware.AwareLog.e("SceneInfo", stringBuilder.toString());
            return -1;
        }
    }

    public java.lang.String getRuleItemValue(java.lang.String ruleItem, int index) {
        if (ruleItem == null) {
            android.rms.iaware.AwareLog.e("SceneInfo", "ruleItem is null, error!");
            return null;
        }
        if (index >= 0) {
            if (index < this.mRulesList.size()) {
                com.android.server.rms.iaware.dev.RuleBase ruleObject = (com.android.server.rms.iaware.dev.RuleBase) this.mRulesList.get(index);
                if (ruleObject != null) {
                    return ruleObject.getItemValue(ruleItem);
                }
                android.rms.iaware.AwareLog.e("SceneInfo", "ruleObject is null, error!");
                return null;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("index is illegal, index:");
        stringBuilder.append(index);
        stringBuilder.append(", list size:");
        stringBuilder.append(this.mRulesList.size());
        android.rms.iaware.AwareLog.e("SceneInfo", stringBuilder.toString());
        return null;
    }

    public java.util.List<java.lang.String> getRuleItemValues(java.lang.String ruleItem) {
        if (ruleItem == null) {
            android.rms.iaware.AwareLog.e("SceneInfo", "ruleItem is null, error!");
            return null;
        }
        java.util.List<java.lang.String> res = new java.util.ArrayList();
        for (com.android.server.rms.iaware.dev.RuleBase ruleObject : this.mRulesList) {
            if (ruleObject != null) {
                java.lang.String itemValue = ruleObject.getItemValue(ruleItem);
                if (itemValue != null) {
                    res.add(itemValue);
                }
            }
        }
        return res;
    }
}
