package com.android.server.rms.iaware.feature;

public class MemoryFeature extends com.android.server.rms.iaware.feature.RFeature {
    private static final int INTERVAL_SAVE_DATA_IN_MSEC = 7200000;
    private static final java.lang.String TAG = "AwareMem_MemFeature";
    private static final com.android.server.rms.iaware.feature.MemoryFeature.FeatureHandler mFeatureHandler = new com.android.server.rms.iaware.feature.MemoryFeature.FeatureHandler();
    private com.android.server.rms.iaware.memory.utils.BigDataStore mBigDataStore = com.android.server.rms.iaware.memory.utils.BigDataStore.getInstance();
    private final java.util.concurrent.atomic.AtomicBoolean mRunning = new java.util.concurrent.atomic.AtomicBoolean(false);

    private static final class FeatureHandler extends android.os.Handler {
        private static final int MSG_CONFIG_PROTECTLRU = 102;
        private static final int MSG_DISABLE_PROTECTLRU = 101;
        private boolean mFirstAccess;

        private FeatureHandler() {
            this.mFirstAccess = true;
        }

        public void removeProtectLruMsg() {
            removeMessages(101);
        }

        public void enableProtectLru() {
            removeProtectLruMsg();
            if (this.mFirstAccess) {
                sendEmptyMessageDelayed(102, 20000);
            }
            com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().notifyProtectLruState(0);
            this.mFirstAccess = false;
        }

        public void disableProtectLru() {
            removeProtectLruMsg();
            sendEmptyMessageDelayed(101, 1000);
        }

        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            switch (msg.what) {
                case 101:
                    com.android.server.rms.iaware.memory.utils.MemoryUtils.disableProtectLru();
                    return;
                case 102:
                    com.android.server.rms.iaware.memory.utils.MemoryUtils.onProtectLruConfigUpdate();
                    return;
                default:
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("error msg what = ");
                    stringBuilder.append(msg.what);
                    android.rms.iaware.AwareLog.e("AwareMem_MemFeature", stringBuilder.toString());
                    return;
            }
        }
    }

    public MemoryFeature(android.content.Context context, android.rms.iaware.AwareConstant.FeatureType featureType, com.android.server.rms.iaware.IRDataRegister dataRegister) {
        super(context, featureType, dataRegister);
        com.android.server.rms.iaware.memory.utils.MemoryConstant.init(this.mContext);
        com.android.server.rms.iaware.memory.utils.MemoryConstant.setCameraPowerUPMem();
        loadMemConfig();
    }

    public boolean enable() {
        subscribleEvents();
        com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().enable();
        com.android.server.rms.iaware.memory.data.dispatch.DataDispatch.getInstance().start();
        setBoostKillSwitch(true);
        com.android.server.rms.iaware.memory.utils.MemoryUtils.writeSwappiness(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigSwappiness());
        com.android.server.rms.iaware.memory.utils.MemoryUtils.writeDirectSwappiness(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigDirectSwappiness());
        mFeatureHandler.enableProtectLru();
        this.mRunning.set(true);
        return true;
    }

    public boolean disable() {
        com.android.server.rms.iaware.memory.utils.MemoryUtils.writeExtraFreeKbytes(com.android.server.rms.iaware.memory.utils.MemoryConstant.DEFAULT_EXTRA_FREE_KBYTES);
        com.android.server.rms.iaware.memory.utils.MemoryUtils.writeSwappiness(60);
        com.android.server.rms.iaware.memory.utils.MemoryUtils.writeDirectSwappiness(60);
        setBoostKillSwitch(false);
        mFeatureHandler.disableProtectLru();
        com.android.server.rms.iaware.memory.data.dispatch.DataDispatch.getInstance().stop();
        com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().disable();
        unSubscribeEvents();
        this.mRunning.set(false);
        return true;
    }

    public boolean reportData(android.rms.iaware.CollectData data) {
        if (!this.mRunning.get()) {
            return false;
        }
        com.android.server.rms.iaware.memory.data.dispatch.DataDispatch.getInstance().reportData(data);
        return true;
    }

    public java.util.ArrayList<android.rms.iaware.DumpData> getDumpData(int time) {
        if (this.mRunning.get()) {
            return com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().getDumpData(time);
        }
        return null;
    }

    public java.lang.String saveBigData(boolean clear) {
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature", "enter saveBigData");
        if (!this.mRunning.get()) {
            return null;
        }
        this.mBigDataStore.totalTimeEnd = android.os.SystemClock.elapsedRealtime();
        this.mBigDataStore.getMeminfoAllocCount();
        this.mBigDataStore.getLmkOccurCount();
        java.lang.String rtStatisJsonStr = creatJsonStr();
        if (clear) {
            clearCache();
        }
        return rtStatisJsonStr;
    }

    public java.util.ArrayList<android.rms.iaware.StatisticsData> getStatisticsData() {
        if (this.mRunning.get()) {
            return com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().getStatisticsData();
        }
        return null;
    }

    public boolean configUpdate() {
        loadMemConfig();
        com.android.server.rms.iaware.memory.utils.MemoryUtils.onProtectLruConfigUpdate();
        com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().notifyProtectLruState(0);
        return true;
    }

    private void loadMemConfig() {
        loadMemConstantConfig(false);
        loadBigMemAppPolicyConfig(getConfig("Memory", "BigMemApp", true));
        com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setMemoryScenePolicyList(loadMemPolicyListConfig());
        loadFileCacheConfig();
        loadMemConstantConfig(true);
    }

    private void loadMemConstantConfig(boolean isCustConfig) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loadMemConstantConfig, isCustConfig : ");
        stringBuilder.append(isCustConfig);
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "MemoryConstant", isCustConfig);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadMemConstantConfig failure cause null configList");
            return;
        }
        com.android.internal.util.MemInfoReader minfo = new com.android.internal.util.MemInfoReader();
        minfo.readMemInfo();
        java.lang.Long totalMemMb = java.lang.Long.valueOf(minfo.getTotalSize() / 1048576);
        for (android.rms.iaware.AwareConfig.Item item : configList.getConfigList()) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.lang.String ramSize = (java.lang.String) item.getProperties().get("ramsize");
                    if (com.android.server.rms.iaware.memory.utils.MemoryUtils.checkRamSize(ramSize, totalMemMb)) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("loadMemConstantConfig success. ramSize: ");
                        stringBuilder2.append(ramSize);
                        stringBuilder2.append(" totalMemMb: ");
                        stringBuilder2.append(totalMemMb);
                        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                        saveMemConstantItem(item);
                        break;
                    }
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("checkRamSize failure cause ramSize: ");
                    stringBuilder3.append(ramSize);
                    stringBuilder3.append(" totalMemMb: ");
                    stringBuilder3.append(totalMemMb);
                    android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder3.toString());
                }
            }
            android.rms.iaware.AwareLog.d("AwareMem_MemFeature", "loadMemConstantConfig continue cause null item");
        }
    }

    public static void loadBigMemAppPolicyConfig(android.rms.iaware.AwareConfig custConfigList) {
        if (custConfigList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadBigMemAppConfig failure cause null configList");
            return;
        }
        for (android.rms.iaware.AwareConfig.Item item : custConfigList.getConfigList()) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
                    java.lang.String appName = (java.lang.String) configPropertries.get("appname");
                    if (appName != null) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("big memory app is ");
                        stringBuilder.append(appName);
                        android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder.toString());
                        saveBigMemoryAppConfig(appName, item);
                    } else {
                        java.lang.String ramSize = (java.lang.String) configPropertries.get("ramsize");
                        java.lang.Long totalMemMb = java.lang.Long.valueOf(com.android.server.rms.iaware.memory.utils.MemoryReader.getInstance().getTotalRam() / 1024);
                        if (com.android.server.rms.iaware.memory.utils.MemoryUtils.checkRamSize(ramSize, totalMemMb)) {
                            saveCameraIonConfig(item);
                        } else {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("checkRamSize failure cause ramSize: ");
                            stringBuilder2.append(ramSize);
                            stringBuilder2.append(" totalMemMb: ");
                            stringBuilder2.append(totalMemMb);
                            android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder2.toString());
                        }
                    }
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadBigMemAppPolicyConfig continue cause null item");
        }
    }

    private static void saveBigMemoryAppConfig(java.lang.String appName, android.rms.iaware.AwareConfig.Item item) {
        java.lang.String appNameTemp = appName;
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if (itemName != null) {
                if (itemValue != null) {
                    java.lang.Object obj = -1;
                    try {
                        if (itemName.hashCode() == -1109843021) {
                            if (itemName.equals("launch")) {
                                obj = null;
                            }
                        }
                        if (obj != null) {
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "no such configuration!");
                        } else {
                            long launchRequestMem = java.lang.Long.parseLong(itemValue.trim());
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("saveBigMemoryAppConfig ");
                            stringBuilder.append(appNameTemp);
                            stringBuilder.append(" request memory is ");
                            stringBuilder.append(launchRequestMem);
                            android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder.toString());
                            com.android.server.rms.iaware.memory.utils.BigMemoryInfo.getInstance().setRequestMemForLaunch(appNameTemp, launchRequestMem);
                        }
                    } catch (java.lang.NumberFormatException e) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("parse app mem error: ");
                        stringBuilder2.append(e);
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature", stringBuilder2.toString());
                    }
                }
            }
        }
    }

    private static void saveCameraIonConfig(android.rms.iaware.AwareConfig.Item item) {
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if (itemName != null) {
                if (itemValue != null) {
                    java.lang.Object obj = -1;
                    try {
                        int hashCode = itemName.hashCode();
                        if (hashCode != -190523471) {
                            if (hashCode == 2089932130) {
                                if (itemName.equals("camera_ion_speedup_switch")) {
                                    obj = null;
                                }
                            }
                        } else if (itemName.equals("camera_powerup_ion_memory")) {
                            obj = 1;
                        }
                        int ionSpeedupSwitch;
                        java.lang.StringBuilder stringBuilder;
                        switch (obj) {
                            case null:
                                ionSpeedupSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("saveCameraIonConfigs camera ion memory speedup switch: ");
                                stringBuilder.append(ionSpeedupSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigIonSpeedupSwitch(ionSpeedupSwitch);
                                break;
                            case 1:
                                ionSpeedupSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("saveCameraIonConfigs camera powerup memory: ");
                                stringBuilder.append(ionSpeedupSwitch * 1024);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setCameraPowerUPMemoryDefault(ionSpeedupSwitch * 1024);
                                break;
                            default:
                                java.lang.String str = "AwareMem_MemFeature";
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("saveCameraIonConfigs no such configuration. ");
                                stringBuilder2.append(itemName);
                                android.rms.iaware.AwareLog.w(str, stringBuilder2.toString());
                                break;
                        }
                    } catch (java.lang.NumberFormatException e) {
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "saveCameraIonConfigs parse memory xml error");
                    }
                }
            }
        }
    }

    private void loadFileCacheConfig() {
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature", "loadFileCacheConfig begin");
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "FileCache", false);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadFileCacheConfig failure cause null configList");
            return;
        }
        android.util.ArrayMap<java.lang.Integer, android.util.ArraySet<java.lang.String>> fileCacheMap = new android.util.ArrayMap();
        for (android.rms.iaware.AwareConfig.Item item : configList.getConfigList()) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
                    java.lang.String strName = (java.lang.String) configPropertries.get("name");
                    if (android.text.TextUtils.isEmpty(strName)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("loadFileCacheConfig failure cause name: ");
                        stringBuilder.append(strName);
                        android.rms.iaware.AwareLog.w("AwareMem_MemFeature", stringBuilder.toString());
                    } else {
                        java.lang.String strLevel = (java.lang.String) configPropertries.get("level");
                        int fileCacheLevel = checkFileCacheLevel(strLevel);
                        java.lang.StringBuilder stringBuilder2;
                        if (fileCacheLevel == -1) {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("checkFileCacheLevel failure cause level: ");
                            stringBuilder2.append(strLevel);
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", stringBuilder2.toString());
                        } else {
                            stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("loadFileCacheConfig success. level: ");
                            stringBuilder2.append(strLevel);
                            android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder2.toString());
                            if (item.getSubItemList() == null) {
                                android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadFileCacheConfig continue cause null item");
                            } else {
                                android.util.ArraySet<java.lang.String> xmlSet = new android.util.ArraySet();
                                for (android.rms.iaware.AwareConfig.SubItem subitem : item.getSubItemList()) {
                                    if (!(subitem == null || android.text.TextUtils.isEmpty(subitem.getValue()))) {
                                        xmlSet.add(subitem.getValue());
                                    }
                                }
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("loadFileCacheConfig xmlSet=");
                                stringBuilder3.append(xmlSet.toString());
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder3.toString());
                                if ("file".equals(strName)) {
                                    fileCacheMap.put(java.lang.Integer.valueOf(fileCacheLevel), xmlSet);
                                } else if ("package".equals(strName)) {
                                    android.util.ArraySet<java.lang.String> pkgSet = com.android.server.rms.iaware.memory.utils.PackageInfoCollector.getLibFilesFromPackage(this.mContext, xmlSet);
                                    if (pkgSet != null && pkgSet.size() > 0) {
                                        fileCacheMap.put(java.lang.Integer.valueOf(fileCacheLevel + 50), pkgSet);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature", "loadFileCacheConfig continue cause null item");
        }
        com.android.server.rms.iaware.memory.utils.MemoryConstant.setFileCacheMap(fileCacheMap);
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature", "loadFileCacheConfig end");
    }

    private int checkFileCacheLevel(java.lang.String fileCacheLevel) {
        int i = -1;
        if (android.text.TextUtils.isEmpty(fileCacheLevel)) {
            return -1;
        }
        try {
            int level = java.lang.Integer.parseInt(fileCacheLevel.trim());
            if (1 <= level && level <= 3) {
                i = level;
            }
            return i;
        } catch (java.lang.NumberFormatException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("parse filecache index error: ");
            stringBuilder.append(e);
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature", stringBuilder.toString());
            return -1;
        }
    }

    private void saveMemConstantItem(android.rms.iaware.AwareConfig.Item item) {
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if (itemName != null) {
                if (itemValue != null) {
                    java.lang.Object obj = -1;
                    try {
                        switch (itemName.hashCode()) {
                            case -1111598932:
                                if (itemName.equals("reservedZram")) {
                                    obj = 6;
                                    break;
                                }
                                break;
                            case -633324046:
                                if (itemName.equals("emergencyMemory")) {
                                    obj = 2;
                                    break;
                                }
                                break;
                            case -489919045:
                                if (itemName.equals("protect_lru_limit")) {
                                    obj = 10;
                                    break;
                                }
                                break;
                            case -484609525:
                                if (itemName.equals("protect_lru_ratio")) {
                                    obj = 11;
                                    break;
                                }
                                break;
                            case -286045405:
                                if (itemName.equals("swappiness")) {
                                    obj = 7;
                                    break;
                                }
                                break;
                            case -34546488:
                                if (itemName.equals("normalMemory")) {
                                    obj = 5;
                                    break;
                                }
                                break;
                            case 175422052:
                                if (itemName.equals("extra_free_kbytes")) {
                                    obj = 9;
                                    break;
                                }
                                break;
                            case 274770233:
                                if (itemName.equals("direct_swappiness")) {
                                    obj = 8;
                                    break;
                                }
                                break;
                            case 671098540:
                                if (itemName.equals("highCpuLoad")) {
                                    obj = 1;
                                    break;
                                }
                                break;
                            case 745458209:
                                if (itemName.equals("defaultCriticalMemory")) {
                                    obj = 4;
                                    break;
                                }
                                break;
                            case 1078523066:
                                if (itemName.equals("lowCpuLoad")) {
                                    obj = null;
                                    break;
                                }
                                break;
                            case 1403791765:
                                if (itemName.equals("bigMemCriticalMemory")) {
                                    obj = 3;
                                    break;
                                }
                                break;
                            default:
                                break;
                        }
                        java.lang.StringBuilder stringBuilder;
                        int swappiness;
                        java.lang.StringBuilder stringBuilder2;
                        java.lang.String protectLruLimit;
                        switch (obj) {
                            case null:
                            case 1:
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig itemName: ");
                                stringBuilder.append(itemName);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
                                saveMemConstantKillItems(itemName, itemValue);
                                break;
                            case 6:
                                long reservedZram = java.lang.Long.parseLong(itemValue.trim());
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("loadMemConfig reservedZram: ");
                                stringBuilder3.append(reservedZram * 1024);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder3.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setReservedZramSpace(1024 * reservedZram);
                                break;
                            case 7:
                                swappiness = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig swappiness: ");
                                stringBuilder2.append(swappiness);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigSwappiness(swappiness);
                                break;
                            case 8:
                                swappiness = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig directswappiness: ");
                                stringBuilder2.append(swappiness);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigDirectSwappiness(swappiness);
                                break;
                            case 9:
                                swappiness = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig extra_free_kbytes: ");
                                stringBuilder2.append(swappiness);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigExtraFreeKbytes(swappiness);
                                break;
                            case 10:
                                protectLruLimit = itemValue.trim();
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig protect lru limit: ");
                                stringBuilder2.append(protectLruLimit);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigProtectLruLimit(protectLruLimit);
                                break;
                            case 11:
                                swappiness = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig protect lru ratio: ");
                                stringBuilder2.append(swappiness);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigProtectLruRatio(swappiness);
                                break;
                            default:
                                protectLruLimit = "AwareMem_MemFeature";
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig no such configuration. ");
                                stringBuilder.append(itemName);
                                android.rms.iaware.AwareLog.w(protectLruLimit, stringBuilder.toString());
                                break;
                        }
                    } catch (java.lang.NumberFormatException e) {
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "parse memory xml error");
                    }
                }
            }
        }
    }

    private void saveMemConstantKillItems(java.lang.String itemName, java.lang.String itemValue) {
        java.lang.Object obj = -1;
        try {
            switch (itemName.hashCode()) {
                case -633324046:
                    if (itemName.equals("emergencyMemory")) {
                        obj = 2;
                        break;
                    }
                    break;
                case -34546488:
                    if (itemName.equals("normalMemory")) {
                        obj = 5;
                        break;
                    }
                    break;
                case 671098540:
                    if (itemName.equals("highCpuLoad")) {
                        obj = 1;
                        break;
                    }
                    break;
                case 745458209:
                    if (itemName.equals("defaultCriticalMemory")) {
                        obj = 4;
                        break;
                    }
                    break;
                case 1078523066:
                    if (itemName.equals("lowCpuLoad")) {
                        obj = null;
                        break;
                    }
                    break;
                case 1403791765:
                    if (itemName.equals("bigMemCriticalMemory")) {
                        obj = 3;
                        break;
                    }
                    break;
                default:
                    break;
            }
            long lowCpuLoad;
            java.lang.StringBuilder stringBuilder;
            long emergemcyMemory;
            java.lang.StringBuilder stringBuilder2;
            switch (obj) {
                case null:
                    lowCpuLoad = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("loadMemConfig lowCpuLoad: ");
                    stringBuilder.append(lowCpuLoad);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setIdleThresHold(lowCpuLoad);
                    break;
                case 1:
                    lowCpuLoad = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("loadMemConfig highCpuLoad: ");
                    stringBuilder.append(lowCpuLoad);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setNormalThresHold(lowCpuLoad);
                    break;
                case 2:
                    emergemcyMemory = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("loadMemConfig emergemcyMemory: ");
                    stringBuilder2.append(emergemcyMemory * 1024);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setEmergencyMemory(1024 * emergemcyMemory);
                    break;
                case 3:
                    emergemcyMemory = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("loadMemConfig bigMemAppCriticalMemory: ");
                    stringBuilder2.append(emergemcyMemory * 1024);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setBigMemoryAppCriticalMemory(1024 * emergemcyMemory);
                    break;
                case 4:
                    emergemcyMemory = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("loadMemConfig criticalMemory: ");
                    stringBuilder2.append(emergemcyMemory * 1024);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setDefaultCriticalMemory(1024 * emergemcyMemory);
                    break;
                case 5:
                    emergemcyMemory = java.lang.Long.parseLong(itemValue.trim());
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("loadMemConfig normalMemory: ");
                    stringBuilder2.append(emergemcyMemory * 1024);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder2.toString());
                    com.android.server.rms.iaware.memory.utils.MemoryConstant.setIdleMemory(1024 * emergemcyMemory);
                    break;
                default:
                    java.lang.String str = "AwareMem_MemFeature";
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("loadMemConfig no such configuration. ");
                    stringBuilder3.append(itemName);
                    android.rms.iaware.AwareLog.w(str, stringBuilder3.toString());
                    break;
            }
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "parse memory xml error");
        }
    }

    private com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList loadMemPolicyListConfig() {
        java.util.Map<java.lang.String, com.android.server.rms.iaware.memory.policy.MemoryScenePolicy> memoryScenePolicies = new android.util.ArrayMap();
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "Memoryitem", false);
        if (configList == null) {
            return new com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList(createDefaultMemorPolicyList());
        }
        for (android.rms.iaware.AwareConfig.Item item : configList.getConfigList()) {
            if (item.getProperties() != null) {
                java.lang.String scene = (java.lang.String) item.getProperties().get("scene");
                if (scene != null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("add scene: ");
                    stringBuilder.append(scene);
                    android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder.toString());
                    java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> memActions = getActionList(item);
                    if (memActions.size() > 0) {
                        memoryScenePolicies.put(scene, new com.android.server.rms.iaware.memory.policy.MemoryScenePolicy(scene, memActions));
                    }
                }
            }
        }
        return new com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList(memoryScenePolicies);
    }

    private java.util.Map<java.lang.String, com.android.server.rms.iaware.memory.policy.MemoryScenePolicy> createDefaultMemorPolicyList() {
        java.util.Map<java.lang.String, com.android.server.rms.iaware.memory.policy.MemoryScenePolicy> memoryScenePolicies = new android.util.ArrayMap();
        java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> memActions = new java.util.ArrayList();
        memActions.add(new com.android.server.rms.iaware.memory.action.KillAction(this.mContext));
        memoryScenePolicies.put("default", new com.android.server.rms.iaware.memory.policy.MemoryScenePolicy("default", memActions));
        java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> bigMemActions = new java.util.ArrayList();
        bigMemActions.add(new com.android.server.rms.iaware.memory.action.QuickKillAction(this.mContext));
        memoryScenePolicies.put("BigMem", new com.android.server.rms.iaware.memory.policy.MemoryScenePolicy("BigMem", bigMemActions));
        java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> idleActions = new java.util.ArrayList();
        idleActions.add(new com.android.server.rms.iaware.memory.action.ReclaimAction(this.mContext));
        idleActions.add(new com.android.server.rms.iaware.memory.action.GpuCompressAction(this.mContext));
        idleActions.add(new com.android.server.rms.iaware.memory.action.SystemTrimAction(this.mContext));
        memoryScenePolicies.put("idle", new com.android.server.rms.iaware.memory.policy.MemoryScenePolicy("idle", idleActions));
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", "use default memory policy cause reading xml config failure");
        return memoryScenePolicies;
    }

    private java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> getActionList(android.rms.iaware.AwareConfig.Item item) {
        java.util.ArrayList<com.android.server.rms.iaware.memory.action.Action> actions = new java.util.ArrayList();
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            if (subItem.getProperties() != null) {
                com.android.server.rms.iaware.memory.action.Action action;
                java.lang.String actionName = (java.lang.String) subItem.getProperties().get("name");
                java.lang.Object obj = -1;
                switch (actionName.hashCode()) {
                    case 102461:
                        if (actionName.equals("gmc")) {
                            obj = 3;
                            break;
                        }
                        break;
                    case 3291998:
                        if (actionName.equals("kill")) {
                            obj = 1;
                            break;
                        }
                        break;
                    case 643839697:
                        if (actionName.equals("systemtrim")) {
                            obj = 4;
                            break;
                        }
                        break;
                    case 1082491369:
                        if (actionName.equals("reclaim")) {
                            obj = null;
                            break;
                        }
                        break;
                    case 1301455563:
                        if (actionName.equals("quickkill")) {
                            obj = 2;
                            break;
                        }
                        break;
                    default:
                        break;
                }
                switch (obj) {
                    case null:
                        action = new com.android.server.rms.iaware.memory.action.ReclaimAction(this.mContext);
                        break;
                    case 1:
                        action = new com.android.server.rms.iaware.memory.action.KillAction(this.mContext);
                        break;
                    case 2:
                        action = new com.android.server.rms.iaware.memory.action.QuickKillAction(this.mContext);
                        break;
                    case 3:
                        action = new com.android.server.rms.iaware.memory.action.GpuCompressAction(this.mContext);
                        break;
                    case 4:
                        action = new com.android.server.rms.iaware.memory.action.SystemTrimAction(this.mContext);
                        break;
                    default:
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "no such action!");
                        action = null;
                        break;
                }
                if (action != null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("add action: ");
                    stringBuilder.append(actionName);
                    android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder.toString());
                    actions.add(action);
                }
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("getActionList return: ");
        stringBuilder2.append(actions);
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature", stringBuilder2.toString());
        return actions;
    }

    private android.rms.iaware.AwareConfig getConfig(java.lang.String featureName, java.lang.String configName, boolean isCustConfig) {
        android.rms.iaware.AwareConfig configList = null;
        if (!(featureName == null || featureName.equals("") || configName == null)) {
            if (!configName.equals("")) {
                try {
                    android.os.IBinder awareservice = android.rms.iaware.IAwareCMSManager.getICMSManager();
                    if (awareservice == null) {
                        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", "can not find service awareservice.");
                    } else if (isCustConfig) {
                        configList = android.rms.iaware.IAwareCMSManager.getCustConfig(awareservice, featureName, configName);
                    } else {
                        configList = android.rms.iaware.IAwareCMSManager.getConfig(awareservice, featureName, configName);
                    }
                } catch (android.os.RemoteException e) {
                    android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "MemoryFeature getConfig RemoteException");
                }
                return configList;
            }
        }
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", "featureName or configName is null");
        return null;
    }

    private void subscribleEvents() {
        if (this.mIRDataRegister != null) {
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_APP, this.mFeatureType);
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_DEV_STATUS, this.mFeatureType);
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_ON, this.mFeatureType);
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_OFF, this.mFeatureType);
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_INPUT, this.mFeatureType);
            this.mIRDataRegister.subscribeData(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_USERHABIT, this.mFeatureType);
        }
    }

    private void unSubscribeEvents() {
        if (this.mIRDataRegister != null) {
            this.mIRDataRegister.unSubscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_APP, this.mFeatureType);
            this.mIRDataRegister.unSubscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_DEV_STATUS, this.mFeatureType);
            this.mIRDataRegister.unSubscribeData(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_ON, this.mFeatureType);
            this.mIRDataRegister.unSubscribeData(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_OFF, this.mFeatureType);
            this.mIRDataRegister.unSubscribeData(android.rms.iaware.AwareConstant.ResourceType.RES_INPUT, this.mFeatureType);
        }
    }

    private void setBoostKillSwitch(boolean isEnable) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setBoostSigKill switch = ");
        stringBuilder.append(isEnable);
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature", stringBuilder.toString());
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
        buffer.putInt(301);
        buffer.putInt(isEnable);
        android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
    }

    private java.lang.String creatJsonStr() {
        org.json.JSONObject memoryAllocateJson = new org.json.JSONObject();
        org.json.JSONObject memoryControlAndLMKJson = new org.json.JSONObject();
        org.json.JSONObject availMemoryTimeJson = new org.json.JSONObject();
        try {
            memoryAllocateJson.put("memoryAllocCount", java.lang.String.valueOf(this.mBigDataStore.meminfoAllocCount - this.mBigDataStore.meminfoAllocCountStash));
            memoryAllocateJson.put("slowPathAllocCount", java.lang.String.valueOf(this.mBigDataStore.slowPathAllocCount - this.mBigDataStore.slowPathAllocCountStash));
            memoryControlAndLMKJson.put("LMKCount", java.lang.String.valueOf(this.mBigDataStore.lmkOccurCount - this.mBigDataStore.lmkOccurCountStash));
            memoryControlAndLMKJson.put("memoryControlCount", java.lang.String.valueOf(this.mBigDataStore.lowMemoryManageCount));
            availMemoryTimeJson.put("belowThresholdTime", java.lang.String.valueOf(this.mBigDataStore.belowThresholdTime));
            this.mBigDataStore.aboveThresholdTime = (this.mBigDataStore.totalTimeEnd - this.mBigDataStore.totalTimeBegin) - this.mBigDataStore.belowThresholdTime;
            availMemoryTimeJson.put("aboveThresholdTime", java.lang.String.valueOf(this.mBigDataStore.aboveThresholdTime));
        } catch (org.json.JSONException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "JSONException...");
        }
        java.lang.StringBuilder strBuilder = new java.lang.StringBuilder();
        strBuilder.append("[iAwareMemoryRTStatis_Start]\n");
        strBuilder.append("{\n");
        strBuilder.append("\"");
        strBuilder.append("memoryAllocateCount");
        strBuilder.append("\"");
        strBuilder.append(":");
        strBuilder.append(memoryAllocateJson.toString());
        strBuilder.append(",");
        strBuilder.append("\n");
        strBuilder.append("\"");
        strBuilder.append("memoryControlAndLMKCount");
        strBuilder.append("\"");
        strBuilder.append(":");
        strBuilder.append(memoryControlAndLMKJson.toString());
        strBuilder.append(",");
        strBuilder.append("\n");
        strBuilder.append("\"");
        strBuilder.append("availMemoryTimeCount");
        strBuilder.append("\"");
        strBuilder.append(":");
        strBuilder.append(availMemoryTimeJson.toString());
        strBuilder.append(",");
        strBuilder.append("\n");
        strBuilder.append("}\n");
        strBuilder.append("[iAwareMemoryRTStatis_End]");
        return strBuilder.toString();
    }

    private void clearCache() {
        android.rms.iaware.AwareLog.e("AwareMem_MemFeature", "enter clearCache...");
        this.mBigDataStore.lowMemoryManageCount = 0;
        this.mBigDataStore.belowThresholdTime = 0;
        this.mBigDataStore.meminfoAllocCountStash = this.mBigDataStore.meminfoAllocCount;
        this.mBigDataStore.slowPathAllocCountStash = this.mBigDataStore.slowPathAllocCount;
        this.mBigDataStore.lmkOccurCountStash = this.mBigDataStore.lmkOccurCount;
        this.mBigDataStore.aboveThresholdTime = 0;
        this.mBigDataStore.totalTimeBegin = android.os.SystemClock.elapsedRealtime();
        this.mBigDataStore.totalTimeEnd = android.os.SystemClock.elapsedRealtime();
    }
}
