package com.android.server.rms.iaware.feature;

public class MemoryFeature2 extends com.android.server.rms.iaware.feature.RFeature {
    private static final int BASE_VERSION = 2;
    private static final int MAX_CACHED_APPS = android.os.SystemProperties.getInt("ro.sys.fw.bg_apps_limit", 32);
    private static final int MAX_CACHED_APP_SIZE = 512;
    private static final java.lang.String MEMORY_BG_PROCS = "memory_bg_procs";
    private static final java.lang.String MEMORY_COLD_WARM_LAUNCH = "memory_cold_warm_launch";
    private static final java.lang.String MEMORY_MMONITOR = "memory_mmonitor";
    private static final int MIN_CACHED_APP_SIZE = 4;
    private static final java.lang.String TAG = "AwareMem_MemFeature2.0";
    public static final java.util.concurrent.atomic.AtomicBoolean isUpMemoryFeature = new java.util.concurrent.atomic.AtomicBoolean(false);
    private int mEmptyProcessPercent;
    private com.android.server.am.HwActivityManagerService mHwAMS;
    private com.android.server.rms.iaware.memory.utils.MemoryLockFile mLockFile;
    private int mNumProcessLimit;
    private com.android.server.rms.iaware.memory.utils.PrereadUtils mPrereadUtils;
    private long timeStamp;

    public MemoryFeature2(android.content.Context context, android.rms.iaware.AwareConstant.FeatureType featureType, com.android.server.rms.iaware.IRDataRegister dataRegister) {
        super(context, featureType, dataRegister);
        this.mHwAMS = null;
        this.mEmptyProcessPercent = android.os.SystemProperties.getInt("ro.sys.fw.empty_app_percent", 50);
        this.mLockFile = new com.android.server.rms.iaware.memory.utils.MemoryLockFile();
        this.timeStamp = 0;
        this.mHwAMS = com.android.server.am.HwActivityManagerService.self();
        this.mNumProcessLimit = MAX_CACHED_APPS;
        this.mPrereadUtils = com.android.server.rms.iaware.memory.utils.PrereadUtils.getInstance();
        com.android.server.rms.iaware.memory.utils.PrereadUtils.setContext(context);
        loadMemConfig();
    }

    public boolean enable() {
        return false;
    }

    public boolean enableFeatureEx(int realVersion) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("enableFeatureEx realVersion=");
        stringBuilder.append(realVersion);
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder.toString());
        if (realVersion < 2) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("enableFeatureEx failed, realVersion: ");
            stringBuilder2.append(realVersion);
            stringBuilder2.append(", baseVersion: ");
            stringBuilder2.append(2);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder2.toString());
            return false;
        }
        isUpMemoryFeature.set(true);
        if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
            com.android.server.rms.iaware.memory.utils.MemoryUtils.writeMMonitorSwitch(1);
        }
        this.mLockFile.iAwareAddPinFile();
        readMemoryAPIWhiteListUid();
        com.android.server.rms.iaware.memory.utils.PrereadUtils prereadUtils = this.mPrereadUtils;
        com.android.server.rms.iaware.memory.utils.PrereadUtils.start();
        com.android.server.rms.memrepair.ProcStateStatisData.getInstance().setEnable(true);
        setEmptyProcessPercent(this.mEmptyProcessPercent);
        setProcessLimit(this.mNumProcessLimit);
        com.android.server.rms.iaware.memory.policy.SystemTrimPolicy.getInstance().enable();
        return true;
    }

    public boolean disable() {
        isUpMemoryFeature.set(false);
        if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
            com.android.server.rms.iaware.memory.utils.MemoryUtils.writeMMonitorSwitch(0);
        }
        this.mLockFile.clearPinFile();
        com.android.server.rms.iaware.memory.utils.MemoryUtils.destroySocket();
        com.android.server.rms.iaware.memory.utils.PrereadUtils prereadUtils = this.mPrereadUtils;
        com.android.server.rms.iaware.memory.utils.PrereadUtils.stop();
        com.android.server.rms.memrepair.ProcStateStatisData.getInstance().setEnable(false);
        setEmptyProcessPercent(-1);
        setProcessLimit(MAX_CACHED_APPS);
        com.android.server.rms.iaware.memory.policy.SystemTrimPolicy.getInstance().disable();
        return true;
    }

    public boolean reportData(android.rms.iaware.CollectData data) {
        return false;
    }

    public boolean configUpdate() {
        loadMemConfig();
        setProcessLimit(this.mNumProcessLimit);
        this.mLockFile.clearPinFile();
        this.mLockFile.iAwareAddPinFile();
        return true;
    }

    public java.lang.String getBigDataByVersion(int iawareVer, boolean forBeta, boolean clearData) {
        return null;
    }

    public java.lang.String getDFTDataByVersion(int iawareVer, boolean forBeta, boolean clearData, boolean betaEncode) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Memoryfeature2 getDFTDataByVersion. iawareVer: ");
        stringBuilder.append(iawareVer);
        stringBuilder.append(", beta: ");
        stringBuilder.append(forBeta);
        stringBuilder.append(", clear: ");
        stringBuilder.append(clearData);
        stringBuilder.append(";betaEncode=");
        stringBuilder.append(betaEncode);
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
        if (betaEncode && isUpMemoryFeature.get() && iawareVer >= 2) {
            if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
                long timeMillis = java.lang.System.currentTimeMillis();
                java.lang.StringBuilder builder = new java.lang.StringBuilder();
                java.lang.String result = com.android.server.rms.iaware.memory.utils.MemoryReader.getMmonitorData();
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("result=");
                stringBuilder2.append(result);
                android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder2.toString());
                if (result != null) {
                    builder.append("{");
                    builder.append(createHeadMsg("memory_mmonitor", timeMillis));
                    builder.append("\"data\":");
                    builder.append(result);
                    builder.append("}\n");
                }
                result = com.android.server.rms.iaware.memory.utils.BigDataStore.getInstance().getColdWarmLaunchData(clearData);
                if (result != null) {
                    builder.append("{");
                    builder.append(createHeadMsg("memory_cold_warm_launch", timeMillis));
                    builder.append(result);
                    builder.append("}\n");
                }
                builder.append("{");
                builder.append(createHeadMsg("memory_bg_procs", timeMillis));
                builder.append(com.android.server.rms.iaware.memory.utils.BigDataStore.getInstance().getBgAppData(clearData));
                builder.append("}");
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("Memoryfeature2 getBigDataByVersion. result: ");
                stringBuilder2.append(builder.toString());
                android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder2.toString());
                this.timeStamp = timeMillis;
                return builder.toString();
            }
        }
        return null;
    }

    private java.lang.String createHeadMsg(java.lang.String featureName, long endTime) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("\"feature\":\"");
        sb.append(featureName);
        sb.append("\",");
        sb.append("\"start\":");
        sb.append(this.timeStamp > 0 ? this.timeStamp : endTime);
        sb.append(",");
        sb.append("\"end\":");
        sb.append(endTime);
        sb.append(",");
        return sb.toString();
    }

    private void loadMemConfig() {
        loadMemConstantConfig(false);
        loadMemConstantConfig(true);
        loadPrereadConfig();
        loadMemRepairConfig();
        com.android.server.rms.iaware.memory.utils.MemoryConstant.clearPinnedFilesStr();
        loadPinFileConfig();
        com.android.server.rms.iaware.feature.MemoryFeature.loadBigMemAppPolicyConfig(getConfig("Memory", "BigMemApp", true));
        com.android.server.rms.iaware.feature.MemoryFeature.loadBigMemAppPolicyConfig(getConfig("Memory", "ionPropertys", true));
        loadSysTrimConfig();
    }

    private void loadMemConstantConfig(boolean isCustConfig) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loadMemConstantConfig, isCustConfig : ");
        stringBuilder.append(isCustConfig);
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "MemoryConstant", isCustConfig);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemConstantConfig failure cause null configList");
            return;
        }
        com.android.internal.util.MemInfoReader minfo = new com.android.internal.util.MemInfoReader();
        minfo.readMemInfo();
        java.lang.Long totalMemMb = java.lang.Long.valueOf(minfo.getTotalSize() / 1048576);
        for (android.rms.iaware.AwareConfig.Item item : configList.getConfigList()) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.lang.String ramSize = (java.lang.String) item.getProperties().get("ramsize");
                    if (com.android.server.rms.iaware.memory.utils.MemoryUtils.checkRamSize(ramSize, totalMemMb)) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("loadMemConstantConfig success. ramSize: ");
                        stringBuilder2.append(ramSize);
                        stringBuilder2.append(" totalMemMb: ");
                        stringBuilder2.append(totalMemMb);
                        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder2.toString());
                        saveMemConstantItem(item);
                        break;
                    }
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("checkRamSize failure cause ramSize: ");
                    stringBuilder3.append(ramSize);
                    stringBuilder3.append(" totalMemMb: ");
                    stringBuilder3.append(totalMemMb);
                    android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder3.toString());
                }
            }
            android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadMemConstantConfig continue cause null item");
        }
    }

    public void loadPrereadConfig() {
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "PrereadFile", true);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPrereadConfig failure, configList is empty");
            return;
        }
        java.util.Map<java.lang.String, java.util.ArrayList<java.lang.String>> filePathMap = new android.util.ArrayMap();
        for (android.rms.iaware.AwareConfig.Item item : configList.getConfigList()) {
            if (item == null) {
                android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPrereadConfig failure, item is empty");
            } else {
                java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
                if (configPropertries == null) {
                    android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPrereadConfig failure, configPropertries is empty");
                } else {
                    try {
                        if (java.lang.Integer.parseInt((java.lang.String) configPropertries.get("prereadSwitch")) == 0) {
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "prereadSwitch off");
                        } else {
                            java.lang.String pkgName = (java.lang.String) configPropertries.get("pkgname");
                            if (pkgName != null) {
                                java.util.ArrayList<java.lang.String> filePath = new java.util.ArrayList();
                                java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = item.getSubItemList();
                                if (subItemList != null) {
                                    for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
                                        java.lang.String itemName = subItem.getName();
                                        java.lang.String itemValue = subItem.getValue();
                                        if ("file".equals(itemName)) {
                                            filePath.add(itemValue);
                                        }
                                    }
                                    filePathMap.put(pkgName, filePath);
                                }
                            }
                        }
                    } catch (java.lang.NumberFormatException e) {
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "Number Format Error !");
                    }
                }
            }
        }
        com.android.server.rms.iaware.memory.utils.MemoryConstant.setPrereadFileMap(filePathMap);
        this.mPrereadUtils.sendPrereadDataUpdateMsg();
    }

    protected android.rms.iaware.AwareConfig getConfig(java.lang.String featureName, java.lang.String configName, boolean isCustConfig) {
        android.rms.iaware.AwareConfig configList = null;
        if (!(featureName == null || featureName.equals("") || configName == null)) {
            if (!configName.equals("")) {
                try {
                    android.os.IBinder awareservice = android.rms.iaware.IAwareCMSManager.getICMSManager();
                    if (awareservice == null) {
                        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "can not find service awareservice.");
                    } else if (isCustConfig) {
                        configList = android.rms.iaware.IAwareCMSManager.getCustConfig(awareservice, featureName, configName);
                    } else {
                        configList = android.rms.iaware.IAwareCMSManager.getConfig(awareservice, featureName, configName);
                    }
                } catch (android.os.RemoteException e) {
                    android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "MemoryFeature getConfig RemoteException");
                }
                return configList;
            }
        }
        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "featureName or configName is null");
        return null;
    }

    private void saveMemConstantItem(android.rms.iaware.AwareConfig.Item item) {
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if (itemName != null) {
                if (itemValue != null) {
                    java.lang.Object obj = -1;
                    try {
                        switch (itemName.hashCode()) {
                            case -1669721547:
                                if (itemName.equals("prereadOdexSwitch")) {
                                    obj = 5;
                                    break;
                                }
                                break;
                            case -1470603166:
                                if (itemName.equals("systemtrim_switch")) {
                                    obj = null;
                                    break;
                                }
                                break;
                            case -822986700:
                                if (itemName.equals("api_max_req_mem")) {
                                    obj = 6;
                                    break;
                                }
                                break;
                            case -798160691:
                                if (itemName.equals("gpuMemory")) {
                                    obj = 2;
                                    break;
                                }
                                break;
                            case -533820387:
                                if (itemName.equals("numEmptyProcessPercent")) {
                                    obj = 4;
                                    break;
                                }
                                break;
                            case -470167246:
                                if (itemName.equals("numProcessLimit")) {
                                    obj = 3;
                                    break;
                                }
                                break;
                            case 53466486:
                                if (itemName.equals("gmc_switch")) {
                                    obj = 1;
                                    break;
                                }
                                break;
                            default:
                                break;
                        }
                        int systemTrimSwitch;
                        java.lang.StringBuilder stringBuilder;
                        long gpuMemoryLimit;
                        java.lang.StringBuilder stringBuilder2;
                        switch (obj) {
                            case null:
                                systemTrimSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig system app ontrim Switch: ");
                                stringBuilder.append(systemTrimSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigSystemTrimSwitch(systemTrimSwitch);
                                break;
                            case 1:
                                systemTrimSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig gmc Switch: ");
                                stringBuilder.append(systemTrimSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setConfigGmcSwitch(systemTrimSwitch);
                                break;
                            case 2:
                                gpuMemoryLimit = java.lang.Long.parseLong(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig gpuMemoryLimit: ");
                                stringBuilder2.append(gpuMemoryLimit * 1024);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setGpuMemoryLimit(1024 * gpuMemoryLimit);
                                break;
                            case 3:
                                systemTrimSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig numProcessLimit: ");
                                stringBuilder.append(systemTrimSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                                this.mNumProcessLimit = android.os.SystemProperties.getInt("ro.sys.fw.bg_apps_limit", systemTrimSwitch);
                                break;
                            case 4:
                                systemTrimSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig numProcessPercent: ");
                                stringBuilder.append(systemTrimSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                                if (systemTrimSwitch >= 0 && systemTrimSwitch <= 100) {
                                    this.mEmptyProcessPercent = android.os.SystemProperties.getInt("ro.sys.fw.empty_app_percent", systemTrimSwitch);
                                    break;
                                }
                            case 5:
                                systemTrimSwitch = java.lang.Integer.parseInt(itemValue.trim());
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("loadMemConfig preread_odex_switch: ");
                                stringBuilder.append(systemTrimSwitch);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                                com.android.server.rms.iaware.memory.utils.PrereadUtils.getInstance();
                                com.android.server.rms.iaware.memory.utils.PrereadUtils.setPrereadOdexSwitch(systemTrimSwitch);
                                break;
                            case 6:
                                gpuMemoryLimit = java.lang.Long.parseLong(itemValue.trim());
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemConfig max api request memory: ");
                                stringBuilder2.append(gpuMemoryLimit);
                                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder2.toString());
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.setMaxAPIRequestMemory(gpuMemoryLimit);
                                break;
                            default:
                                java.lang.String str = "AwareMem_MemFeature2.0";
                                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                                stringBuilder3.append("loadMemConfig no such configuration. ");
                                stringBuilder3.append(itemName);
                                android.rms.iaware.AwareLog.w(str, stringBuilder3.toString());
                                break;
                        }
                    } catch (java.lang.NumberFormatException e) {
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
                    }
                }
            }
        }
    }

    private void setProcessLimit(int max) {
        if (max >= 4 && max <= 512) {
            if (this.mHwAMS != null) {
                this.mHwAMS.setProcessLimit(max);
            }
        }
    }

    private void setEmptyProcessPercent(int percent) {
        try {
            android.os.SystemProperties.set("sys.iaware.empty_app_percent", java.lang.Integer.toString(percent));
        } catch (java.lang.IllegalArgumentException e) {
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "setEmptyProcessPercent IllegalArgumentException! ");
        }
    }

    private void loadPinFilesItem(android.rms.iaware.AwareConfig.Item item, int mrSize) {
        if (mrSize > 20) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("loadPinFilesItem too long mrSize=");
            stringBuilder.append(mrSize);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return;
        }
        int curIndex = 0;
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            if (curIndex < mrSize) {
                if (subItem != null) {
                    java.lang.String itemName = subItem.getName();
                    java.lang.String itemValue = subItem.getValue();
                    if (!android.text.TextUtils.isEmpty(itemName)) {
                        if (!android.text.TextUtils.isEmpty(itemValue)) {
                            java.lang.Object obj = -1;
                            if (itemName.hashCode() == 3143036) {
                                if (itemName.equals("file")) {
                                    obj = null;
                                }
                            }
                            if (obj != null) {
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadPinFilesItem no such configuration:");
                                stringBuilder2.append(itemName);
                                android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder2.toString());
                                curIndex = mrSize + 1;
                            } else {
                                com.android.server.rms.iaware.memory.utils.MemoryConstant.addPinnedFilesStr(itemValue.trim());
                                curIndex++;
                            }
                        }
                    }
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "loadPinFilesItem null item");
                    break;
                }
            } else {
                curIndex = mrSize + 1;
                break;
            }
        }
    }

    private void loadSysTrimConfig() {
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadSysTrimConfig begin");
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "SystemMemMng", false);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig failure cause null configList");
            return;
        }
        java.util.List<android.rms.iaware.AwareConfig.Item> itemList = configList.getConfigList();
        if (itemList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig failure cause null itemList");
            return;
        }
        for (android.rms.iaware.AwareConfig.Item item : itemList) {
            if (item == null) {
                android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig continue cause null item");
            } else {
                java.util.List<android.rms.iaware.AwareConfig.SubItem> subItems = item.getSubItemList();
                if (subItems == null) {
                    android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig continue cause null subitem");
                } else {
                    for (android.rms.iaware.AwareConfig.SubItem subItem : subItems) {
                        java.util.Map<java.lang.String, java.lang.String> properties = subItem.getProperties();
                        if (properties != null) {
                            java.lang.String packageName = (java.lang.String) properties.get("packageName");
                            java.lang.String threshold = (java.lang.String) properties.get("threshold");
                            if (!android.text.TextUtils.isEmpty(packageName)) {
                                if (!android.text.TextUtils.isEmpty(threshold)) {
                                    try {
                                        long thres = java.lang.Long.parseLong(threshold) * 1024;
                                        if (thres <= 0) {
                                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig continue cause, the threshhold is less than 0");
                                        } else {
                                            com.android.server.rms.iaware.memory.policy.SystemTrimPolicy.getInstance().updateProcThreshold(packageName, thres);
                                        }
                                    } catch (java.lang.NumberFormatException e) {
                                        android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadSysTrimConfig continue cause subitem threshhold is not long");
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadSysTrimConfig end");
    }

    private void loadPinFileConfig() {
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadPinFileConfig begin");
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "PinFile", false);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPinFileConfig failure cause null configList");
            return;
        }
        java.util.List<android.rms.iaware.AwareConfig.Item> itemList = configList.getConfigList();
        if (itemList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPinFileConfig failure cause null itemList");
            return;
        }
        com.android.internal.util.MemInfoReader minfo = new com.android.internal.util.MemInfoReader();
        minfo.readMemInfo();
        java.lang.Long totalMemMb = java.lang.Long.valueOf(minfo.getTotalSize() / 1048576);
        for (android.rms.iaware.AwareConfig.Item item : itemList) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
                    java.lang.String strName = (java.lang.String) configPropertries.get("name");
                    if (android.text.TextUtils.isEmpty(strName)) {
                        android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPinFileConfig failure null item name");
                    } else if (com.android.server.rms.iaware.memory.utils.MemoryUtils.checkRamSize((java.lang.String) configPropertries.get("ramsize"), totalMemMb)) {
                        int size = getSize((java.lang.String) configPropertries.get("size"));
                        if (size < 1) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("loadPinFileConfig continue failure size: ");
                            stringBuilder.append(size);
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder.toString());
                        } else if (item.getSubItemList() == null) {
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPinFileConfig continue cause null subitem");
                        } else if (strName.equals("files")) {
                            loadPinFilesItem(item, size);
                        }
                    } else {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("checkRamSize failure ramSize, totalMemMb: ");
                        stringBuilder2.append(totalMemMb);
                        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder2.toString());
                    }
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadPinFileConfig continue cause null item");
        }
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadPinFileConfig end");
    }

    private void loadMemRepairConfig() {
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadMemRepairConfig begin");
        android.rms.iaware.AwareConfig configList = getConfig("Memory", "memRepair", false);
        if (configList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemRepairConfig failure cause null configList");
            return;
        }
        java.util.List<android.rms.iaware.AwareConfig.Item> itemList = configList.getConfigList();
        if (itemList == null) {
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemRepairConfig failure cause null itemList");
            return;
        }
        com.android.internal.util.MemInfoReader minfo = new com.android.internal.util.MemInfoReader();
        minfo.readMemInfo();
        java.lang.Long totalMemMb = java.lang.Long.valueOf(minfo.getTotalSize() / 1048576);
        for (android.rms.iaware.AwareConfig.Item item : itemList) {
            if (item != null) {
                if (item.getProperties() != null) {
                    java.util.Map<java.lang.String, java.lang.String> configPropertries = item.getProperties();
                    java.lang.String strName = (java.lang.String) configPropertries.get("name");
                    if (android.text.TextUtils.isEmpty(strName)) {
                        android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemRepairConfig failure null item name");
                    } else {
                        int size = getSize((java.lang.String) configPropertries.get("size"));
                        if (size < 1) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("loadMemRepairConfig continue failure size: ");
                            stringBuilder.append(size);
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder.toString());
                        } else if (item.getSubItemList() == null) {
                            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemRepairConfig continue cause null subitem");
                        } else if (strName.equals("base")) {
                            loadMemRepairConstantItem(item, size);
                        } else if (!com.android.server.rms.iaware.memory.utils.MemoryUtils.checkRamSize((java.lang.String) configPropertries.get("ramsize"), totalMemMb)) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("checkRamSize failure ramSize, totalMemMb: ");
                            stringBuilder2.append(totalMemMb);
                            android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", stringBuilder2.toString());
                        } else if (strName.equals("min_max_threshold")) {
                            loadMemRepairMinMaxThresItem(item, size);
                        } else if (strName.equals("proc_emergency_threshold")) {
                            loadMemRepairProcThresItem(totalMemMb.longValue(), item, size);
                        }
                    }
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", "loadMemRepairConfig continue cause null item");
        }
        android.rms.iaware.AwareLog.d("AwareMem_MemFeature2.0", "loadMemRepairConfig end");
    }

    /* JADX WARNING: Removed duplicated region for block: B:42:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00c1  */
    private void loadMemRepairConstantItem(android.rms.iaware.AwareConfig.Item r23, int r24) {
        /*
        r22 = this;
        r0 = r24;
        r1 = 0;
        r2 = 5;
        r2 = new int[r2];
        r2 = {0, 0, 0, 0, 0};
        r3 = 0;
        r4 = 1;
        r5 = 2;
        r6 = 3;
        r7 = 4;
        r8 = 1;
        r9 = r23.getSubItemList();
        r9 = r9.iterator();
    L_0x0017:
        r10 = r9.hasNext();
        if (r10 == 0) goto L_0x00b9;
    L_0x001d:
        r10 = r9.next();
        r10 = (android.rms.iaware.AwareConfig.SubItem) r10;
        if (r1 < r0) goto L_0x002c;
    L_0x0025:
        r1 = r0 + 1;
        r14 = r22;
        goto L_0x00bf;
    L_0x002c:
        if (r10 != 0) goto L_0x002f;
    L_0x002e:
        goto L_0x0017;
    L_0x002f:
        r11 = r10.getName();
        r12 = r10.getValue();
        r13 = android.text.TextUtils.isEmpty(r11);
        if (r13 != 0) goto L_0x00b9;
    L_0x003d:
        r13 = android.text.TextUtils.isEmpty(r12);
        if (r13 == 0) goto L_0x004a;
        r14 = r22;
        r16 = r1;
        goto L_0x00bd;
    L_0x004a:
        r13 = -1;
        r14 = r11.hashCode();
        switch(r14) {
            case -1602877080: goto L_0x007b;
            case -1575767891: goto L_0x0071;
            case -1086546204: goto L_0x0067;
            case -1005530493: goto L_0x005d;
            case 1887307647: goto L_0x0053;
            default: goto L_0x0052;
        };
    L_0x0052:
        goto L_0x0084;
    L_0x0053:
        r14 = "bg_interval";
        r14 = r11.equals(r14);
        if (r14 == 0) goto L_0x0084;
    L_0x005b:
        r13 = 3;
        goto L_0x0084;
    L_0x005d:
        r14 = "fg_interval";
        r14 = r11.equals(r14);
        if (r14 == 0) goto L_0x0084;
    L_0x0065:
        r13 = 2;
        goto L_0x0084;
    L_0x0067:
        r14 = "fg_min_count";
        r14 = r11.equals(r14);
        if (r14 == 0) goto L_0x0084;
    L_0x006f:
        r13 = 0;
        goto L_0x0084;
    L_0x0071:
        r14 = "dvalue_negative_percent";
        r14 = r11.equals(r14);
        if (r14 == 0) goto L_0x0084;
    L_0x0079:
        r13 = 4;
        goto L_0x0084;
    L_0x007b:
        r14 = "bg_min_count";
        r14 = r11.equals(r14);
        if (r14 == 0) goto L_0x0084;
    L_0x0083:
        r13 = 1;
    L_0x0084:
        switch(r13) {
            case 0: goto L_0x00a4;
            case 1: goto L_0x00a4;
            case 2: goto L_0x00a4;
            case 3: goto L_0x00a4;
            case 4: goto L_0x00a4;
            default: goto L_0x0087;
        };
    L_0x0087:
        r14 = r22;
        r13 = "AwareMem_MemFeature2.0";
        r15 = new java.lang.StringBuilder;
        r15.<init>();
        r16 = r1;
        r1 = "loadMemRepairConstantItem no such configuration:";
        r15.append(r1);
        r15.append(r11);
        r1 = r15.toString();
        android.rms.iaware.AwareLog.w(r13, r1);
        r1 = r0 + 1;
        goto L_0x00b7;
    L_0x00a4:
        r13 = r12.trim();
        r14 = r22;
        r8 = r14.saveMemRepairConstantItem(r11, r13, r2);
        if (r8 == 0) goto L_0x00b3;
    L_0x00b0:
        r13 = r1 + 1;
        goto L_0x00b5;
    L_0x00b3:
        r13 = r0 + 1;
    L_0x00b5:
        r1 = r13;
    L_0x00b7:
        goto L_0x0017;
    L_0x00b9:
        r14 = r22;
        r16 = r1;
    L_0x00bd:
        r1 = r16;
    L_0x00bf:
        if (r1 != r0) goto L_0x00f1;
    L_0x00c1:
        if (r8 != 0) goto L_0x00c4;
    L_0x00c3:
        goto L_0x00f1;
    L_0x00c4:
        r9 = 60000; // 0xea60 float:8.4078E-41 double:2.9644E-319;
        r15 = com.android.server.rms.memrepair.ProcStateStatisData.getInstance();
        r16 = r2[r3];
        r17 = r2[r4];
        r11 = r2[r5];
        r11 = (long) r11;
        r18 = r11 * r9;
        r11 = r2[r6];
        r11 = (long) r11;
        r20 = r11 * r9;
        r15.updateConfig(r16, r17, r18, r20);
        r11 = com.android.server.rms.memrepair.MemRepairPolicy.getInstance();
        r12 = r2[r3];
        r13 = r2[r4];
        r11.updateCollectCount(r12, r13);
        r11 = com.android.server.rms.memrepair.MemRepairPolicy.getInstance();
        r12 = r2[r7];
        r11.updateDValueFloatPercent(r12);
        return;
    L_0x00f1:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.iaware.feature.MemoryFeature2.loadMemRepairConstantItem(android.rms.iaware.AwareConfig$Item, int):void");
    }

    private boolean saveMemRepairConstantItem(java.lang.String r10, java.lang.String r11, int[] r12) {
        /*
        r9 = this;
        r0 = 0;
        if (r12 == 0) goto L_0x010d;
    L_0x0003:
        r1 = r12.length;
        r2 = 5;
        if (r1 == r2) goto L_0x0009;
    L_0x0007:
        goto L_0x010d;
    L_0x0009:
        r1 = 0;
        r2 = 1;
        r3 = 2;
        r4 = 3;
        r5 = 4;
        r6 = 1;
        r7 = -1;
        r8 = r10.hashCode();
        switch(r8) {
            case -1602877080: goto L_0x003f;
            case -1575767891: goto L_0x0035;
            case -1086546204: goto L_0x002c;
            case -1005530493: goto L_0x0022;
            case 1887307647: goto L_0x0018;
            default: goto L_0x0017;
        };
    L_0x0017:
        goto L_0x0049;
    L_0x0018:
        r0 = "bg_interval";
        r0 = r10.equals(r0);
        if (r0 == 0) goto L_0x0049;
    L_0x0020:
        r0 = 3;
        goto L_0x004a;
    L_0x0022:
        r0 = "fg_interval";
        r0 = r10.equals(r0);
        if (r0 == 0) goto L_0x0049;
    L_0x002a:
        r0 = 2;
        goto L_0x004a;
    L_0x002c:
        r8 = "fg_min_count";
        r8 = r10.equals(r8);
        if (r8 == 0) goto L_0x0049;
    L_0x0034:
        goto L_0x004a;
    L_0x0035:
        r0 = "dvalue_negative_percent";
        r0 = r10.equals(r0);
        if (r0 == 0) goto L_0x0049;
    L_0x003d:
        r0 = 4;
        goto L_0x004a;
    L_0x003f:
        r0 = "bg_min_count";
        r0 = r10.equals(r0);
        if (r0 == 0) goto L_0x0049;
    L_0x0047:
        r0 = 1;
        goto L_0x004a;
    L_0x0049:
        r0 = r7;
    L_0x004a:
        switch(r0) {
            case 0: goto L_0x00eb;
            case 1: goto L_0x00ca;
            case 2: goto L_0x00a9;
            case 3: goto L_0x0088;
            case 4: goto L_0x0066;
            default: goto L_0x004d;
        };
    L_0x004d:
        r0 = 0;
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem no such configuration:";
        r7.append(r8);
        r7.append(r10);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.w(r6, r7);
        goto L_0x010c;
    L_0x0066:
        r0 = r11.trim();
        r0 = r9.parseConstDValuePercent(r0, r12, r5);
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem percent:";
        r7.append(r8);
        r8 = r12[r5];
        r7.append(r8);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.i(r6, r7);
        goto L_0x010c;
    L_0x0088:
        r0 = r11.trim();
        r0 = r9.parseConstInterval(r0, r12, r4);
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem bg interval:";
        r7.append(r8);
        r8 = r12[r4];
        r7.append(r8);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.i(r6, r7);
        goto L_0x010c;
    L_0x00a9:
        r0 = r11.trim();
        r0 = r9.parseConstInterval(r0, r12, r3);
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem fg interval:";
        r7.append(r8);
        r8 = r12[r3];
        r7.append(r8);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.i(r6, r7);
        goto L_0x010c;
    L_0x00ca:
        r0 = r11.trim();
        r0 = r9.parseConstMinCount(r0, r12, r2);
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem minCount:";
        r7.append(r8);
        r8 = r12[r2];
        r7.append(r8);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.i(r6, r7);
        goto L_0x010c;
    L_0x00eb:
        r0 = r11.trim();
        r0 = r9.parseConstMinCount(r0, r12, r1);
        r6 = "AwareMem_MemFeature2.0";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "saveMemRepairConstantItem minCount:";
        r7.append(r8);
        r8 = r12[r1];
        r7.append(r8);
        r7 = r7.toString();
        android.rms.iaware.AwareLog.i(r6, r7);
    L_0x010c:
        return r0;
    L_0x010d:
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.iaware.feature.MemoryFeature2.saveMemRepairConstantItem(java.lang.String, java.lang.String, int[]):boolean");
    }

    private boolean parseConstMinCount(java.lang.String itemValue, int[] constValues, int index) {
        try {
            int minCount = java.lang.Integer.parseInt(itemValue.trim());
            if (minCount >= 6) {
                if (minCount <= 50) {
                    constValues[index] = minCount;
                    return true;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error minCount:");
            stringBuilder.append(minCount);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
            return false;
        }
    }

    private boolean parseConstInterval(java.lang.String itemValue, int[] constValues, int index) {
        try {
            int interval = java.lang.Integer.parseInt(itemValue.trim());
            if (interval >= 2) {
                if (interval <= 30) {
                    constValues[index] = interval;
                    return true;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error interval:");
            stringBuilder.append(interval);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
            return false;
        }
    }

    private boolean parseConstDValuePercent(java.lang.String itemValue, int[] constValues, int index) {
        try {
            int percent = java.lang.Integer.parseInt(itemValue.trim());
            if (percent >= 1) {
                if (percent <= 30) {
                    constValues[index] = percent;
                    return true;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error percent:");
            stringBuilder.append(percent);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
            return false;
        }
    }

    private void loadMemRepairMinMaxThresItem(android.rms.iaware.AwareConfig.Item item, int mrSize) {
        if (mrSize > 20) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("loadMemRepairMinMaxThresItem too long mrSize=");
            stringBuilder.append(mrSize);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return;
        }
        long[][] memThresHolds = (long[][]) java.lang.reflect.Array.newInstance(long.class, new int[]{mrSize, 3});
        int index = 0;
        for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
            if (index < mrSize) {
                if (subItem != null) {
                    java.lang.String itemName = subItem.getName();
                    java.lang.String itemValue = subItem.getValue();
                    if (!android.text.TextUtils.isEmpty(itemName)) {
                        if (!android.text.TextUtils.isEmpty(itemValue)) {
                            java.lang.Object obj = -1;
                            if (itemName.hashCode() == -1545477013) {
                                if (itemName.equals("threshold")) {
                                    obj = null;
                                }
                            }
                            if (obj != null) {
                                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("loadMemRepairMinMaxThresItem no such configuration:");
                                stringBuilder2.append(itemName);
                                android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder2.toString());
                                index = mrSize + 1;
                            } else if (parseMinMaxThres(itemValue.trim(), memThresHolds[index])) {
                                index++;
                            } else {
                                index = mrSize + 1;
                            }
                        }
                    }
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "loadMemRepairMinMaxThresItem null item");
                    break;
                }
            } else {
                index = mrSize + 1;
                break;
            }
        }
        if (index == mrSize) {
            com.android.server.rms.memrepair.MemRepairPolicy.getInstance().updateFloatThresHold(memThresHolds);
        }
    }

    private boolean parseMinMaxThres(java.lang.String itemValue, long[] memThresHolds) {
        try {
            try {
                java.lang.String[] sets = itemValue.split(";");
                if (sets.length != 3) {
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "error split item");
                    return false;
                }
                long minFloatThres = java.lang.Long.parseLong(sets[0].trim());
                long maxFloatThres = java.lang.Long.parseLong(sets[1].trim());
                long percentage = java.lang.Long.parseLong(sets[2].trim());
                if (minFloatThres >= 0 && maxFloatThres >= 0 && minFloatThres < maxFloatThres) {
                    if (percentage >= 1) {
                        memThresHolds[0] = minFloatThres * 1024;
                        memThresHolds[1] = 1024 * maxFloatThres;
                        memThresHolds[2] = percentage;
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("mem minthres:");
                        stringBuilder.append(minFloatThres);
                        stringBuilder.append(",maxthres:");
                        stringBuilder.append(maxFloatThres);
                        stringBuilder.append(",percent:");
                        stringBuilder.append(percentage);
                        android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                        return true;
                    }
                }
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("error minthres:");
                stringBuilder2.append(minFloatThres);
                stringBuilder2.append(",maxthres:");
                stringBuilder2.append(maxFloatThres);
                stringBuilder2.append(",percent:");
                stringBuilder2.append(percentage);
                android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder2.toString());
                return false;
            } catch (java.lang.NumberFormatException e) {
                android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
                return false;
            }
        } catch (java.lang.NumberFormatException e2) {
            java.lang.String str = itemValue;
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
            return false;
        }
    }

    private void loadMemRepairProcThresItem(long totalMemMb, android.rms.iaware.AwareConfig.Item item, int itemSize) {
        int i = itemSize;
        if (i == 2) {
            long[][] thresHolds = (long[][]) java.lang.reflect.Array.newInstance(long.class, new int[]{1, 2});
            int index = 0;
            for (android.rms.iaware.AwareConfig.SubItem subItem : item.getSubItemList()) {
                if (index >= i) {
                    index = i + 1;
                } else if (subItem != null) {
                    java.lang.String itemName = subItem.getName();
                    java.lang.String itemValue = subItem.getValue();
                    if (!android.text.TextUtils.isEmpty(itemName)) {
                        if (!android.text.TextUtils.isEmpty(itemValue)) {
                            boolean finded = true;
                            int findIndex = 0;
                            int i2 = -1;
                            int hashCode = itemName.hashCode();
                            if (hashCode != -1332194002) {
                                if (hashCode == 1984457027) {
                                    if (itemName.equals("foreground")) {
                                        i2 = 0;
                                    }
                                }
                            } else if (itemName.equals("background")) {
                                i2 = 1;
                            }
                            switch (i2) {
                                case 0:
                                    findIndex = 0;
                                    break;
                                case 1:
                                    findIndex = 1;
                                    break;
                                default:
                                    finded = false;
                                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                    stringBuilder.append("loadMemRepairProcThresItem no such configuration:");
                                    stringBuilder.append(itemName);
                                    android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder.toString());
                                    index = i + 1;
                                    break;
                            }
                            int index2 = index;
                            index = findIndex;
                            if (finded) {
                                if (parseProcThres(itemValue.trim(), thresHolds[0], index, totalMemMb)) {
                                    index2++;
                                } else {
                                    index = i + 1;
                                }
                            }
                            index = index2;
                        }
                    }
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", "loadMemRepairProcThresItem null item");
                }
                if (index == i && thresHolds[0][0] > thresHolds[0][1]) {
                    com.android.server.rms.memrepair.MemRepairPolicy.getInstance().updateProcThresHold(thresHolds);
                }
            }
            com.android.server.rms.memrepair.MemRepairPolicy.getInstance().updateProcThresHold(thresHolds);
        }
    }

    private boolean parseProcThres(java.lang.String itemValue, long[] thresHolds, int index, long totalMemMb) {
        try {
            java.lang.StringBuilder stringBuilder;
            long thres = java.lang.Long.parseLong(itemValue.trim());
            if (thres >= 1) {
                if (thres < totalMemMb) {
                    thresHolds[index] = 1024 * thres;
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("process threshold:");
                    stringBuilder.append(thres);
                    android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
                    return true;
                }
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error process threshold:");
            stringBuilder.append(thres);
            android.rms.iaware.AwareLog.i("AwareMem_MemFeature2.0", stringBuilder.toString());
            return false;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse memory xml error");
            return false;
        }
    }

    private int getSize(java.lang.String strSize) {
        if (strSize == null) {
            return 0;
        }
        try {
            int iSize = java.lang.Integer.parseInt(strSize.trim());
            if (iSize >= 1) {
                return iSize;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("loadMemRepairMinMaxThresItem error size:");
            stringBuilder.append(iSize);
            android.rms.iaware.AwareLog.w("AwareMem_MemFeature2.0", stringBuilder.toString());
            return 0;
        } catch (java.lang.NumberFormatException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "parse size error");
            return 0;
        }
    }

    private void readMemoryAPIWhiteListUid() {
        java.lang.String cameraPackagename = "com.huawei.camera";
        com.android.server.mtm.MultiTaskManagerService mMtmService = com.android.server.mtm.MultiTaskManagerService.self();
        if (mMtmService != null) {
            android.content.Context mcontext = mMtmService.context();
            if (mcontext != null) {
                android.content.pm.PackageManager pm = mcontext.getPackageManager();
                if (pm != null) {
                    try {
                        android.content.pm.ApplicationInfo appInfo = pm.getApplicationInfo(cameraPackagename, 1);
                        if (appInfo != null && appInfo.uid > 0) {
                            com.android.server.rms.iaware.memory.utils.MemoryConstant.setSysCameraUid(appInfo.uid);
                        }
                    } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                        android.rms.iaware.AwareLog.e("AwareMem_MemFeature2.0", "can not get uid");
                    }
                }
            }
        }
    }
}
