package com.android.server.rms.iaware.feature;

public class StartWindowFeature extends com.android.server.rms.iaware.feature.RFeature {
    private static final int FEATURE_MIN_VERSION = 3;
    private static final java.lang.String TAG = "StartWindowFeature";
    private static final int UNKNOW_CHARGING = 0;
    private static boolean mFeature = false;
    private static final boolean mIgnoreUsbState = android.os.SystemProperties.getBoolean("persist.sys.aware.ignore.usb", false);
    private static boolean mIsCharging = false;
    private static final boolean mStartWindowEnabled = android.os.SystemProperties.getBoolean("persist.sys.aware.stwin.enable", true);
    private static boolean mUsbConnected = false;
    private android.content.BroadcastReceiver mReceiver = new com.android.server.rms.iaware.feature.StartWindowFeature.StartWindowBroadcastReceiver();

    private static class StartWindowBroadcastReceiver extends android.content.BroadcastReceiver {
        private StartWindowBroadcastReceiver() {
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                java.lang.String action = intent.getAction();
                java.lang.StringBuilder stringBuilder;
                java.lang.StringBuilder stringBuilder2;
                if ("android.hardware.usb.action.USB_STATE".equals(action)) {
                    boolean usbConnected = intent.getBooleanExtra("connected", false);
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(" receiver for  ");
                    stringBuilder.append(action);
                    stringBuilder.append("  usbConnected ");
                    stringBuilder.append(usbConnected);
                    android.rms.iaware.AwareLog.d("StartWindowFeature", stringBuilder.toString());
                    if (usbConnected != com.android.server.rms.iaware.feature.StartWindowFeature.mUsbConnected) {
                        com.android.server.rms.iaware.feature.StartWindowFeature.mUsbConnected = usbConnected;
                    }
                    com.android.server.rms.iaware.feature.StartWindowFeature.precessPowerDisconnected();
                } else if ("android.intent.action.ACTION_POWER_CONNECTED".equals(action)) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(" receiver for  ");
                    stringBuilder2.append(action);
                    android.rms.iaware.AwareLog.d("StartWindowFeature", stringBuilder2.toString());
                    if (!com.android.server.rms.iaware.feature.StartWindowFeature.mIsCharging) {
                        com.android.server.rms.iaware.feature.StartWindowFeature.mIsCharging = true;
                    }
                } else if ("android.intent.action.ACTION_POWER_DISCONNECTED".equals(action)) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append(" receiver for  ");
                    stringBuilder2.append(action);
                    android.rms.iaware.AwareLog.d("StartWindowFeature", stringBuilder2.toString());
                    com.android.server.rms.iaware.feature.StartWindowFeature.precessPowerDisconnected();
                } else if ("android.intent.action.BATTERY_CHANGED".equals(action)) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append(" receiver for  ");
                    stringBuilder3.append(action);
                    android.rms.iaware.AwareLog.d("StartWindowFeature", stringBuilder3.toString());
                    int plugedtype = intent.getIntExtra("plugged", 0);
                    if (!(com.android.server.rms.iaware.feature.StartWindowFeature.mIsCharging || plugedtype == 0)) {
                        com.android.server.rms.iaware.feature.StartWindowFeature.mIsCharging = true;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("power connected battery charging plugged type: ");
                        stringBuilder.append(plugedtype);
                        android.rms.iaware.AwareLog.d("StartWindowFeature", stringBuilder.toString());
                    }
                }
            }
        }
    }

    public StartWindowFeature(android.content.Context context, android.rms.iaware.AwareConstant.FeatureType featureType, com.android.server.rms.iaware.IRDataRegister dataRegister) {
        super(context, featureType, dataRegister);
    }

    public boolean enable() {
        android.rms.iaware.AwareLog.i("StartWindowFeature", "StartWindowFeature is a iaware3.0 feature, don't allow enable!");
        return false;
    }

    public boolean enableFeatureEx(int realVersion) {
        java.lang.StringBuilder stringBuilder;
        if (realVersion < 3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("the min version of StartWindowFeature is 3, but current version is ");
            stringBuilder.append(realVersion);
            stringBuilder.append(", don't allow enable!");
            android.rms.iaware.AwareLog.i("StartWindowFeature", stringBuilder.toString());
            return false;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("StartWindowFeature enabled, mFeature=");
        stringBuilder.append(mFeature);
        android.rms.iaware.AwareLog.i("StartWindowFeature", stringBuilder.toString());
        if (!mFeature) {
            registerReceiver();
        }
        setEnable(true);
        updateUsbState();
        return true;
    }

    public boolean disable() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("StartWindowFeature disabled, mFeature=");
        stringBuilder.append(mFeature);
        android.rms.iaware.AwareLog.i("StartWindowFeature", stringBuilder.toString());
        if (mFeature) {
            unregisterReceiver();
        }
        setEnable(false);
        updateUsbState();
        return true;
    }

    public boolean reportData(android.rms.iaware.CollectData data) {
        return false;
    }

    private void registerReceiver() {
        if (!(this.mContext == null || mIgnoreUsbState)) {
            android.content.IntentFilter usbFilter = new android.content.IntentFilter();
            usbFilter.addAction("android.hardware.usb.action.USB_STATE");
            usbFilter.addAction("android.intent.action.BATTERY_CHANGED");
            usbFilter.addAction("android.intent.action.ACTION_POWER_CONNECTED");
            usbFilter.addAction("android.intent.action.ACTION_POWER_DISCONNECTED");
            this.mContext.registerReceiver(this.mReceiver, usbFilter);
        }
    }

    private void unregisterReceiver() {
        if (this.mContext != null) {
            this.mContext.unregisterReceiver(this.mReceiver);
        }
    }

    private static void precessPowerDisconnected() {
        if (mIsCharging && !mUsbConnected) {
            mIsCharging = false;
        }
    }

    private void updateUsbState() {
        boolean z = false;
        if (mIgnoreUsbState) {
            mUsbConnected = false;
        } else if (this.mContext != null) {
            android.content.Intent batteryStatusIntent = this.mContext.registerReceiver(null, new android.content.IntentFilter("android.intent.action.BATTERY_CHANGED"));
            if (batteryStatusIntent != null) {
                int plugedtype = batteryStatusIntent.getIntExtra("plugged", 0);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("ACTION_BATTERY_CHANGED plugedtype=");
                stringBuilder.append(plugedtype);
                android.rms.iaware.AwareLog.i("StartWindowFeature", stringBuilder.toString());
                if (plugedtype != 0) {
                    z = true;
                }
                mIsCharging = z;
            }
        }
    }

    private static void setEnable(boolean enable) {
        mFeature = enable;
    }

    public static boolean isStartWindowEnable() {
        return mFeature && mStartWindowEnabled && !mIsCharging;
    }
}
