package com.android.server.rms.iaware.feature;

public class VsyncFeature extends com.android.server.rms.iaware.feature.RFeature {
    private static final int BASE_VERSION = 2;
    private static final java.lang.String CONFIG_SUBSWITCH = "sub_switch";
    private static final int DEAULT_SWITCH_ON = 1;
    private static final java.lang.String FEATURE_SUBSWITCH = "VsyncFirst";
    private static final java.lang.String ITEM_PROP_TYPE = "type";
    private static final java.lang.String ITEM_TYPE_SWITCH = "switch";
    private static final java.lang.String SWITCH_NAME = "vsync_first";
    private static final java.lang.String TAG = "VsyncFeature";

    public VsyncFeature(android.content.Context context, android.rms.iaware.AwareConstant.FeatureType type, com.android.server.rms.iaware.IRDataRegister dataRegister) {
        super(context, type, dataRegister);
    }

    public boolean isCustEnable() {
        android.rms.iaware.AwareConfig.Item item = getSwitchConfig(getAwareCustConfig("VsyncFirst", "sub_switch"));
        boolean z = true;
        if (item == null) {
            return true;
        }
        if (getSwitchValue(item) != 1) {
            z = false;
        }
        return z;
    }

    private android.rms.iaware.AwareConfig getAwareCustConfig(java.lang.String feature, java.lang.String config) {
        android.rms.iaware.AwareConfig custConfig = null;
        try {
            android.os.IBinder awareservice = android.rms.iaware.IAwareCMSManager.getICMSManager();
            if (awareservice != null) {
                custConfig = android.rms.iaware.IAwareCMSManager.getCustConfig(awareservice, feature, config);
            }
        } catch (android.os.RemoteException e) {
            android.rms.iaware.AwareLog.e("VsyncFeature", "getAwareCustConfig RemoteException");
        }
        return custConfig;
    }

    private android.rms.iaware.AwareConfig.Item getSwitchConfig(android.rms.iaware.AwareConfig config) {
        if (config == null) {
            android.rms.iaware.AwareLog.i("VsyncFeature", "the cust config file is null");
            return null;
        }
        java.util.List<android.rms.iaware.AwareConfig.Item> itemList = config.getConfigList();
        if (itemList == null) {
            return null;
        }
        for (android.rms.iaware.AwareConfig.Item item : itemList) {
            java.util.Map<java.lang.String, java.lang.String> properties = item.getProperties();
            if (properties != null) {
                if ("switch".equals((java.lang.String) properties.get("type"))) {
                    return item;
                }
            }
        }
        return null;
    }

    private int getSwitchValue(android.rms.iaware.AwareConfig.Item item) {
        int result = 1;
        if (item == null) {
            return 1;
        }
        java.util.List<android.rms.iaware.AwareConfig.SubItem> subItemList = item.getSubItemList();
        if (subItemList == null) {
            return 1;
        }
        for (android.rms.iaware.AwareConfig.SubItem subItem : subItemList) {
            java.lang.String itemName = subItem.getName();
            java.lang.String itemValue = subItem.getValue();
            if ("vsync_first".equals(itemName)) {
                try {
                    result = java.lang.Integer.parseInt(itemValue);
                } catch (java.lang.NumberFormatException e) {
                    android.rms.iaware.AwareLog.e("VsyncFeature", "parse Int failed");
                }
            }
        }
        return result;
    }

    public boolean reportData(android.rms.iaware.CollectData data) {
        return false;
    }

    public boolean enable() {
        android.rms.iaware.AwareLog.i("VsyncFeature", "enable failed! feature based on IAware2.0, enable() method should not be called!");
        return false;
    }

    public boolean disable() {
        android.rms.iaware.AwareLog.i("VsyncFeature", "disable iaware vsyncfirst feature!");
        android.os.SystemProperties.set("persist.sys.iaware.vsyncfirst", "false");
        return true;
    }

    public boolean enableFeatureEx(int realVersion) {
        java.lang.StringBuilder stringBuilder;
        if (realVersion < 2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("enableFeatureEx failed, realVersion: ");
            stringBuilder.append(realVersion);
            stringBuilder.append(", vsyncfirst baseVersion: ");
            stringBuilder.append(2);
            android.rms.iaware.AwareLog.i("VsyncFeature", stringBuilder.toString());
            return false;
        }
        android.rms.iaware.AwareLog.i("VsyncFeature", "enableFeatureEx iaware vsyncfirst feature!");
        boolean custValue = isCustEnable();
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("enableFeatureEx custValue:");
        stringBuilder.append(custValue);
        android.rms.iaware.AwareLog.i("VsyncFeature", stringBuilder.toString());
        if (custValue) {
            android.os.SystemProperties.set("persist.sys.iaware.vsyncfirst", "true");
        } else {
            android.os.SystemProperties.set("persist.sys.iaware.vsyncfirst", "false");
        }
        return true;
    }
}
