package com.android.server.rms.iaware.hiber.listener;

public final class ReportDataDispatch {
    private static final java.lang.String TAG = "AppHiber_ReportDataDispatch";
    private static com.android.server.rms.iaware.hiber.listener.ReportDataDispatch mReportDataDispatch = null;
    private com.android.server.rms.iaware.hiber.listener.ResAppHandler mResAppDataHandler = com.android.server.rms.iaware.hiber.listener.ResAppHandler.getInstance();
    private com.android.server.rms.iaware.hiber.listener.ResInputHandler mResInputHandler = com.android.server.rms.iaware.hiber.listener.ResInputHandler.getInstance();
    private final java.util.concurrent.atomic.AtomicBoolean mRunning = new java.util.concurrent.atomic.AtomicBoolean(false);
    private com.android.server.rms.iaware.hiber.listener.DevStatusHandler msDevStatusHandler = com.android.server.rms.iaware.hiber.listener.DevStatusHandler.getInstance();

    private ReportDataDispatch() {
    }

    public static synchronized com.android.server.rms.iaware.hiber.listener.ReportDataDispatch getInstance() {
        com.android.server.rms.iaware.hiber.listener.ReportDataDispatch reportDataDispatch;
        synchronized (com.android.server.rms.iaware.hiber.listener.ReportDataDispatch.class) {
            if (mReportDataDispatch == null) {
                mReportDataDispatch = new com.android.server.rms.iaware.hiber.listener.ReportDataDispatch();
            }
            reportDataDispatch = mReportDataDispatch;
        }
        return reportDataDispatch;
    }

    public void start() {
        if (mReportDataDispatch == null) {
            android.rms.iaware.AwareLog.w("AppHiber_ReportDataDispatch", "ReportDataDispatch is only permitted for system user");
            return;
        }
        android.rms.iaware.AwareLog.d("AppHiber_ReportDataDispatch", "start");
        this.mRunning.set(true);
    }

    public void stop() {
        if (mReportDataDispatch == null) {
            android.rms.iaware.AwareLog.w("AppHiber_ReportDataDispatch", "ReportDataDispatch is only permitted for system user");
            return;
        }
        android.rms.iaware.AwareLog.d("AppHiber_ReportDataDispatch", "stop");
        this.mRunning.set(false);
    }

    public int reportData(android.rms.iaware.CollectData data) {
        if (data == null) {
            android.rms.iaware.AwareLog.e("AppHiber_ReportDataDispatch", "data is null, invalid");
            return -1;
        } else if (this.mRunning.get()) {
            long timestamp = data.getTimeStamp();
            android.rms.iaware.AwareConstant.ResourceType type = android.rms.iaware.AwareConstant.ResourceType.getResourceType(data.getResId());
            if (type != android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_ON) {
                if (type != android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_OFF) {
                    if (type != android.rms.iaware.AwareConstant.ResourceType.RES_APP) {
                        if (type != android.rms.iaware.AwareConstant.ResourceType.RES_INPUT) {
                            android.rms.iaware.AwareLog.w("AppHiber_ReportDataDispatch", "Invalid ResourceType");
                            return -1;
                        }
                    }
                    java.lang.String eventData = data.getData();
                    com.android.server.rms.iaware.memory.data.content.AttrSegments.Builder builder = new com.android.server.rms.iaware.memory.data.content.AttrSegments.Builder();
                    builder.addCollectData(eventData);
                    com.android.server.rms.iaware.memory.data.content.AttrSegments attrSegments = builder.build();
                    if (!attrSegments.isValid()) {
                        android.rms.iaware.AwareLog.e("AppHiber_ReportDataDispatch", "Invalid collectData, or event");
                        return -1;
                    } else if (android.rms.iaware.AwareConstant.ResourceType.RES_APP == type) {
                        return this.mResAppDataHandler.reportData(timestamp, attrSegments.getEvent().intValue(), attrSegments);
                    } else {
                        return this.mResInputHandler.reportData(timestamp, attrSegments.getEvent().intValue(), attrSegments);
                    }
                }
            }
            int state = 20011;
            if (android.rms.iaware.AwareConstant.ResourceType.RESOURCE_SCREEN_OFF == type) {
                state = 90011;
            }
            return this.msDevStatusHandler.reportData(timestamp, state, null);
        } else {
            android.rms.iaware.AwareLog.e("AppHiber_ReportDataDispatch", "dispatch not start");
            return -1;
        }
    }
}
