package com.android.server.rms.iaware.memory.action;

public class SystemTrimAction extends com.android.server.rms.iaware.memory.action.Action {
    private static final long DEFAULT_APP_INTERVAL = 1800000;
    private static final long DEFAULT_PROCESS_INTERVAL = 3000;
    private static final int MSG_SEND_BROADCAST = 101;
    private static final java.lang.String TAG = "AwareMem_SystemTrimAction";
    private static final java.util.Map<java.lang.String, java.lang.Long> mPackageNames = new android.util.ArrayMap();
    private static final java.util.List<com.android.server.mtm.taskstatus.ProcessInfo> mProcessInfos = new java.util.ArrayList();
    private com.android.server.am.HwActivityManagerService mHwAMS;
    private android.os.Handler mSystemTrimHandler;

    private class SystemTrimHandler extends android.os.Handler {
        public SystemTrimHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            super.handleMessage(msg);
            if (msg.what == 101) {
                com.android.server.rms.iaware.memory.action.SystemTrimAction.this.doTrim();
            }
        }
    }

    public SystemTrimAction(android.content.Context context) {
        super(context);
        this.mSystemTrimHandler = null;
        this.mHwAMS = com.android.server.am.HwActivityManagerService.self();
        this.mSystemTrimHandler = new com.android.server.rms.iaware.memory.action.SystemTrimAction.SystemTrimHandler(com.android.internal.os.BackgroundThread.get().getLooper());
    }

    public int execute(android.os.Bundle extras) {
        if (extras == null) {
            android.rms.iaware.AwareLog.w("AwareMem_SystemTrimAction", "system memory action for extras null");
            return -1;
        } else if (com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigSystemTrimSwitch() == 0) {
            android.rms.iaware.AwareLog.d("AwareMem_SystemTrimAction", "system trim function is close");
            return -1;
        } else if (android.rms.iaware.DeviceInfo.getDeviceLevel() <= 1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("system trim function can be excuted on middle or low level, level=");
            stringBuilder.append(android.rms.iaware.DeviceInfo.getDeviceLevel());
            android.rms.iaware.AwareLog.d("AwareMem_SystemTrimAction", stringBuilder.toString());
            return -1;
        } else {
            long start = android.os.SystemClock.elapsedRealtime();
            java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> procsGroups = com.android.server.rms.iaware.memory.utils.MemoryUtils.getAppMngSortPolicyForSystemTrim();
            if (procsGroups == null) {
                android.rms.iaware.AwareLog.w("AwareMem_SystemTrimAction", "getAppMngSortPolicyForSystemTrim is null!");
                return -1;
            }
            java.util.Set<com.android.server.mtm.taskstatus.ProcessInfo> procInfos = com.android.server.rms.iaware.memory.policy.SystemTrimPolicy.getInstance().getProcNeedTrim(procsGroups);
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("generic system memory cost time:");
            stringBuilder2.append(android.os.SystemClock.elapsedRealtime() - start);
            android.rms.iaware.AwareLog.d("AwareMem_SystemTrimAction", stringBuilder2.toString());
            if (procInfos != null) {
                if (!procInfos.isEmpty()) {
                    synchronized (mProcessInfos) {
                        if (mProcessInfos.isEmpty()) {
                            addProcToListForTrim(procInfos);
                            this.mSystemTrimHandler.sendEmptyMessage(101);
                            return 0;
                        }
                        android.rms.iaware.AwareLog.w("AwareMem_SystemTrimAction", "is on trimming now, ignore this");
                        return -1;
                    }
                }
            }
            android.rms.iaware.AwareLog.d("AwareMem_SystemTrimAction", "no proc need to trim");
            return -1;
        }
    }

    public void reset() {
        synchronized (mProcessInfos) {
            mProcessInfos.clear();
        }
    }

    private void addProcToListForTrim(java.util.Set<com.android.server.mtm.taskstatus.ProcessInfo> procInfos) {
        for (com.android.server.mtm.taskstatus.ProcessInfo proc : procInfos) {
            if (!(proc == null || proc.mPackageName == null)) {
                if (!proc.mPackageName.isEmpty()) {
                    java.lang.String packageName = (java.lang.String) proc.mPackageName.get(0);
                    if (mPackageNames.containsKey(packageName)) {
                        if (android.os.SystemClock.elapsedRealtime() - ((java.lang.Long) mPackageNames.get(packageName)).longValue() > 1800000) {
                            mProcessInfos.add(proc);
                        }
                    } else {
                        mProcessInfos.add(proc);
                    }
                }
            }
        }
    }

    private void doTrim() {
        synchronized (mProcessInfos) {
            if (mProcessInfos.isEmpty()) {
                return;
            }
            com.android.server.mtm.taskstatus.ProcessInfo processInfo = (com.android.server.mtm.taskstatus.ProcessInfo) mProcessInfos.remove(0);
            com.android.server.rms.iaware.memory.utils.MemoryUtils.trimMemory(this.mHwAMS, java.lang.String.valueOf(processInfo.mPid), android.os.UserHandle.getUserId(processInfo.mUid), 15, false);
            mPackageNames.put((java.lang.String) processInfo.mPackageName.get(0), java.lang.Long.valueOf(android.os.SystemClock.elapsedRealtime()));
            if (mProcessInfos.isEmpty()) {
                return;
            }
            this.mSystemTrimHandler.sendEmptyMessageDelayed(101, 3000);
        }
    }
}
