package com.android.server.rms.iaware.memory.policy;

public class AbsMemoryExecutor {
    private static final java.lang.String TAG = "AwareMem_AbsMemExec";
    com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.IAwareMemState mMemState = new com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.IAwareMemState();
    java.util.concurrent.atomic.AtomicBoolean mStopAction = new java.util.concurrent.atomic.AtomicBoolean(false);

    protected final class CalcRunnable implements java.lang.Runnable {
        private final boolean mLaunchBigMemApp;
        private final com.android.server.rms.iaware.memory.policy.MemoryScenePolicy mMemoryScenePolicy;

        CalcRunnable(com.android.server.rms.iaware.memory.policy.MemoryScenePolicy memoryScenePolicy, boolean launchBigMemApp) {
            this.mMemoryScenePolicy = memoryScenePolicy;
            this.mLaunchBigMemApp = launchBigMemApp;
            if (this.mLaunchBigMemApp) {
                com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setBigMemAppLaunching(true);
            } else {
                com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setRunningPolicy(memoryScenePolicy);
            }
        }

        public void run() {
            if (com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.this.mStopAction.get()) {
                this.mMemoryScenePolicy.clear();
                if (this.mLaunchBigMemApp) {
                    com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setBigMemAppLaunching(false);
                } else {
                    com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setRunningPolicy(null);
                }
                return;
            }
            android.os.Process.setThreadPriority(this.mLaunchBigMemApp ? -2 : 10);
            com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.this.mMemState.setStatus(3);
            this.mMemoryScenePolicy.execute();
            this.mMemoryScenePolicy.clear();
            if (this.mLaunchBigMemApp) {
                com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setBigMemAppLaunching(false);
            } else {
                com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setRunningPolicy(null);
            }
            com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1004, 0, 0, null);
            com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().setPollingPeriod(this.mMemoryScenePolicy.getPollingPeriod());
            com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.this.mMemState.setStatus(0);
        }
    }

    protected static final class IAwareMemState {
        static final int CACL_CPU = 2;
        static final int CACL_MEM = 1;
        static final int EXE_ACT = 3;
        static final int IDLE = 0;
        java.util.concurrent.atomic.AtomicInteger status = new java.util.concurrent.atomic.AtomicInteger(0);

        protected IAwareMemState() {
        }

        public void reset() {
            this.status.getAndSet(0);
        }

        public void setStatus(int stat) {
            this.status.getAndSet(stat);
        }

        public int getStatus() {
            return this.status.get();
        }

        public java.lang.String toString() {
            switch (this.status.get()) {
                case 0:
                    return "status idleing";
                case 1:
                    return "status calculating mem";
                case 2:
                    return "status calculating cpu";
                case 3:
                    return "status execute action";
                default:
                    return "status error";
            }
        }
    }

    protected static final class MemThreadFactory implements java.util.concurrent.ThreadFactory {
        private final java.lang.String mName;

        MemThreadFactory(java.lang.String name) {
            this.mName = name;
        }

        public java.lang.Thread newThread(java.lang.Runnable r) {
            return new java.lang.Thread(r, this.mName);
        }
    }

    public void enableMemoryRecover() {
        this.mMemState.setStatus(0);
    }

    public void disableMemoryRecover() {
    }

    public void stopMemoryRecover() {
    }

    public void executeMemoryRecover(android.os.Bundle extras) {
    }

    public void setMemHandlerThread(android.os.HandlerThread handlerThread) {
    }

    public void setProtectCacheFlag(int state) {
    }
}
