package com.android.server.rms.iaware.memory.policy;

public class BigMemoryExecutor extends com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor {
    private static final java.lang.String TAG = "AwareMem_BigMemExec";
    private java.util.concurrent.ThreadPoolExecutor mBigMemAppExecutor;
    private long totalKillMem;

    public BigMemoryExecutor() {
        this.mBigMemAppExecutor = null;
        this.totalKillMem = 0;
        this.mBigMemAppExecutor = new java.util.concurrent.ThreadPoolExecutor(0, 1, 10, java.util.concurrent.TimeUnit.SECONDS, new java.util.concurrent.LinkedBlockingQueue(1), new com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.MemThreadFactory("iaware.mem.bigmem"));
    }

    public void disableMemoryRecover() {
        this.mMemState.setStatus(0);
    }

    public void executeMemoryRecover(android.os.Bundle extras) {
        if (extras == null) {
            android.rms.iaware.AwareLog.e("AwareMem_BigMemExec", "executeMemoryRecover extras null");
            return;
        }
        long reqMemory = checkBigAppAvailableMemory(extras);
        if (reqMemory <= 0) {
            this.mMemState.setStatus(0);
            return;
        }
        com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList memoryScenePolicyList = com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().getMemoryScenePolicyList();
        if (memoryScenePolicyList == null) {
            android.rms.iaware.AwareLog.e("AwareMem_BigMemExec", "executeMemoryRecover memoryScenePolicyList null");
            return;
        }
        com.android.server.rms.iaware.memory.policy.MemoryScenePolicy bigMemoryScenePolicy = memoryScenePolicyList.getMemoryScenePolicy("BigMem");
        if (bigMemoryScenePolicy == null) {
            this.mMemState.setStatus(0);
            return;
        }
        extras.putLong("reqMem", reqMemory);
        bigMemoryScenePolicy.setExtras(extras);
        com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().stopMemoryPolicy(true);
        try {
            this.mBigMemAppExecutor.execute(new com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.CalcRunnable(bigMemoryScenePolicy, true));
        } catch (java.util.concurrent.RejectedExecutionException e) {
            android.rms.iaware.AwareLog.e("AwareMem_BigMemExec", "Failed to execute! reject");
        } catch (java.lang.Exception e2) {
            android.rms.iaware.AwareLog.e("AwareMem_BigMemExec", "Failed to execute! reset");
        }
    }

    private long checkBigAppAvailableMemory(android.os.Bundle extras) {
        long reqMem;
        long targetMemKB;
        long targetMemKB2;
        android.os.Bundle bundle = extras;
        int event = bundle.getInt("event");
        if (event == 15010) {
            reqMem = bundle.getLong("reqMem", 0);
            targetMemKB = com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() + reqMem;
            com.android.server.rms.iaware.memory.utils.MemoryConstant.addTotalAPIRequestMemory(reqMem);
            android.rms.iaware.AwareLog.i("AwareMem_BigMemExec", "request mem event");
            targetMemKB2 = targetMemKB;
        } else {
            targetMemKB2 = com.android.server.rms.iaware.memory.utils.BigMemoryInfo.getInstance().getAppLaunchRequestMemory(bundle.getString("appName")) * 1024;
            reqMem = targetMemKB2 - com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory();
            com.android.server.rms.iaware.memory.utils.MemoryConstant.addTotalAPIRequestMemory(reqMem);
            this.totalKillMem = 0;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("big mem event target");
            stringBuilder.append(targetMemKB2);
            stringBuilder.append("kb");
            android.rms.iaware.AwareLog.i("AwareMem_BigMemExec", stringBuilder.toString());
        }
        targetMemKB = com.android.server.rms.iaware.memory.utils.MemoryConstant.getTotalAPIRequestMemory();
        java.lang.StringBuilder stringBuilder2;
        if (targetMemKB > com.android.server.rms.iaware.memory.utils.MemoryConstant.getMaxAPIRequestMemory()) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("total request memory has exceed limit:");
            stringBuilder2.append(targetMemKB);
            stringBuilder2.append("kb");
            android.rms.iaware.AwareLog.i("AwareMem_BigMemExec", stringBuilder2.toString());
            return -1;
        }
        long availableNow = com.android.server.rms.iaware.memory.utils.MemoryReader.getInstance().getMemAvailable();
        long killMem = targetMemKB2 - availableNow;
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("Avail:");
        stringBuilder3.append(availableNow);
        stringBuilder3.append("kb. prepare:");
        stringBuilder3.append(reqMem);
        stringBuilder3.append("kb. totalReqMem:");
        stringBuilder3.append(targetMemKB);
        stringBuilder3.append("kb");
        android.rms.iaware.AwareLog.i("AwareMem_BigMemExec", stringBuilder3.toString());
        if (killMem <= 0) {
            com.android.server.rms.iaware.memory.utils.EventTracker instance = com.android.server.rms.iaware.memory.utils.EventTracker.getInstance();
            stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("has enough avail mem:");
            stringBuilder3.append(availableNow);
            instance.trackEvent(1001, 0, 0, stringBuilder3.toString());
            return -1;
        }
        this.totalKillMem += killMem;
        stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("killMem:");
        stringBuilder2.append(killMem);
        stringBuilder2.append("kb. totalKill:");
        stringBuilder2.append(this.totalKillMem);
        stringBuilder2.append("kb");
        android.rms.iaware.AwareLog.i("AwareMem_BigMemExec", stringBuilder2.toString());
        return killMem;
    }
}
