package com.android.server.rms.iaware.memory.policy;

public class IdleMemoryExecutor extends com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor {
    private static final int CONTINUOUS_LOW_MEM_COUNT_THRESHOLD = 3;
    private static final int MSG_CYCLE_RECYCLE = 11;
    private static final int PROTECTLRU_MIN_TIME_GAP = 600000;
    private static final int SYSTEM_MEMORY_STATE_BASE = 0;
    private static final int SYSTEM_MEMORY_STATE_LOW = 1;
    private static final int SYSTEM_MEMORY_STATE_NORMAL = 0;
    private static final java.lang.String TAG = "AwareMem_IdleMemExec";
    private com.android.server.rms.iaware.memory.utils.BigDataStore mBigDataStore;
    private java.util.concurrent.ThreadPoolExecutor mIdleMemAppExecutor;
    private com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag mLastExecutorActionFlag;
    private com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemHandler mMemHandler;
    private int mProtectCacheFlag;
    private long mProtectCacheTimestamp;
    private long mSysCpuOverLoadCnt;
    private com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.LimitedSizeQueue<java.lang.Integer> mSysLowMemStateTracker;

    private enum ActionFlag {
        ACTION_NONE,
        ACTION_RECLAIM,
        ACTION_KILL
    }

    private static final class CpuResult {
        boolean mBusy;
        int mCpuLoad;
        java.lang.String mTraceInfo;

        private CpuResult() {
            this.mCpuLoad = 0;
            this.mBusy = true;
            this.mTraceInfo = null;
        }
    }

    private static final class LimitedSizeQueue<K> extends java.util.LinkedList<K> {
        private static final long serialVersionUID = 6928859904407185256L;
        private int maxSize;

        public LimitedSizeQueue(int size) {
            this.maxSize = size;
        }

        public boolean add(K k) {
            boolean added = super.add(k);
            while (added && size() > this.maxSize) {
                super.remove();
            }
            return added;
        }
    }

    private final class MemHandler extends android.os.Handler {
        public MemHandler(android.os.Looper looper) {
            super(looper);
        }

        public void removeAllMessage() {
            removeMessages(11);
        }

        public android.os.Message getMessage(int what, int arg1, java.lang.Object obj) {
            return obtainMessage(what, arg1, 0, obj);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 11) {
                com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.this.handleRecycleMsg(msg);
            }
        }
    }

    private static final class MemoryResult {
        long mAvailable;
        boolean mEmergency;
        long mRequest;
        java.lang.String mScene;
        java.lang.String mTraceInfo;

        private MemoryResult() {
            this.mRequest = 0;
            this.mAvailable = 0;
            this.mEmergency = false;
            this.mScene = null;
            this.mTraceInfo = null;
        }
    }

    public IdleMemoryExecutor() {
        this.mIdleMemAppExecutor = null;
        this.mBigDataStore = com.android.server.rms.iaware.memory.utils.BigDataStore.getInstance();
        this.mSysLowMemStateTracker = null;
        this.mLastExecutorActionFlag = com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_NONE;
        this.mIdleMemAppExecutor = new java.util.concurrent.ThreadPoolExecutor(0, 1, 30, java.util.concurrent.TimeUnit.SECONDS, new java.util.concurrent.LinkedBlockingQueue(1), new com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.MemThreadFactory("iaware.mem.default"));
        this.mSysCpuOverLoadCnt = 0;
        this.mProtectCacheFlag = 0;
        this.mProtectCacheTimestamp = android.os.SystemClock.uptimeMillis();
        this.mSysLowMemStateTracker = new com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.LimitedSizeQueue(3);
        for (int i = 0; i < 3; i++) {
            this.mSysLowMemStateTracker.add(java.lang.Integer.valueOf(0));
        }
    }

    public void disableMemoryRecover() {
        this.mMemState.setStatus(0);
        if (this.mMemHandler != null) {
            this.mMemHandler.removeAllMessage();
        }
    }

    public void stopMemoryRecover() {
        this.mStopAction.set(true);
        disableMemoryRecover();
    }

    public void executeMemoryRecover(android.os.Bundle extras) {
        int event = extras.getInt("event");
        if (this.mMemHandler != null) {
            this.mMemHandler.sendMessage(this.mMemHandler.getMessage(11, event, extras));
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("executeMemoryRecover event=");
            stringBuilder.append(event);
            android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
        }
    }

    public void setMemHandlerThread(android.os.HandlerThread handlerThread) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setHandler: object=");
        stringBuilder.append(handlerThread);
        android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
        this.mMemHandler = new com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemHandler(handlerThread.getLooper());
    }

    private void executeIdleMemory(int event, android.os.Bundle extras) {
        this.mStopAction.set(false);
        com.android.server.rms.iaware.memory.policy.MemoryScenePolicy idleMemoryScenePolicy = createPolicyByMemCpu(extras);
        if (idleMemoryScenePolicy == null) {
            this.mMemState.setStatus(0);
            return;
        }
        idleMemoryScenePolicy.setExtras(extras);
        try {
            this.mIdleMemAppExecutor.execute(new com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor.CalcRunnable(idleMemoryScenePolicy, false));
        } catch (java.util.concurrent.RejectedExecutionException e) {
            android.rms.iaware.AwareLog.e("AwareMem_IdleMemExec", "Failed to execute! reject");
        } catch (java.lang.Exception e2) {
            android.rms.iaware.AwareLog.e("AwareMem_IdleMemExec", "Failed to execute! reset");
        }
    }

    private com.android.server.rms.iaware.memory.policy.MemoryScenePolicy createPolicyByMemCpu(android.os.Bundle extras) {
        android.os.Bundle bundle = extras;
        com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList memoryScenePolicyList = com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().getMemoryScenePolicyList();
        if (memoryScenePolicyList != null) {
            if (bundle != null) {
                com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemoryResult memResult = calculateMemStatus();
                long beginTime = java.lang.System.currentTimeMillis();
                updateSysMemStates(memResult.mAvailable);
                if (!isProtectCache() && isContLowMemState()) {
                    setProtectCache(1);
                } else if (!isUnprotectCache() && isContNormalMemState() && isProtectLruTimeOk()) {
                    setProtectCache(0);
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Bybass set protect cache. States: ");
                    stringBuilder.append(this.mProtectCacheFlag);
                    stringBuilder.append(", ");
                    stringBuilder.append(java.util.Arrays.toString(this.mSysLowMemStateTracker.toArray()));
                    android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
                }
                long exeTime = java.lang.System.currentTimeMillis() - beginTime;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("setProtectCache time ");
                stringBuilder2.append(exeTime);
                android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder2.toString());
                updateExtraFreeKbytes(memResult.mAvailable);
                if (memResult.mScene == null) {
                    com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1001, 0, 0, memResult.mTraceInfo);
                    return null;
                }
                com.android.server.rms.iaware.memory.policy.MemoryScenePolicy policy = memoryScenePolicyList.getMemoryScenePolicy(memResult.mScene);
                if (policy != null) {
                    if (policy.canBeExecuted()) {
                        if (!memResult.mEmergency) {
                            com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.CpuResult cpuResult = calculateCPUStatus(policy, memResult.mAvailable);
                            bundle.putInt("cpuLoad", cpuResult.mCpuLoad);
                            bundle.putBoolean("cpuBusy", cpuResult.mBusy);
                            if (cpuResult.mBusy) {
                                com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1001, 0, 0, cpuResult.mTraceInfo);
                                this.mSysCpuOverLoadCnt++;
                                return null;
                            }
                        }
                        this.mSysCpuOverLoadCnt = 0;
                        bundle.putLong("reqMem", memResult.mRequest);
                        policy.setExtras(bundle);
                        com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1003, 0, 0, memResult.mTraceInfo);
                        return policy;
                    }
                }
                java.lang.String reason = policy == null ? "null policy" : "policy can not execute";
                java.lang.String traceInfo = new java.lang.StringBuilder();
                traceInfo.append(memResult.mTraceInfo);
                traceInfo.append(" but ");
                traceInfo.append(reason);
                com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1001, 0, 0, traceInfo.toString());
                return null;
            }
        }
        android.rms.iaware.AwareLog.e("AwareMem_IdleMemExec", "createPolicyByMemCpu memoryScenePolicyList null");
        return null;
    }

    private void updateExtraFreeKbytes(long availableRam) {
        if (availableRam > 0) {
            if (availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory()) {
                com.android.server.rms.iaware.memory.utils.MemoryUtils.writeExtraFreeKbytes(com.android.server.rms.iaware.memory.utils.MemoryConstant.DEFAULT_EXTRA_FREE_KBYTES);
            } else {
                com.android.server.rms.iaware.memory.utils.MemoryUtils.writeExtraFreeKbytes(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigExtraFreeKbytes());
            }
        }
    }

    private com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemoryResult calculateMemStatus() {
        com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemoryResult memResult = new com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.MemoryResult();
        if (canRecoverExecute("calculateMemStatus")) {
            boolean z = true;
            this.mMemState.setStatus(1);
            long availableRam = com.android.server.rms.iaware.memory.utils.MemoryReader.getInstance().getMemAvailable();
            if (availableRam <= 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("calculateMemStatus read availableRam err!");
                stringBuilder.append(availableRam);
                android.rms.iaware.AwareLog.e("AwareMem_IdleMemExec", stringBuilder.toString());
                memResult.mTraceInfo = "read availableRam err";
                return memResult;
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("calculateMemStatus memory availableRam=");
            stringBuilder2.append(availableRam);
            android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder2.toString());
            memResult.mAvailable = availableRam;
            java.lang.StringBuilder stringBuilder3;
            if (availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory()) {
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("memory enough ");
                stringBuilder3.append(availableRam);
                memResult.mTraceInfo = stringBuilder3.toString();
                this.mLastExecutorActionFlag = com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_NONE;
                setBelowThresholdTime();
            } else if (availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory()) {
                memResult.mRequest = com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory() - availableRam;
                memResult.mScene = "idle";
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("memory low ");
                stringBuilder3.append(availableRam);
                memResult.mTraceInfo = stringBuilder3.toString();
                this.mLastExecutorActionFlag = com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_RECLAIM;
                setBelowThresholdTime();
            } else if (availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() - com.android.server.rms.iaware.memory.utils.MemoryConstant.getReclaimKillGapMemory()) {
                if (this.mLastExecutorActionFlag != com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_KILL) {
                    memResult.mRequest = com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory() - availableRam;
                    memResult.mScene = "idle";
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("memory in Idle gap ");
                    stringBuilder3.append(availableRam);
                    memResult.mTraceInfo = stringBuilder3.toString();
                } else {
                    memResult.mRequest = com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() - availableRam;
                    memResult.mScene = "default";
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("memory in Critical gap ");
                    stringBuilder3.append(availableRam);
                    memResult.mTraceInfo = stringBuilder3.toString();
                }
                this.mLastExecutorActionFlag = com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_KILL;
                setLowMemoryManageCount();
            } else {
                setLowMemoryManageCount();
                this.mLastExecutorActionFlag = com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.ActionFlag.ACTION_KILL;
                memResult.mRequest = com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() - availableRam;
                memResult.mScene = "default";
                if (availableRam > com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory()) {
                    z = false;
                }
                memResult.mEmergency = z;
                memResult.mTraceInfo = memResult.mEmergency ? "memory emergemcy " : "memory critical ";
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append(memResult.mTraceInfo);
                stringBuilder3.append(availableRam);
                memResult.mTraceInfo = stringBuilder3.toString();
            }
            return memResult;
        }
        memResult.mTraceInfo = "DME not running or interrupted";
        return memResult;
    }

    private com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.CpuResult calculateCPUStatus(com.android.server.rms.iaware.memory.policy.MemoryScenePolicy policy, long mem) {
        com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.CpuResult cpuResult = new com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor.CpuResult();
        boolean z = true;
        if (canRecoverExecute("calculateCPUStatus")) {
            this.mMemState.setStatus(2);
            long cpuLoad = com.android.server.rms.iaware.memory.utils.CpuReader.getInstance().getCpuPercent();
            if (cpuLoad < 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("calculateCPUStatus faild to read cpuload=");
                stringBuilder.append(cpuLoad);
                android.rms.iaware.AwareLog.e("AwareMem_IdleMemExec", stringBuilder.toString());
                cpuResult.mTraceInfo = "read cpuload err";
                cpuResult.mBusy = true;
                return cpuResult;
            }
            cpuResult.mCpuLoad = (int) cpuLoad;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("calculateCPUStatus cpu pressure ");
            stringBuilder2.append(cpuLoad);
            android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder2.toString());
            java.lang.StringBuilder stringBuilder3;
            if (cpuLoad < policy.getCpuPressure(mem, com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleThresHold(), this.mSysCpuOverLoadCnt)) {
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("cpuload ");
                stringBuilder3.append(cpuLoad);
                cpuResult.mTraceInfo = stringBuilder3.toString();
                cpuResult.mBusy = false;
                return cpuResult;
            }
            if (cpuLoad < policy.getCpuPressure(mem, com.android.server.rms.iaware.memory.utils.MemoryConstant.getNormalThresHold(), this.mSysCpuOverLoadCnt)) {
                java.lang.String str;
                if (com.android.server.rms.iaware.memory.data.handle.DataInputHandle.getInstance().getActiveStatus() == 2) {
                    z = false;
                }
                cpuResult.mBusy = z;
                if (cpuResult.mBusy) {
                    str = "phone in active state";
                } else {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("cpuload ");
                    stringBuilder3.append(cpuLoad);
                    str = stringBuilder3.toString();
                }
                cpuResult.mTraceInfo = str;
            } else {
                cpuResult.mBusy = true;
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("cpuload high ");
                stringBuilder3.append(cpuLoad);
                cpuResult.mTraceInfo = stringBuilder3.toString();
            }
            return cpuResult;
        }
        cpuResult.mTraceInfo = "DME not running or interrupted";
        cpuResult.mBusy = true;
        return cpuResult;
    }

    private boolean canRecoverExecute(java.lang.String functionName) {
        if (!this.mStopAction.get()) {
            return true;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("");
        stringBuilder.append(functionName);
        stringBuilder.append(" iaware not running, action=");
        stringBuilder.append(this.mStopAction.get());
        android.rms.iaware.AwareLog.w("AwareMem_IdleMemExec", stringBuilder.toString());
        return false;
    }

    private void handleRecycleMsg(android.os.Message msg) {
        int event = msg.arg1;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("MemHandler event=");
        stringBuilder.append(event);
        android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
        android.os.Bundle extras = msg.obj;
        if (extras == null) {
            android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", "MemHandler extras is null");
            return;
        }
        long timestamp = extras.getLong("timeStamp");
        if (this.mMemState.getStatus() != 0) {
            com.android.server.rms.iaware.memory.utils.EventTracker instance = com.android.server.rms.iaware.memory.utils.EventTracker.getInstance();
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("mem ");
            stringBuilder2.append(this.mMemState.toString());
            instance.trackEvent(1001, event, timestamp, stringBuilder2.toString());
        } else if (com.android.server.rms.iaware.memory.policy.MemoryExecutorServer.getInstance().getBigMemAppLaunching()) {
            android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", "MemHandler big memory app is running");
        } else {
            if (event > 0 && timestamp > 0) {
                com.android.server.rms.iaware.memory.utils.EventTracker.getInstance().trackEvent(1000, event, timestamp, null);
            }
            executeIdleMemory(event, extras);
        }
    }

    private void setBelowThresholdTime() {
        if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
            long belowThresholdTimeEnd = android.os.SystemClock.elapsedRealtime();
            if (this.mBigDataStore.belowThresholdTimeBegin > 0 && belowThresholdTimeEnd - this.mBigDataStore.belowThresholdTimeBegin > 0) {
                com.android.server.rms.iaware.memory.utils.BigDataStore bigDataStore = this.mBigDataStore;
                bigDataStore.belowThresholdTime += belowThresholdTimeEnd - this.mBigDataStore.belowThresholdTimeBegin;
                this.mBigDataStore.belowThresholdTimeBegin = 0;
            }
        }
    }

    private void setLowMemoryManageCount() {
        if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
            if (this.mBigDataStore.belowThresholdTimeBegin == 0) {
                this.mBigDataStore.belowThresholdTimeBegin = android.os.SystemClock.elapsedRealtime();
            }
            com.android.server.rms.iaware.memory.utils.BigDataStore bigDataStore = this.mBigDataStore;
            bigDataStore.lowMemoryManageCount++;
        }
    }

    private void updateSysMemStates(long memAvailKB) {
        if (memAvailKB >= 0) {
            int state;
            if (memAvailKB < com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory()) {
                state = 1;
            } else {
                state = 0;
            }
            this.mSysLowMemStateTracker.add(java.lang.Integer.valueOf(state));
        }
    }

    private boolean isContLowMemState() {
        for (int i = 0; i < 3; i++) {
            if (((java.lang.Integer) this.mSysLowMemStateTracker.get(i)).intValue() != 1) {
                return false;
            }
        }
        return true;
    }

    private boolean isContNormalMemState() {
        for (int i = 0; i < 3; i++) {
            if (((java.lang.Integer) this.mSysLowMemStateTracker.get(i)).intValue() != 0) {
                return false;
            }
        }
        return true;
    }

    private boolean isProtectCache() {
        return this.mProtectCacheFlag == 1;
    }

    private boolean isUnprotectCache() {
        return this.mProtectCacheFlag == 0;
    }

    public void setProtectCacheFlag(int state) {
        this.mProtectCacheFlag = state;
    }

    private void setProtectCache(int state) {
        java.lang.StringBuilder stringBuilder;
        if (state != 1) {
            if (state != 0) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setProtectCache invalid state: ");
                stringBuilder.append(state);
                stringBuilder.append(". States: ");
                stringBuilder.append(this.mProtectCacheFlag);
                stringBuilder.append(", ");
                stringBuilder.append(java.util.Arrays.toString(this.mSysLowMemStateTracker.toArray()));
                android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
                return;
            }
        }
        this.mProtectCacheFlag = state;
        this.mProtectCacheTimestamp = android.os.SystemClock.uptimeMillis();
        com.android.server.rms.iaware.memory.utils.MemoryUtils.dynamicSetProtectLru(state);
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setProtectCache state: ");
        stringBuilder.append(state);
        stringBuilder.append(". States: ");
        stringBuilder.append(this.mProtectCacheFlag);
        stringBuilder.append(", ");
        stringBuilder.append(java.util.Arrays.toString(this.mSysLowMemStateTracker.toArray()));
        android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
    }

    private boolean isProtectLruTimeOk() {
        long now = android.os.SystemClock.uptimeMillis();
        boolean ret = now > this.mProtectCacheTimestamp && now - this.mProtectCacheTimestamp >= 600000;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("isProtectLruTimeOk: ");
        stringBuilder.append(ret);
        stringBuilder.append(". States: ");
        stringBuilder.append(this.mProtectCacheFlag);
        stringBuilder.append(", ");
        stringBuilder.append(java.util.Arrays.toString(this.mSysLowMemStateTracker.toArray()));
        android.rms.iaware.AwareLog.d("AwareMem_IdleMemExec", stringBuilder.toString());
        return ret;
    }
}
