package com.android.server.rms.iaware.memory.policy;

public class MemoryExecutorServer {
    private static final java.lang.String TAG = "AwareMem_MemExecSvr";
    private static final java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.rms.iaware.memory.policy.MemoryExecutorServer sMemoryExecutorServer;
    boolean mBigMemAppLaunching = false;
    private final com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor mBigMemoryExecutor = new com.android.server.rms.iaware.memory.policy.BigMemoryExecutor();
    private final com.android.server.rms.iaware.memory.policy.AbsMemoryExecutor mIdleMemoryExecutor = new com.android.server.rms.iaware.memory.policy.IdleMemoryExecutor();
    com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList mMemoryScenePolicyList = null;
    com.android.server.rms.iaware.memory.utils.PollingTimer mPollingTimer = new com.android.server.rms.iaware.memory.utils.PollingTimer();
    com.android.server.rms.iaware.memory.policy.MemoryScenePolicy mRunningPolicy = null;

    public static com.android.server.rms.iaware.memory.policy.MemoryExecutorServer getInstance() {
        com.android.server.rms.iaware.memory.policy.MemoryExecutorServer memoryExecutorServer;
        synchronized (mLock) {
            if (sMemoryExecutorServer == null) {
                sMemoryExecutorServer = new com.android.server.rms.iaware.memory.policy.MemoryExecutorServer();
            }
            memoryExecutorServer = sMemoryExecutorServer;
        }
        return memoryExecutorServer;
    }

    private MemoryExecutorServer() {
    }

    public void enable() {
        this.mIdleMemoryExecutor.enableMemoryRecover();
        this.mBigMemoryExecutor.enableMemoryRecover();
        setPollingPeriod(com.android.server.rms.iaware.memory.utils.MemoryConstant.getDefaultTimerPeriod());
        this.mMemoryScenePolicyList.clear();
    }

    public void disable() {
        this.mPollingTimer.stopTimer();
        this.mIdleMemoryExecutor.disableMemoryRecover();
        this.mBigMemoryExecutor.disableMemoryRecover();
        this.mMemoryScenePolicyList.reset();
    }

    public void executeMemoryRecover(java.lang.String scene, android.os.Bundle extras, int event, long timeStamp) {
        if (getBigMemAppLaunching()) {
            android.rms.iaware.AwareLog.i("AwareMem_MemExecSvr", "executeMemoryRecover big mem app is running");
            return;
        }
        if (extras != null) {
            if (this.mMemoryScenePolicyList != null) {
                extras.putInt("event", event);
                extras.putLong("timeStamp", timeStamp);
                if ("BigMem".equals(scene)) {
                    this.mBigMemoryExecutor.executeMemoryRecover(extras);
                } else {
                    this.mIdleMemoryExecutor.executeMemoryRecover(extras);
                }
                return;
            }
        }
        android.rms.iaware.AwareLog.e("AwareMem_MemExecSvr", "executeMemoryRecover null policy!!");
    }

    public void stopMemoryRecover() {
        if (getBigMemAppLaunching()) {
            android.rms.iaware.AwareLog.i("AwareMem_MemExecSvr", "stopExecuteMemoryRecover big memory app is running");
            return;
        }
        this.mBigMemoryExecutor.stopMemoryRecover();
        this.mIdleMemoryExecutor.stopMemoryRecover();
        stopMemoryPolicy(false);
    }

    public void setMemHandlerThread(android.os.HandlerThread handlerThread) {
        if (handlerThread != null) {
            this.mIdleMemoryExecutor.setMemHandlerThread(handlerThread);
            this.mPollingTimer.setPollingTimerHandler(handlerThread);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setHandler: object=");
            stringBuilder.append(handlerThread);
            android.rms.iaware.AwareLog.d("AwareMem_MemExecSvr", stringBuilder.toString());
            return;
        }
        android.rms.iaware.AwareLog.e("AwareMem_MemExecSvr", "setHandler: why handlerThread is null!!");
    }

    public void setRunningPolicy(com.android.server.rms.iaware.memory.policy.MemoryScenePolicy memoryScenePolicy) {
        synchronized (mLock) {
            this.mRunningPolicy = memoryScenePolicy;
        }
    }

    public com.android.server.rms.iaware.memory.policy.MemoryScenePolicy getRunningPolicy() {
        com.android.server.rms.iaware.memory.policy.MemoryScenePolicy memoryScenePolicy;
        synchronized (mLock) {
            memoryScenePolicy = this.mRunningPolicy;
        }
        return memoryScenePolicy;
    }

    public void setPollingPeriod(long pollingPeriod) {
        if (this.mPollingTimer != null) {
            this.mPollingTimer.setPollingPeriod(pollingPeriod);
            this.mPollingTimer.resetTimer();
        }
    }

    public boolean getBigMemAppLaunching() {
        boolean z;
        synchronized (mLock) {
            z = this.mBigMemAppLaunching;
        }
        return z;
    }

    public void setBigMemAppLaunching(boolean isBigMemAppLaunching) {
        synchronized (mLock) {
            this.mBigMemAppLaunching = isBigMemAppLaunching;
        }
    }

    public void setMemoryScenePolicyList(com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList memoryScenePolicyList) {
        this.mMemoryScenePolicyList = memoryScenePolicyList;
    }

    public com.android.server.rms.iaware.memory.policy.MemoryScenePolicyList getMemoryScenePolicyList() {
        return this.mMemoryScenePolicyList;
    }

    public boolean stopMemoryPolicy(boolean forced) {
        boolean interrupt;
        synchronized (mLock) {
            interrupt = getRunningPolicy() != null ? getRunningPolicy().interrupt(forced) : true;
        }
        return interrupt;
    }

    public void notifyProtectLruState(int state) {
        this.mIdleMemoryExecutor.setProtectCacheFlag(state);
    }
}
