package com.android.server.rms.iaware.memory.policy;

public class MemoryScenePolicy {
    private static final java.lang.String TAG = "AwareMem_MemPolicy";
    private final java.util.List<com.android.server.rms.iaware.memory.action.Action> mActions;
    private android.os.Bundle mExtras;
    private final java.lang.String mName;

    public MemoryScenePolicy(java.lang.String name, java.util.List<com.android.server.rms.iaware.memory.action.Action> actionList) {
        this.mActions = actionList;
        this.mName = name;
    }

    public java.lang.String getSceneName() {
        return this.mName;
    }

    public void setExtras(android.os.Bundle extras) {
        this.mExtras = extras;
    }

    public android.os.Bundle getExtras() {
        return this.mExtras;
    }

    public int execute() {
        if (this.mExtras == null) {
            return -1;
        }
        long reqMem = this.mExtras.getLong("reqMem");
        java.lang.StringBuilder stringBuilder;
        if (reqMem <= 0) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Execute memorypolicy exit, because of reqMem is negative:");
            stringBuilder.append(reqMem);
            android.rms.iaware.AwareLog.w("AwareMem_MemPolicy", stringBuilder.toString());
            return -1;
        } else if (reqMem > com.android.server.rms.iaware.memory.utils.MemoryConstant.getMaxReqMem()) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Execute memorypolicy exit, because of reqMem is too big:");
            stringBuilder.append(reqMem);
            android.rms.iaware.AwareLog.w("AwareMem_MemPolicy", stringBuilder.toString());
            return -1;
        } else {
            if (this.mActions != null) {
                if (!this.mActions.isEmpty()) {
                    int result = 0;
                    long start = android.os.SystemClock.elapsedRealtime();
                    for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
                        result |= action.execute(this.mExtras);
                    }
                    long end = android.os.SystemClock.elapsedRealtime();
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("Execute memorypolicy use: ");
                    stringBuilder2.append(end - start);
                    stringBuilder2.append(" ms");
                    android.rms.iaware.AwareLog.d("AwareMem_MemPolicy", stringBuilder2.toString());
                    return result;
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_MemPolicy", "Memorypolicy actions is empty");
            return -1;
        }
    }

    public void clear() {
        android.rms.iaware.AwareLog.d("AwareMem_MemPolicy", "clear memorypolicy");
        this.mExtras = null;
        forceInterrupt(false);
    }

    public void reset() {
        android.rms.iaware.AwareLog.d("AwareMem_MemPolicy", "reset memorypolicy");
        this.mExtras = null;
        forceInterrupt(true);
        if (this.mActions != null) {
            if (!this.mActions.isEmpty()) {
                for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
                    action.reset();
                }
            }
        }
    }

    public boolean canBeExecuted() {
        if (this.mActions != null) {
            if (!this.mActions.isEmpty()) {
                for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
                    if (!action.canBeExecuted()) {
                        return false;
                    }
                }
                return true;
            }
        }
        android.rms.iaware.AwareLog.w("AwareMem_MemPolicy", "Memorypolicy canBeExecuted: actions is empty");
        return false;
    }

    public long getPollingPeriod() {
        if (this.mActions != null) {
            if (!this.mActions.isEmpty()) {
                int maxStepCount = getPollingStepCount();
                if (maxStepCount <= 0) {
                    return getMemPressure();
                }
                long pollingPeriod;
                if (maxStepCount < 15) {
                    pollingPeriod = (long) (((double) com.android.server.rms.iaware.memory.utils.MemoryConstant.getDefaultTimerPeriod()) * java.lang.Math.pow(2.0d, (double) maxStepCount));
                } else {
                    pollingPeriod = com.android.server.rms.iaware.memory.utils.MemoryConstant.getMaxTimerPeriod();
                }
                return pollingPeriod;
            }
        }
        return com.android.server.rms.iaware.memory.utils.MemoryConstant.getDefaultTimerPeriod();
    }

    private int getPollingStepCount() {
        int maxStepCount = 0;
        for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
            int stepCount = action.getLastExecFailCount();
            if (action.getLastExecFailCount() < 1) {
                return 0;
            }
            maxStepCount = maxStepCount < stepCount ? stepCount : maxStepCount;
        }
        return maxStepCount;
    }

    private long getMemPressure() {
        long availableRam = com.android.server.rms.iaware.memory.utils.MemoryReader.getInstance().getMemAvailable();
        if (availableRam <= 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("calcMemPressure read availableRam err!");
            stringBuilder.append(availableRam);
            android.rms.iaware.AwareLog.w("AwareMem_MemPolicy", stringBuilder.toString());
            return com.android.server.rms.iaware.memory.utils.MemoryConstant.getDefaultTimerPeriod();
        } else if (availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory()) {
            return 10000;
        } else {
            long minInterval = com.android.server.rms.iaware.memory.utils.MemoryConstant.getMinTimerPeriod();
            if (availableRam <= com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory()) {
                return minInterval;
            }
            long interval = (10000 * (availableRam - com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory())) / (com.android.server.rms.iaware.memory.utils.MemoryConstant.getIdleMemory() - com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory());
            return interval < minInterval ? minInterval : interval;
        }
    }

    public long getCpuPressure(long availableRam, long cpuThresHold, long sysCpuOverLoadCnt) {
        long j = sysCpuOverLoadCnt;
        if (availableRam < com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory() || availableRam >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory()) {
            return cpuThresHold;
        }
        long curCpuLoad = (cpuThresHold + (((com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() - availableRam) * (100 - cpuThresHold)) / (com.android.server.rms.iaware.memory.utils.MemoryConstant.getCriticalMemory() - com.android.server.rms.iaware.memory.utils.MemoryConstant.getEmergencyMemory()))) + (6 * j);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getCpuPressure curCpuLoad=");
        stringBuilder.append(curCpuLoad);
        stringBuilder.append(" sysCpuOverLoadCnt:");
        stringBuilder.append(j);
        android.rms.iaware.AwareLog.d("AwareMem_MemPolicy", stringBuilder.toString());
        return curCpuLoad;
    }

    public boolean interrupt(boolean forced) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Interrupt memorypolicy: forced=");
        stringBuilder.append(forced);
        android.rms.iaware.AwareLog.i("AwareMem_MemPolicy", stringBuilder.toString());
        if (!forced) {
            return reqInterrupt();
        }
        forceInterrupt(true);
        return true;
    }

    private void forceInterrupt(boolean interrupted) {
        if (this.mActions != null) {
            if (!this.mActions.isEmpty()) {
                for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
                    action.interrupt(interrupted);
                }
            }
        }
    }

    private boolean reqInterrupt() {
        if (this.mActions != null) {
            if (!this.mActions.isEmpty()) {
                boolean result = true;
                for (com.android.server.rms.iaware.memory.action.Action action : this.mActions) {
                    if (!action.reqInterrupt(this.mExtras)) {
                        result = false;
                    }
                }
                return result;
            }
        }
        return true;
    }
}
