package com.android.server.rms.iaware.memory.utils;

public final class EventTracker {
    private static final int MAX_DUMP_RECORD_TIME = 60000;
    public static final int MEMORY_FEATURE_ID = android.rms.iaware.AwareConstant.FeatureType.getFeatureId(android.rms.iaware.AwareConstant.FeatureType.FEATURE_MEMORY);
    private static final int STATISTICS_TYPE_ACTION = 2;
    private static final java.lang.String TAG = "AwareMem_EventTracker";
    public static final int TRACK_TYPE_END = 1004;
    public static final int TRACK_TYPE_EXIT = 1001;
    public static final int TRACK_TYPE_INIT = 1000;
    public static final int TRACK_TYPE_KILL = 1002;
    public static final int TRACK_TYPE_STOP = 1005;
    public static final int TRACK_TYPE_TRIG = 1003;
    private static com.android.server.rms.iaware.memory.utils.EventTracker mEventTracker = null;
    private int mEvent = 0;
    private java.util.ArrayList<android.rms.iaware.DumpData> mRecordData = new java.util.ArrayList();
    private java.util.ArrayList<android.rms.iaware.StatisticsData> mStatisticsData = new java.util.ArrayList();
    private long mTimeStamp = 0;
    private boolean mValid = false;

    public static com.android.server.rms.iaware.memory.utils.EventTracker getInstance() {
        com.android.server.rms.iaware.memory.utils.EventTracker eventTracker;
        synchronized (com.android.server.rms.iaware.memory.utils.EventTracker.class) {
            if (mEventTracker == null) {
                mEventTracker = new com.android.server.rms.iaware.memory.utils.EventTracker();
            }
            eventTracker = mEventTracker;
        }
        return eventTracker;
    }

    private EventTracker() {
    }

    public static java.lang.String toString(int event) {
        switch (event) {
            case 10001:
                return "TOUCH_DOWN";
            case 15001:
                return "APP_PROCESS_LAUNCHER_BEGIN";
            case 15003:
                return "APP_PROCESS_EXIT_BEGIN";
            case 15005:
                return "APP_ACTIVITY_BEGIN";
            case 20011:
                return "SCREEN_ON";
            case 30002:
                return "POLLING_TIMEOUT";
            case 80001:
                return "TOUCH_UP";
            case 85001:
                return "APP_PROCESS_LAUNCHER_FINISH";
            case 85003:
                return "APP_PROCESS_EXIT_FINIFH";
            case 85005:
                return "APP_ACTIVITY_FINISH";
            case 90011:
                return "SCREEN_OFF";
            default:
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Unknown:");
                stringBuilder.append(event);
                return stringBuilder.toString();
        }
    }

    private static java.lang.String format(int event, long timeStamp) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("[");
        stringBuilder.append(toString(event));
        stringBuilder.append("_");
        stringBuilder.append(timeStamp);
        stringBuilder.append("]");
        return stringBuilder.toString();
    }

    public void trackEvent(int type, int newEvent, long newTimeStamp, java.lang.String info) {
        java.lang.StringBuilder stringBuilder;
        switch (type) {
            case 1000:
                this.mValid = true;
                this.mEvent = newEvent;
                this.mTimeStamp = newTimeStamp;
                break;
            case 1001:
                if (newEvent <= 0) {
                    this.mValid = false;
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("");
                    stringBuilder.append(format(this.mEvent, this.mTimeStamp));
                    stringBuilder.append(" is abandoned for ");
                    stringBuilder.append(info);
                    android.rms.iaware.AwareLog.i("AwareMem_EventTracker", stringBuilder.toString());
                    break;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(format(newEvent, newTimeStamp));
                stringBuilder.append(" is abandoned for event ");
                stringBuilder.append(format(this.mEvent, this.mTimeStamp));
                stringBuilder.append(" is ");
                stringBuilder.append(info);
                android.rms.iaware.AwareLog.i("AwareMem_EventTracker", stringBuilder.toString());
                break;
            case 1002:
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("");
                stringBuilder.append(format(this.mEvent, this.mTimeStamp));
                stringBuilder.append(" kill ");
                stringBuilder.append(info);
                android.rms.iaware.AwareLog.i("AwareMem_EventTracker", stringBuilder.toString());
                break;
            case 1003:
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("");
                stringBuilder.append(format(this.mEvent, this.mTimeStamp));
                stringBuilder.append(" trigger ");
                stringBuilder.append(info);
                android.rms.iaware.AwareLog.i("AwareMem_EventTracker", stringBuilder.toString());
                break;
            case 1004:
                this.mValid = false;
                break;
            case 1005:
                if (this.mValid) {
                    this.mValid = false;
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(format(this.mEvent, this.mTimeStamp));
                    stringBuilder.append(" is removed for received event ");
                    stringBuilder.append(format(newEvent, newTimeStamp));
                    android.rms.iaware.AwareLog.i("AwareMem_EventTracker", stringBuilder.toString());
                    break;
                }
                break;
            default:
                return;
        }
    }

    public java.util.ArrayList<android.rms.iaware.DumpData> getDumpData(int time) {
        java.lang.Throwable th;
        long currenttime = java.lang.System.currentTimeMillis();
        synchronized (this.mRecordData) {
            int i;
            try {
                if (this.mRecordData.isEmpty()) {
                    return null;
                }
                java.util.ArrayList<android.rms.iaware.DumpData> tempdumplist = new java.util.ArrayList();
                int i2 = this.mRecordData.size() > 5 ? this.mRecordData.size() - 5 : 0;
                while (i2 < this.mRecordData.size()) {
                    android.rms.iaware.DumpData tempDd = (android.rms.iaware.DumpData) this.mRecordData.get(i2);
                    if (currenttime - tempDd.getTime() < ((long) time) * 1000) {
                        tempdumplist.add(tempDd);
                    }
                    i2++;
                }
                i = time;
                if (tempdumplist.isEmpty()) {
                    return null;
                }
                return tempdumplist;
            } catch (Throwable th2) {
                th = th2;
                throw th;
            }
        }
    }

    public void insertDumpData(long time, java.lang.String operation, int exetime, java.lang.String reason) {
        if (operation != null) {
            if (reason != null) {
                android.rms.iaware.DumpData Dd = new android.rms.iaware.DumpData(time, MEMORY_FEATURE_ID, operation, exetime, reason);
                synchronized (this.mRecordData) {
                    if (this.mRecordData.isEmpty()) {
                        this.mRecordData.add(Dd);
                    } else {
                        boolean flag = true;
                        while (!this.mRecordData.isEmpty()) {
                            if (!(time - ((android.rms.iaware.DumpData) this.mRecordData.get(0)).getTime() > 60000)) {
                                break;
                            }
                            this.mRecordData.remove(0);
                        }
                        this.mRecordData.add(Dd);
                    }
                }
            }
        }
    }

    public java.util.ArrayList<android.rms.iaware.StatisticsData> getStatisticsData() {
        synchronized (this.mStatisticsData) {
            if (this.mStatisticsData.isEmpty()) {
                return null;
            }
            java.util.ArrayList<android.rms.iaware.StatisticsData> tempList = new java.util.ArrayList();
            int listSize = this.mStatisticsData.size();
            for (int i = 0; i < listSize; i++) {
                android.rms.iaware.StatisticsData tempSd = (android.rms.iaware.StatisticsData) this.mStatisticsData.get(i);
                tempList.add(new android.rms.iaware.StatisticsData(tempSd.getFeatureId(), tempSd.getType(), tempSd.getSubType(), tempSd.getOccurCount(), tempSd.getTotalTime(), tempSd.getEffect(), tempSd.getStartTime(), tempSd.getEndTime()));
            }
            clearArrayList();
            return tempList;
        }
    }

    public void insertStatisticData(java.lang.String subtype, int exetime, int effect) {
        java.lang.String str = subtype;
        if (str != null) {
            synchronized (this.mStatisticsData) {
                int size = this.mStatisticsData.size();
                long now = java.lang.System.currentTimeMillis();
                for (int i = 0; i < size; i++) {
                    android.rms.iaware.StatisticsData data = (android.rms.iaware.StatisticsData) this.mStatisticsData.get(i);
                    if (data.getSubType().equals(str)) {
                        data.setTotalTime(data.getTotalTime() + exetime);
                        data.setOccurCount(data.getOccurCount() + 1);
                        data.setEffect(data.getEffect() + effect);
                        data.setEndTime(now);
                        return;
                    }
                }
                this.mStatisticsData.add(new android.rms.iaware.StatisticsData(MEMORY_FEATURE_ID, 2, str, 1, exetime, effect, now, now));
            }
        }
    }

    private void clearArrayList() {
        synchronized (this.mStatisticsData) {
            if (this.mStatisticsData.isEmpty()) {
                return;
            }
            java.util.Iterator<android.rms.iaware.StatisticsData> it = this.mStatisticsData.iterator();
            long now = java.lang.System.currentTimeMillis();
            while (it.hasNext()) {
                android.rms.iaware.StatisticsData tempSd = (android.rms.iaware.StatisticsData) it.next();
                tempSd.setOccurCount(0);
                tempSd.setTotalTime(0);
                tempSd.setEffect(0);
                tempSd.setStartTime(now);
                tempSd.setEndTime(now);
            }
        }
    }
}
