package com.android.server.rms.iaware.memory.utils;

public class MemoryReader {
    private static final int BACKUP_APP_ADJ = 3;
    private static final int CACHED_APP_MAX_ADJ = 15;
    private static final int CACHED_APP_MIN_ADJ = 9;
    private static final int FOREGROUND_APP_ADJ = 0;
    private static final java.lang.String LMK_KILL_COUNT = "/sys/module/lowmemorykiller/parameters/kill_count";
    private static final int LMK_MINFREE_SIZE = 6;
    private static final java.lang.String MEMINFO_ALLOC_COUNT = "/sys/kernel/debug/slowpath_count";
    private static final int PERCEPTIBLE_APP_ADJ = 2;
    private static final int PREVIOUS_APP_ADJ = 7;
    private static final int[] PROCESS_STATM_FORMAT = new int[]{32, 8224, 8224, 32, 32, 32, 32};
    private static final int PROCESS_STATM_SHARED = 1;
    private static final int PROCESS_STATM_VSS = 0;
    private static final int PROCESS_SWAPS_TOTAL = 0;
    private static final int PROCESS_SWAPS_USED = 1;
    private static final int PROC_COLON_TERM = 58;
    private static final int PROC_LINE_TERM = 10;
    private static final int[] PROC_MEMINFO_FORMAT = new int[]{58, 8250, 8250};
    private static final java.lang.String PROC_MEMINFO_NAME = "/proc/meminfo_lite";
    private static final int[] PROC_MMONITOR_FORMAT = new int[]{8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224, 8224};
    private static final java.lang.String PROC_MMONITOR_NAME = "/proc/mmonitor";
    private static final int[] PROC_SWAPS_FORMAT = new int[]{266, 265, 8201, 8201};
    private static final java.lang.String PROC_SWAPS_NAME = "/proc/swaps";
    private static final int SERVICE_B_ADJ = 8;
    private static final java.lang.String TAG = "AwareMem_MemReader";
    private static final int VISIBLE_APP_ADJ = 1;
    private static final java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.rms.iaware.memory.utils.MemoryReader sReader;
    private long mMemAvailable = 0;
    private long mMemFree = 0;
    private com.android.server.rms.collector.MemInfoReader mMemInfo = new com.android.server.rms.collector.MemInfoReader();
    private long mMemTotal = 0;

    public static com.android.server.rms.iaware.memory.utils.MemoryReader getInstance() {
        com.android.server.rms.iaware.memory.utils.MemoryReader memoryReader;
        synchronized (mLock) {
            if (sReader == null) {
                sReader = new com.android.server.rms.iaware.memory.utils.MemoryReader();
            }
            memoryReader = sReader;
        }
        return memoryReader;
    }

    private MemoryReader() {
    }

    public long getTotalRam() {
        long j;
        synchronized (mLock) {
            if (0 == this.mMemTotal) {
                this.mMemInfo.readMemInfo();
                this.mMemTotal = this.mMemInfo.getTotalSizeKb();
            }
            j = this.mMemTotal;
        }
        return j;
    }

    public long getFreeRam() {
        synchronized (mLock) {
            if (updateMemoryInfo() != 0) {
                return -1;
            }
            long j = this.mMemFree;
            return j;
        }
    }

    public long getMemAvailable() {
        synchronized (mLock) {
            if (updateMemoryInfo() != 0) {
                return -1;
            }
            long j = this.mMemAvailable;
            return j;
        }
    }

    public static boolean isZramOK() {
        boolean ret = false;
        long[] out = new long[2];
        if (android.os.Process.readProcFile("/proc/swaps", PROC_SWAPS_FORMAT, null, out, null)) {
            long total = out[0];
            long used = out[1];
            if (used >= 0 && total >= 0 && total - used > com.android.server.rms.iaware.memory.utils.MemoryConstant.getReservedZramSpace()) {
                ret = true;
            }
        } else {
            android.rms.iaware.AwareLog.e("AwareMem_MemReader", "getUsedZram failed");
        }
        return ret;
    }

    public static long getPssForPid(int pid) {
        if (pid < 1) {
            return 0;
        }
        java.lang.String statmFile = new java.lang.StringBuilder();
        statmFile.append("/proc/");
        statmFile.append(pid);
        statmFile.append("/statm");
        long[] statmData = new long[2];
        if (android.os.Process.readProcFile(statmFile.toString(), PROCESS_STATM_FORMAT, null, statmData, null)) {
            long vss = statmData[0];
            long shared = statmData[1];
            if (vss > shared) {
                return (vss - shared) << 2;
            }
        }
        return 0;
    }

    private int updateMemoryInfo() {
        long[] memData = new long[2];
        if (android.os.Process.readProcFile("/proc/meminfo_lite", PROC_MEMINFO_FORMAT, null, memData, null)) {
            this.mMemFree = memData[0];
            this.mMemAvailable = memData[1];
        } else if (this.mMemInfo.readMemInfo() != 0) {
            return -1;
        } else {
            this.mMemFree = this.mMemInfo.getFreeSizeKb();
            this.mMemAvailable = this.mMemInfo.getCachedSizeKb() + this.mMemInfo.getFreeSizeKb();
        }
        return 0;
    }

    public static long getLmkOccurCount() {
        long[] occurCount = new long[1];
        if (android.os.Process.readProcFile("/sys/module/lowmemorykiller/parameters/kill_count", new int[]{8224}, null, occurCount, null)) {
            return occurCount[0];
        }
        return 0;
    }

    public static java.lang.String[] getMeminfoAllocCount() {
        java.lang.String[] meminfoAllocCount = new java.lang.String[2];
        if (android.os.Process.readProcFile("/sys/kernel/debug/slowpath_count", new int[]{4106, 4106}, meminfoAllocCount, null, null)) {
            return meminfoAllocCount;
        }
        return new java.lang.String[0];
    }

    public static java.lang.String getMmonitorData() {
        long[] mmonitorData = new long[PROC_MMONITOR_FORMAT.length];
        if (android.os.Process.readProcFile("/proc/mmonitor", PROC_MMONITOR_FORMAT, null, mmonitorData, null)) {
            return parseMemData(mmonitorData);
        }
        return null;
    }

    private static java.lang.String parseMemData(long[] data) {
        if (data != null) {
            if (data.length >= PROC_MMONITOR_FORMAT.length) {
                java.lang.StringBuilder sb = new java.lang.StringBuilder();
                sb.append("[");
                sb.append("{\"pgAlloc\":\"");
                sb.append(data[1]);
                sb.append("\",\"slowpath0\":\"");
                sb.append(data[2]);
                sb.append("\",\"slowpath1\":\"");
                sb.append(data[3]);
                sb.append("\",\"slowpath2\":\"");
                sb.append(data[4]);
                sb.append("\",\"slowpath3\":\"");
                sb.append(data[5]);
                sb.append("\",\"slowpath4\":\"");
                sb.append(data[6]);
                sb.append("\",\"compactStall\":\"");
                sb.append(data[7]);
                sb.append("\",\"compactSuc\":\"");
                sb.append(data[8]);
                sb.append("\",\"warnAllocFailed\":\"");
                sb.append(data[9]);
                sb.append("\",\"fcache\":\"");
                sb.append(data[11]);
                sb.append("\",\"fcacheMiss\":\"");
                sb.append(data[13]);
                sb.append("\"}");
                sb.append("]");
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("parseMemData: ");
                stringBuilder.append(sb.toString());
                android.rms.iaware.AwareLog.d("AwareMem_MemReader", stringBuilder.toString());
                return sb.toString();
            }
        }
        android.rms.iaware.AwareLog.e("AwareMem_MemReader", "parseMemData: data null");
        return null;
    }
}
