package com.android.server.rms.iaware.memory.utils;

public class MemoryUtils {
    private static final long FLUSH_TIMEOUT = 2000;
    private static final int MAX_RECV_BYTE_BUFFER_LENTH = 8;
    private static final java.lang.String MEMORY_SOCKET = "iawared";
    private static final java.lang.String TAG = "AwareMem_MemoryUtils";
    private static java.io.InputStream mInputStream;
    private static final java.lang.Object mLock = new java.lang.Object();
    private static android.net.LocalSocket mMemorySocket;
    private static java.io.OutputStream mOutputStream;

    public static com.android.server.mtm.iaware.appmng.AwareAppMngSortPolicy getAppMngSortPolicy(int resourceType, int groupId) {
        return getAppMngSortPolicy(resourceType, groupId, 0);
    }

    public static com.android.server.mtm.iaware.appmng.AwareAppMngSortPolicy getAppMngSortPolicy(int resourceType, int groupId, int subType) {
        if (com.android.server.mtm.iaware.appmng.AwareAppMngSort.checkAppMngEnable() && groupId >= 0) {
            if (groupId <= 3) {
                com.android.server.mtm.iaware.appmng.AwareAppMngSort sorted = com.android.server.mtm.iaware.appmng.AwareAppMngSort.getInstance();
                if (sorted == null) {
                    return null;
                }
                return sorted.getAppMngSortPolicy(resourceType, subType, groupId);
            }
        }
        return null;
    }

    public static com.android.server.mtm.iaware.appmng.AwareAppMngSortPolicy getAppMngSortPolicyForMemRepair(int sceneType) {
        if (!com.android.server.mtm.iaware.appmng.AwareAppMngSort.checkAppMngEnable()) {
            return null;
        }
        com.android.server.mtm.iaware.appmng.AwareAppMngSort sorted = com.android.server.mtm.iaware.appmng.AwareAppMngSort.getInstance();
        if (sorted == null) {
            return null;
        }
        return sorted.getAppMngSortPolicyForMemRepair(sceneType);
    }

    public static java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> getAppMngSortPolicyForSystemTrim() {
        if (!com.android.server.mtm.iaware.appmng.AwareAppMngSort.checkAppMngEnable()) {
            return null;
        }
        com.android.server.mtm.iaware.appmng.AwareAppMngSort sorted = com.android.server.mtm.iaware.appmng.AwareAppMngSort.getInstance();
        if (sorted == null) {
            return null;
        }
        return sorted.getAppMngSortPolicyForSystemTrim();
    }

    public static java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo> getAppMngProcGroup(com.android.server.mtm.iaware.appmng.AwareAppMngSortPolicy policy, int groupId) {
        if (policy == null) {
            android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "getAppMngProcGroup sort policy null!");
            return null;
        }
        java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessBlockInfo> processGroups = null;
        switch (groupId) {
            case 0:
                processGroups = policy.getForbidStopProcBlockList();
                break;
            case 1:
                processGroups = policy.getShortageStopProcBlockList();
                break;
            case 2:
                processGroups = policy.getAllowStopProcBlockList();
                break;
            default:
                android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "getAppMngProcGroup unknown group id!");
                break;
        }
        return processGroups;
    }

    public static int killProcessGroupForQuickKill(int uid, int pid) {
        android.os.StrictMode.ThreadPolicy savedPolicy = android.os.StrictMode.allowThreadDiskReads();
        try {
            int killProcessGroupForQuickKill = com.android.server.rms.collector.ResourceCollector.killProcessGroupForQuickKill(uid, pid);
            return killProcessGroupForQuickKill;
        } finally {
            android.os.StrictMode.setThreadPolicy(savedPolicy);
        }
    }

    public static void writeSwappiness(int swappiness) {
        if (swappiness <= 200) {
            if (swappiness >= 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setSwappiness = ");
                stringBuilder.append(swappiness);
                android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", stringBuilder.toString());
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
                buffer.putInt(302);
                buffer.putInt(swappiness);
                android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
                return;
            }
        }
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "invalid swappiness value");
    }

    public static void writeDirectSwappiness(int directswappiness) {
        if (directswappiness <= 200) {
            if (directswappiness >= 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setDirectSwappiness = ");
                stringBuilder.append(directswappiness);
                android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", stringBuilder.toString());
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
                buffer.putInt(303);
                buffer.putInt(directswappiness);
                android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
                return;
            }
        }
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "invalid directswappiness value");
    }

    public static void writeExtraFreeKbytes(int extrafreekbytes) {
        if (extrafreekbytes > 0) {
            if (extrafreekbytes < 200000) {
                int lastExtraFreeKbytes = android.os.SystemProperties.getInt("sys.sysctl.extra_free_kbytes", 24300);
                if (lastExtraFreeKbytes == extrafreekbytes) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("extrafreekbytes is already ");
                    stringBuilder.append(lastExtraFreeKbytes);
                    stringBuilder.append(", no need to set");
                    android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder.toString());
                    return;
                }
                android.os.SystemProperties.set("sys.sysctl.extra_free_kbytes", java.lang.Integer.toString(extrafreekbytes));
                return;
            }
        }
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "invalid extrafreekbytes value");
    }

    private static void configProtectLru() {
        setProtectLruLimit(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigProtectLruLimit());
        setProtectLruRatio(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigProtectLruRatio());
        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", "onProtectLruConfigUpdate");
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
        buffer.putInt(308);
        buffer.putInt(0);
        android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
        setFileProtectLru(304);
    }

    public static void enableProtectLru() {
        setProtectLruSwitch(true);
    }

    public static void disableProtectLru() {
        setProtectLruSwitch(false);
    }

    public static void onProtectLruConfigUpdate() {
        configProtectLru();
        disableProtectLru();
    }

    public static void dynamicSetProtectLru(int state) {
        if (state == 1) {
            enableProtectLru();
        } else if (state == 0) {
            disableProtectLru();
        }
    }

    private static void setProtectLruRatio(int ratio) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("set ProtectLru ratio = ");
        stringBuilder.append(ratio);
        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder.toString());
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
        buffer.putInt(307);
        buffer.putInt(ratio);
        android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
    }

    private static void setFileProtectLru(int commandType) {
        android.util.ArrayMap<java.lang.Integer, android.util.ArraySet<java.lang.String>> filterMap = com.android.server.rms.iaware.memory.utils.MemoryConstant.getFileCacheMap();
        if (filterMap != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("set ProtectLru filterMap size:");
            stringBuilder.append(filterMap.size());
            android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", stringBuilder.toString());
            java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(272);
            int i = 0;
            try {
                int mapSize = filterMap.size();
                while (i < mapSize) {
                    int index = ((java.lang.Integer) filterMap.keyAt(i)).intValue();
                    int isDir = 0;
                    if (index > 50) {
                        index -= 50;
                        isDir = 1;
                    }
                    android.util.ArraySet<java.lang.String> filterSet = (android.util.ArraySet) filterMap.valueAt(i);
                    if (filterSet != null) {
                        java.util.Iterator it = filterSet.iterator();
                        while (it.hasNext()) {
                            java.lang.String filterStr = (java.lang.String) it.next();
                            if (!android.text.TextUtils.isEmpty(filterStr)) {
                                java.lang.StringBuilder stringBuilder2;
                                byte[] stringBytes = filterStr.getBytes("UTF-8");
                                if (stringBytes.length >= 1) {
                                    if (stringBytes.length <= 255) {
                                        stringBuilder2 = new java.lang.StringBuilder();
                                        stringBuilder2.append("setPackageProtectLru filterStr = ");
                                        stringBuilder2.append(filterStr);
                                        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder2.toString());
                                        buffer.clear();
                                        buffer.putInt(commandType);
                                        buffer.putInt(isDir);
                                        buffer.putInt(index);
                                        buffer.putInt(stringBytes.length);
                                        buffer.put(stringBytes);
                                        buffer.putChar(0);
                                        if (sendPacket(buffer) != 0) {
                                            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "setPackageProtectLru sendPacket failed");
                                        }
                                    }
                                }
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("setPackageProtectLru incorrect filterStr = ");
                                stringBuilder2.append(filterStr);
                                android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder2.toString());
                            }
                        }
                        i++;
                    } else {
                        return;
                    }
                }
            } catch (java.io.UnsupportedEncodingException e) {
                android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "setPackageProtectLru UTF-8 not supported");
            }
        }
    }

    private static void setProtectLruLimit(java.lang.String lruConfigStr) {
        if (checkLimitConfigStr(lruConfigStr)) {
            java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(268);
            try {
                java.lang.StringBuilder stringBuilder;
                byte[] stringBytes = lruConfigStr.getBytes("UTF-8");
                if (stringBytes.length >= 1) {
                    if (stringBytes.length <= 255) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("setProtectLruLimit configstr=");
                        stringBuilder.append(lruConfigStr);
                        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder.toString());
                        buffer.clear();
                        buffer.putInt(305);
                        buffer.putInt(stringBytes.length);
                        buffer.put(stringBytes);
                        buffer.putChar(0);
                        if (sendPacket(buffer) != 0) {
                            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "setProtectLruLimit sendPacket failed");
                        }
                        return;
                    }
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setProtectLruLimit incorrect config = ");
                stringBuilder.append(lruConfigStr);
                android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
            } catch (java.io.UnsupportedEncodingException e) {
                android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "setProtectLruLimit UTF-8 not supported?!?");
            }
        }
    }

    private static boolean checkLimitConfigStr(java.lang.String lruConfigStr) {
        if (lruConfigStr == null) {
            return false;
        }
        java.lang.String[] lruConfigStrArray = lruConfigStr.split(" ");
        if (lruConfigStrArray.length != 3) {
            return false;
        }
        int i = 0;
        while (i < lruConfigStrArray.length) {
            int levelValue = java.lang.Integer.parseInt(lruConfigStrArray[i]);
            if (levelValue >= 0) {
                if (levelValue <= 100) {
                    i++;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("protect lru level value is invalid: ");
            stringBuilder.append(levelValue);
            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
            return false;
        }
        return true;
    }

    private static void setProtectLruSwitch(boolean isEnable) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("set ProtectLru switch = ");
        stringBuilder.append(isEnable);
        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder.toString());
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
        buffer.putInt(306);
        buffer.putInt(isEnable);
        android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
    }

    public static boolean checkRamSize(java.lang.String ramSize, java.lang.Long totalMemMb) {
        if (ramSize == null) {
            return false;
        }
        try {
            long ramSizeL = java.lang.Long.parseLong(ramSize.trim());
            if (totalMemMb.longValue() > ramSizeL || totalMemMb.longValue() <= ramSizeL - 1024) {
                return false;
            }
            return true;
        } catch (java.lang.NumberFormatException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("parse ramsze error: ");
            stringBuilder.append(e);
            android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", stringBuilder.toString());
            return false;
        }
    }

    public static void setReclaimGPUMemory(boolean isCompress, int pid) {
        java.lang.String str = "AwareMem_MemoryUtils";
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(isCompress ? "compress" : "decompress");
        stringBuilder.append(" GPU memory, pid:");
        stringBuilder.append(pid);
        android.rms.iaware.AwareLog.d(str, stringBuilder.toString());
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(12);
        buffer.putInt(313);
        buffer.putInt(isCompress);
        buffer.putInt(pid);
        android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
    }

    public static boolean trimMemory(com.android.server.am.HwActivityManagerService hwAms, java.lang.String proc, int level) {
        return trimMemory(hwAms, proc, -2, level, true);
    }

    public static boolean trimMemory(com.android.server.am.HwActivityManagerService hwAms, java.lang.String proc, int userId, int level, boolean fromIAware) {
        java.lang.StringBuilder stringBuilder;
        boolean ret = false;
        if (hwAms == null) {
            return false;
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("trim Memory, proc:");
        stringBuilder2.append(proc);
        stringBuilder2.append(" userId:");
        stringBuilder2.append(userId);
        stringBuilder2.append(" level:");
        stringBuilder2.append(level);
        stringBuilder2.append(" fromIAware:");
        stringBuilder2.append(fromIAware);
        android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder2.toString());
        try {
            ret = hwAms.setProcessMemoryTrimLevel(proc, userId, level, fromIAware);
        } catch (android.os.RemoteException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("trim Memory remote exception, proc:");
            stringBuilder.append(proc);
            stringBuilder.append(" userId:");
            stringBuilder.append(userId);
            stringBuilder.append(" level:");
            stringBuilder.append(level);
            stringBuilder.append(" fromIAware:");
            stringBuilder.append(fromIAware);
            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
        } catch (java.lang.IllegalArgumentException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("trim Memory illegal arg exception, proc:");
            stringBuilder.append(proc);
            stringBuilder.append(" userId:");
            stringBuilder.append(userId);
            stringBuilder.append(" level:");
            stringBuilder.append(level);
            stringBuilder.append(" fromIAware:");
            stringBuilder.append(fromIAware);
            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
        }
        return ret;
    }

    public static void sendActivityDisplayedTime(java.lang.String activityName, int pid, int time) {
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(276);
        try {
            java.lang.StringBuilder stringBuilder;
            byte[] stringBytes = activityName.getBytes("UTF-8");
            if (stringBytes.length >= 1) {
                if (stringBytes.length <= 255) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("sendActivityDisplayedTime: ");
                    stringBuilder.append(activityName);
                    stringBuilder.append(" ");
                    stringBuilder.append(pid);
                    stringBuilder.append(" ");
                    stringBuilder.append(time);
                    android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", stringBuilder.toString());
                    buffer.clear();
                    buffer.putInt(330);
                    buffer.putInt(pid);
                    buffer.putInt(time);
                    buffer.putInt(stringBytes.length);
                    buffer.put(stringBytes);
                    buffer.putChar(0);
                    if (sendPacket(buffer) != 0) {
                        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "sendActivityDisplayedTime sendPacket failed");
                    }
                    return;
                }
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sendActivityDisplayedTime incorrect activityName = ");
            stringBuilder.append(activityName);
            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
        } catch (java.io.UnsupportedEncodingException e) {
            android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "sendActivityDisplayedTime UTF-8 not supported?!?");
        }
    }

    public static void writeMMonitorSwitch(int switchValue) {
        if (switchValue <= 1) {
            if (switchValue >= 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("writeMMonitorSwitch = ");
                stringBuilder.append(switchValue);
                android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", stringBuilder.toString());
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(8);
                buffer.putInt(332);
                buffer.putInt(switchValue);
                android.rms.iaware.IAwaredConnection.getInstance().sendPacket(buffer.array());
                return;
            }
        }
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", "invalid mmonitor switch value");
    }

    private static void createSocket() {
        if (mMemorySocket == null) {
            try {
                mMemorySocket = new android.net.LocalSocket(3);
                mMemorySocket.connect(new android.net.LocalSocketAddress("iawared", android.net.LocalSocketAddress.Namespace.RESERVED));
                mOutputStream = mMemorySocket.getOutputStream();
                mInputStream = mMemorySocket.getInputStream();
                mMemorySocket.setReceiveBufferSize(8);
                android.rms.iaware.AwareLog.d("AwareMem_MemoryUtils", "createSocket Success!");
            } catch (java.io.IOException e) {
                android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "createSocket happend IOException");
                destroySocket();
            }
        }
    }

    public static void destroySocket() {
        synchronized (mLock) {
            if (mOutputStream != null) {
                try {
                    mOutputStream.close();
                } catch (java.io.IOException e) {
                    android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "mOutputStream close failed! happend IOException");
                }
                mOutputStream = null;
            }
            if (mInputStream != null) {
                try {
                    mInputStream.close();
                } catch (java.io.IOException e2) {
                    android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "mInputStream close failed! happend IOException");
                }
                mInputStream = null;
            }
            if (mMemorySocket != null) {
                try {
                    mMemorySocket.close();
                } catch (java.io.IOException e3) {
                    android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "closeSocket failed! happend IOException");
                }
                mMemorySocket = null;
            }
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxRuntimeException: Exception block dominator not found, method:com.android.server.rms.iaware.memory.utils.MemoryUtils.sendPacket(java.nio.ByteBuffer):int, dom blocks: [B:4:0x0006, B:16:0x001e]
        	at jadx.core.dex.visitors.regions.ProcessTryCatchRegions.searchTryCatchDominators(ProcessTryCatchRegions.java:89)
        	at jadx.core.dex.visitors.regions.ProcessTryCatchRegions.process(ProcessTryCatchRegions.java:45)
        	at jadx.core.dex.visitors.regions.RegionMakerVisitor.postProcessRegions(RegionMakerVisitor.java:63)
        	at jadx.core.dex.visitors.regions.RegionMakerVisitor.visit(RegionMakerVisitor.java:58)
        	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:27)
        	at jadx.core.dex.visitors.DepthTraversal.lambda$visit$1(DepthTraversal.java:14)
        	at java.util.ArrayList.forEach(ArrayList.java:1257)
        	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:14)
        	at jadx.core.ProcessClass.process(ProcessClass.java:32)
        	at jadx.core.ProcessClass.lambda$processDependencies$0(ProcessClass.java:51)
        	at java.lang.Iterable.forEach(Iterable.java:75)
        	at jadx.core.ProcessClass.processDependencies(ProcessClass.java:51)
        	at jadx.core.ProcessClass.process(ProcessClass.java:37)
        	at jadx.api.JadxDecompiler.processClass(JadxDecompiler.java:292)
        	at jadx.api.JavaClass.decompile(JavaClass.java:62)
        	at jadx.api.JadxDecompiler.lambda$appendSourcesSave$0(JadxDecompiler.java:200)
        */
    public static int sendPacket(java.nio.ByteBuffer r7) {
        /*
        r0 = mLock;
        monitor-enter(r0);
        r1 = -1;
        if (r7 != 0) goto L_0x0012;
    L_0x0006:
        r2 = "AwareMem_MemoryUtils";	 Catch:{ all -> 0x0010 }
        r3 = "sendPacket ByteBuffer is null!";	 Catch:{ all -> 0x0010 }
        android.rms.iaware.AwareLog.w(r2, r3);	 Catch:{ all -> 0x0010 }
        monitor-exit(r0);	 Catch:{ all -> 0x0010 }
        return r1;	 Catch:{ all -> 0x0010 }
    L_0x0010:
        r1 = move-exception;	 Catch:{ all -> 0x0010 }
        goto L_0x0044;	 Catch:{ all -> 0x0010 }
    L_0x0012:
        r2 = 2;	 Catch:{ all -> 0x0010 }
    L_0x0013:
        r3 = mMemorySocket;	 Catch:{ all -> 0x0010 }
        if (r3 != 0) goto L_0x001a;	 Catch:{ all -> 0x0010 }
    L_0x0017:
        createSocket();	 Catch:{ all -> 0x0010 }
    L_0x001a:
        r3 = mOutputStream;	 Catch:{ all -> 0x0010 }
        if (r3 == 0) goto L_0x0040;
    L_0x001e:
        r3 = mOutputStream;	 Catch:{ IOException -> 0x0033 }
        r4 = r7.array();	 Catch:{ IOException -> 0x0033 }
        r5 = r7.position();	 Catch:{ IOException -> 0x0033 }
        r6 = 0;	 Catch:{ IOException -> 0x0033 }
        r3.write(r4, r6, r5);	 Catch:{ IOException -> 0x0033 }
        r3 = 2000; // 0x7d0 float:2.803E-42 double:9.88E-321;	 Catch:{ IOException -> 0x0033 }
        flush(r3);	 Catch:{ IOException -> 0x0033 }
        monitor-exit(r0);	 Catch:{ all -> 0x0010 }
        return r6;	 Catch:{ all -> 0x0010 }
    L_0x0033:
        r3 = move-exception;	 Catch:{ all -> 0x0010 }
        r4 = "AwareMem_MemoryUtils";	 Catch:{ all -> 0x0010 }
        r5 = "mOutputStream write failed! happend IOException";	 Catch:{ all -> 0x0010 }
        android.rms.iaware.AwareLog.e(r4, r5);	 Catch:{ all -> 0x0010 }
        destroySocket();	 Catch:{ all -> 0x0010 }
        r2 = r2 + -1;	 Catch:{ all -> 0x0010 }
    L_0x0040:
        if (r2 > 0) goto L_0x0013;	 Catch:{ all -> 0x0010 }
    L_0x0042:
        monitor-exit(r0);	 Catch:{ all -> 0x0010 }
        return r1;	 Catch:{ all -> 0x0010 }
    L_0x0044:
        monitor-exit(r0);	 Catch:{ all -> 0x0010 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.iaware.memory.utils.MemoryUtils.sendPacket(java.nio.ByteBuffer):int");
    }

    private static void flush(long millis) throws java.io.IOException {
        java.io.FileDescriptor myFd = mMemorySocket.getFileDescriptor();
        if (myFd != null) {
            long start = android.os.SystemClock.uptimeMillis();
            android.system.Int32Ref pending = new android.system.Int32Ref(0);
            while (true) {
                try {
                    android.system.Os.ioctlInt(myFd, android.system.OsConstants.TIOCOUTQ, pending);
                    if (pending.value > 0) {
                        if (android.os.SystemClock.uptimeMillis() - start < millis) {
                            int left = pending.value;
                            if (left <= 1000) {
                                try {
                                    java.lang.Thread.sleep(0, 10);
                                } catch (java.lang.InterruptedException e) {
                                    return;
                                }
                            } else if (left <= 5000) {
                                java.lang.Thread.sleep(0, 500);
                            } else {
                                java.lang.Thread.sleep(1);
                            }
                        } else {
                            android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", "Socket flush timed out !!!");
                            throw new java.io.IOException("flush timeout");
                        }
                    }
                    return;
                } catch (android.system.ErrnoException e2) {
                    throw e2.rethrowAsIOException();
                }
            }
        }
        throw new java.io.IOException("socket closed");
    }

    public static byte[] recvPacket(int byteSize) {
        byte[] emptyByte = new byte[0];
        if (byteSize <= 0 || mInputStream == null) {
            return emptyByte;
        }
        byte[] recvByte = new byte[byteSize];
        try {
            java.util.Arrays.fill(recvByte, (byte) 0);
            if (mInputStream.read(recvByte) == 0) {
                return emptyByte;
            }
            return recvByte;
        } catch (java.io.IOException e) {
            android.rms.iaware.AwareLog.e("AwareMem_MemoryUtils", " mInputStream write failed happend IOException!");
            destroySocket();
            return emptyByte;
        }
    }

    public static void enterSpecialSceneNotify(int total_watermark, int worker_mask, int autostop_timeout) {
        java.lang.StringBuilder stringBuilder;
        if (com.android.server.rms.iaware.feature.MemoryFeature2.isUpMemoryFeature.get()) {
            if (com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigIonSpeedupSwitch() != 0) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Enter special scene, total_watermark: ");
                stringBuilder.append(total_watermark);
                stringBuilder.append(", worker_mask: ");
                stringBuilder.append(worker_mask);
                stringBuilder.append(", autostop_timeout: ");
                stringBuilder.append(autostop_timeout);
                android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", stringBuilder.toString());
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(16);
                buffer.putInt(340);
                buffer.putInt(total_watermark);
                buffer.putInt(worker_mask);
                buffer.putInt(autostop_timeout);
                sendPacket(buffer);
                return;
            }
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("iaware2.0 mem feature  ");
        stringBuilder.append(com.android.server.rms.iaware.feature.MemoryFeature2.isUpMemoryFeature.get());
        stringBuilder.append(",  camera ion memory speedup switch ");
        stringBuilder.append(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigIonSpeedupSwitch());
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
    }

    public static void exitSpecialSceneNotify() {
        if (com.android.server.rms.iaware.feature.MemoryFeature2.isUpMemoryFeature.get()) {
            if (com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigIonSpeedupSwitch() != 0) {
                android.rms.iaware.AwareLog.i("AwareMem_MemoryUtils", "Exit special scene");
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(4);
                buffer.putInt(341);
                sendPacket(buffer);
                return;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("iaware2.0 mem feature ");
        stringBuilder.append(com.android.server.rms.iaware.feature.MemoryFeature2.isUpMemoryFeature.get());
        stringBuilder.append(",  camera ion memory speedup switch ");
        stringBuilder.append(com.android.server.rms.iaware.memory.utils.MemoryConstant.getConfigIonSpeedupSwitch());
        android.rms.iaware.AwareLog.w("AwareMem_MemoryUtils", stringBuilder.toString());
    }
}
