package com.android.server.rms.iaware.memory.utils;

class PackageStats {
    private java.util.Calendar mCalendar = java.util.Calendar.getInstance();
    private int[] mCurDate = new int[]{0, 0, 0};
    private final android.util.SparseArray<com.android.server.rms.iaware.memory.utils.PackageStats.PackageState> mPackages = new android.util.SparseArray();

    interface BaseOperation {
        void addTimestamp(int i, long j);

        void calcMax();

        void cleanTimestamp(long j, long j2);
    }

    static final class PackageState extends com.android.server.rms.iaware.memory.utils.RecordTable {
        public final java.lang.String mPackageName;
        public final android.util.ArrayMap<java.lang.String, com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState> mProcesses = new android.util.ArrayMap();
        private boolean mTraceProcess = false;
        public final int mUid;

        public PackageState(java.lang.String packageName, int uid) {
            this.mPackageName = packageName;
            this.mUid = uid;
            if (uid < 10000) {
                this.mTraceProcess = true;
            }
        }

        public long addRecord(int record, java.lang.String processName, long timeStamp) {
            if (!android.text.TextUtils.isEmpty(processName)) {
                getProcessState(processName).addTimestamp(record, timeStamp);
            }
            super.addTimestamp(record, timeStamp);
            return this.mTotalRecordCounts[record];
        }

        public void cleanRange(long nowTime, long interval) {
            if (this.mTraceProcess) {
                int size = this.mProcesses.size();
                for (int i = 0; i < size; i++) {
                    ((com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState) this.mProcesses.valueAt(i)).cleanTimestamp(nowTime, interval);
                }
            }
            super.cleanTimestamp(nowTime, interval);
        }

        public void calcMax() {
            if (this.mTraceProcess) {
                int size = this.mProcesses.size();
                for (int i = 0; i < size; i++) {
                    ((com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState) this.mProcesses.valueAt(i)).calcMax();
                }
            }
            super.calcMax();
        }

        private com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState getProcessState(java.lang.String processName) {
            com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState state = (com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState) this.mProcesses.get(processName);
            if (state != null) {
                return state;
            }
            state = new com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState(this.mTraceProcess);
            this.mProcesses.put(processName, state);
            return state;
        }
    }

    static final class ProcessState implements com.android.server.rms.iaware.memory.utils.PackageStats.BaseOperation {
        private com.android.server.rms.iaware.memory.utils.RecordTable mRecordTable;
        private final boolean mTraced;

        ProcessState(boolean traced) {
            this.mTraced = traced;
        }

        public void addTimestamp(int record, long timeStamp) {
            if (this.mTraced) {
                getRecordTable().addTimestamp(record, timeStamp);
            }
        }

        public void cleanTimestamp(long nowTime, long interval) {
            if (this.mTraced) {
                getRecordTable().cleanTimestamp(nowTime, interval);
            }
        }

        public void calcMax() {
            if (this.mTraced) {
                getRecordTable().calcMax();
            }
        }

        public com.android.server.rms.iaware.memory.utils.RecordTable getRecordTable() {
            if (this.mRecordTable == null) {
                this.mRecordTable = new com.android.server.rms.iaware.memory.utils.RecordTable();
            }
            return this.mRecordTable;
        }
    }

    PackageStats() {
        initDate();
    }

    long addRecord(int record, java.lang.String packageName, int uid, java.lang.String processName, long timeStamp) {
        return getPackageState(packageName, uid, true).addRecord(record, processName, timeStamp);
    }

    com.android.server.rms.iaware.memory.utils.PackageStats.PackageState getPackageState(java.lang.String packageName, int uid) {
        return getPackageState(packageName, uid, false);
    }

    void cleanRange(long nowTime, long interval) {
        int size = this.mPackages.size();
        for (int i = 0; i < size; i++) {
            ((com.android.server.rms.iaware.memory.utils.PackageStats.PackageState) this.mPackages.valueAt(i)).cleanRange(nowTime, interval);
        }
    }

    void calcMax() {
        this.mCalendar.setTime(new java.util.Date());
        if (this.mCurDate[2] != this.mCalendar.get(5)) {
            int size = this.mPackages.size();
            for (int i = 0; i < size; i++) {
                ((com.android.server.rms.iaware.memory.utils.PackageStats.PackageState) this.mPackages.valueAt(i)).calcMax();
            }
            initDate();
        }
    }

    private void initDate() {
        this.mCurDate[0] = this.mCalendar.get(1);
        this.mCurDate[1] = this.mCalendar.get(2);
        this.mCurDate[2] = this.mCalendar.get(5);
    }

    private com.android.server.rms.iaware.memory.utils.PackageStats.PackageState getPackageState(java.lang.String packageName, int uid, boolean forced) {
        com.android.server.rms.iaware.memory.utils.PackageStats.PackageState pkgState = (com.android.server.rms.iaware.memory.utils.PackageStats.PackageState) this.mPackages.get(uid);
        if (!forced || pkgState != null) {
            return pkgState;
        }
        pkgState = new com.android.server.rms.iaware.memory.utils.PackageStats.PackageState(packageName, uid);
        this.mPackages.put(uid, pkgState);
        return pkgState;
    }
}
