package com.android.server.rms.iaware.memory.utils;

public class PollingTimer {
    private static final int MSG_POLLING_TIMER = 10;
    private static final java.lang.String TAG = "AwareMem_PollingTimer";
    private java.util.concurrent.atomic.AtomicLong mCurPeriod = new java.util.concurrent.atomic.AtomicLong(0);
    private java.util.concurrent.atomic.AtomicBoolean mIsMaxPeriodTime = new java.util.concurrent.atomic.AtomicBoolean(false);
    private java.util.concurrent.atomic.AtomicLong mLastPeriod = new java.util.concurrent.atomic.AtomicLong(2000);
    private java.util.concurrent.atomic.AtomicLong mNumPoll = new java.util.concurrent.atomic.AtomicLong(1);
    private java.util.concurrent.atomic.AtomicLong mOffsetPeriod = new java.util.concurrent.atomic.AtomicLong(0);
    private com.android.server.rms.iaware.memory.utils.PollingTimer.PollingTimerHandler mPollingTimerHandler;

    private final class PollingTimerHandler extends android.os.Handler {
        public PollingTimerHandler(android.os.Looper looper) {
            super(looper);
        }

        public void removeAllMessage() {
            removeMessages(10);
        }

        public android.os.Message getMessage(int what) {
            return obtainMessage(what, 0, 0, null);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what != 10) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("illegal message: ");
                stringBuilder.append(msg.what);
                android.rms.iaware.AwareLog.w("AwareMem_PollingTimer", stringBuilder.toString());
                return;
            }
            android.os.Bundle extras = new android.os.Bundle();
            extras.putString("appName", "AwareMem_PollingTimer");
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("mNumPoll: ");
            stringBuilder2.append(com.android.server.rms.iaware.memory.utils.PollingTimer.this.mNumPoll);
            android.rms.iaware.AwareLog.d("AwareMem_PollingTimer", stringBuilder2.toString());
            if (com.android.server.rms.iaware.memory.data.handle.DataAppHandle.getInstance().isActivityLaunching()) {
                android.rms.iaware.AwareLog.i("AwareMem_PollingTimer", "time event abandond because of activity starting");
            } else {
                com.android.server.rms.iaware.memory.policy.DMEServer.getInstance().execute("default", extras, 30002, android.os.SystemClock.uptimeMillis());
                com.android.server.rms.iaware.memory.utils.PollingTimer.this.mNumPoll.getAndIncrement();
            }
            synchronized (com.android.server.rms.iaware.memory.utils.PollingTimer.class) {
                com.android.server.rms.iaware.memory.utils.PollingTimer.this.updateNextPeriod();
            }
            if (com.android.server.rms.iaware.memory.utils.PollingTimer.this.mPollingTimerHandler != null) {
                com.android.server.rms.iaware.memory.utils.PollingTimer.this.mPollingTimerHandler.sendMessageDelayed(com.android.server.rms.iaware.memory.utils.PollingTimer.this.mPollingTimerHandler.getMessage(10), com.android.server.rms.iaware.memory.utils.PollingTimer.this.mCurPeriod.get());
            }
        }
    }

    public void setPollingTimerHandler(android.os.HandlerThread handlerThread) {
        if (handlerThread != null) {
            this.mPollingTimerHandler = new com.android.server.rms.iaware.memory.utils.PollingTimer.PollingTimerHandler(handlerThread.getLooper());
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setHandler: object=");
            stringBuilder.append(handlerThread);
            android.rms.iaware.AwareLog.d("AwareMem_PollingTimer", stringBuilder.toString());
            return;
        }
        android.rms.iaware.AwareLog.e("AwareMem_PollingTimer", "setHandler: handlerThread is null!");
    }

    public void stopTimer() {
        if (this.mPollingTimerHandler != null) {
            this.mPollingTimerHandler.removeAllMessage();
        }
        this.mOffsetPeriod.set(0);
        this.mNumPoll.set(1);
        this.mLastPeriod.set(2000);
        this.mIsMaxPeriodTime.set(false);
    }

    public void resetTimer() {
        stopTimer();
        if (this.mPollingTimerHandler != null) {
            this.mPollingTimerHandler.sendMessageDelayed(this.mPollingTimerHandler.getMessage(10), this.mCurPeriod.get());
        }
    }

    public void setPollingPeriod(long pollingPeriod) {
        synchronized (com.android.server.rms.iaware.memory.utils.PollingTimer.class) {
            this.mCurPeriod.set(pollingPeriod);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setPollingPeriod=");
        stringBuilder.append(pollingPeriod);
        android.rms.iaware.AwareLog.d("AwareMem_PollingTimer", stringBuilder.toString());
    }

    private void updateNextPeriod() {
        if (!this.mIsMaxPeriodTime.get()) {
            this.mCurPeriod.addAndGet(this.mOffsetPeriod.get());
            this.mCurPeriod.set(this.mCurPeriod.get() <= 0 ? com.android.server.rms.iaware.memory.utils.MemoryConstant.getDefaultTimerPeriod() : this.mCurPeriod.get());
            if (this.mCurPeriod.get() >= com.android.server.rms.iaware.memory.utils.MemoryConstant.getMaxTimerPeriod()) {
                this.mCurPeriod.set(com.android.server.rms.iaware.memory.utils.MemoryConstant.getMaxTimerPeriod());
                this.mNumPoll.set(1);
                this.mIsMaxPeriodTime.set(true);
            }
            long tmp = this.mNumPoll.get() % ((long) com.android.server.rms.iaware.memory.utils.MemoryConstant.getNumTimerPeriod()) == 0 ? this.mLastPeriod.get() * 2 : this.mLastPeriod.get();
            this.mLastPeriod.set(tmp);
            this.mOffsetPeriod.set(tmp);
        }
    }
}
