package com.android.server.rms.iaware.memory.utils;

public class PrereadUtils {
    private static final int DATA_UPDATE_MSG = 1;
    private static final java.lang.String DEX_SUFFIX = ".dex";
    private static final int MAX_DIR_LOOP = 5;
    private static final int MAX_PREREAD_PKG_NUM = 200;
    private static final int MSG_MEM_PREREAD_ID = 4662;
    private static final int PREREAD_FILE_NUM = 2;
    private static final int RECV_BYTE_BUFFER_LENTH = 8;
    private static final int SWITCH_ON = 1;
    private static final java.lang.String TAG = "AwareMem_PrereadUtils";
    private static final java.lang.String VDEX_SUFFIX = ".vdex";
    private static final java.util.concurrent.atomic.AtomicBoolean mConfigUpdating = new java.util.concurrent.atomic.AtomicBoolean(true);
    private static android.content.Context mContext;
    private static java.util.Set<java.lang.String> mExcludedPkgSet = new java.util.HashSet();
    private static final java.util.concurrent.atomic.AtomicBoolean mMemorySwitch = new java.util.concurrent.atomic.AtomicBoolean(false);
    private static java.lang.Boolean mPrereadOdex = java.lang.Boolean.valueOf(false);
    private static java.util.List<java.lang.String> mPrereadPkgList = new java.util.ArrayList();
    private static com.android.server.rms.iaware.memory.utils.PrereadUtils mPrereadUtils;
    private com.android.server.rms.iaware.memory.utils.PrereadUtils.PrereadHandler mPrereadHandler = new com.android.server.rms.iaware.memory.utils.PrereadUtils.PrereadHandler();

    static final class PrereadHandler extends android.os.Handler {
        PrereadHandler() {
        }

        public void handleMessage(android.os.Message msg) {
            if (msg == null) {
                android.rms.iaware.AwareLog.e("AwareMem_PrereadUtils", "null == msg");
                return;
            }
            if (msg.what == 1) {
                android.rms.iaware.AwareLog.i("AwareMem_PrereadUtils", "DATA_UPDATE_MSG");
                com.android.server.rms.iaware.memory.utils.PrereadUtils.prereadDataUpdate();
            }
        }
    }

    private enum SetPathType {
        REMOVE_PATH,
        SET_PACKAGE,
        SET_PATH
    }

    private PrereadUtils() {
    }

    public static void setContext(android.content.Context context) {
        mContext = context;
    }

    public static com.android.server.rms.iaware.memory.utils.PrereadUtils getInstance() {
        com.android.server.rms.iaware.memory.utils.PrereadUtils prereadUtils;
        synchronized (com.android.server.rms.iaware.memory.utils.PrereadUtils.class) {
            if (mPrereadUtils == null) {
                mPrereadUtils = new com.android.server.rms.iaware.memory.utils.PrereadUtils();
            }
            prereadUtils = mPrereadUtils;
        }
        return prereadUtils;
    }

    public static void start() {
        mMemorySwitch.set(true);
    }

    public static void stop() {
        mPrereadPkgList.clear();
        mExcludedPkgSet.clear();
        mMemorySwitch.set(false);
    }

    public static void setPrereadOdexSwitch(int prereadSwitch) {
        if (android.os.Build.VERSION.SDK_INT < 26) {
            mPrereadOdex = java.lang.Boolean.valueOf(false);
            return;
        }
        boolean z = true;
        if (1 != prereadSwitch) {
            z = false;
        }
        mPrereadOdex = java.lang.Boolean.valueOf(z);
    }

    public static boolean addPkgFilesIfNecessary(java.lang.String pkgName) {
        if (pkgName != null) {
            if (mContext != null) {
                if (mMemorySwitch.get() && !mConfigUpdating.get()) {
                    if (mPrereadOdex.booleanValue()) {
                        if (mExcludedPkgSet.contains(pkgName)) {
                            return false;
                        }
                        if (mPrereadPkgList.contains(pkgName)) {
                            return true;
                        }
                        java.util.List<java.lang.String> fileList = getDexfilesFromPkg(pkgName);
                        if (!fileList.isEmpty()) {
                            if (fileList.size() <= 2) {
                                if (mPrereadPkgList.size() >= 200) {
                                    removePackageFiles((java.lang.String) mPrereadPkgList.remove(0));
                                }
                                if (setPrereadPath(com.android.server.rms.iaware.memory.utils.PrereadUtils.SetPathType.SET_PACKAGE.ordinal(), pkgName)) {
                                    for (java.lang.String filePath : fileList) {
                                        if (filePath != null) {
                                            setPrereadPath(com.android.server.rms.iaware.memory.utils.PrereadUtils.SetPathType.SET_PATH.ordinal(), filePath);
                                        }
                                    }
                                    mPrereadPkgList.add(pkgName);
                                    return true;
                                }
                                mExcludedPkgSet.add(pkgName);
                                return false;
                            }
                        }
                        mExcludedPkgSet.add(pkgName);
                        return false;
                    }
                }
                return false;
            }
        }
        return false;
    }

    private static java.util.List<java.lang.String> getDexfilesFromPkg(java.lang.String pkgName) {
        java.util.List<java.lang.String> fileList = new java.util.ArrayList();
        try {
            android.content.pm.UserInfo currentUser = android.app.ActivityManagerNative.getDefault().getCurrentUser();
            if (currentUser == null) {
                return fileList;
            }
            android.content.Context context = mContext.createPackageContextAsUser(pkgName, 1152, new android.os.UserHandle(currentUser.id));
            java.lang.String sourceDir = context.getApplicationInfo().sourceDir;
            if (sourceDir == null) {
                return fileList;
            }
            if (sourceDir.lastIndexOf(java.io.File.separator) <= 0) {
                android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "source dir name error");
            } else {
                traverseFolder(sourceDir.substring(0, sourceDir.lastIndexOf(java.io.File.separator)), fileList, 0);
            }
            if (fileList.size() != 0) {
                return fileList;
            }
            fileList = getDexFileStatus(context);
            return fileList;
        } catch (android.content.pm.PackageManager.NameNotFoundException e) {
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "getDexfilesFromPkg NameNotFoundException.");
        } catch (android.os.RemoteException e2) {
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "getDexfilesFromPkg remoteException.");
        }
    }

    private static java.util.List<java.lang.String> getDexFileStatus(android.content.Context context) {
        java.lang.String[] instructionSets = com.android.server.pm.InstructionSets.getAppDexInstructionSets(context.getApplicationInfo());
        java.util.ArrayList fileList = new java.util.ArrayList();
        if (instructionSets == null) {
            return fileList;
        }
        java.lang.String[] dexCodeInstructionSets = com.android.server.pm.InstructionSets.getDexCodeInstructionSets(instructionSets);
        if (dexCodeInstructionSets == null) {
            return fileList;
        }
        int i;
        java.util.ArrayList<java.lang.String> paths = new java.util.ArrayList();
        if (context.getApplicationInfo().sourceDir != null) {
            paths.add(context.getApplicationInfo().sourceDir);
        }
        java.lang.String[] splitSourceDirs = context.getApplicationInfo().splitSourceDirs;
        if (splitSourceDirs != null) {
            for (i = 0; i < splitSourceDirs.length; i++) {
                if (splitSourceDirs[i] != null) {
                    paths.add(splitSourceDirs[i]);
                }
            }
        }
        try {
            for (java.lang.String instructionSet : dexCodeInstructionSets) {
                if (instructionSet != null) {
                    java.util.Iterator it = paths.iterator();
                    while (it.hasNext()) {
                        java.lang.String dir = (java.lang.String) it.next();
                        if (dir.lastIndexOf(java.io.File.separator) > 0) {
                            java.lang.String status = dalvik.system.DexFile.getDexFileStatus(dir, instructionSet);
                            if (status != null) {
                                if (status.lastIndexOf(".dex") > 0) {
                                    java.lang.String odexPath = status.substring(0, status.lastIndexOf(".dex") + ".dex".length());
                                    fileList.add(odexPath);
                                    java.lang.String vdexPath = new java.lang.StringBuilder();
                                    vdexPath.append(odexPath.substring(0, odexPath.lastIndexOf(".")));
                                    vdexPath.append(".vdex");
                                    fileList.add(vdexPath.toString());
                                }
                            }
                        }
                    }
                }
            }
        } catch (java.io.IOException e) {
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "preread getDexFileStatus IOException ");
        }
        if (fileList.size() != 2) {
            fileList.clear();
        }
        return fileList;
    }

    public static void removePackageFiles(java.lang.String pkgName) {
        if (pkgName != null) {
            setPrereadPath(com.android.server.rms.iaware.memory.utils.PrereadUtils.SetPathType.REMOVE_PATH.ordinal(), pkgName);
            mPrereadPkgList.remove(pkgName);
            mExcludedPkgSet.remove(pkgName);
        }
    }

    private static void traverseFolder(java.lang.String path, java.util.List<java.lang.String> fileList, int loop) {
        if (loop <= 5 && path != null) {
            if (fileList != null) {
                java.io.File file = new java.io.File(path);
                if (file.exists()) {
                    java.io.File[] files = file.listFiles();
                    if (files != null) {
                        if (files.length != 0) {
                            for (java.io.File subfile : files) {
                                if (subfile != null) {
                                    try {
                                        java.lang.String subfilePath = subfile.getCanonicalPath();
                                        if (subfile.isDirectory()) {
                                            traverseFolder(subfilePath, fileList, loop + 1);
                                        } else if (filterFiles(subfilePath) && !fileList.contains(subfilePath)) {
                                            fileList.add(subfilePath);
                                        }
                                    } catch (java.io.IOException e) {
                                        android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "traverseFolder: getCanonicalPath IOException!");
                                        return;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    private static boolean filterFiles(java.lang.String fileName) {
        if (fileName == null) {
            return false;
        }
        if (!fileName.endsWith(".odex")) {
            if (!fileName.endsWith(".vdex")) {
                return false;
            }
        }
        return true;
    }

    private static int parseRecvPacket(int byteSize) {
        byte[] recvByte = com.android.server.rms.iaware.memory.utils.MemoryUtils.recvPacket(byteSize);
        int ret = -1;
        if (recvByte.length == 0) {
            return -1;
        }
        android.os.Parcel recvMsgParcel = android.os.Parcel.obtain();
        recvMsgParcel.unmarshall(recvByte, 0, recvByte.length);
        recvMsgParcel.setDataPosition(0);
        int func_Id = recvMsgParcel.readInt();
        int status = recvMsgParcel.readInt();
        if (func_Id == 4662) {
            ret = status;
        }
        recvMsgParcel.recycle();
        return ret;
    }

    public static void sendPrereadMsg(java.lang.String pkgName) {
        if (pkgName != null && mMemorySwitch.get()) {
            if (!mConfigUpdating.get()) {
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(264);
                try {
                    byte[] stringBytes = pkgName.getBytes("UTF-8");
                    if (stringBytes.length >= 1) {
                        if (stringBytes.length <= 255) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("sendPrereadMsg pkgname = ");
                            stringBuilder.append(pkgName);
                            android.rms.iaware.AwareLog.i("AwareMem_PrereadUtils", stringBuilder.toString());
                            buffer.clear();
                            buffer.putInt(314);
                            buffer.putInt(stringBytes.length);
                            buffer.put(stringBytes);
                            buffer.putChar(0);
                            if (-1 == com.android.server.rms.iaware.memory.utils.MemoryUtils.sendPacket(buffer)) {
                                android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "sendPrereadMsg sendPacket failed");
                                return;
                            }
                            if (parseRecvPacket(8) == 0) {
                                mPrereadPkgList.clear();
                                prereadDataUpdate();
                            }
                            return;
                        }
                    }
                    android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "sendPrereadMsg incorrect packageName");
                } catch (java.io.UnsupportedEncodingException e) {
                    android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "UnsupportedEncodingException!");
                }
            }
        }
    }

    private static void prereadDataRemove() {
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(4);
        buffer.clear();
        buffer.putInt(312);
        if (-1 == com.android.server.rms.iaware.memory.utils.MemoryUtils.sendPacket(buffer)) {
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "prereadDataRemove sendPacket failed");
        }
    }

    private static boolean setPrereadPath(int opCode, java.lang.String stringValue) {
        if (stringValue == null) {
            return false;
        }
        java.nio.ByteBuffer buffer = java.nio.ByteBuffer.allocate(268);
        try {
            byte[] stringValueBytes = stringValue.getBytes("UTF-8");
            if (stringValueBytes.length >= 1) {
                if (stringValueBytes.length <= 255) {
                    java.lang.String filename = new java.io.File(stringValue).getName();
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("setPrereadPath :opCode ");
                    stringBuilder.append(opCode);
                    stringBuilder.append(", ");
                    stringBuilder.append(filename);
                    android.rms.iaware.AwareLog.d("AwareMem_PrereadUtils", stringBuilder.toString());
                    buffer.clear();
                    buffer.putInt(311);
                    buffer.putInt(opCode);
                    buffer.putInt(stringValueBytes.length);
                    buffer.put(stringValueBytes);
                    buffer.putChar(0);
                    if (-1 != com.android.server.rms.iaware.memory.utils.MemoryUtils.sendPacket(buffer)) {
                        return true;
                    }
                    android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "setPathPreread sendPacket failed");
                    return false;
                }
            }
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "setPrereadPath incorrect stringValueBytes");
            return false;
        } catch (java.io.UnsupportedEncodingException e) {
            android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "UnsupportedEncodingException!");
            return false;
        }
    }

    public void sendPrereadDataUpdateMsg() {
        mConfigUpdating.set(true);
        android.os.Message msg = android.os.Message.obtain();
        msg.what = 1;
        this.mPrereadHandler.sendMessageDelayed(msg, 20000);
    }

    private static void prereadDataUpdate() {
        mConfigUpdating.set(true);
        if (!mPrereadOdex.booleanValue()) {
            mPrereadPkgList.clear();
            mExcludedPkgSet.clear();
        }
        prereadDataRemove();
        for (java.util.Map.Entry<java.lang.String, java.util.ArrayList<java.lang.String>> entry : com.android.server.rms.iaware.memory.utils.MemoryConstant.getCameraPrereadFileMap().entrySet()) {
            java.util.List<java.lang.String> filePathList = (java.util.List) entry.getValue();
            if (filePathList == null) {
                android.rms.iaware.AwareLog.w("AwareMem_PrereadUtils", "prereadDataUpdate: filePathList is null");
                break;
            } else if (setPrereadPath(com.android.server.rms.iaware.memory.utils.PrereadUtils.SetPathType.SET_PACKAGE.ordinal(), (java.lang.String) entry.getKey())) {
                for (java.lang.String filePath : filePathList) {
                    if (filePath != null) {
                        setPrereadPath(com.android.server.rms.iaware.memory.utils.PrereadUtils.SetPathType.SET_PATH.ordinal(), filePath);
                    }
                }
            }
        }
        mConfigUpdating.set(false);
    }
}
