package com.android.server.rms.iaware.sysload;

public class SysLoadManager {
    private static final int FINGERSENSE_OPT = 4;
    private static final int GAME_SCENE_DELAYED = 0;
    private static final int INPUT_FILTER_OPT = 1;
    private static final int MSG_BASE_VALUE = 100;
    private static final int MSG_CHECK_STATUS = 108;
    private static final int MSG_CLOSE_FEATURE = 107;
    private static final int MSG_ENTER_GAME_SCENE = 101;
    private static final int MSG_EXIT_GAME_SCENE = 102;
    private static final int MSG_SINGLE_HAND_OFF = 106;
    private static final int MSG_SINGLE_HAND_ON = 105;
    private static final int MSG_WAKEUP_LOCK = 103;
    private static final int MSG_WAKEUP_RELEASE = 104;
    private static final int PROPERTY_OPT = 8;
    private static final int SINGLE_HAND_OPT = 2;
    private static final int SKIP_USER_ACTIVITY = 16;
    private static final java.lang.String SYSLOAD_SINGLEHAND_TYPE = "LazyMode";
    private static final java.lang.String TAG = "SysLoadManager";
    private static final java.util.concurrent.atomic.AtomicBoolean mIsFeatureEnable = new java.util.concurrent.atomic.AtomicBoolean(false);
    private static com.android.server.rms.iaware.sysload.SysLoadManager sInstance;
    private static java.lang.Object syncObject = new java.lang.Object();
    private final android.util.ArrayMap<com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord, java.lang.Integer> mCallbacks;
    private android.content.Context mContext;
    private com.android.server.rms.iaware.sysload.SysLoadManager.HighLoadHandler mHighLoadHandler;
    private com.android.server.input.HwInputManagerService mInputManagerService;
    private int mInputStatus;
    private int mInputStatusCache;
    private java.util.concurrent.atomic.AtomicBoolean mIsGameScene;
    private int mLockNum;
    private android.os.PowerManager mPowerManager;
    private int mSingleMode;
    private final com.android.server.rms.iaware.sysload.SysLoadManager.SyncRoot mSyncRoot;

    private final class CallbackRecord implements android.os.IBinder.DeathRecipient {
        private final android.rms.iaware.ISceneCallback mCallback;
        public final int mUid;

        public CallbackRecord(int uid, android.rms.iaware.ISceneCallback callback) {
            this.mUid = uid;
            this.mCallback = callback;
        }

        public void binderDied() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("GameScene listener for uid ");
            stringBuilder.append(this.mUid);
            stringBuilder.append(" died.");
            android.rms.iaware.AwareLog.d("SysLoadManager", stringBuilder.toString());
            com.android.server.rms.iaware.sysload.SysLoadManager.this.onCallbackDied(this);
        }

        public void notifySceneChangedAsync(boolean start, int scene) {
            try {
                this.mCallback.onSceneChanged(scene, start, 0, 0, "");
            } catch (android.os.RemoteException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Failed to notify application ");
                stringBuilder.append(this.mUid);
                stringBuilder.append(" that game scene changed, assuming it died.");
                android.rms.iaware.AwareLog.e("SysLoadManager", stringBuilder.toString());
                binderDied();
            }
        }
    }

    private class HighLoadHandler extends android.os.Handler {
        public HighLoadHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder;
            super.handleMessage(msg);
            if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("handleMessage what = ");
                stringBuilder.append(msg.what);
                stringBuilder.append(" mLockNum:");
                stringBuilder.append(com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum);
                stringBuilder.append(" gameMode:");
                stringBuilder.append(com.android.server.rms.iaware.sysload.SysLoadManager.this.mIsGameScene.get());
                android.rms.iaware.AwareLog.i("SysLoadManager", stringBuilder.toString());
            }
            switch (msg.what) {
                case 101:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.setGameScene();
                    return;
                case 102:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.resetGameScene();
                    return;
                case 103:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum = com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum + 1;
                    if (com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum == 1) {
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.setIawareGameMode(true);
                        return;
                    }
                    return;
                case 104:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum = com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum - 1;
                    if (com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum <= 0) {
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.setIawareGameMode(false);
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum = 0;
                        return;
                    }
                    return;
                case 105:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.sendInputAwareSingleMode(true);
                    return;
                case 106:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.sendInputAwareSingleMode(false);
                    return;
                case 107:
                    com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum = 0;
                    return;
                case 108:
                    if (com.android.server.rms.iaware.sysload.SysLoadManager.this.mIsGameScene.get()) {
                        android.rms.iaware.AwareLog.w("SysLoadManager", "check status current is game mode");
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.resetGameScene();
                        return;
                    } else if (com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum > 0) {
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.mLockNum = 0;
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.mInputStatus = com.android.server.rms.iaware.sysload.SysLoadManager.this.mInputStatus & -17;
                        com.android.server.rms.iaware.sysload.SysLoadManager.this.inputOptDisable();
                        return;
                    } else {
                        return;
                    }
                default:
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("error msg what = ");
                    stringBuilder.append(msg.what);
                    android.rms.iaware.AwareLog.e("SysLoadManager", stringBuilder.toString());
                    return;
            }
        }
    }

    public static final class SyncRoot {
    }

    private SysLoadManager() {
        this.mHighLoadHandler = null;
        this.mIsGameScene = new java.util.concurrent.atomic.AtomicBoolean(false);
        this.mLockNum = 0;
        this.mCallbacks = new android.util.ArrayMap();
        this.mSyncRoot = new com.android.server.rms.iaware.sysload.SysLoadManager.SyncRoot();
        this.mInputManagerService = null;
        this.mPowerManager = null;
        this.mContext = null;
        this.mInputStatus = 2;
        this.mInputStatusCache = -1;
        this.mSingleMode = 0;
        this.mHighLoadHandler = new com.android.server.rms.iaware.sysload.SysLoadManager.HighLoadHandler(com.android.internal.os.BackgroundThread.get().getLooper());
    }

    public static com.android.server.rms.iaware.sysload.SysLoadManager getInstance() {
        com.android.server.rms.iaware.sysload.SysLoadManager sysLoadManager;
        synchronized (syncObject) {
            if (sInstance == null) {
                sInstance = new com.android.server.rms.iaware.sysload.SysLoadManager();
            }
            sysLoadManager = sInstance;
        }
        return sysLoadManager;
    }

    private final void setIawareGameMode(boolean lock) {
        if (this.mIsGameScene.get()) {
            if (lock) {
                this.mInputStatus |= 16;
            } else {
                this.mInputStatus &= -17;
            }
            sendInputIawareMode(this.mInputStatus);
        }
    }

    private final void sendInputAwareSingleMode(boolean singleMode) {
        if (singleMode) {
            this.mInputStatus &= -3;
        } else {
            this.mInputStatus |= 2;
        }
        sendInputIawareMode(this.mInputStatus);
    }

    private final void sendInputIawareMode(int status) {
        if (this.mInputManagerService != null && this.mInputStatusCache != status) {
            if (android.rms.iaware.AwareConstant.CURRENT_USER_TYPE == 3) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("send input mode finished cur mode:");
                stringBuilder.append(this.mInputStatusCache);
                stringBuilder.append(" to mode:");
                stringBuilder.append(status);
                android.rms.iaware.AwareLog.i("SysLoadManager", stringBuilder.toString());
            }
            this.mInputStatusCache = status;
            this.mInputManagerService.setIawareGameMode(this.mInputStatusCache);
        }
    }

    public void enable() {
        if (mIsFeatureEnable.get()) {
            android.rms.iaware.AwareLog.d("SysLoadManager", "SysLoadManager has already enable!");
        } else if (android.rms.iaware.DeviceInfo.getDeviceLevel() < 0) {
            android.rms.iaware.AwareLog.e("SysLoadManager", "Device Level unknow!");
        } else {
            mIsFeatureEnable.set(true);
        }
    }

    public void setContext(android.content.Context context) {
        this.mContext = context;
    }

    public void disable() {
        if (mIsFeatureEnable.get()) {
            mIsFeatureEnable.set(false);
            this.mHighLoadHandler.sendEmptyMessageDelayed(107, 0);
            if (this.mIsGameScene.get()) {
                inputOptDisable();
            }
            return;
        }
        android.rms.iaware.AwareLog.d("SysLoadManager", "SysLoadManager has already disable!");
    }

    public void enterGameSceneMsg() {
        if (mIsFeatureEnable.get()) {
            this.mHighLoadHandler.removeMessages(101);
            this.mHighLoadHandler.sendEmptyMessageDelayed(101, 0);
        }
    }

    public void exitGameSceneMsg() {
        if (mIsFeatureEnable.get()) {
            this.mHighLoadHandler.removeMessages(102);
            this.mHighLoadHandler.sendEmptyMessageDelayed(102, 0);
        }
    }

    public void enterLauncher() {
        if (mIsFeatureEnable.get()) {
            this.mHighLoadHandler.sendEmptyMessageDelayed(108, 0);
        }
    }

    public void setInputManagerService(com.android.server.input.HwInputManagerService inputManagerService) {
        this.mInputManagerService = inputManagerService;
    }

    private void inputOptEnable() {
        if (android.rms.iaware.DeviceInfo.getDeviceLevel() > 1) {
            this.mInputStatus |= 4;
        }
        if (this.mLockNum > 0) {
            this.mInputStatus |= 16;
        }
        sendInputIawareMode(this.mInputStatus);
    }

    private void inputOptDisable() {
        if (android.rms.iaware.DeviceInfo.getDeviceLevel() > 1) {
            this.mInputStatus &= -5;
        }
        this.mLockNum = 0;
        this.mInputStatus &= -17;
        sendInputIawareMode(this.mInputStatus);
    }

    public void notifyWakeLock(int uid, int pid, java.lang.String packageName, java.lang.String tag) {
        if (!mIsFeatureEnable.get()) {
            android.rms.iaware.AwareLog.d("SysLoadManager", "SysLoadOpt has already disable!");
        } else if (this.mInputManagerService != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("acquire wakelock, pid: ");
            stringBuilder.append(pid);
            stringBuilder.append(", uid: ");
            stringBuilder.append(uid);
            stringBuilder.append(", packageName: ");
            stringBuilder.append(packageName);
            stringBuilder.append(", tag: ");
            stringBuilder.append(tag);
            android.rms.iaware.AwareLog.d("SysLoadManager", stringBuilder.toString());
            this.mHighLoadHandler.sendEmptyMessageDelayed(103, 0);
        }
    }

    public void notifyWakeLockRelease(int uid, int pid, java.lang.String packageName, java.lang.String tag) {
        if (!mIsFeatureEnable.get()) {
            android.rms.iaware.AwareLog.d("SysLoadManager", "SysLoadOpt has already disable!");
        } else if (this.mInputManagerService != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("release wakelock, pid: ");
            stringBuilder.append(pid);
            stringBuilder.append(", uid: ");
            stringBuilder.append(uid);
            stringBuilder.append(", packageName: ");
            stringBuilder.append(packageName);
            stringBuilder.append(", tag: ");
            stringBuilder.append(tag);
            android.rms.iaware.AwareLog.d("SysLoadManager", stringBuilder.toString());
            if (this.mIsGameScene.get()) {
                notifyToPMSUserActivity();
            }
            this.mHighLoadHandler.sendEmptyMessageDelayed(104, 0);
        }
    }

    private void notifyToPMSUserActivity() {
        if (this.mPowerManager == null && this.mContext != null) {
            this.mPowerManager = (android.os.PowerManager) this.mContext.getSystemService("power");
        }
        if (this.mPowerManager != null) {
            this.mPowerManager.userActivity(android.os.SystemClock.uptimeMillis(), 2, 0);
        } else {
            android.rms.iaware.AwareLog.e("SysLoadManager", "power manager service is null");
        }
    }

    private void setGameScene() {
        if (mIsFeatureEnable.get()) {
            this.mIsGameScene.set(true);
            dispatchGameSceneChanged(true);
            inputOptEnable();
        }
    }

    private void resetGameScene() {
        if (mIsFeatureEnable.get()) {
            if (this.mLockNum > 0) {
                notifyToPMSUserActivity();
            }
            this.mIsGameScene.set(false);
            dispatchGameSceneChanged(false);
            inputOptDisable();
        }
    }

    public boolean isScene(int scene) {
        if (scene != 2) {
            return false;
        }
        return this.mIsGameScene.get();
    }

    public void reportData(android.rms.iaware.CollectData data) {
        if (data != null) {
            android.os.Bundle bundle = data.getBundle();
            if (bundle != null) {
                this.mSingleMode = bundle.getInt("LazyMode");
                if (this.mSingleMode == 0) {
                    this.mHighLoadHandler.sendEmptyMessageDelayed(106, 0);
                } else {
                    this.mHighLoadHandler.sendEmptyMessageDelayed(105, 0);
                }
                java.lang.String str = "SysLoadManager";
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("current SingleMode:");
                stringBuilder.append(this.mSingleMode == 0 ? "off" : "on");
                android.rms.iaware.AwareLog.d(str, stringBuilder.toString());
            }
        }
    }

    public boolean isLiteSysLoadEnable() {
        return mIsFeatureEnable.get();
    }

    public void registerCallback(android.rms.iaware.ISceneCallback callback, int scene) {
        if (mIsFeatureEnable.get() && callback != null) {
            int callingUid = android.os.Binder.getCallingUid();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("game scene registerCallback callback ");
            stringBuilder.append(callback);
            stringBuilder.append(" callingUid ");
            stringBuilder.append(callingUid);
            stringBuilder.append(" callingPid ");
            stringBuilder.append(android.os.Binder.getCallingPid());
            android.rms.iaware.AwareLog.d("SysLoadManager", stringBuilder.toString());
            synchronized (this.mSyncRoot) {
                com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord record = new com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord(callingUid, callback);
                try {
                    callback.asBinder().linkToDeath(record, 0);
                } catch (android.os.RemoteException e) {
                    android.rms.iaware.AwareLog.e("SysLoadManager", "Couldn't register for the death!!!!!");
                }
                this.mCallbacks.put(record, java.lang.Integer.valueOf(scene));
                if ((scene & 3) != 0) {
                    record.notifySceneChangedAsync(this.mIsGameScene.get(), 2);
                }
            }
        }
    }

    private void onCallbackDied(com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord record) {
        synchronized (this.mSyncRoot) {
            this.mCallbacks.remove(record);
        }
    }

    private void dispatchGameSceneChanged(boolean start) {
        java.util.ArrayList<com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord> tempCallbacks = new java.util.ArrayList();
        synchronized (this.mSyncRoot) {
            tempCallbacks.clear();
            for (java.util.Map.Entry<com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord, java.lang.Integer> m : this.mCallbacks.entrySet()) {
                com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord callback = (com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord) m.getKey();
                java.lang.Integer secens = (java.lang.Integer) m.getValue();
                if (!(secens == null || (secens.intValue() & 3) == 0)) {
                    tempCallbacks.add(callback);
                }
            }
        }
        int count = tempCallbacks.size();
        for (int i = 0; i < count; i++) {
            ((com.android.server.rms.iaware.sysload.SysLoadManager.CallbackRecord) tempCallbacks.get(i)).notifySceneChangedAsync(start, 2);
        }
        tempCallbacks.clear();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("dispatchGameSceneChanged count ");
        stringBuilder.append(count);
        android.rms.iaware.AwareLog.d("SysLoadManager", stringBuilder.toString());
    }
}
