package com.android.server.rms.io;

public class IOExceptionHandle {
    private static final int BIGDATA_FACTOR_APP_VALUE = 1048576;
    private static final int BIG_LOG_FACTOR_APP_VALUE = 1;
    public static final long BYTES_SIZE_1G = (android.rms.utils.Utils.DEBUG ? 10485760 : 1073741824);
    private static final java.lang.String DEVICE_STATUS_PATH = "log";
    public static final int EXCEPTION_TYPE_APP_EXCEPTION = 6;
    public static final int EXCEPTION_TYPE_WRITE_TYPES = 1;
    public static final int IO_EXCEPTION_DAYS_LIMIT = (android.rms.utils.Utils.DEBUG ? 1 : 7);
    private static final java.lang.String TAG = "RMS.IO.IOExceptionHandle";
    private static final long TIME_VALUES_MONTH = 2592000000L;
    private static final java.lang.String WRITE_BYTES_FILE_PREFIX = "total_writebytes";
    private static final int WRITTEN_BYTES_EXCEPTION_DAYS_LIMIT = 7;
    private static final long WRITTEN_BYTES_EXCEPTION_LIMIT = (12 * BYTES_SIZE_1G);
    private com.android.server.rms.io.IOStatsService mIOStatsService = null;
    private final com.android.server.rms.utils.Interrupt mInterrupt = new com.android.server.rms.utils.Interrupt();

    static class AppExceptionData {
        public java.lang.String mPkgName;
        public long mStartTime;
        public long mTotalWrittenBytes;

        AppExceptionData() {
        }
    }

    interface CheckHandler {
        com.android.server.rms.io.IOExceptionHandle.ExceptionData check();
    }

    static class ExceptionData {
        public java.lang.Object mData;
        public int mExceptionType;

        public ExceptionData(int exceptionType, java.lang.Object data) {
            this.mExceptionType = exceptionType;
            this.mData = data;
        }
    }

    static class LifeTimeData {
        public int mLifeTime;
        public long mTime;

        public LifeTimeData(long time, int lifeTime) {
            this.mTime = time;
            this.mLifeTime = lifeTime;
        }
    }

    static class WriteBytesData {
        public long mTime;
        public long mWriteBytes;

        public WriteBytesData(long time, long writeBytes) {
            this.mTime = time;
            this.mWriteBytes = writeBytes;
        }
    }

    static class CheckAppHandler implements com.android.server.rms.io.IOExceptionHandle.CheckHandler {
        private com.android.server.rms.io.IOExceptionHandle mIOExceptionHandle = null;

        public CheckAppHandler(com.android.server.rms.io.IOExceptionHandle iOExceptionHandle) {
            this.mIOExceptionHandle = iOExceptionHandle;
        }

        public com.android.server.rms.io.IOExceptionHandle.ExceptionData check() {
            java.util.List<com.android.server.rms.io.IOExceptionHandle.AppExceptionData> appExceptionList = this.mIOExceptionHandle.checkExceptionOnApp();
            if (appExceptionList == null || appExceptionList.size() <= 0) {
                return null;
            }
            return new com.android.server.rms.io.IOExceptionHandle.ExceptionData(6, appExceptionList);
        }
    }

    public IOExceptionHandle(com.android.server.rms.io.IOStatsService iOStatsService) {
        this.mIOStatsService = iOStatsService;
        this.mInterrupt.reset();
    }

    private java.util.List<com.android.server.rms.io.IOExceptionHandle.AppExceptionData> checkExceptionOnApp() {
        android.util.Log.i("RMS.IO.IOExceptionHandle", "do the checking on the App");
        android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> historyList = this.mIOStatsService.getAllIOStatsCollection();
        if (historyList != null) {
            if (historyList.size() != 0) {
                java.util.List<com.android.server.rms.io.IOExceptionHandle.AppExceptionData> exceptionList = new java.util.ArrayList();
                int historyListSize = historyList.size();
                for (int index = 0; index < historyListSize; index++) {
                    com.android.server.rms.io.IOExceptionHandle.AppExceptionData appExceptionData = ((com.android.server.rms.io.IOStatsHistory) historyList.get(historyList.keyAt(index))).checkIfAppIOException();
                    if (appExceptionData != null) {
                        exceptionList.add(appExceptionData);
                    }
                }
                if (exceptionList.size() > 0) {
                    android.util.Log.i("RMS.IO.IOExceptionHandle", "An App Exception occurs");
                } else if (exceptionList.size() == 0) {
                    android.util.Log.i("RMS.IO.IOExceptionHandle", "no error on the app");
                }
                return exceptionList;
            }
        }
        android.util.Log.e("RMS.IO.IOExceptionHandle", "checkExceptionOnApp, the historyList is empty");
        return null;
    }

    public void interrupt() {
        this.mInterrupt.trigger();
    }

    public com.android.server.rms.io.IOExceptionHandle.ExceptionData checkIfExistException() {
        java.util.List<com.android.server.rms.io.IOExceptionHandle.CheckHandler> checkList = new java.util.ArrayList();
        checkList.add(new com.android.server.rms.io.IOExceptionHandle.CheckAppHandler(this));
        com.android.server.rms.io.IOExceptionHandle.ExceptionData result = null;
        for (com.android.server.rms.io.IOExceptionHandle.CheckHandler checkHandler : checkList) {
            if (this.mInterrupt.checkInterruptAndReset()) {
                android.util.Log.e("RMS.IO.IOExceptionHandle", "checkIfExistException,interrupted by user");
                break;
            }
            result = checkHandler.check();
            if (result != null) {
                break;
            }
        }
        return result;
    }

    public void handleIOException(com.android.server.rms.io.IOExceptionHandle.ExceptionData exceptionData) {
        if (exceptionData == null) {
            android.util.Log.e("RMS.IO.IOExceptionHandle", "handleIOException,the exceptionData is null");
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("handleIOException,the exception type:");
        stringBuilder.append(exceptionData.mExceptionType);
        android.util.Log.i("RMS.IO.IOExceptionHandle", stringBuilder.toString());
        if (this.mInterrupt.checkInterruptAndReset()) {
            android.util.Log.e("RMS.IO.IOExceptionHandle", "handleIOException,interrupted by user");
            return;
        }
        if (exceptionData.mExceptionType == 6) {
            uploadAppException(exceptionData.mData);
        }
    }

    private void uploadAppException(java.lang.Object exceptionData) {
        java.util.List<com.android.server.rms.io.IOExceptionHandle.AppExceptionData> appExceptionList = null;
        boolean isInvalid = false;
        try {
            appExceptionList = (java.util.List) exceptionData;
        } catch (java.lang.Exception ex) {
            java.lang.Exception exception = ex;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("uploadAppException,the exceptionData is invalid:");
            stringBuilder.append(ex.getMessage());
            android.util.Log.e("RMS.IO.IOExceptionHandle", stringBuilder.toString());
            isInvalid = true;
        }
        if (!isInvalid) {
            com.android.server.rms.record.ResourceRecordStore resourceRecordStore = com.android.server.rms.record.ResourceRecordStore.getInstance();
            for (com.android.server.rms.io.IOExceptionHandle.AppExceptionData appExceptionData : appExceptionList) {
                com.android.server.rms.record.ResourceUtils.uploadBigDataLogToIMonitor(25, appExceptionData.mPkgName, 1, (int) (appExceptionData.mTotalWrittenBytes / 1048576));
                if (resourceRecordStore != null) {
                    resourceRecordStore.createAndCheckUploadBigDataInfos(-1, 25, appExceptionData.mPkgName, 1, 0, (int) (appExceptionData.mTotalWrittenBytes / 1048576), null);
                }
            }
        }
    }
}
