package com.android.server.rms.io;

public class IOFileRotator {
    private static final int MAX_FILE_SIZE = 262144;
    private static long MAX_SIZE_BASE_PATH = 2097152;
    private static final java.lang.String SUFFIX_BACKUP = ".backup";
    private static final java.lang.String SUFFIX_NO_BACKUP = ".no_backup";
    private static final java.lang.String TAG = "RMS.IO.FileRotator";
    private static long mMaxSizeForBasePath = MAX_SIZE_BASE_PATH;
    private final java.io.File mBasePath;
    private final long mDeleteAgeMillis;
    private long mMaxFileSize;
    private final java.lang.String mPrefix;
    private final long mRotateAgeMillis;

    private static class FileInfo {
        public long endMillis;
        public final java.lang.String prefix;
        public long startMillis;

        public FileInfo(java.lang.String prefix) {
            this.prefix = (java.lang.String) com.android.internal.util.Preconditions.checkNotNull(prefix);
        }

        public boolean parse(java.lang.String name) {
            java.lang.StringBuilder stringBuilder;
            this.endMillis = -1;
            this.startMillis = -1;
            int dotIndex = name.lastIndexOf(46);
            int dashIndex = name.lastIndexOf(45);
            if (dotIndex != -1) {
                if (dashIndex != -1) {
                    if (this.prefix.equals(name.substring(0, dotIndex))) {
                        try {
                            this.startMillis = java.lang.Long.parseLong(name.substring(dotIndex + 1, dashIndex));
                            if (name.length() - dashIndex == 1) {
                                this.endMillis = Long.MAX_VALUE;
                            } else {
                                this.endMillis = java.lang.Long.parseLong(name.substring(dashIndex + 1));
                            }
                            return true;
                        } catch (java.lang.NumberFormatException e) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("FileInfo.parse,name:");
                            stringBuilder2.append(name);
                            stringBuilder2.append(" NumberFormatException");
                            android.util.Slog.e("RMS.IO.FileRotator", stringBuilder2.toString());
                            return false;
                        }
                    }
                    if (android.rms.utils.Utils.DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("FileInfo.parse,name:");
                        stringBuilder.append(name);
                        stringBuilder.append(" prefix doesn't match");
                        android.util.Log.d("RMS.IO.FileRotator", stringBuilder.toString());
                    }
                    return false;
                }
            }
            if (android.rms.utils.Utils.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("FileInfo.parse,name:");
                stringBuilder.append(name);
                stringBuilder.append(" missing time section");
                android.util.Log.d("RMS.IO.FileRotator", stringBuilder.toString());
            }
            return false;
        }

        public java.lang.String build() {
            java.lang.StringBuilder name = new java.lang.StringBuilder();
            name.append(this.prefix);
            name.append('.');
            name.append(this.startMillis);
            name.append('-');
            if (this.endMillis != Long.MAX_VALUE) {
                name.append(this.endMillis);
            }
            return name.toString();
        }

        public boolean isActive() {
            return this.endMillis == Long.MAX_VALUE;
        }
    }

    public interface Reader {
        void read(java.io.InputStream inputStream) throws java.io.IOException;
    }

    public interface Writer {
        void write(java.io.OutputStream outputStream) throws java.io.IOException;
    }

    public interface Rewriter extends com.android.server.rms.io.IOFileRotator.Reader, com.android.server.rms.io.IOFileRotator.Writer {
        void reset();

        boolean shouldWrite();
    }

    private static class RewriterDef implements com.android.server.rms.io.IOFileRotator.Rewriter {
        private com.android.server.rms.io.IOFileRotator.Reader mReader = null;
        private com.android.server.rms.io.IOFileRotator.Writer mWriter = null;

        public RewriterDef(com.android.server.rms.io.IOFileRotator.Reader reader, com.android.server.rms.io.IOFileRotator.Writer writer) {
            this.mReader = reader;
            this.mWriter = writer;
        }

        public void reset() {
        }

        public void read(java.io.InputStream in) throws java.io.IOException {
            if (this.mReader == null) {
                android.util.Log.e("RMS.IO.FileRotator", "RewriterDef,the reader is null");
            } else {
                this.mReader.read(in);
            }
        }

        public boolean shouldWrite() {
            return true;
        }

        public void write(java.io.OutputStream out) throws java.io.IOException {
            if (this.mWriter == null) {
                android.util.Log.e("RMS.IO.FileRotator", "RewriterDef,the Writer is null");
            } else {
                this.mWriter.write(out);
            }
        }
    }

    public IOFileRotator(java.io.File basePath, java.lang.String prefix, long rotateAgeMillis, long deleteAgeMillis, long maxFileSize) {
        this(basePath, prefix, rotateAgeMillis, deleteAgeMillis);
        this.mMaxFileSize = maxFileSize;
    }

    public IOFileRotator(java.io.File basePath, java.lang.String prefix, long rotateAgeMillis, long deleteAgeMillis) {
        this.mMaxFileSize = 262144;
        this.mBasePath = (java.io.File) com.android.internal.util.Preconditions.checkNotNull(basePath);
        this.mPrefix = (java.lang.String) com.android.internal.util.Preconditions.checkNotNull(prefix);
        this.mRotateAgeMillis = rotateAgeMillis;
        this.mDeleteAgeMillis = deleteAgeMillis;
        if (!(this.mBasePath.exists() || this.mBasePath.mkdirs())) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("IOFileRotator,fail to create the directory:");
            stringBuilder.append(this.mBasePath);
            android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
        }
        for (java.lang.String name : getBasePathFileList()) {
            if (name.startsWith(this.mPrefix)) {
                java.lang.StringBuilder stringBuilder2;
                java.io.File backupFile;
                java.lang.StringBuilder stringBuilder3;
                if (name.endsWith(".backup")) {
                    if (android.rms.utils.Utils.DEBUG) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("recovering ");
                        stringBuilder2.append(name);
                        android.util.Log.d("RMS.IO.FileRotator", stringBuilder2.toString());
                    }
                    backupFile = new java.io.File(this.mBasePath, name);
                    if (!backupFile.renameTo(new java.io.File(this.mBasePath, name.substring(0, name.length() - ".backup".length())))) {
                        stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("IOFileRotator,fail to renameTo,file:");
                        stringBuilder3.append(backupFile.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                } else if (name.endsWith(".no_backup")) {
                    if (android.rms.utils.Utils.DEBUG) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("recovering ");
                        stringBuilder2.append(name);
                        android.util.Log.d("RMS.IO.FileRotator", stringBuilder2.toString());
                    }
                    backupFile = new java.io.File(this.mBasePath, name);
                    java.io.File file = new java.io.File(this.mBasePath, name.substring(0, name.length() - ".no_backup".length()));
                    if (!backupFile.delete()) {
                        stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("IOFileRotator,fail to delete,file:");
                        stringBuilder3.append(backupFile.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                    if (!file.delete()) {
                        stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("IOFileRotator,fail to delete,file:");
                        stringBuilder3.append(file.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                }
            }
        }
    }

    public void deleteAll() {
        com.android.server.rms.io.IOFileRotator.FileInfo info = new com.android.server.rms.io.IOFileRotator.FileInfo(this.mPrefix);
        for (java.lang.String name : getBasePathFileList()) {
            if (info.parse(name)) {
                if (!new java.io.File(this.mBasePath, name).delete()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("deleteAll,fail to delete the file:");
                    stringBuilder.append(name);
                    android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
                }
            }
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: EliminatePhiNodes
        jadx.core.utils.exceptions.JadxRuntimeException: Assign predecessor not found for B:6:0x001c from B:24:?
        	at jadx.core.dex.visitors.ssa.EliminatePhiNodes.replaceMerge(EliminatePhiNodes.java:102)
        	at jadx.core.dex.visitors.ssa.EliminatePhiNodes.replaceMergeInstructions(EliminatePhiNodes.java:68)
        	at jadx.core.dex.visitors.ssa.EliminatePhiNodes.visit(EliminatePhiNodes.java:31)
        	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:27)
        	at jadx.core.dex.visitors.DepthTraversal.lambda$visit$1(DepthTraversal.java:14)
        	at java.util.ArrayList.forEach(ArrayList.java:1257)
        	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:14)
        	at jadx.core.ProcessClass.process(ProcessClass.java:32)
        	at jadx.api.JadxDecompiler.processClass(JadxDecompiler.java:292)
        	at jadx.api.JavaClass.decompile(JavaClass.java:62)
        	at jadx.api.JadxDecompiler.lambda$appendSourcesSave$0(JadxDecompiler.java:200)
        */
    public void dumpAll(java.io.OutputStream r10) throws java.io.IOException {
        /*
        r9 = this;
        r0 = new java.util.zip.ZipOutputStream;
        r0.<init>(r10);
        r1 = new com.android.server.rms.io.IOFileRotator$FileInfo;	 Catch:{ all -> 0x0048 }
        r2 = r9.mPrefix;	 Catch:{ all -> 0x0048 }
        r1.<init>(r2);	 Catch:{ all -> 0x0048 }
        r2 = r9.getBasePathFileList();	 Catch:{ all -> 0x0048 }
        r3 = r2.length;	 Catch:{ all -> 0x0048 }
        r4 = 0;	 Catch:{ all -> 0x0048 }
    L_0x0012:
        if (r4 >= r3) goto L_0x0043;	 Catch:{ all -> 0x0048 }
    L_0x0014:
        r5 = r2[r4];	 Catch:{ all -> 0x0048 }
        r6 = r1.parse(r5);	 Catch:{ all -> 0x0048 }
        if (r6 == 0) goto L_0x0040;	 Catch:{ all -> 0x0048 }
    L_0x001c:
        r6 = new java.util.zip.ZipEntry;	 Catch:{ all -> 0x0048 }
        r6.<init>(r5);	 Catch:{ all -> 0x0048 }
        r0.putNextEntry(r6);	 Catch:{ all -> 0x0048 }
        r7 = new java.io.File;	 Catch:{ all -> 0x0048 }
        r8 = r9.mBasePath;	 Catch:{ all -> 0x0048 }
        r7.<init>(r8, r5);	 Catch:{ all -> 0x0048 }
        r8 = new java.io.FileInputStream;	 Catch:{ all -> 0x0048 }
        r8.<init>(r7);	 Catch:{ all -> 0x0048 }
        libcore.io.Streams.copy(r8, r0);	 Catch:{ all -> 0x003b }
        libcore.io.IoUtils.closeQuietly(r8);	 Catch:{ all -> 0x0048 }
        r0.closeEntry();	 Catch:{ all -> 0x0048 }
        goto L_0x0040;	 Catch:{ all -> 0x0048 }
    L_0x003b:
        r3 = move-exception;	 Catch:{ all -> 0x0048 }
        libcore.io.IoUtils.closeQuietly(r8);	 Catch:{ all -> 0x0048 }
        throw r3;	 Catch:{ all -> 0x0048 }
    L_0x0040:
        r4 = r4 + 1;
        goto L_0x0012;
    L_0x0043:
        libcore.io.IoUtils.closeQuietly(r0);
        return;
    L_0x0048:
        r1 = move-exception;
        libcore.io.IoUtils.closeQuietly(r0);
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.io.IOFileRotator.dumpAll(java.io.OutputStream):void");
    }

    public long getAvailableBytesInActiveFile(long currentTimeMillis) {
        long j = 0;
        long availableBytes = 0;
        try {
            availableBytes = this.mMaxFileSize - new java.io.File(this.mBasePath, getActiveName(currentTimeMillis)).length();
            if (availableBytes > 0) {
                j = availableBytes;
            }
            availableBytes = j;
        } catch (java.lang.RuntimeException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkIfActiveFileFull,RuntimeException:");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
        } catch (java.lang.Exception e2) {
            android.util.Log.e("RMS.IO.FileRotator", "checkIfActiveFileFull,fail to read the file's size");
        } catch (Throwable th) {
        }
        return availableBytes;
    }

    public boolean removeFilesWhenOverFlow() {
        int index = 0;
        boolean isHandle = false;
        try {
            long directorySize = android.rms.utils.Utils.getSizeOfDirectory(this.mBasePath);
            if (directorySize < mMaxSizeForBasePath) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("removeFilesWhenOverFlow,the total size is ok,current size:");
                stringBuilder.append(directorySize);
                android.util.Log.i("RMS.IO.FileRotator", stringBuilder.toString());
                return false;
            }
            java.lang.String[] baseFiles = getBasePathFileList();
            int totalSize = 0;
            int deleteEndIndex = 0;
            for (int index2 = baseFiles.length - 1; index2 >= 0; index2--) {
                totalSize = (int) (((long) totalSize) + new java.io.File(this.mBasePath, baseFiles[index2]).length());
                if (((long) totalSize) >= mMaxSizeForBasePath) {
                    deleteEndIndex = index2;
                    break;
                }
            }
            while (index <= deleteEndIndex) {
                if (!new java.io.File(this.mBasePath, baseFiles[index]).delete()) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("removeFilesWhenOverFlow,fail to delete the ");
                    stringBuilder2.append(baseFiles[index]);
                    android.util.Log.e("RMS.IO.FileRotator", stringBuilder2.toString());
                }
                index++;
            }
            isHandle = true;
            return isHandle;
        } catch (java.lang.RuntimeException e) {
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("removeFilesWhenOverFlow,RuntimeException:");
            stringBuilder3.append(e.getMessage());
            android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
        } catch (java.lang.Exception e2) {
            android.util.Log.e("RMS.IO.FileRotator", "removeFilesWhenOverFlow,fail to read the file's size");
        }
    }

    public void forceFile(long currentTimeMillis, long endTimeMills) {
        java.lang.String activeFileName = getActiveName(currentTimeMillis);
        java.io.File currentFile = new java.io.File(this.mBasePath, activeFileName);
        if (currentFile.exists()) {
            com.android.server.rms.io.IOFileRotator.FileInfo info = new com.android.server.rms.io.IOFileRotator.FileInfo(this.mPrefix);
            if (info.parse(activeFileName)) {
                if (info.isActive()) {
                    info.endMillis = endTimeMills;
                    java.io.File destFile = new java.io.File(this.mBasePath, info.build());
                    if (!currentFile.renameTo(destFile)) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("forceFile,fail to renameTo:destFile");
                        stringBuilder.append(destFile.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
                    }
                }
            }
        }
    }

    public void rewriteActive(com.android.server.rms.io.IOFileRotator.Rewriter rewriter, long currentTimeMillis) throws java.io.IOException {
        if (rewriter == null) {
            android.util.Log.e("RMS.IO.FileRotator", "rewriteActive,the rewriter is null");
        } else {
            rewriteSingle(rewriter, getActiveName(currentTimeMillis));
        }
    }

    @java.lang.Deprecated
    public void combineActive(com.android.server.rms.io.IOFileRotator.Reader reader, com.android.server.rms.io.IOFileRotator.Writer writer, long currentTimeMillis) throws java.io.IOException {
        rewriteActive(new com.android.server.rms.io.IOFileRotator.RewriterDef(reader, writer), currentTimeMillis);
    }

    private void rewriteSingle(com.android.server.rms.io.IOFileRotator.Rewriter rewriter, java.lang.String name) throws java.io.IOException {
        java.lang.StringBuilder stringBuilder;
        java.io.IOException rethrowAsIoException;
        if (android.rms.utils.Utils.DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("rewriting ");
            stringBuilder2.append(name);
            android.util.Log.d("RMS.IO.FileRotator", stringBuilder2.toString());
        }
        java.io.File file = new java.io.File(this.mBasePath, name);
        rewriter.reset();
        java.io.File file2;
        java.lang.StringBuilder stringBuilder3;
        java.io.File backupFile;
        if (file.exists()) {
            readFile(file, rewriter);
            if (rewriter.shouldWrite()) {
                file2 = this.mBasePath;
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append(name);
                stringBuilder3.append(".backup");
                backupFile = new java.io.File(file2, stringBuilder3.toString());
                if (!file.renameTo(backupFile)) {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("rewriteSingle,fail to renameTo:");
                    stringBuilder3.append(backupFile.getName());
                    android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                }
                try {
                    writeFile(file, rewriter);
                    if (!backupFile.delete()) {
                        stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("rewriteSingle,fail to delete the file:");
                        stringBuilder3.append(backupFile.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                } catch (java.lang.Throwable t) {
                    if (!file.delete()) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("rewriteSingle,fail to delete the file:");
                        stringBuilder.append(file.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
                    }
                    if (!backupFile.renameTo(file)) {
                        stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("rewriteSingle,fail to renameTo:");
                        stringBuilder3.append(backupFile.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                    rethrowAsIoException = rethrowAsIoException(t);
                }
            } else {
                return;
            }
        }
        file2 = this.mBasePath;
        stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append(name);
        stringBuilder3.append(".no_backup");
        backupFile = new java.io.File(file2, stringBuilder3.toString());
        if (!backupFile.createNewFile()) {
            stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("rewriteSingle,fail to createNewFile,");
            stringBuilder3.append(backupFile.getName());
            android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
        }
        try {
            writeFile(file, rewriter);
            if (!backupFile.delete()) {
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("rewriteSingle,fail to delete the file:");
                stringBuilder3.append(backupFile.getName());
                android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
            }
        } catch (java.lang.Throwable t2) {
            if (!file.delete()) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("rewriteSingle,fail to delete the file:");
                stringBuilder.append(file.getName());
                android.util.Log.e("RMS.IO.FileRotator", stringBuilder.toString());
            }
            if (!backupFile.delete()) {
                stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("rewriteSingle,fail to delete the file:");
                stringBuilder3.append(backupFile.getName());
                android.util.Log.e("RMS.IO.FileRotator", stringBuilder3.toString());
            }
            rethrowAsIoException = rethrowAsIoException(t2);
        }
    }

    public void readMatching(com.android.server.rms.io.IOFileRotator.Reader reader, long matchStartMillis, long matchEndMillis) throws java.io.IOException {
        com.android.server.rms.io.IOFileRotator.FileInfo info = new com.android.server.rms.io.IOFileRotator.FileInfo(this.mPrefix);
        for (java.lang.String name : getBasePathFileList()) {
            if (info.parse(name)) {
                if (info.startMillis <= matchEndMillis && matchStartMillis <= info.endMillis) {
                    if (android.rms.utils.Utils.DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("reading matching ");
                        stringBuilder.append(name);
                        android.util.Log.d("RMS.IO.FileRotator", stringBuilder.toString());
                    }
                    readFile(new java.io.File(this.mBasePath, name), reader);
                }
            }
        }
    }

    private java.lang.String getActiveName(long currentTimeMillis) {
        java.lang.String oldestActiveName = null;
        long oldestActiveStart = Long.MAX_VALUE;
        com.android.server.rms.io.IOFileRotator.FileInfo info = new com.android.server.rms.io.IOFileRotator.FileInfo(this.mPrefix);
        for (java.lang.String name : getBasePathFileList()) {
            if (info.parse(name)) {
                if (info.isActive() && info.startMillis < currentTimeMillis && info.startMillis < oldestActiveStart) {
                    oldestActiveName = name;
                    oldestActiveStart = info.startMillis;
                }
            }
        }
        if (oldestActiveName != null) {
            return oldestActiveName;
        }
        info.startMillis = currentTimeMillis;
        info.endMillis = Long.MAX_VALUE;
        return info.build();
    }

    private java.lang.String[] getBasePathFileList() {
        java.lang.String[] baseFiles = this.mBasePath.list();
        if (baseFiles != null && baseFiles.length != 0) {
            return baseFiles;
        }
        android.util.Log.e("RMS.IO.FileRotator", "getBasePathFileList,the baseFiles is empty");
        return new java.lang.String[0];
    }

    public void maybeRotate(long currentTimeMillis) {
        long j = currentTimeMillis;
        long rotateBefore = j - this.mRotateAgeMillis;
        long deleteBefore = j - this.mDeleteAgeMillis;
        com.android.server.rms.io.IOFileRotator.FileInfo info = new com.android.server.rms.io.IOFileRotator.FileInfo(this.mPrefix);
        java.lang.String[] baseFileList = getBasePathFileList();
        int length = baseFileList.length;
        int i = 0;
        while (i < length) {
            java.lang.String name = baseFileList[i];
            if (info.parse(name)) {
                if (info.isActive()) {
                    if (info.startMillis <= rotateBefore) {
                        if (android.rms.utils.Utils.DEBUG) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("rotating ");
                            stringBuilder.append(name);
                            android.util.Log.d("RMS.IO.FileRotator", stringBuilder.toString());
                        }
                        info.endMillis = j;
                        java.io.File file = new java.io.File(this.mBasePath, name);
                        java.io.File destFile = new java.io.File(this.mBasePath, info.build());
                        if (!file.renameTo(destFile)) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("maybeRotate,fail to renameTo:");
                            stringBuilder2.append(destFile.getName());
                            android.util.Log.e("RMS.IO.FileRotator", stringBuilder2.toString());
                        }
                    }
                } else if (info.endMillis <= deleteBefore) {
                    if (android.rms.utils.Utils.DEBUG) {
                        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                        stringBuilder3.append("deleting ");
                        stringBuilder3.append(name);
                        android.util.Log.d("RMS.IO.FileRotator", stringBuilder3.toString());
                    }
                    java.io.File file2 = new java.io.File(this.mBasePath, name);
                    if (!file2.delete()) {
                        java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                        stringBuilder4.append("maybeRotate,fail to delete the file:");
                        stringBuilder4.append(file2.getName());
                        android.util.Log.e("RMS.IO.FileRotator", stringBuilder4.toString());
                    }
                }
            }
            i++;
            j = currentTimeMillis;
        }
    }

    private static void readFile(java.io.File file, com.android.server.rms.io.IOFileRotator.Reader reader) throws java.io.IOException {
        java.io.BufferedInputStream bis = new java.io.BufferedInputStream(new java.io.FileInputStream(file));
        try {
            reader.read(bis);
        } finally {
            libcore.io.IoUtils.closeQuietly(bis);
        }
    }

    private static void writeFile(java.io.File file, com.android.server.rms.io.IOFileRotator.Writer writer) throws java.io.IOException {
        java.io.FileOutputStream fos = new java.io.FileOutputStream(file);
        java.io.BufferedOutputStream bos = new java.io.BufferedOutputStream(fos);
        try {
            writer.write(bos);
            bos.flush();
        } finally {
            android.os.FileUtils.sync(fos);
            libcore.io.IoUtils.closeQuietly(bos);
        }
    }

    private static java.io.IOException rethrowAsIoException(java.lang.Throwable t) throws java.io.IOException {
        if (t instanceof java.io.IOException) {
            throw ((java.io.IOException) t);
        }
        throw new java.io.IOException(t.getMessage(), t);
    }
}
