package com.android.server.rms.io;

public final class IOStatsCollection implements com.android.server.rms.io.IOFileRotator.Reader, java.lang.Cloneable {
    private static final java.lang.String TAG = "RMS.IO.IOStatsCollection";
    private android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> mStatsMap = new android.util.SparseArray();

    public int getTotalBytes() {
        int totalBytes = 0;
        int statsMapSize = this.mStatsMap.size();
        for (int index = 0; index < statsMapSize; index++) {
            totalBytes = (int) (((long) totalBytes) + ((com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(this.mStatsMap.keyAt(index))).getTotalBytesNum());
        }
        return totalBytes;
    }

    public android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> getIOStatsHistoryMap() {
        return this.mStatsMap;
    }

    public void reset() {
        this.mStatsMap.clear();
    }

    public void dump(java.io.PrintWriter pw) {
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.IO.IOStatsCollection", "begin dump IOStatsCollection");
        }
        int statsMapSize = this.mStatsMap.size();
        for (int index = 0; index < statsMapSize; index++) {
            int uid = this.mStatsMap.keyAt(index);
            com.android.server.rms.io.IOStatsHistory history = (com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(uid);
            if (history == null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("uid:");
                stringBuilder.append(uid);
                stringBuilder.append("'s history is empty");
                android.util.Log.e("RMS.IO.IOStatsCollection", stringBuilder.toString());
            } else {
                history.dump(pw);
            }
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.IO.IOStatsCollection", "end dump IOStatsCollection");
        }
    }

    public void addHistories(com.android.server.rms.io.IOStatsCollection fromCollection) {
        if (fromCollection != null) {
            if (fromCollection.getIOStatsHistoryMap().size() != 0) {
                android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> fromHistoryMap = fromCollection.getIOStatsHistoryMap();
                int historyMapSize = fromHistoryMap.size();
                for (int index = 0; index < historyMapSize; index++) {
                    int uid = fromHistoryMap.keyAt(index);
                    com.android.server.rms.io.IOStatsHistory history = (com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(uid);
                    com.android.server.rms.io.IOStatsHistory addHistory = (com.android.server.rms.io.IOStatsHistory) fromHistoryMap.get(uid);
                    if (history == null) {
                        this.mStatsMap.put(uid, addHistory.clone());
                    } else {
                        history.addAllEntries(addHistory);
                    }
                }
                return;
            }
        }
        android.util.Log.e("RMS.IO.IOStatsCollection", "addHistories,the fromCollection is empty");
    }

    public com.android.server.rms.io.IOStatsCollection clone() {
        try {
            com.android.server.rms.io.IOStatsCollection clone = (com.android.server.rms.io.IOStatsCollection) super.clone();
            clone.mStatsMap = new android.util.SparseArray();
            clone.addHistories(this);
            return clone;
        } catch (java.lang.CloneNotSupportedException e) {
            android.util.Log.e("RMS.IO.IOStatsCollection", "fail to clone IOStatsCollection,use the default value");
            return new com.android.server.rms.io.IOStatsCollection();
        }
    }

    public void recordHistory(com.android.server.rms.io.IOStatsHistory history) {
        if (history == null) {
            android.util.Log.e("RMS.IO.IOStatsCollection", "recordHistory,history is null");
            return;
        }
        int uid = history.getUid();
        if (uid <= 0) {
            android.util.Log.e("RMS.IO.IOStatsCollection", "recordHistory,uid is invalid");
            return;
        }
        com.android.server.rms.io.IOStatsHistory historyFound = (com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(uid);
        if (historyFound == null) {
            this.mStatsMap.put(uid, history.clone());
        } else {
            historyFound.addAllEntries(history);
        }
    }

    public void read(java.io.InputStream in) throws java.io.IOException {
        java.io.InputStream inputStream = in;
        if (inputStream == null) {
            android.util.Log.e("RMS.IO.IOStatsCollection", "read,InputStream is null");
            return;
        }
        int uid;
        com.android.server.rms.io.IOStatsHistory history;
        java.io.DataInputStream inputStream2 = new java.io.DataInputStream(inputStream);
        android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> current = this.mStatsMap.clone();
        this.mStatsMap.clear();
        while (inputStream2.available() >= 28) {
            uid = inputStream2.readInt();
            java.lang.String packageName = inputStream2.readUTF();
            long startTime = inputStream2.readLong();
            long numberOfWrite = inputStream2.readLong();
            long numberOfRead = inputStream2.readLong();
            if (this.mStatsMap.indexOfKey(uid) >= 0) {
                history = (com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(uid);
            } else {
                history = new com.android.server.rms.io.IOStatsHistory(uid, packageName);
                this.mStatsMap.put(uid, history);
            }
            history.addEntry(startTime, numberOfRead, numberOfWrite);
        }
        uid = current.size();
        for (int index = 0; index < uid; index++) {
            int uid2 = current.keyAt(index);
            history = (com.android.server.rms.io.IOStatsHistory) current.get(uid2);
            if (this.mStatsMap.indexOfKey(uid2) >= 0) {
                ((com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(uid2)).addAllEntries(history);
            } else {
                this.mStatsMap.put(uid2, history);
            }
        }
    }

    public void write(java.io.OutputStream out) throws java.io.IOException {
        if (out == null) {
            android.util.Log.e("RMS.IO.IOStatsCollection", "write,OutputStream is null");
            return;
        }
        java.io.DataOutputStream dataOutStream = new java.io.DataOutputStream(out);
        int statsMapSize = this.mStatsMap.size();
        for (int index = 0; index < statsMapSize; index++) {
            ((com.android.server.rms.io.IOStatsHistory) this.mStatsMap.get(this.mStatsMap.keyAt(index))).writeToStream(dataOutStream);
        }
        dataOutStream.flush();
    }
}
