package com.android.server.rms.io;

public final class IOStatsHistory implements java.lang.Cloneable {
    public static final int ENTRY_BYTE_SIZE = 28;
    private static final java.lang.String FORMAT_UTF = "UTF-8";
    private static final java.lang.String TAG = "RMS.IO.IOStatsHistory";
    private java.util.List<com.android.server.rms.io.IOStatsHistory.Entry> mIOStatsList;
    private java.lang.String mPkgName;
    private int mUid;

    private static class Entry implements java.lang.Cloneable {
        public long mNumberOfRead;
        public long mNumberOfWrite;
        public long mStartTime;

        public Entry(long startTime, long numberOfRead, long numberOfWrite) {
            this.mStartTime = startTime;
            this.mNumberOfRead = numberOfRead;
            this.mNumberOfWrite = numberOfWrite;
        }

        public boolean isTheSameDay(long time) {
            return time == this.mStartTime;
        }

        public boolean isWriteBytesOverLimit() {
            return this.mNumberOfWrite / com.android.server.rms.io.IOExceptionHandle.BYTES_SIZE_1G >= 1;
        }

        public com.android.server.rms.io.IOStatsHistory.Entry clone() {
            try {
                return (com.android.server.rms.io.IOStatsHistory.Entry) super.clone();
            } catch (java.lang.CloneNotSupportedException e) {
                android.util.Log.e("RMS.IO.IOStatsHistory", "fail to clone Entry,use the default object");
                return new com.android.server.rms.io.IOStatsHistory.Entry(0, 0, 0);
            }
        }
    }

    public IOStatsHistory(int uid, java.lang.String pkgName) {
        this.mIOStatsList = new java.util.ArrayList();
        this.mUid = uid;
        this.mPkgName = pkgName;
    }

    public IOStatsHistory(int uid, java.lang.String pkgName, long startTime, long numberOfRead, long numberOfWrite) {
        this(uid, pkgName);
        addEntry(startTime, numberOfRead, numberOfWrite);
    }

    public java.lang.String getPkgName() {
        return this.mPkgName;
    }

    public int getUid() {
        return this.mUid;
    }

    public long getTotalBytesNum() {
        int i = 0;
        int pkgByteSize = 0;
        try {
            if (this.mPkgName != null) {
                i = this.mPkgName.getBytes("UTF-8").length;
            }
            pkgByteSize = i;
        } catch (java.lang.Exception ex) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getTotalBytesNum,msg:");
            stringBuilder.append(ex.getMessage());
            android.util.Log.e("RMS.IO.IOStatsHistory", stringBuilder.toString());
        }
        return (long) ((this.mIOStatsList.size() * 28) + pkgByteSize);
    }

    public void addEntry(long startTime, long numberOfRead, long numberOfWrite) {
        long j;
        boolean isSameDay = false;
        com.android.server.rms.io.IOStatsHistory.Entry lastEntry = null;
        if (this.mIOStatsList.size() > 0) {
            lastEntry = (com.android.server.rms.io.IOStatsHistory.Entry) this.mIOStatsList.get(this.mIOStatsList.size() - 1);
            j = startTime;
            isSameDay = lastEntry.isTheSameDay(j);
        } else {
            j = startTime;
        }
        if (!isSameDay || lastEntry == null) {
            java.util.List list = this.mIOStatsList;
            com.android.server.rms.io.IOStatsHistory.Entry entry = r3;
            com.android.server.rms.io.IOStatsHistory.Entry entry2 = new com.android.server.rms.io.IOStatsHistory.Entry(j, numberOfRead, numberOfWrite);
            list.add(entry);
            return;
        }
        lastEntry.mNumberOfRead += numberOfRead;
        lastEntry.mNumberOfWrite += numberOfWrite;
        boolean z = isSameDay;
    }

    public void addAllEntries(com.android.server.rms.io.IOStatsHistory addHistory) {
        if (addHistory != null) {
            if (addHistory.mIOStatsList.size() != 0) {
                for (com.android.server.rms.io.IOStatsHistory.Entry entry : addHistory.mIOStatsList) {
                    addEntry(entry.mStartTime, entry.mNumberOfRead, entry.mNumberOfWrite);
                }
                return;
            }
        }
        android.util.Log.e("RMS.IO.IOStatsHistory", "addAllEntries, the addHistory is empty");
    }

    public long calculateTotalWrittenBytes(long startTime, long endTime) {
        long totalWrittenBytes = 0;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("calculateTotalWrittenBytes:");
        stringBuilder.append(startTime);
        stringBuilder.append(",");
        stringBuilder.append(endTime);
        android.util.Log.i("RMS.IO.IOStatsHistory", stringBuilder.toString());
        for (com.android.server.rms.io.IOStatsHistory.Entry entry : this.mIOStatsList) {
            if (entry.mStartTime >= startTime && entry.mStartTime <= endTime) {
                totalWrittenBytes += entry.mNumberOfWrite;
            }
        }
        return totalWrittenBytes;
    }

    public com.android.server.rms.io.IOExceptionHandle.AppExceptionData checkIfAppIOException() {
        int historyCount = this.mIOStatsList.size();
        if (historyCount < com.android.server.rms.io.IOExceptionHandle.IO_EXCEPTION_DAYS_LIMIT) {
            android.util.Log.i("RMS.IO.IOStatsHistory", "checkIfAppIOException,the number of daily histories is too small");
            return null;
        }
        int count = historyCount - com.android.server.rms.io.IOExceptionHandle.IO_EXCEPTION_DAYS_LIMIT;
        com.android.server.rms.io.IOExceptionHandle.AppExceptionData appExceptionData = null;
        for (int index = 0; index <= count; index++) {
            appExceptionData = checkIfMuchWritting((historyCount - 1) - index);
            if (appExceptionData != null) {
                break;
            }
        }
        if (appExceptionData != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("checkIfAppIOException,the first day is :");
            stringBuilder.append(android.rms.utils.Utils.getDateFormatValue(appExceptionData.mStartTime));
            android.util.Log.i("RMS.IO.IOStatsHistory", stringBuilder.toString());
        }
        return appExceptionData;
    }

    private com.android.server.rms.io.IOExceptionHandle.AppExceptionData checkIfMuchWritting(int recordStartIndex) {
        com.android.server.rms.io.IOExceptionHandle.AppExceptionData appExceptionData = new com.android.server.rms.io.IOExceptionHandle.AppExceptionData();
        boolean isExistExp = false;
        long lastDayValue = 0;
        int ioExceptionCount = 0;
        for (int recordIndex = recordStartIndex; recordIndex >= 0; recordIndex--) {
            java.lang.StringBuilder stringBuilder;
            com.android.server.rms.io.IOStatsHistory.Entry currentEntry = (com.android.server.rms.io.IOStatsHistory.Entry) this.mIOStatsList.get(recordIndex);
            if (currentEntry.isWriteBytesOverLimit()) {
                if (ioExceptionCount <= 0 || android.rms.utils.Utils.getDifferencesByDay(lastDayValue, currentEntry.mStartTime) == 1) {
                    if (ioExceptionCount == 0) {
                        appExceptionData.mPkgName = this.mPkgName;
                        appExceptionData.mStartTime = currentEntry.mStartTime;
                    }
                    if (android.rms.utils.Utils.DEBUG) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("checkIfMuchWritting: reach the limit: lastDayValue:");
                        stringBuilder.append(lastDayValue);
                        stringBuilder.append(",daytime:");
                        stringBuilder.append(currentEntry.mStartTime);
                        android.util.Log.d("RMS.IO.IOStatsHistory", stringBuilder.toString());
                    }
                    ioExceptionCount++;
                    lastDayValue = currentEntry.mStartTime;
                    appExceptionData.mTotalWrittenBytes += currentEntry.mNumberOfWrite;
                    if (ioExceptionCount >= com.android.server.rms.io.IOExceptionHandle.IO_EXCEPTION_DAYS_LIMIT) {
                        isExistExp = true;
                        break;
                    }
                }
            }
            if (android.rms.utils.Utils.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("checkIfMuchWritting: overtime or not reach the limit: lastDayValue:");
                stringBuilder.append(lastDayValue);
                stringBuilder.append(",daytime:");
                stringBuilder.append(currentEntry.mStartTime);
                android.util.Log.d("RMS.IO.IOStatsHistory", stringBuilder.toString());
            }
            ioExceptionCount = 0;
            appExceptionData.mPkgName = null;
            appExceptionData.mStartTime = 0;
            lastDayValue = 0;
        }
        if (isExistExp) {
            return appExceptionData;
        }
        return null;
    }

    public void dump(java.io.PrintWriter pw) {
        if (android.rms.utils.Utils.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("dump uid:");
            stringBuilder.append(this.mUid);
            android.util.Log.d("RMS.IO.IOStatsHistory", stringBuilder.toString());
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("history:uid:");
        stringBuilder2.append(this.mUid);
        pw.println(stringBuilder2.toString());
        stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("history:package:");
        stringBuilder2.append(this.mPkgName);
        pw.println(stringBuilder2.toString());
        for (com.android.server.rms.io.IOStatsHistory.Entry entry : this.mIOStatsList) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("uid:");
            stringBuilder2.append(this.mUid);
            stringBuilder2.append(",startTime:");
            stringBuilder2.append(android.rms.utils.Utils.getDateFormatValue(entry.mStartTime));
            stringBuilder2.append(",numberOfRead:");
            stringBuilder2.append(entry.mNumberOfRead);
            stringBuilder2.append(",numberOfWrite:");
            stringBuilder2.append(entry.mNumberOfWrite);
            pw.println(stringBuilder2.toString());
        }
    }

    public void writeToStream(java.io.DataOutputStream out) throws java.io.IOException {
        if (out == null) {
            android.util.Log.e("RMS.IO.IOStatsHistory", "writeToStream,DataOutputStream is null");
            return;
        }
        for (com.android.server.rms.io.IOStatsHistory.Entry entry : this.mIOStatsList) {
            if (entry.mNumberOfWrite != 0 || entry.mNumberOfRead != 0) {
                out.writeInt(this.mUid);
                out.writeUTF(this.mPkgName != null ? this.mPkgName : "");
                out.writeLong(entry.mStartTime);
                out.writeLong(entry.mNumberOfWrite);
                out.writeLong(entry.mNumberOfRead);
            } else if (android.rms.utils.Utils.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("uid:");
                stringBuilder.append(this.mUid);
                stringBuilder.append(",writeToStream,either the number of writing or reading is empty");
                android.util.Log.d("RMS.IO.IOStatsHistory", stringBuilder.toString());
            }
        }
    }

    public int queryNumberOfAccessingIO(int queryType, long startTime, long endTime) {
        if (this.mIOStatsList.size() == 0) {
            return -1;
        }
        int ioStatsNum = 0;
        for (com.android.server.rms.io.IOStatsHistory.Entry ioStats : this.mIOStatsList) {
            if (ioStats.mStartTime >= startTime) {
                if (ioStats.mStartTime <= endTime) {
                    if (queryType == 1) {
                        ioStatsNum = (int) (((long) ioStatsNum) + ioStats.mNumberOfRead);
                    } else if (queryType == 2) {
                        ioStatsNum = (int) (((long) ioStatsNum) + ioStats.mNumberOfWrite);
                    } else if (queryType == 3) {
                        ioStatsNum = (int) (((long) ((int) (((long) ioStatsNum) + ioStats.mNumberOfRead))) + ioStats.mNumberOfWrite);
                    }
                }
            }
        }
        return ioStatsNum;
    }

    public com.android.server.rms.io.IOStatsHistory clone() {
        try {
            com.android.server.rms.io.IOStatsHistory clone = (com.android.server.rms.io.IOStatsHistory) super.clone();
            clone.mIOStatsList = new java.util.ArrayList();
            clone.addAllEntries(this);
            return clone;
        } catch (java.lang.CloneNotSupportedException e) {
            android.util.Log.e("RMS.IO.IOStatsHistory", "fail to clone IOStatsHistory,use the default object");
            return new com.android.server.rms.io.IOStatsHistory(0, "");
        }
    }

    public com.android.server.rms.io.IOStatsHistory subtractFirstEntry(com.android.server.rms.io.IOStatsHistory compareHistory) {
        if (this.mIOStatsList.size() == 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("uid:");
            stringBuilder.append(this.mUid);
            stringBuilder.append("subtractFirstEntry,the IOStatsList is empty");
            android.util.Log.e("RMS.IO.IOStatsHistory", stringBuilder.toString());
            return null;
        } else if (compareHistory == null) {
            if (android.rms.utils.Utils.DEBUG) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("uid:");
                stringBuilder2.append(this.mUid);
                stringBuilder2.append("subtractFirstEntry,the compareHistory is null");
                android.util.Log.d("RMS.IO.IOStatsHistory", stringBuilder2.toString());
            }
            com.android.server.rms.io.IOStatsHistory history = new com.android.server.rms.io.IOStatsHistory(this.mUid, this.mPkgName);
            history.addAllEntries(this);
            return history;
        } else {
            com.android.server.rms.io.IOStatsHistory.Entry currentEntry = (com.android.server.rms.io.IOStatsHistory.Entry) this.mIOStatsList.get(0);
            com.android.server.rms.io.IOStatsHistory.Entry compareEntry = (com.android.server.rms.io.IOStatsHistory.Entry) compareHistory.mIOStatsList.get(0);
            long numberOfWrite = currentEntry.mNumberOfWrite - compareEntry.mNumberOfWrite;
            long numberOfRead = currentEntry.mNumberOfRead - compareEntry.mNumberOfRead;
            if (numberOfWrite == 0 && numberOfRead == 0) {
                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("uid:");
                stringBuilder3.append(this.mUid);
                stringBuilder3.append("subtractFirstEntry,both the number of Writting and Reading are emtpy");
                android.util.Log.e("RMS.IO.IOStatsHistory", stringBuilder3.toString());
                return null;
            }
            com.android.server.rms.io.IOStatsHistory history2 = new com.android.server.rms.io.IOStatsHistory(this.mUid, this.mPkgName);
            history2.addEntry(currentEntry.mStartTime, numberOfRead, numberOfWrite);
            return history2;
        }
    }
}
