package com.android.server.rms.io;

public class IOStatsService extends android.rms.io.IIOStatsServiceManager.Stub {
    private static final java.lang.String DUMP_ALL_TAG = "ALL";
    private static final boolean DUMP_BEFORE_DELETE = true;
    private static final java.lang.String DUMP_PENDING_TAG = "PENDING";
    private static final java.lang.String DUMP_TYPE_FULL = "--full";
    private static final java.lang.String DUMP_TYPE_PENDING = "--pending";
    private static final java.lang.Object[] EMPTY_OBJECT = new java.lang.Object[0];
    private static final int INSTALL_TYPE_HW_PREINSTALL = 1;
    private static final int INSTALL_TYPE_INVALID = -1;
    private static final int INSTALL_TYPE_SYSTEM_APP = 2;
    private static final int INSTALL_TYPE_THIRDPARTY_APP = 3;
    private static final java.lang.String IOS_STATS_FILE_PREFIX = "io_stats";
    private static final long IO_STATS_FILE_DELETED_PERIOD = 864000000;
    private static final long IO_STATS_FILE_ROTATE_PERIOD = 86400000;
    private static final java.lang.String IO_STATS_PATH = "data/system/iostats";
    private static final int MSG_INIT = 1;
    private static final int MSG_LOAD_INIT_DATA = 3;
    private static final int MSG_READ_IO_STATS = 6;
    private static final int MSG_SAVE_FORCE_WRITE = 4;
    private static final int MSG_SCREEN_OFF_SAVE = 5;
    private static final int MSG_STATS_MONITOR = 2;
    private static final int NOT_3RD_PARTY_UID = -1;
    private static final long PERIOD_TIME_READ_STATS = 3600000;
    public static final int QUERY_RESULT_FAIL = -1;
    public static final int QUERY_TYPE_READ = 1;
    public static final int QUERY_TYPE_READ_WRITE = 3;
    public static final int QUERY_TYPE_WRITE = 2;
    private static final long SAVE_PERIOD_TIME = 3600000;
    private static final java.lang.String TAG = "RMS.IO.IOStatsService";
    private static final java.lang.String TAG_IOSTATS_DUMP = "iostats_dump";
    private static com.android.server.rms.io.IOStatsService mIOStatsService = null;
    private static final java.lang.Object mLock = new java.lang.Object();
    private java.util.List<java.lang.Integer> mAllUidsMonitoredList = new java.util.ArrayList();
    private com.android.server.rms.io.IOStatsCollection mCompleteCollection = null;
    private android.content.Context mContext = null;
    private android.os.DropBoxManager mDropBox;
    private android.os.Handler mHandler = null;
    private android.os.Handler.Callback mHandlerCallback = new android.os.Handler.Callback() {
        public boolean handleMessage(android.os.Message msg) {
            if (msg == null) {
                android.util.Log.e("RMS.IO.IOStatsService", "handleMessage,the msg is null");
                return false;
            }
            int i = msg.what;
            if (i != 1) {
                switch (i) {
                    case 3:
                        com.android.server.rms.io.IOStatsService.this.loadIOStatsFromDisk();
                        com.android.server.rms.io.IOStatsService.this.loadAllUidsMonitored();
                        com.android.server.rms.io.IOStatsService.this.writeMonitoredUidsToKernel();
                        com.android.server.rms.CompactJobService.addDefragglers(new com.android.server.rms.defraggler.IODefraggler());
                        return true;
                    case 4:
                        com.android.server.rms.io.IOStatsService.this.saveIOStatsAndLatestUids(true);
                        return true;
                    case 5:
                        com.android.server.rms.io.IOStatsService.this.saveIOStatsAndLatestUids(false);
                        com.android.server.rms.io.IOStatsService.this.mLastScreenOffTime = java.lang.System.currentTimeMillis();
                        return true;
                    case 6:
                        com.android.server.rms.io.IOStatsService.this.periodReadTask();
                        com.android.server.rms.io.IOStatsService.this.periodRunReadTask();
                        return true;
                    default:
                        return true;
                }
            }
            com.android.server.rms.io.IOStatsService.this.handleInitService();
            return true;
        }
    };
    private com.android.server.rms.io.IOExceptionHandle mIOExceptionHandle = null;
    private boolean mIsServiceReady = false;
    private long mLastScreenOffTime = 0;
    private com.android.server.rms.io.IOStatsCollection mLastSnapShotCollecton = null;
    private android.os.Looper mLooper = null;
    private android.content.pm.PackageManager mPM = null;
    private android.content.BroadcastReceiver mPackageReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            com.android.server.rms.io.IOStatsService.this.notifyUidChanged(false, intent, "PackageReceiver");
        }
    };
    private java.util.List<java.lang.Integer> mPendingAddUidList = new java.util.ArrayList();
    private com.android.server.rms.io.IOStatsCollection mPendingCollection = null;
    private java.util.List<java.lang.Integer> mPendingDeleteUidList = new java.util.ArrayList();
    private com.android.server.rms.io.IOStatsService.CombiningRewriter mPendingRewriter = null;
    private java.util.List<java.lang.Integer> mQueryTypeList = null;
    private com.android.server.rms.io.IOFileRotator mRotator = null;
    private android.content.BroadcastReceiver mScreenOffReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            android.util.Log.i("RMS.IO.IOStatsService", "onReceive:screen off");
            com.android.server.rms.io.IOStatsService.this.mHandler.sendEmptyMessage(5);
        }
    };
    private android.content.BroadcastReceiver mShutdownReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            android.util.Log.i("RMS.IO.IOStatsService", "onReceive:shut down");
            com.android.server.rms.io.IOStatsService.this.readStatsFromKernel();
            com.android.server.rms.io.IOStatsService.this.mHandler.sendEmptyMessage(4);
        }
    };
    private java.util.Hashtable<java.lang.Integer, java.lang.String> mUidPkgTable = new java.util.Hashtable();
    private android.content.BroadcastReceiver mUidRemoveReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            com.android.server.rms.io.IOStatsService.this.notifyUidChanged(true, intent, "UidRemoveReceiver");
        }
    };

    private static class CombiningRewriter implements com.android.server.rms.io.IOFileRotator.Rewriter {
        private final com.android.server.rms.io.IOStatsCollection mCollection;

        public CombiningRewriter(com.android.server.rms.io.IOStatsCollection collection) {
            this.mCollection = collection;
        }

        public void reset() {
        }

        public void read(java.io.InputStream in) throws java.io.IOException {
            this.mCollection.read(in);
        }

        public boolean shouldWrite() {
            return true;
        }

        public void write(java.io.OutputStream out) throws java.io.IOException {
            this.mCollection.write(new java.io.DataOutputStream(out));
        }
    }

    private IOStatsService(android.content.Context context, android.os.Looper looper) {
        android.util.Log.i("RMS.IO.IOStatsService", "IOStatsService construct");
        this.mContext = context;
        this.mLooper = looper;
        this.mQueryTypeList = new java.util.ArrayList();
        this.mQueryTypeList.add(java.lang.Integer.valueOf(1));
        this.mQueryTypeList.add(java.lang.Integer.valueOf(2));
        this.mQueryTypeList.add(java.lang.Integer.valueOf(3));
    }

    public static com.android.server.rms.io.IOStatsService getInstance(android.content.Context context, android.os.Looper looper) {
        com.android.server.rms.io.IOStatsService iOStatsService;
        synchronized (mLock) {
            if (mIOStatsService == null) {
                mIOStatsService = new com.android.server.rms.io.IOStatsService(context, looper);
                android.util.Log.i("RMS.IO.IOStatsService", "add the IOStatsService");
                android.os.ServiceManager.addService("iostatsservice", mIOStatsService);
            }
            iOStatsService = mIOStatsService;
        }
        return iOStatsService;
    }

    public void startIOStatsService() {
        android.util.Log.i("RMS.IO.IOStatsService", "startIOStatsService");
        if (this.mLooper == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "startIOStatsService,the looper is null");
            return;
        }
        if (this.mHandler != null) {
            this.mHandler.removeCallbacksAndMessages(null);
        }
        this.mHandler = new android.os.Handler(this.mLooper, this.mHandlerCallback);
        this.mHandler.sendEmptyMessage(1);
    }

    private void periodRunReadTask() {
        this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(6), 3600000);
    }

    private void handleInitService() {
        android.util.Log.i("RMS.IO.IOStatsService", "initialize the Service");
        if (this.mContext == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "handleInitService,the context is null");
            return;
        }
        try {
            this.mIOExceptionHandle = new com.android.server.rms.io.IOExceptionHandle(this);
            this.mRotator = new com.android.server.rms.io.IOFileRotator(new java.io.File("data/system/iostats"), "io_stats", 86400000, 864000000);
            this.mRotator.removeFilesWhenOverFlow();
            this.mDropBox = (android.os.DropBoxManager) this.mContext.getSystemService("dropbox");
            this.mPM = this.mContext.getPackageManager();
            this.mPendingCollection = new com.android.server.rms.io.IOStatsCollection();
            this.mPendingRewriter = new com.android.server.rms.io.IOStatsService.CombiningRewriter(this.mPendingCollection);
            this.mCompleteCollection = new com.android.server.rms.io.IOStatsCollection();
            this.mLastSnapShotCollecton = new com.android.server.rms.io.IOStatsCollection();
            this.mHandler.sendEmptyMessage(3);
            this.mContext.registerReceiver(this.mScreenOffReceiver, new android.content.IntentFilter("android.intent.action.SCREEN_OFF"), null, this.mHandler);
            android.content.IntentFilter packageFilter = new android.content.IntentFilter("android.intent.action.PACKAGE_ADDED");
            packageFilter.addDataScheme("package");
            this.mContext.registerReceiver(this.mPackageReceiver, packageFilter, null, this.mHandler);
            this.mContext.registerReceiver(this.mUidRemoveReceiver, new android.content.IntentFilter("android.intent.action.UID_REMOVED"), null, this.mHandler);
            this.mContext.registerReceiver(this.mShutdownReceiver, new android.content.IntentFilter("android.intent.action.ACTION_SHUTDOWN"), null, this.mHandler);
            periodRunReadTask();
            this.mIsServiceReady = true;
        } catch (java.lang.Exception ex) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("handleInitService,error message:");
            stringBuilder.append(ex.getMessage());
            android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
        }
    }

    public int query(int uid) throws android.os.RemoteException {
        return 0;
    }

    protected void dump(java.io.FileDescriptor fd, java.io.PrintWriter pw, java.lang.String[] args) {
        if (this.mContext == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "dump,the context is null");
        } else if (this.mContext.checkCallingOrSelfPermission("android.permission.DUMP") != 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Permission Denial: can't dump IOStatsService from from pid=");
            stringBuilder.append(android.os.Binder.getCallingPid());
            stringBuilder.append(", uid=");
            stringBuilder.append(android.os.Binder.getCallingUid());
            pw.println(stringBuilder.toString());
        } else if (android.os.Binder.getCallingUid() > 1000) {
            dumpIOStatsFromDisk(pw, args);
        }
    }

    private void dumpIOStatsFromDisk(java.io.PrintWriter pw, java.lang.String[] args) {
        if (args != null) {
            if (args.length != 0) {
                try {
                    pw.println("begin dumpIOStatsFromDisk");
                    for (java.lang.String argValue : args) {
                        dumpIOStatsCollection(argValue, pw);
                    }
                    pw.println("end dumpIOStatsFromDisk");
                } catch (java.lang.RuntimeException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("RuntimeException,fail to dumpIOStatsFromDisk:");
                    stringBuilder.append(e.getMessage());
                    pw.println(stringBuilder.toString());
                } catch (java.lang.Exception e2) {
                    pw.println("fail to dumpIOStatsFromDisk");
                }
                return;
            }
        }
        android.util.Log.e("RMS.IO.IOStatsService", "dumpIOStatsFromDisk,no argument");
    }

    private void dumpIOStatsCollection(java.lang.String tag, java.io.PrintWriter pw) throws java.io.IOException {
        if ("--full".equals(tag) || "--pending".equals(tag)) {
            com.android.server.rms.io.IOStatsCollection collection;
            if ("--full".equals(tag)) {
                com.android.server.rms.io.IOStatsCollection collection2 = new com.android.server.rms.io.IOStatsCollection();
                this.mRotator.readMatching(collection2, Long.MIN_VALUE, Long.MAX_VALUE);
                collection = collection2;
            } else {
                collection = this.mPendingCollection;
            }
            if (collection == null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(tag);
                stringBuilder.append(" is empty");
                pw.println(stringBuilder.toString());
                return;
            }
            collection.dump(pw);
        }
    }

    public android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> getAllIOStatsCollection() {
        if (this.mIsServiceReady) {
            com.android.server.rms.io.IOStatsCollection allCollection = this.mCompleteCollection.clone();
            allCollection.addHistories(this.mPendingCollection.clone());
            return allCollection.getIOStatsHistoryMap();
        }
        android.util.Log.e("RMS.IO.IOStatsService", "getAllIOStatsCollection,the service is not ready");
        return null;
    }

    private void readStatsFromKernel() {
        android.util.Log.i("RMS.IO.IOStatsService", "readStatsFromKernel");
        if (this.mIsServiceReady) {
            com.android.server.rms.io.IOStatsCollection collection = com.android.server.rms.io.KernelIOStats.readUidIOStatsFromKernel(this.mUidPkgTable);
            if (collection.getTotalBytes() == 0) {
                android.util.Log.i("RMS.IO.IOStatsService", "readStatsFromKernel,the IO Stats information is empty ");
                return;
            }
            android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> currentIOStats = collection.getIOStatsHistoryMap();
            android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> lastIOStats = this.mLastSnapShotCollecton.getIOStatsHistoryMap();
            int curIOStatsSize = currentIOStats.size();
            for (int index = 0; index < curIOStatsSize; index++) {
                int uid = currentIOStats.keyAt(index);
                com.android.server.rms.io.IOStatsHistory additionHistory = ((com.android.server.rms.io.IOStatsHistory) currentIOStats.get(uid)).subtractFirstEntry((com.android.server.rms.io.IOStatsHistory) lastIOStats.get(uid));
                if (additionHistory != null) {
                    this.mPendingCollection.recordHistory(additionHistory);
                    if (android.rms.utils.Utils.DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("add uid:");
                        stringBuilder.append(uid);
                        stringBuilder.append(",totalBytes in pending is ");
                        stringBuilder.append(this.mPendingCollection.getTotalBytes());
                        android.util.Log.d("RMS.IO.IOStatsService", stringBuilder.toString());
                    }
                }
            }
            this.mLastSnapShotCollecton = collection;
            return;
        }
        android.util.Log.e("RMS.IO.IOStatsService", "readStatsFromKernel,the service is not ready");
    }

    public void periodReadTask() {
        readStatsFromKernel();
    }

    public boolean periodMonitorTask() {
        if (this.mIsServiceReady) {
            android.util.Log.i("RMS.IO.IOStatsService", "do the periodMonitorTask");
            com.android.server.rms.io.IOExceptionHandle.ExceptionData exceptionData = this.mIOExceptionHandle.checkIfExistException();
            if (exceptionData == null) {
                android.util.Log.i("RMS.IO.IOStatsService", "periodMonitorTask,no exception occurs");
                return true;
            }
            this.mIOExceptionHandle.handleIOException(exceptionData);
            return true;
        }
        android.util.Log.e("RMS.IO.IOStatsService", "periodMonitorTask,the service isn't ready");
        return false;
    }

    public void interruptMonitorTask() {
        if (this.mIsServiceReady) {
            android.util.Log.i("RMS.IO.IOStatsService", "do the interruptMonitorTask");
            this.mIOExceptionHandle.interrupt();
            return;
        }
        android.util.Log.e("RMS.IO.IOStatsService", "interruptMonitorTask,the service isn't ready");
    }

    public int query(long startTime, long endTime, int uid, java.lang.String packageName, int queryType) {
        int i = uid;
        java.lang.String str = packageName;
        if (!this.mIsServiceReady) {
            android.util.Log.e("RMS.IO.IOStatsService", "query,the service is not ready");
            return -1;
        } else if (startTime > endTime) {
            android.util.Log.e("RMS.IO.IOStatsService", java.lang.String.format("query,starttime is bigger than endtime:time period:%d - %d", new java.lang.Object[]{java.lang.Long.valueOf(startTime), java.lang.Long.valueOf(endTime)}));
            return -1;
        } else if (this.mQueryTypeList.contains(java.lang.Integer.valueOf(queryType))) {
            int uidQuery;
            if (i > 0) {
                uidQuery = i;
            } else {
                uidQuery = getUidByPackageName(str);
            }
            com.android.server.rms.io.IOStatsHistory history = (com.android.server.rms.io.IOStatsHistory) this.mCompleteCollection.getIOStatsHistoryMap().get(uidQuery);
            if (history != null) {
                return history.queryNumberOfAccessingIO(queryType, startTime, endTime);
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("not find any history of uid:");
            stringBuilder.append(i);
            stringBuilder.append(",package:");
            stringBuilder.append(str);
            android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
            return -1;
        } else {
            android.util.Log.e("RMS.IO.IOStatsService", java.lang.String.format("query,querytype is invalid:%d", new java.lang.Object[]{java.lang.Integer.valueOf(queryType)}));
            return -1;
        }
    }

    private int getUidByPackageName(java.lang.String packageName) {
        if (packageName != null) {
            if (packageName.length() != 0) {
                int uidQuery = 0;
                for (java.util.Map.Entry<java.lang.Integer, java.lang.String> keyPair : this.mUidPkgTable.entrySet()) {
                    if (packageName.equals(keyPair.getValue())) {
                        uidQuery = ((java.lang.Integer) keyPair.getKey()).intValue();
                        break;
                    }
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("query,the uid found is ");
                stringBuilder.append(uidQuery);
                stringBuilder.append(",package:");
                stringBuilder.append(packageName);
                android.util.Log.i("RMS.IO.IOStatsService", stringBuilder.toString());
                return uidQuery;
            }
        }
        return 0;
    }

    private void loadIOStatsFromDisk() {
        try {
            android.util.Log.i("RMS.IO.IOStatsService", "loadIOStatsFromDisk");
            this.mRotator.readMatching(this.mCompleteCollection, Long.MIN_VALUE, Long.MAX_VALUE);
        } catch (java.io.IOException e) {
            android.util.Log.wtf("RMS.IO.IOStatsService", "fail to loadIOStatsFromDisk,IO Exception occurs", e);
            recoverFromWtf();
        } catch (java.lang.OutOfMemoryError e2) {
            android.util.Log.wtf("RMS.IO.IOStatsService", "fail to loadIOStatsFromDisk,OutOfMemoryError occurs", e2);
            recoverFromWtf();
        }
    }

    private void recoverFromWtf() {
        java.io.ByteArrayOutputStream os = new java.io.ByteArrayOutputStream();
        try {
            this.mRotator.dumpAll(os);
        } catch (java.io.IOException e) {
            os.reset();
        } catch (Throwable th) {
            libcore.io.IoUtils.closeQuietly(os);
        }
        libcore.io.IoUtils.closeQuietly(os);
        if (this.mDropBox != null) {
            this.mDropBox.addData("iostats_dump", os.toByteArray(), 0);
        }
        this.mRotator.deleteAll();
    }

    private void loadAllUidsMonitored() {
        android.util.Log.i("RMS.IO.IOStatsService", "loadAllUidsMonitored");
        if (this.mPM == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "loadAllUidsMonitored,the PowerManager is null");
            return;
        }
        this.mAllUidsMonitoredList.clear();
        this.mUidPkgTable.clear();
        addThirdPartyUid(this.mPM.getInstalledApplications(0));
        android.util.Log.i("RMS.IO.IOStatsService", java.lang.String.format("loadAllUidsMonitored, the number of third party's apks is %d", new java.lang.Object[]{java.lang.Integer.valueOf(this.mAllUidsMonitoredList.size())}));
    }

    private void addThirdPartyUid(java.util.List<android.content.pm.ApplicationInfo> appList) {
        if (appList != null) {
            if (appList.size() != 0) {
                for (android.content.pm.ApplicationInfo appInfo : appList) {
                    if (appInfo != null) {
                        if (checkIfThirdPartyApp(appInfo.packageName)) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("third party apk,packageName:");
                            stringBuilder.append(appInfo.packageName);
                            stringBuilder.append(",uid:");
                            stringBuilder.append(appInfo.uid);
                            android.util.Log.d("RMS.IO.IOStatsService", stringBuilder.toString());
                            this.mAllUidsMonitoredList.add(java.lang.Integer.valueOf(appInfo.uid));
                            this.mPendingAddUidList.add(java.lang.Integer.valueOf(appInfo.uid));
                            if (!this.mUidPkgTable.containsKey(java.lang.Integer.valueOf(appInfo.uid))) {
                                this.mUidPkgTable.put(java.lang.Integer.valueOf(appInfo.uid), appInfo.packageName);
                            }
                        }
                    }
                }
                return;
            }
        }
        android.util.Log.e("RMS.IO.IOStatsService", "no app is installed");
    }

    private boolean checkIfThirdPartyApp(java.lang.String packageName) {
        boolean z = false;
        if (packageName != null) {
            if (!packageName.isEmpty()) {
                boolean isThirdPartyApp = false;
                java.lang.StringBuilder stringBuilder;
                try {
                    java.lang.String[] splitArray = packageName.split(":");
                    if (splitArray.length == 0) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("checkIfThirdPartyApp,packageName :");
                        stringBuilder.append(packageName);
                        stringBuilder.append(" is invalid");
                        android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
                        return false;
                    }
                    int installType = getAppType(this.mPM.getApplicationInfo(splitArray.length > 1 ? splitArray[1] : splitArray[0], 0));
                    if (installType != 1) {
                        if (installType != 3) {
                            return z;
                        }
                    }
                    z = true;
                    return z;
                } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("checkIfThirdPartyApp,");
                    stringBuilder.append(packageName);
                    stringBuilder.append(" not found in the apklist");
                    android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
                    return false;
                } catch (java.lang.Exception e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("checkIfThirdPartyApp,the Other Exception occurs,:");
                    stringBuilder.append(packageName);
                    android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
                    return false;
                }
            }
        }
        android.util.Log.e("RMS.IO.IOStatsService", "checkIfThirdPartyApp, the packageName is empty");
        return false;
    }

    private int getAppType(android.content.pm.ApplicationInfo info) {
        if (info == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,the ApplicationInfo is null ");
            return -1;
        }
        try {
            int hwFlags = ((java.lang.Integer) android.content.pm.ApplicationInfo.class.getField("hwFlags").get(info)).intValue();
            boolean preInstalledFlagCheck = false;
            boolean systemFlagCheck = (info.flags & 1) != 0;
            if ((33554432 & hwFlags) != 0) {
                preInstalledFlagCheck = true;
            }
            if (systemFlagCheck && preInstalledFlagCheck) {
                return 1;
            }
            if (systemFlagCheck) {
                return 2;
            }
            return 3;
        } catch (java.lang.NoSuchFieldException e) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,NoSuchFieldException occurs");
            return -1;
        } catch (java.lang.IllegalArgumentException e2) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,IllegalArgumentException occurs");
            return -1;
        } catch (java.lang.IllegalAccessException e3) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,IllegalAccessException occurs");
            return -1;
        } catch (java.lang.RuntimeException e4) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,RuntimeException occurs");
            return -1;
        } catch (java.lang.Exception e5) {
            android.util.Log.e("RMS.IO.IOStatsService", "getAppType,the other Exception occurs");
            return -1;
        }
    }

    private void writeMonitoredUidsToKernel() {
        android.util.Log.i("RMS.IO.IOStatsService", "writeMonitoredUidsToKernel");
        com.android.server.rms.io.KernelIOStats.writeUidList(this.mPendingDeleteUidList, this.mPendingAddUidList);
        this.mPendingDeleteUidList.clear();
        this.mPendingAddUidList.clear();
    }

    private void writeToStatsFile(boolean isForceWrite) {
        int totalBytes = this.mPendingCollection.getTotalBytes();
        if (totalBytes == 0) {
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.IO.IOStatsService", "no pending bytes to upload");
            }
            return;
        }
        android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> pendingHistoryMap = this.mPendingCollection.getIOStatsHistoryMap();
        android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> overFlowHistoryMap = removeOverFlowFromPending(totalBytes, pendingHistoryMap);
        long currentTimeMillis = java.lang.System.currentTimeMillis();
        forcePersistLocked(currentTimeMillis);
        if (overFlowHistoryMap.size() > 0) {
            handleOverFlowSizeHistory(isForceWrite, pendingHistoryMap, overFlowHistoryMap, currentTimeMillis);
        }
    }

    private void handleOverFlowSizeHistory(boolean isForceWrite, android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> pendingHistoryMap, android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> overFlowHistoryMap, long currentTimeMillis) {
        android.util.Log.i("RMS.IO.IOStatsService", "handleOverFlowSizeHistory");
        int overFlowHistoryMapSize = overFlowHistoryMap.size();
        for (int index = 0; index < overFlowHistoryMapSize; index++) {
            int uidKey = overFlowHistoryMap.keyAt(index);
            pendingHistoryMap.put(uidKey, ((com.android.server.rms.io.IOStatsHistory) overFlowHistoryMap.get(uidKey)).clone());
        }
        this.mRotator.forceFile(currentTimeMillis, java.lang.System.currentTimeMillis());
        if (isForceWrite) {
            android.util.Log.i("RMS.IO.IOStatsService", "handleOverFlowSizeHistory,force to write all the pending datas");
            forcePersistLocked(currentTimeMillis);
        }
    }

    private android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> removeOverFlowFromPending(int totalPendingBytes, android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> pendingHistoryMap) {
        long availableBytes = this.mRotator.getAvailableBytesInActiveFile(java.lang.System.currentTimeMillis());
        if (((long) totalPendingBytes) <= availableBytes) {
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.IO.IOStatsService", "the file is enough for the pending bytes");
            }
            return new android.util.SparseArray();
        }
        int index;
        android.util.SparseArray<com.android.server.rms.io.IOStatsHistory> overFlowHistoryMap = new android.util.SparseArray();
        int pendingHistoryMapSize = pendingHistoryMap.size();
        int index2 = 0;
        int totalBytesNum = 0;
        for (index = 0; index < pendingHistoryMapSize; index++) {
            int uid = pendingHistoryMap.keyAt(index);
            com.android.server.rms.io.IOStatsHistory history = (com.android.server.rms.io.IOStatsHistory) pendingHistoryMap.get(uid);
            totalBytesNum = (int) (((long) totalBytesNum) + history.getTotalBytesNum());
            if (((long) totalBytesNum) > availableBytes) {
                overFlowHistoryMap.put(uid, history.clone());
            }
        }
        index = overFlowHistoryMap.size();
        while (index2 < index) {
            pendingHistoryMap.remove(overFlowHistoryMap.keyAt(index2));
            index2++;
        }
        return overFlowHistoryMap;
    }

    private void forcePersistLocked(long currentTimeMillis) {
        try {
            android.util.Log.i("RMS.IO.IOStatsService", "forcePersistLocked");
            com.android.server.rms.io.IOStatsCollection clonePendingCollection = this.mPendingCollection.clone();
            this.mRotator.rewriteActive(this.mPendingRewriter, currentTimeMillis);
            this.mRotator.maybeRotate(currentTimeMillis);
            this.mRotator.removeFilesWhenOverFlow();
            this.mCompleteCollection.addHistories(clonePendingCollection);
            this.mPendingCollection.reset();
        } catch (java.io.IOException e) {
            android.util.Log.wtf("RMS.IO.IOStatsService", "problem persisting pending stats", e);
            recoverFromWtf();
        } catch (java.lang.OutOfMemoryError e2) {
            android.util.Log.wtf("RMS.IO.IOStatsService", "problem persisting pending stats", e2);
            recoverFromWtf();
        }
    }

    public void saveIOStatsAndLatestUids(boolean isForceWrite) {
        if (!this.mIsServiceReady) {
            android.util.Log.e("RMS.IO.IOStatsService", "saveIOStatsAndLatestUids,the service is not ready");
        } else if (isForceWrite || java.lang.System.currentTimeMillis() - this.mLastScreenOffTime >= 3600000) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("saveIOStatsAndLatestUids,isForceWrite:");
            stringBuilder.append(isForceWrite);
            android.util.Log.i("RMS.IO.IOStatsService", stringBuilder.toString());
            writeToStatsFile(isForceWrite);
        } else {
            android.util.Log.i("RMS.IO.IOStatsService", "saveIOStatsAndLatestUids,the time interval is too shorter than the last screen off");
        }
    }

    private java.lang.Object[] getUidFromIntentExtras(android.content.Intent intent) {
        if (intent == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "getUidFromIntentExtras,intent is null");
            return EMPTY_OBJECT;
        }
        android.os.Bundle bundle = intent.getExtras();
        if (bundle == null) {
            android.util.Log.e("RMS.IO.IOStatsService", "getUidFromIntentExtras,bundle is null");
            return EMPTY_OBJECT;
        }
        java.lang.Object[] result = new java.lang.Object[2];
        int uid = bundle.getInt("android.intent.extra.UID");
        if (!"android.intent.action.UID_REMOVED".equals(intent.getAction())) {
            java.lang.String packageName = intent.getDataString();
            java.lang.StringBuilder stringBuilder;
            if (checkIfThirdPartyApp(packageName)) {
                result[0] = java.lang.Integer.valueOf(uid);
                result[1] = packageName;
                if (android.rms.utils.Utils.DEBUG) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("third party apk:");
                    stringBuilder.append(packageName);
                    android.util.Log.d("RMS.IO.IOStatsService", stringBuilder.toString());
                }
                return result;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(packageName);
            stringBuilder.append(" is not the 3rd party apk");
            android.util.Log.i("RMS.IO.IOStatsService", stringBuilder.toString());
            return EMPTY_OBJECT;
        } else if (this.mAllUidsMonitoredList.contains(java.lang.Integer.valueOf(uid))) {
            result[0] = java.lang.Integer.valueOf(uid);
            result[1] = "";
            return result;
        } else {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("apk (uid:");
            stringBuilder2.append(uid);
            stringBuilder2.append(") is not the 3rd party apk");
            android.util.Log.i("RMS.IO.IOStatsService", stringBuilder2.toString());
            return EMPTY_OBJECT;
        }
    }

    private void notifyUidChanged(boolean isUidRemoval, android.content.Intent intent, java.lang.String flowTAG) {
        java.lang.Object[] result = getUidFromIntentExtras(intent);
        if (result.length < 2) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(flowTAG);
            stringBuilder.append(",uid is invalid");
            android.util.Log.e("RMS.IO.IOStatsService", stringBuilder.toString());
            return;
        }
        try {
            refreshMonitoredUids(isUidRemoval, java.lang.Integer.parseInt(result[0].toString()), result[1].toString());
        } catch (java.lang.Exception ex) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("notifyUidChanged,An Exception occurs:");
            stringBuilder2.append(ex.getMessage());
            android.util.Log.e("RMS.IO.IOStatsService", stringBuilder2.toString());
        }
    }

    public void refreshMonitoredUids(boolean isUidRemoval, int uid, java.lang.String pkgName) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("refreshMonitoredUids,isUidRemoval:");
        stringBuilder.append(isUidRemoval);
        stringBuilder.append(",uid:");
        stringBuilder.append(uid);
        android.util.Log.i("RMS.IO.IOStatsService", stringBuilder.toString());
        if (this.mIsServiceReady) {
            if (isUidRemoval) {
                this.mPendingDeleteUidList.add(java.lang.Integer.valueOf(uid));
                this.mAllUidsMonitoredList.remove(java.lang.Integer.valueOf(uid));
            } else {
                this.mPendingAddUidList.add(java.lang.Integer.valueOf(uid));
                this.mAllUidsMonitoredList.add(java.lang.Integer.valueOf(uid));
                if (!this.mUidPkgTable.containsKey(java.lang.Integer.valueOf(uid))) {
                    this.mUidPkgTable.put(java.lang.Integer.valueOf(uid), pkgName);
                }
            }
            writeMonitoredUidsToKernel();
            return;
        }
        android.util.Log.e("RMS.IO.IOStatsService", "refreshMonitoredUids,the service is not ready");
    }
}
