package com.android.server.rms.ipcchecker;

public class HwIpcChecker implements com.android.server.rms.IHwIpcChecker, java.lang.Runnable {
    private static final int COMPLETED = 0;
    private static final int OVERDUE = 3;
    private static final java.lang.String TAG = "RMS.HwIpcChecker";
    private static final int WAITED_HALF = 2;
    private static final int WAITING = 1;
    private boolean mCompleted;
    private com.android.server.rms.IHwIpcMonitor mCurrentMonitor;
    private android.os.Handler mHandler;
    private final java.util.ArrayList<com.android.server.rms.IHwIpcMonitor> mHwIpcMonitors = new java.util.ArrayList();
    private final java.lang.Object mLock;
    private long mStartTime;
    private final long mWaitMax;

    public HwIpcChecker(java.lang.Object object, android.os.Handler handler, long waitMaxMillis) {
        this.mWaitMax = waitMaxMillis;
        this.mCompleted = true;
        this.mHandler = getAvailableHandler(handler);
        this.mLock = object;
    }

    private android.os.Handler getAvailableHandler(android.os.Handler handler) {
        if (handler != null) {
            return new android.os.Handler(handler.getLooper());
        }
        android.os.HandlerThread handlerThread = new android.os.HandlerThread("RMS.HwIpcChecker", 10);
        handlerThread.start();
        return new android.os.Handler(handlerThread.getLooper());
    }

    public void addMonitor(com.android.server.rms.IHwIpcMonitor monitor) {
        if (monitor != null) {
            this.mHwIpcMonitors.add(monitor);
        }
    }

    public void scheduleCheckLocked() {
        if (this.mHwIpcMonitors.size() == 0) {
            this.mCompleted = true;
            if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
                android.util.Log.i("RMS.HwIpcChecker", "No Ipc Monitor");
            }
        } else if (this.mCompleted) {
            this.mCompleted = false;
            this.mCurrentMonitor = null;
            this.mStartTime = android.os.SystemClock.uptimeMillis();
            this.mHandler.postAtFrontOfQueue(this);
        }
    }

    private boolean isOverdueLocked() {
        boolean flag = !this.mCompleted && android.os.SystemClock.uptimeMillis() > this.mStartTime + this.mWaitMax;
        if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isOverdueLocked ");
            stringBuilder.append(flag);
            stringBuilder.append(" waittime");
            stringBuilder.append(this.mWaitMax);
            android.util.Log.i("RMS.HwIpcChecker", stringBuilder.toString());
        }
        return flag;
    }

    public com.android.server.rms.IHwIpcMonitor getCurrentIpcMonitor() {
        if (isOverdueLocked()) {
            android.util.Log.i("RMS.HwIpcChecker", "IPC is overdue");
            if (this.mCurrentMonitor != null) {
                java.lang.String monitor = describeBlockedStateLocked();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("recovery for ipc monitor [");
                stringBuilder.append(monitor);
                stringBuilder.append("]");
                android.util.Log.i("RMS.HwIpcChecker", stringBuilder.toString());
                return this.mCurrentMonitor;
            }
        }
        return com.android.server.rms.ipcchecker.GeneralIpcMonitor.getInstance();
    }

    private java.lang.String describeBlockedStateLocked() {
        if (this.mCurrentMonitor == null) {
            return "No Blocked monitor";
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Blocked in monitor ");
        stringBuilder.append(this.mCurrentMonitor.getClass().getName());
        return stringBuilder.toString();
    }

    public void run() {
        int size = this.mHwIpcMonitors.size();
        if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Ipc Monitor size ");
            stringBuilder.append(size);
            android.util.Log.i("RMS.HwIpcChecker", stringBuilder.toString());
        }
        for (int i = 0; i < size; i++) {
            synchronized (this.mLock) {
                this.mCurrentMonitor = (com.android.server.rms.IHwIpcMonitor) this.mHwIpcMonitors.get(i);
            }
            if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
                android.util.Log.i("RMS.HwIpcChecker", "ipc monitor enter");
            }
            this.mCurrentMonitor.doMonitor();
            if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
                android.util.Log.i("RMS.HwIpcChecker", "ipc monitor exit");
            }
        }
        synchronized (this.mLock) {
            if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
                android.util.Log.i("RMS.HwIpcChecker", "ipc monitor check finish");
            }
            this.mCompleted = true;
            this.mCurrentMonitor = null;
        }
    }
}
