package com.android.server.rms.memrepair;

public class ProcStateData {
    private static final java.lang.String TAG = "AwareMem_PSData";
    private int mCustomProcState;
    private java.util.concurrent.atomic.AtomicLong mLastPss = new java.util.concurrent.atomic.AtomicLong(0);
    private long mLastPssTime;
    private java.util.concurrent.atomic.AtomicLong mMaxPss = new java.util.concurrent.atomic.AtomicLong(0);
    private int mMergeCount = 0;
    private java.util.concurrent.atomic.AtomicLong mMinPss = new java.util.concurrent.atomic.AtomicLong(0);
    private int mNextMergeCount = 0;
    private final java.lang.Object mObjectLock = new java.lang.Object();
    private int mPid;
    private java.lang.String mProcName;
    private java.util.List<java.lang.Long> mStatePssList = new java.util.ArrayList();

    public ProcStateData(int pid, java.lang.String procName, int customProcState) {
        this.mPid = pid;
        this.mProcName = procName;
        this.mCustomProcState = customProcState;
    }

    public void addPssToList(long pss, long now, long intervalTime, int sampleCount) {
        long j = pss;
        long j2 = now;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("pss=");
        stringBuilder.append(j);
        stringBuilder.append(";now=");
        stringBuilder.append(j2);
        stringBuilder.append(";intervalTime=");
        stringBuilder.append(((long) (1 << this.mMergeCount)) * intervalTime);
        android.rms.iaware.AwareLog.d("AwareMem_PSData", stringBuilder.toString());
        this.mLastPss.set(j);
        synchronized (this.mObjectLock) {
            int lastIndex = this.mStatePssList.size() - 1;
            if (lastIndex < 0) {
                this.mMinPss.set(j);
                this.mMaxPss.set(j);
            } else {
                this.mMinPss.set(this.mMinPss.get() < j ? this.mMinPss.get() : j);
                this.mMaxPss.set(this.mMaxPss.get() > j ? this.mMaxPss.get() : j);
            }
            if (lastIndex <= -1 || j2 - this.mLastPssTime > ((long) (1 << this.mMergeCount)) * intervalTime) {
                this.mStatePssList.add(java.lang.Long.valueOf(pss));
                this.mLastPssTime = j2;
                this.mNextMergeCount = 1;
            } else {
                this.mStatePssList.set(lastIndex, java.lang.Long.valueOf(((((java.lang.Long) this.mStatePssList.get(lastIndex)).longValue() * ((long) this.mNextMergeCount)) + j) / ((long) (this.mNextMergeCount + 1))));
                this.mNextMergeCount++;
            }
            if (this.mStatePssList.size() == 2 * sampleCount) {
                int i = 0;
                while (i < this.mStatePssList.size()) {
                    int lastIndex2 = lastIndex;
                    this.mStatePssList.set(i / 2, java.lang.Long.valueOf((((java.lang.Long) this.mStatePssList.get(i)).longValue() + ((java.lang.Long) this.mStatePssList.get(i + 1)).longValue()) / 2));
                    i += 2;
                    lastIndex = lastIndex2;
                }
                for (lastIndex = this.mStatePssList.size() - 1; lastIndex > sampleCount - 1; lastIndex--) {
                    this.mStatePssList.remove(lastIndex);
                }
                this.mMergeCount++;
            }
        }
    }

    public int getPid() {
        return this.mPid;
    }

    public java.lang.String getProcName() {
        return this.mProcName;
    }

    public int getState() {
        return this.mCustomProcState;
    }

    public long getMinPss() {
        return this.mMinPss.get();
    }

    public long getMaxPss() {
        return this.mMaxPss.get();
    }

    public long getLastPss() {
        return this.mLastPss.get();
    }

    public int getMergeCount() {
        return this.mMergeCount;
    }

    public java.util.List<java.lang.Long> getStatePssList() {
        java.util.ArrayList<java.lang.Long> cloneList = new java.util.ArrayList();
        synchronized (this.mObjectLock) {
            if (this.mStatePssList.size() > 0) {
                cloneList.addAll(this.mStatePssList);
                return cloneList;
            }
            android.rms.iaware.AwareLog.d("AwareMem_PSData", "mStatePssList size is zero");
            return null;
        }
    }
}
