package com.android.server.rms.record;

public class AppUsageFileRecord {
    private static final java.lang.String APPUSAGE_FILE_PREFIX = "app_usage";
    private static final java.lang.String APPUSAGE_PATH = "data/system/usagetime";
    private static final int MAX_FILE_SIZE = 131072;
    private static final java.lang.String TAG = "RMS.AppUsageFileRecord";
    private com.android.server.rms.io.IOFileRotator mAppUsageRotator = null;
    private com.android.server.rms.record.AppUsageTime mAppUsageTime = null;
    private final android.content.Context mContext;
    private final boolean mEnabled;

    public AppUsageFileRecord(android.content.Context context, int time, boolean enable) {
        this.mAppUsageTime = com.android.server.rms.record.AppUsageTime.getInstance(context, time);
        this.mContext = context;
        this.mEnabled = enable;
        if (this.mEnabled) {
            this.mAppUsageRotator = new com.android.server.rms.io.IOFileRotator(new java.io.File("data/system/usagetime"), "app_usage", 1, 1, 131072);
        }
    }

    public void loadUsageInfo() {
        if (this.mEnabled) {
            this.mAppUsageRotator.removeFilesWhenOverFlow();
            try {
                this.mAppUsageRotator.readMatching(this.mAppUsageTime, Long.MIN_VALUE, Long.MAX_VALUE);
            } catch (java.io.IOException e) {
                android.util.Log.e("RMS.AppUsageFileRecord", "loadUsageInfo exception ", e);
                this.mAppUsageRotator.deleteAll();
            } catch (java.lang.OutOfMemoryError e2) {
                this.mAppUsageRotator.deleteAll();
                android.util.Log.e("RMS.AppUsageFileRecord", "LoadUsageInfo outof memory ", e2);
            }
        }
    }

    public void saveUsageInfo() {
        if (this.mEnabled) {
            int totalBytes = this.mAppUsageTime.getTotalBytes();
            if (totalBytes != 0) {
                if (totalBytes > 131072) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("AppUsage file is so big that we have to clear it, bytes is ");
                    stringBuilder.append(this.mAppUsageTime.getTotalBytes());
                    android.util.Log.e("RMS.AppUsageFileRecord", stringBuilder.toString());
                    this.mAppUsageTime.clear();
                    this.mAppUsageRotator.deleteAll();
                    return;
                }
                try {
                    this.mAppUsageRotator.rewriteActive(this.mAppUsageTime, 1);
                    this.mAppUsageRotator.removeFilesWhenOverFlow();
                } catch (java.io.IOException e) {
                    android.util.Log.e("RMS.AppUsageFileRecord", "saveUsageInfo exception ", e);
                    this.mAppUsageRotator.deleteAll();
                } catch (java.lang.OutOfMemoryError e2) {
                    android.util.Log.e("RMS.AppUsageFileRecord", "saveUsageInfo outof memory ", e2);
                    this.mAppUsageRotator.deleteAll();
                }
            }
        }
    }

    public void updateUsageInfo(java.lang.String pkg) {
        this.mAppUsageTime.setHistoryTime(pkg, com.android.server.rms.record.ResourceUtils.getAppTime(this.mContext, pkg));
    }

    public int getUsageTimeforUpload(java.lang.String pkg) {
        return this.mAppUsageTime.getUsageTimeforUpload(pkg);
    }
}
