package com.android.server.rms.record;

public class AppUsageTime implements com.android.server.rms.io.IOFileRotator.Reader, com.android.server.rms.io.IOFileRotator.Rewriter {
    private static final java.lang.String TAG = "RMS.AppUsageTime";
    private static com.android.server.rms.record.AppUsageTime mAppUsageTime;
    private final android.content.Context mContext;
    private final int mTimeforHistoryInstalled;
    private final java.util.HashMap<java.lang.String, com.android.server.rms.record.AppUsageTime.UsageInfo> mUsageTimeMap = new java.util.HashMap();

    static final class UsageInfo {
        private static final int ENTRY_BYTE_SIZE = 18;
        private static final java.lang.String FORMAT_UTF = "UTF-8";
        private long mHistoryTime;
        private java.lang.String mPkg;
        private long mUsageTime;

        UsageInfo(java.lang.String pkg, long time, long historyTime) {
            this.mPkg = pkg;
            this.mUsageTime = time;
            this.mHistoryTime = historyTime;
        }

        private long getTotalBytesNum() {
            int i = 0;
            int pkgByteSize = 0;
            try {
                if (this.mPkg != null) {
                    i = this.mPkg.getBytes("UTF-8").length;
                }
                pkgByteSize = i;
            } catch (java.lang.Exception ex) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getTotalBytesNum, msg: ");
                stringBuilder.append(ex.getMessage());
                android.util.Log.e("RMS.AppUsageTime", stringBuilder.toString());
            }
            return (long) (18 + pkgByteSize);
        }
    }

    private AppUsageTime(android.content.Context context, int time) {
        this.mContext = context;
        this.mTimeforHistoryInstalled = time;
    }

    public static synchronized com.android.server.rms.record.AppUsageTime getInstance(android.content.Context context, int time) {
        com.android.server.rms.record.AppUsageTime appUsageTime;
        synchronized (com.android.server.rms.record.AppUsageTime.class) {
            if (mAppUsageTime == null) {
                mAppUsageTime = new com.android.server.rms.record.AppUsageTime(context, time);
            }
            appUsageTime = mAppUsageTime;
        }
        return appUsageTime;
    }

    public static synchronized com.android.server.rms.record.AppUsageTime self() {
        com.android.server.rms.record.AppUsageTime appUsageTime;
        synchronized (com.android.server.rms.record.AppUsageTime.class) {
            appUsageTime = mAppUsageTime;
        }
        return appUsageTime;
    }

    public void dumpInfo(boolean historyTimeDump) {
        if (android.rms.utils.Utils.HWFLOW) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("dumpInfo: there is ");
            stringBuilder.append(this.mUsageTimeMap.size());
            stringBuilder.append(" applicaitions to be recorded!");
            android.util.Log.i("RMS.AppUsageTime", stringBuilder.toString());
        }
        for (java.util.Map.Entry entry : this.mUsageTimeMap.entrySet()) {
            com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) entry.getValue();
            if (info != null) {
                java.lang.StringBuilder stringBuilder2;
                if (historyTimeDump) {
                    if (android.rms.utils.Utils.HWFLOW) {
                        stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("dumpInfo: pkg ");
                        stringBuilder2.append(info.mPkg);
                        stringBuilder2.append(", usageTime ");
                        stringBuilder2.append(info.mUsageTime);
                        stringBuilder2.append(" history time ");
                        stringBuilder2.append(info.mHistoryTime);
                        android.util.Log.i("RMS.AppUsageTime", stringBuilder2.toString());
                    }
                } else if (android.rms.utils.Utils.HWFLOW) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("dumpInfo: pkg ");
                    stringBuilder2.append(info.mPkg);
                    stringBuilder2.append(", usageTime is ");
                    stringBuilder2.append((info.mUsageTime - info.mHistoryTime) / 1000);
                    stringBuilder2.append("s");
                    android.util.Log.i("RMS.AppUsageTime", stringBuilder2.toString());
                }
            }
        }
    }

    private boolean existUsageInfoLocked(java.lang.String pkg) {
        if (pkg == null || ((com.android.server.rms.record.AppUsageTime.UsageInfo) this.mUsageTimeMap.get(pkg)) == null) {
            return false;
        }
        return true;
    }

    private boolean addUsageInfoLocked(java.lang.String pkg, long time, long historyTime) {
        if (pkg == null || ((com.android.server.rms.record.AppUsageTime.UsageInfo) this.mUsageTimeMap.get(pkg)) != null) {
            return false;
        }
        this.mUsageTimeMap.put(pkg, new com.android.server.rms.record.AppUsageTime.UsageInfo(pkg, time, historyTime));
        return true;
    }

    private void setUsageTimeLocked(java.lang.String pkg, long time) {
        if (pkg != null) {
            com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) this.mUsageTimeMap.get(pkg);
            if (info != null) {
                info.mUsageTime = time;
            }
        }
    }

    /* JADX WARNING: Missing block: B:24:0x005b, code:
            if (android.rms.utils.Utils.DEBUG == false) goto L_0x0063;
     */
    /* JADX WARNING: Missing block: B:25:0x005d, code:
            mAppUsageTime.dumpInfo(true);
     */
    /* JADX WARNING: Missing block: B:27:0x0068, code:
            return (int) (r0 / 1000);
     */
    public int getUsageTimeforUpload(java.lang.String r11) {
        /*
        r10 = this;
        if (r11 != 0) goto L_0x0004;
    L_0x0002:
        r0 = 0;
        return r0;
    L_0x0004:
        r0 = 0;
        r2 = r10.mUsageTimeMap;
        monitor-enter(r2);
        r3 = r10.existUsageInfoLocked(r11);	 Catch:{ all -> 0x0069 }
        if (r3 != 0) goto L_0x0022;
    L_0x000f:
        r3 = r10.mContext;	 Catch:{ all -> 0x0069 }
        r6 = com.android.server.rms.record.ResourceUtils.getAppTime(r3, r11);	 Catch:{ all -> 0x0069 }
        r8 = 0;
        r4 = r10;
        r5 = r11;
        r4.addUsageInfoLocked(r5, r6, r8);	 Catch:{ all -> 0x001e }
        r0 = r6;
        goto L_0x0058;
    L_0x001e:
        r0 = move-exception;
        r3 = r0;
        r0 = r6;
        goto L_0x006a;
    L_0x0022:
        r3 = r10.getRealUsageTimeLocked(r11);	 Catch:{ all -> 0x0069 }
        r0 = r3;
        r3 = r10.mTimeforHistoryInstalled;	 Catch:{ all -> 0x0069 }
        r3 = (long) r3;	 Catch:{ all -> 0x0069 }
        r3 = (r0 > r3 ? 1 : (r0 == r3 ? 0 : -1));
        if (r3 > 0) goto L_0x003e;
    L_0x002e:
        r3 = r10.mContext;	 Catch:{ all -> 0x0069 }
        r3 = com.android.server.rms.record.ResourceUtils.getAppTime(r3, r11);	 Catch:{ all -> 0x0069 }
        r0 = r3;
        r10.setUsageTimeLocked(r11, r0);	 Catch:{ all -> 0x0069 }
        r3 = r10.getRealUsageTimeLocked(r11);	 Catch:{ all -> 0x0069 }
        r0 = r3;
        goto L_0x0058;
    L_0x003e:
        r3 = android.rms.utils.Utils.DEBUG;	 Catch:{ all -> 0x0069 }
        if (r3 == 0) goto L_0x0058;
    L_0x0042:
        r3 = "RMS.AppUsageTime";
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0069 }
        r4.<init>();	 Catch:{ all -> 0x0069 }
        r5 = "getUsageTimeforUpload: history installed, time ";
        r4.append(r5);	 Catch:{ all -> 0x0069 }
        r4.append(r0);	 Catch:{ all -> 0x0069 }
        r4 = r4.toString();	 Catch:{ all -> 0x0069 }
        android.util.Log.d(r3, r4);	 Catch:{ all -> 0x0069 }
    L_0x0058:
        monitor-exit(r2);	 Catch:{ all -> 0x0069 }
        r2 = android.rms.utils.Utils.DEBUG;
        if (r2 == 0) goto L_0x0063;
    L_0x005d:
        r2 = mAppUsageTime;
        r3 = 1;
        r2.dumpInfo(r3);
    L_0x0063:
        r2 = 1000; // 0x3e8 float:1.401E-42 double:4.94E-321;
        r2 = r0 / r2;
        r2 = (int) r2;
        return r2;
    L_0x0069:
        r3 = move-exception;
    L_0x006a:
        monitor-exit(r2);	 Catch:{ all -> 0x0069 }
        throw r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.record.AppUsageTime.getUsageTimeforUpload(java.lang.String):int");
    }

    public boolean isHistoryInstalledApp(java.lang.String pkg) {
        if (getRealUsageTimeLocked(pkg) > ((long) this.mTimeforHistoryInstalled)) {
            return true;
        }
        return false;
    }

    public void setHistoryTime(java.lang.String pkg, long historyTime) {
        if (pkg != null) {
            synchronized (this.mUsageTimeMap) {
                com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) this.mUsageTimeMap.get(pkg);
                if (info != null) {
                    info.mUsageTime = historyTime;
                    info.mHistoryTime = historyTime;
                } else {
                    addUsageInfoLocked(pkg, historyTime, historyTime);
                }
            }
        }
    }

    public long getRealUsageTimeLocked(java.lang.String pkg) {
        if (pkg == null) {
            return 0;
        }
        com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) this.mUsageTimeMap.get(pkg);
        if (info != null) {
            return info.mUsageTime - info.mHistoryTime;
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.AppUsageTime", "getRealUsageTimeLocked: this isn't a recorded app and we should check UsageStatsManger");
        }
        return com.android.server.rms.record.ResourceUtils.getAppTime(this.mContext, pkg);
    }

    public int getTotalBytes() {
        int totalBytes = 0;
        synchronized (this.mUsageTimeMap) {
            for (java.util.Map.Entry entry : this.mUsageTimeMap.entrySet()) {
                com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) entry.getValue();
                if (info != null) {
                    totalBytes = (int) (((long) totalBytes) + info.getTotalBytesNum());
                }
            }
        }
        if (android.rms.utils.Utils.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("total bytes is ");
            stringBuilder.append(totalBytes);
            android.util.Log.d("RMS.AppUsageTime", stringBuilder.toString());
        }
        return totalBytes;
    }

    public void clear() {
        synchronized (this.mUsageTimeMap) {
            if (this.mUsageTimeMap.isEmpty()) {
                return;
            }
            this.mUsageTimeMap.clear();
        }
    }

    public void read(java.io.InputStream in) throws java.io.IOException {
        if (in == null) {
            android.util.Log.e("RMS.AppUsageTime", "read, InputStream is null");
            return;
        }
        java.io.DataInputStream inputStream = new java.io.DataInputStream(in);
        while (inputStream.available() >= 18) {
            addUsageInfoLocked(inputStream.readUTF(), inputStream.readLong(), inputStream.readLong());
        }
    }

    public void reset() {
    }

    public boolean shouldWrite() {
        return true;
    }

    public void write(java.io.OutputStream out) throws java.io.IOException {
        if (!this.mUsageTimeMap.isEmpty()) {
            if (out == null) {
                android.util.Log.e("RMS.AppUsageTime", "write, OutputStream is null");
                return;
            }
            if (android.rms.utils.Utils.HWFLOW) {
                dumpInfo(true);
            }
            java.io.DataOutputStream dataOutStream = new java.io.DataOutputStream(out);
            for (java.util.Map.Entry entry : this.mUsageTimeMap.entrySet()) {
                com.android.server.rms.record.AppUsageTime.UsageInfo info = (com.android.server.rms.record.AppUsageTime.UsageInfo) entry.getValue();
                if (info != null && info.mUsageTime > 0) {
                    dataOutStream.writeUTF(info.mPkg != null ? info.mPkg : "");
                    dataOutStream.writeLong(info.mUsageTime);
                    dataOutStream.writeLong(info.mHistoryTime);
                }
            }
            dataOutStream.flush();
        }
    }
}
