package com.android.server.rms.record;

public class ResourceRecordStore {
    private static final int IS_ACTION = 1;
    private static int MAX_NUM_BIGDATAINFOS_IN_LIST = (android.rms.utils.Utils.IS_DEBUG_VERSION ? 1 : 20);
    private static final java.lang.String TAG = "RMS.ResourceRecordStore";
    private static com.android.server.rms.record.ResourceRecordStore mResourceRecordStore = null;
    private java.util.List<com.android.server.rms.record.ResourceRecordStore.BigDataInfo> mBigDataInfos = new java.util.ArrayList();
    private android.content.Context mContext = null;
    private android.os.Handler mHandler = null;
    private final java.util.HashMap<java.lang.Long, com.android.server.rms.record.ResourceOverloadRecord> mResourceStatusMap = new java.util.HashMap();
    private android.content.SharedPreferences mSharedPreferences = null;

    private static final class BigDataInfo {
        public java.lang.String mPkg;
        public int mResourceType;
        public int mUid;
        public int overloadNum;
        public int speedOverLoadPeroid;
        public int totalNum;

        private BigDataInfo() {
            this.mPkg = "";
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mUid:");
            stringBuilder.append(this.mUid);
            stringBuilder.append(" mPkg:");
            stringBuilder.append(this.mPkg);
            stringBuilder.append(" mResourceType:");
            stringBuilder.append(this.mResourceType);
            stringBuilder.append(" overloadNum:");
            stringBuilder.append(this.overloadNum);
            stringBuilder.append(" speedOverLoadPeroid:");
            stringBuilder.append(this.speedOverLoadPeroid);
            stringBuilder.append(" totalNum:");
            stringBuilder.append(this.totalNum);
            return stringBuilder.toString();
        }
    }

    private ResourceRecordStore(android.content.Context context) {
        this.mContext = context;
    }

    public static synchronized com.android.server.rms.record.ResourceRecordStore getInstance(android.content.Context context) {
        com.android.server.rms.record.ResourceRecordStore resourceRecordStore;
        synchronized (com.android.server.rms.record.ResourceRecordStore.class) {
            if (mResourceRecordStore == null) {
                mResourceRecordStore = new com.android.server.rms.record.ResourceRecordStore(context);
            }
            resourceRecordStore = mResourceRecordStore;
        }
        return resourceRecordStore;
    }

    public static synchronized com.android.server.rms.record.ResourceRecordStore getInstance() {
        com.android.server.rms.record.ResourceRecordStore resourceRecordStore;
        synchronized (com.android.server.rms.record.ResourceRecordStore.class) {
            resourceRecordStore = mResourceRecordStore;
        }
        return resourceRecordStore;
    }

    public void dumpImpl(java.io.PrintWriter pw) {
        pw.println("System Resource Manager");
        synchronized (this.mResourceStatusMap) {
            for (java.util.Map.Entry<java.lang.Long, com.android.server.rms.record.ResourceOverloadRecord> entry : this.mResourceStatusMap.entrySet()) {
                com.android.server.rms.record.ResourceOverloadRecord record = (com.android.server.rms.record.ResourceOverloadRecord) entry.getValue();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Process use resource overload:uid=");
                stringBuilder.append(record.getUid());
                stringBuilder.append(" pkg=");
                stringBuilder.append(record.getPackageName());
                stringBuilder.append(" resourceType=");
                stringBuilder.append(record.getResourceType());
                stringBuilder.append(" mSpeedOverloadNum=");
                stringBuilder.append(record.getSpeedOverloadNum());
                stringBuilder.append(" mSpeedOverLoadPeroid=");
                stringBuilder.append(record.getSpeedOverLoadPeroid());
                stringBuilder.append(" mCountOverLoadNum=");
                stringBuilder.append(record.getCountOverLoadNum());
                stringBuilder.append(" pid =");
                stringBuilder.append(record.getPid());
                pw.println(stringBuilder.toString());
            }
        }
    }

    public boolean hasResourceStatusRecord(long id) {
        boolean z;
        synchronized (this.mResourceStatusMap) {
            z = this.mResourceStatusMap.get(java.lang.Long.valueOf(id)) != null;
        }
        return z;
    }

    private com.android.server.rms.record.ResourceOverloadRecord getResourceStatusRecord(int callingUid, int pid, int resourceType) {
        com.android.server.rms.record.ResourceOverloadRecord record;
        long id = com.android.server.rms.record.ResourceUtils.getResourceId(callingUid, pid, resourceType);
        synchronized (this.mResourceStatusMap) {
            record = (com.android.server.rms.record.ResourceOverloadRecord) this.mResourceStatusMap.get(java.lang.Long.valueOf(id));
            if (record == null) {
                record = createResourceStatusRecord(id);
            }
        }
        return record;
    }

    public void setMessageHandler(android.os.Handler mHandler) {
        this.mHandler = mHandler;
    }

    /* JADX WARNING: Missing block: B:15:0x0052, code:
            return;
     */
    /* JADX WARNING: Missing block: B:21:0x0071, code:
            r0 = com.android.server.rms.record.ResourceUtils.getProcessTypeId(r2, r10, -1);
     */
    /* JADX WARNING: Missing block: B:22:0x0078, code:
            if (android.rms.utils.Utils.DEBUG == false) goto L_0x00b0;
     */
    /* JADX WARNING: Missing block: B:23:0x007a, code:
            r12 = new java.lang.StringBuilder();
            r12.append("getResourceOverloadMax: pkg=");
            r12.append(r10);
            r12.append(", hardThreshold=");
            r12.append(r7);
            r12.append(", overLoadNum=");
            r12.append(r6);
            r12.append(", type=");
            r12.append(r3);
            r12.append(", killingprocessType=");
            r12.append(r0);
            android.util.Log.w("RMS.ResourceRecordStore", r12.toString());
     */
    /* JADX WARNING: Missing block: B:24:0x00b0, code:
            if (r9 != false) goto L_0x011a;
     */
    /* JADX WARNING: Missing block: B:25:0x00b2, code:
            if (r6 <= r7) goto L_0x011a;
     */
    /* JADX WARNING: Missing block: B:26:0x00b4, code:
            if (r0 != r3) goto L_0x011a;
     */
    /* JADX WARNING: Missing block: B:27:0x00b6, code:
            r8 = android.app.mtm.MultiTaskManager.getInstance();
     */
    /* JADX WARNING: Missing block: B:28:0x00ba, code:
            if (r8 == 0) goto L_0x00f2;
     */
    /* JADX WARNING: Missing block: B:30:0x00c2, code:
            if (r8.forcestopApps(r19) == false) goto L_0x00f4;
     */
    /* JADX WARNING: Missing block: B:31:0x00c4, code:
            cleanResRecordAppDied(r18, r19);
     */
    /* JADX WARNING: Missing block: B:32:0x00c9, code:
            if (android.rms.utils.Utils.DEBUG != false) goto L_0x00d3;
     */
    /* JADX WARNING: Missing block: B:34:0x00cd, code:
            if (android.rms.utils.Utils.HWFLOW == false) goto L_0x00d0;
     */
    /* JADX WARNING: Missing block: B:36:0x00d0, code:
            r16 = r0;
     */
    /* JADX WARNING: Missing block: B:37:0x00d3, code:
            r15 = new java.lang.StringBuilder();
            r16 = r0;
            r15.append("killOverloadApp ");
            r15.append(r10);
            r15.append("successfully!");
            android.util.Log.d("RMS.ResourceRecordStore", r15.toString());
     */
    /* JADX WARNING: Missing block: B:38:0x00f2, code:
            r13 = r19;
     */
    /* JADX WARNING: Missing block: B:39:0x00f4, code:
            r16 = r0;
     */
    /* JADX WARNING: Missing block: B:40:0x00f8, code:
            if (android.rms.utils.Utils.DEBUG != false) goto L_0x00fe;
     */
    /* JADX WARNING: Missing block: B:42:0x00fc, code:
            if (android.rms.utils.Utils.HWFLOW == false) goto L_0x011e;
     */
    /* JADX WARNING: Missing block: B:43:0x00fe, code:
            r12 = new java.lang.StringBuilder();
            r12.append("killOverloadApp ");
            r12.append(r10);
            r12.append("failed!");
            android.util.Log.d("RMS.ResourceRecordStore", r12.toString());
     */
    /* JADX WARNING: Missing block: B:44:0x011a, code:
            r13 = r19;
            r16 = r0;
     */
    /* JADX WARNING: Missing block: B:45:0x011e, code:
            return;
     */
    public void handleOverloadResource(int r18, int r19, int r20, int r21) {
        /*
        r17 = this;
        r1 = r17;
        r2 = r18;
        r3 = r21;
        r4 = com.android.server.rms.record.ResourceUtils.getResourceId(r18, r19, r20);
        r6 = 0;
        r7 = 0;
        r8 = -1;
        r9 = 0;
        r10 = 0;
        r11 = 0;
        r12 = r1.mResourceStatusMap;
        monitor-enter(r12);
        r0 = r1.mResourceStatusMap;	 Catch:{ all -> 0x0122 }
        r13 = java.lang.Long.valueOf(r4);	 Catch:{ all -> 0x0122 }
        r0 = r0.get(r13);	 Catch:{ all -> 0x0122 }
        r0 = (com.android.server.rms.record.ResourceOverloadRecord) r0;	 Catch:{ all -> 0x0122 }
        r11 = r0;
        if (r11 != 0) goto L_0x005a;
    L_0x0022:
        r0 = android.rms.utils.Utils.DEBUG;	 Catch:{ all -> 0x0053 }
        if (r0 == 0) goto L_0x004f;
    L_0x0026:
        r0 = "RMS.ResourceRecordStore";
        r13 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0053 }
        r13.<init>();	 Catch:{ all -> 0x0053 }
        r14 = "get record failed uid ";
        r13.append(r14);	 Catch:{ all -> 0x0053 }
        r13.append(r2);	 Catch:{ all -> 0x0053 }
        r14 = " id ";
        r13.append(r14);	 Catch:{ all -> 0x0053 }
        r13.append(r4);	 Catch:{ all -> 0x0053 }
        r14 = " resourceType ";
        r13.append(r14);	 Catch:{ all -> 0x0053 }
        r14 = r20;
        r13.append(r14);	 Catch:{ all -> 0x011f }
        r13 = r13.toString();	 Catch:{ all -> 0x011f }
        android.util.Log.d(r0, r13);	 Catch:{ all -> 0x011f }
        goto L_0x0051;
    L_0x004f:
        r14 = r20;
    L_0x0051:
        monitor-exit(r12);	 Catch:{ all -> 0x011f }
        return;
    L_0x0053:
        r0 = move-exception;
        r14 = r20;
    L_0x0056:
        r13 = r19;
        goto L_0x0127;
    L_0x005a:
        r14 = r20;
        r0 = r11.isInWhiteList();	 Catch:{ all -> 0x011f }
        r9 = r0;
        r0 = r11.getCountOverLoadNum();	 Catch:{ all -> 0x011f }
        r6 = r0;
        r0 = r11.getHardThreshold();	 Catch:{ all -> 0x011f }
        r7 = r0;
        r0 = r11.getPackageName();	 Catch:{ all -> 0x011f }
        r10 = r0;
        monitor-exit(r12);	 Catch:{ all -> 0x011f }
        r0 = -1;
        r0 = com.android.server.rms.record.ResourceUtils.getProcessTypeId(r2, r10, r0);
        r8 = android.rms.utils.Utils.DEBUG;
        if (r8 == 0) goto L_0x00b0;
    L_0x007a:
        r8 = "RMS.ResourceRecordStore";
        r12 = new java.lang.StringBuilder;
        r12.<init>();
        r13 = "getResourceOverloadMax: pkg=";
        r12.append(r13);
        r12.append(r10);
        r13 = ", hardThreshold=";
        r12.append(r13);
        r12.append(r7);
        r13 = ", overLoadNum=";
        r12.append(r13);
        r12.append(r6);
        r13 = ", type=";
        r12.append(r13);
        r12.append(r3);
        r13 = ", killingprocessType=";
        r12.append(r13);
        r12.append(r0);
        r12 = r12.toString();
        android.util.Log.w(r8, r12);
    L_0x00b0:
        if (r9 != 0) goto L_0x011a;
    L_0x00b2:
        if (r6 <= r7) goto L_0x011a;
    L_0x00b4:
        if (r0 != r3) goto L_0x011a;
    L_0x00b6:
        r8 = android.app.mtm.MultiTaskManager.getInstance();
        if (r8 == 0) goto L_0x00f2;
    L_0x00bc:
        r13 = r19;
        r12 = r8.forcestopApps(r13);
        if (r12 == 0) goto L_0x00f4;
    L_0x00c4:
        r17.cleanResRecordAppDied(r18, r19);
        r12 = android.rms.utils.Utils.DEBUG;
        if (r12 != 0) goto L_0x00d3;
    L_0x00cb:
        r12 = android.rms.utils.Utils.HWFLOW;
        if (r12 == 0) goto L_0x00d0;
    L_0x00cf:
        goto L_0x00d3;
    L_0x00d0:
        r16 = r0;
        goto L_0x011e;
    L_0x00d3:
        r12 = "RMS.ResourceRecordStore";
        r15 = new java.lang.StringBuilder;
        r15.<init>();
        r16 = r0;
        r0 = "killOverloadApp ";
        r15.append(r0);
        r15.append(r10);
        r0 = "successfully!";
        r15.append(r0);
        r0 = r15.toString();
        android.util.Log.d(r12, r0);
        goto L_0x011e;
    L_0x00f2:
        r13 = r19;
    L_0x00f4:
        r16 = r0;
        r0 = android.rms.utils.Utils.DEBUG;
        if (r0 != 0) goto L_0x00fe;
    L_0x00fa:
        r0 = android.rms.utils.Utils.HWFLOW;
        if (r0 == 0) goto L_0x011e;
    L_0x00fe:
        r0 = "RMS.ResourceRecordStore";
        r12 = new java.lang.StringBuilder;
        r12.<init>();
        r15 = "killOverloadApp ";
        r12.append(r15);
        r12.append(r10);
        r15 = "failed!";
        r12.append(r15);
        r12 = r12.toString();
        android.util.Log.d(r0, r12);
        goto L_0x011e;
    L_0x011a:
        r13 = r19;
        r16 = r0;
    L_0x011e:
        return;
    L_0x011f:
        r0 = move-exception;
        goto L_0x0056;
    L_0x0122:
        r0 = move-exception;
        r13 = r19;
        r14 = r20;
    L_0x0127:
        monitor-exit(r12);	 Catch:{ all -> 0x0129 }
        throw r0;
    L_0x0129:
        r0 = move-exception;
        goto L_0x0127;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.record.ResourceRecordStore.handleOverloadResource(int, int, int, int):void");
    }

    public com.android.server.rms.record.ResourceOverloadRecord createResourceStatusRecord(long id) {
        com.android.server.rms.record.ResourceOverloadRecord record;
        synchronized (this.mResourceStatusMap) {
            record = new com.android.server.rms.record.ResourceOverloadRecord();
            this.mResourceStatusMap.put(java.lang.Long.valueOf(id), record);
        }
        return record;
    }

    public void recordResourceOverloadStatus(android.os.Message msg) {
        java.lang.StringBuilder stringBuilder;
        android.os.Message message = msg;
        int uid = message.arg1;
        int resourceType = message.arg2;
        com.android.internal.os.SomeArgs args = message.obj;
        java.lang.String pkg = args.arg1;
        int overloadNum = args.argi1;
        int speedOverLoadPeroid = args.argi2;
        int totalNum = args.argi3;
        int pid = args.argi4;
        args.recycle();
        if (resourceType == 16) {
            pkg = android.rms.utils.Utils.getPackageNameByUid(uid);
            if (pkg == null) {
                pkg = "";
            }
        }
        java.lang.String pkg2 = pkg;
        android.os.Bundle bundle = msg.getData();
        java.lang.String pkg3 = pkg2;
        int pid2 = pid;
        createUploadBigDataInfos(uid, resourceType, pkg2, overloadNum, speedOverLoadPeroid, totalNum, bundle);
        checkUploadBigDataInfos();
        int hardThreshold = 0;
        android.os.Bundle bundle2 = bundle;
        if (bundle2.containsKey("hard_threshold")) {
            hardThreshold = bundle2.getInt("hard_threshold");
            if (android.rms.utils.Utils.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("recordResourceOverloadStatus! hardThreshold:");
                stringBuilder.append(hardThreshold);
                android.util.Log.d("RMS.ResourceRecordStore", stringBuilder.toString());
            }
        }
        if (bundle2.containsKey("current_count")) {
            totalNum = bundle2.getInt("current_count");
            if (android.rms.utils.Utils.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("recordResourceOverloadStatus! curOverloadCount:");
                stringBuilder.append(totalNum);
                android.util.Log.d("RMS.ResourceRecordStore", stringBuilder.toString());
            }
        }
        com.android.server.rms.record.ResourceOverloadRecord record = getResourceStatusRecord(uid, pid2, resourceType);
        record.setInWhiteList(bundle2.getBoolean("isInWhiteList", false));
        record.setUid(uid);
        record.setPid(pid2);
        record.setPackageName(pkg3);
        record.setResourceType(resourceType);
        if (overloadNum > 0) {
            record.setSpeedOverloadNum(overloadNum);
        }
        if (speedOverLoadPeroid > 0) {
            record.setSpeedOverLoadPeroid(speedOverLoadPeroid);
        }
        if (totalNum > 0) {
            record.setCountOverLoadNum(totalNum);
        }
        if (hardThreshold > 0) {
            record.setHardThreshold(hardThreshold);
        }
        uploadBigDataLog(record);
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "recordResourceOverloadStatus!");
        }
    }

    public void createAndCheckUploadBigDataInfos(int uid, int resourceType, java.lang.String pkg, int overloadNum, int speedOverLoadPeriod, int totalNum, android.os.Bundle bundle) {
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "createAndCheckUploadBigDataInfos!");
        }
        if (this.mHandler != null) {
            android.os.Message msg = this.mHandler.obtainMessage();
            msg.what = 12;
            msg.arg1 = uid;
            msg.arg2 = resourceType;
            com.android.internal.os.SomeArgs args = com.android.internal.os.SomeArgs.obtain();
            args.arg1 = pkg;
            args.argi1 = overloadNum;
            args.argi2 = speedOverLoadPeriod;
            args.argi3 = totalNum;
            msg.obj = args;
            if (bundle != null) {
                msg.setData(bundle);
            }
            this.mHandler.sendMessage(msg);
        }
    }

    public void createAndCheckUploadBigDataInfos(android.os.Message msg) {
        android.os.Message message = msg;
        if (message != null) {
            int uid = message.arg1;
            int resourceType = message.arg2;
            com.android.internal.os.SomeArgs args = message.obj;
            java.lang.String pkg = args.arg1;
            int overloadNum = args.argi1;
            int speedOverLoadPeriod = args.argi2;
            int totalNum = args.argi3;
            args.recycle();
            createUploadBigDataInfos(uid, resourceType, pkg, overloadNum, speedOverLoadPeriod, totalNum, msg.getData());
            checkUploadBigDataInfos();
        }
    }

    private void createUploadBigDataInfos(int uid, int resourceType, java.lang.String pkg, int overloadNum, int speedOverLoadPeroid, int totalNum, android.os.Bundle bundle) {
        com.android.server.rms.record.ResourceRecordStore.BigDataInfo uploadInfo = findBigDataInfoInList(pkg, resourceType);
        if (bundle != null) {
            if (bundle.containsKey("third_party_app_lifetime") && android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.ResourceRecordStore", "createUploadBigDataInfos! BUNDLE_THIRD_PARTY_APP_LIFETIME");
            }
            if (bundle.containsKey("third_party_app_usetime") && android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.ResourceRecordStore", "createUploadBigDataInfos! BUNDLE_THIRD_PARTY_APP_USETIME");
            }
        }
        if (uploadInfo != null) {
            uploadInfo.overloadNum += overloadNum;
            uploadInfo.speedOverLoadPeroid = uploadInfo.speedOverLoadPeroid > speedOverLoadPeroid ? uploadInfo.speedOverLoadPeroid : speedOverLoadPeroid;
            uploadInfo.totalNum = uploadInfo.totalNum > totalNum ? uploadInfo.totalNum : totalNum;
        } else {
            uploadInfo = new com.android.server.rms.record.ResourceRecordStore.BigDataInfo();
            uploadInfo.mPkg = pkg == null ? "" : pkg;
            uploadInfo.mUid = uid;
            uploadInfo.mResourceType = resourceType;
            uploadInfo.overloadNum = overloadNum;
            uploadInfo.speedOverLoadPeroid = speedOverLoadPeroid;
            uploadInfo.totalNum = totalNum;
            this.mBigDataInfos.add(uploadInfo);
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "createUploadBigDataInfos!");
        }
    }

    private void checkUploadBigDataInfos() {
        if (this.mBigDataInfos != null) {
            if (this.mBigDataInfos.size() >= MAX_NUM_BIGDATAINFOS_IN_LIST) {
                uploadBigDataInfos();
            }
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.ResourceRecordStore", "checkUploadBigDataInfos!");
            }
        }
    }

    private com.android.server.rms.record.ResourceRecordStore.BigDataInfo findBigDataInfoInList(java.lang.String pkg, int resourceType) {
        for (com.android.server.rms.record.ResourceRecordStore.BigDataInfo mBigDataInfo : this.mBigDataInfos) {
            if (mBigDataInfo.mPkg.equals(pkg) && mBigDataInfo.mResourceType == resourceType) {
                return mBigDataInfo;
            }
        }
        return null;
    }

    public void uploadBigDataInfos() {
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "uploadBigDataInfos!");
        }
        if (this.mBigDataInfos != null) {
            if (this.mBigDataInfos.size() != 0) {
                if (android.rms.utils.Utils.IS_DEBUG_VERSION || !isExceedMonthlyUploadBigdataInfoCount()) {
                    for (com.android.server.rms.record.ResourceRecordStore.BigDataInfo bigDataInfo : this.mBigDataInfos) {
                        uploadBigDataInfoToIMonitor(bigDataInfo);
                    }
                    addToMonthlyUploadBigdataInfoCount(this.mBigDataInfos.size());
                    this.mBigDataInfos.clear();
                    return;
                }
                this.mBigDataInfos.clear();
            }
        }
    }

    private boolean uploadBigDataInfoToIMonitor(com.android.server.rms.record.ResourceRecordStore.BigDataInfo bigDataInfo) {
        if (bigDataInfo == null) {
            return false;
        }
        android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(901003010);
        java.lang.StringBuilder stringBuilder;
        if (eStream != null) {
            eStream.setParam((short) 0, bigDataInfo.mPkg);
            eStream.setParam((short) 1, bigDataInfo.mResourceType);
            eStream.setParam((short) 2, bigDataInfo.overloadNum);
            eStream.setParam((short) 3, bigDataInfo.totalNum);
            android.util.IMonitor.sendEvent(eStream);
            android.util.IMonitor.closeEventStream(eStream);
            if (android.rms.utils.Utils.DEBUG) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("uploadBigDataInfoToIMonitor! Bigdatainfo");
                stringBuilder.append(bigDataInfo.toString());
                android.util.Log.i("RMS.ResourceRecordStore", stringBuilder.toString());
            }
            return true;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Send FAULT_CODE_BIGDATA failed for :");
        stringBuilder.append(bigDataInfo.toString());
        android.util.Log.w("RMS.ResourceRecordStore", stringBuilder.toString());
        return false;
    }

    private void addToMonthlyUploadBigdataInfoCount(int uploadCount) {
        if (isSharedPrefsExist()) {
            int currentCount = this.mSharedPreferences.getInt("rmsUploadLimit", 0);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("mSharedPreferences current count is ");
            stringBuilder.append(currentCount);
            android.util.Log.i("RMS.ResourceRecordStore", stringBuilder.toString());
            android.content.SharedPreferences.Editor editor = this.mSharedPreferences.edit();
            editor.putInt("rmsUploadLimit", currentCount + uploadCount);
            editor.commit();
            return;
        }
        android.util.Log.e("RMS.ResourceRecordStore", "mSharedPreferences do not exist");
    }

    private boolean isExceedMonthlyUploadBigdataInfoCount() {
        if (isSharedPrefsExist()) {
            int storedMonth = this.mSharedPreferences.getInt("rmsCurMonth", -1);
            int currentMonth = java.util.Calendar.getInstance().get(2) + 1;
            if (storedMonth != currentMonth) {
                if (android.rms.utils.Utils.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("mSharedPreferences storedMonth is ");
                    stringBuilder.append(storedMonth);
                    stringBuilder.append(" currentMonth is ");
                    stringBuilder.append(currentMonth);
                    android.util.Log.i("RMS.ResourceRecordStore", stringBuilder.toString());
                }
                android.content.SharedPreferences.Editor editor = this.mSharedPreferences.edit();
                editor.putInt("rmsCurMonth", currentMonth);
                editor.putInt("rmsUploadLimit", 0);
                editor.commit();
                return false;
            } else if (this.mSharedPreferences.getInt("rmsUploadLimit", 0) <= com.android.server.rms.record.ResourceUtils.MONTHLY_BIGDATA_INFO_UPLOAD_COUNT_LIMIT) {
                return false;
            } else {
                if (android.rms.utils.Utils.DEBUG) {
                    android.util.Log.i("RMS.ResourceRecordStore", "ExceedMonthlyUploadBigdataInfoCount in SharedPrefs");
                }
                return true;
            }
        }
        android.util.Log.e("RMS.ResourceRecordStore", "mSharedPreferences do not exist");
        return false;
    }

    private boolean isSharedPrefsExist() {
        if (this.mContext == null) {
            return false;
        }
        if (this.mSharedPreferences == null) {
            this.mSharedPreferences = com.android.server.rms.record.ResourceUtils.getPinnedSharedPrefs(this.mContext);
        }
        if (this.mSharedPreferences != null) {
            return true;
        }
        android.util.Log.i("RMS.ResourceRecordStore", "mSharedPreferences equals Null");
        return false;
    }

    public void notifyResourceStatus(android.os.Message msg) {
        int resourceType = msg.arg1;
        int resourceStatus = msg.arg2;
        com.android.internal.os.SomeArgs args = msg.obj;
        java.lang.String resourceName = args.arg1;
        android.os.Bundle bd = args.arg2;
        args.recycle();
        android.app.mtm.MultiTaskManager instance = android.app.mtm.MultiTaskManager.getInstance();
        if (instance != null) {
            instance.notifyResourceStatusOverload(resourceType, resourceName, resourceStatus, bd);
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "notifyResourceStatus!");
        }
    }

    public void uploadResourceStatusRecord(long id, com.android.server.rms.record.ResourceOverloadRecord record) {
        synchronized (this.mResourceStatusMap) {
            this.mResourceStatusMap.put(java.lang.Long.valueOf(id), record);
        }
        uploadBigDataLog(record);
    }

    public void cleanResourceRecordMap(android.os.Message msg) {
        long id = com.android.server.rms.record.ResourceUtils.getResourceId(msg.arg1, 0, msg.arg2);
        synchronized (this.mResourceStatusMap) {
            this.mResourceStatusMap.remove(java.lang.Long.valueOf(id));
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "cleanResourceRecordMap!");
        }
    }

    public void cleanResRecordAppDied(int uid, int pid) {
        synchronized (this.mResourceStatusMap) {
            for (int i = 10; i <= 33; i++) {
                if (i != 18) {
                    this.mResourceStatusMap.remove(java.lang.Long.valueOf(com.android.server.rms.record.ResourceUtils.getResourceId(uid, pid, i)));
                }
            }
        }
        if (android.rms.utils.Utils.DEBUG) {
            android.util.Log.d("RMS.ResourceRecordStore", "cleanResourceRecordInAppDied!");
        }
    }

    public void uploadBigDataLog(com.android.server.rms.record.ResourceOverloadRecord record) {
        com.android.server.rms.record.ResourceUtils.uploadBigDataLogToIMonitor(record.getResourceType(), record.getPackageName(), record.getSpeedOverloadNum(), record.getCountOverLoadNum());
    }

    public boolean isOverloadResourceRecord(int callingUid, int pid, int resourceType) {
        long id = com.android.server.rms.record.ResourceUtils.getResourceId(callingUid, pid, resourceType);
        synchronized (this.mResourceStatusMap) {
            if (((com.android.server.rms.record.ResourceOverloadRecord) this.mResourceStatusMap.get(java.lang.Long.valueOf(id))) == null) {
                return false;
            }
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.d("RMS.ResourceRecordStore", "isOverloadResourceRecord: has overload record!");
            }
            return true;
        }
    }
}
