package com.android.server.rms.record;

public class ResourceUtils {
    public static final java.lang.String CURRENT_MONTH = "rmsCurMonth";
    public static final int FAULT_CODE_ACTIVITY = 901003020;
    public static final int FAULT_CODE_ALARM = 901003014;
    public static final int FAULT_CODE_APPCRASH = 901003016;
    public static final int FAULT_CODE_APPOPS = 901003015;
    public static final int FAULT_CODE_BIGDATA = 901003010;
    public static final int FAULT_CODE_BROADCAST = 901003012;
    public static final int FAULT_CODE_CURSOR = 901003018;
    public static final int FAULT_CODE_IOABN_WR_UID = 901003019;
    public static final int FAULT_CODE_IPC_TIMEOUT = 901003021;
    public static final int FAULT_CODE_NOTIFICATION = 901003011;
    public static final int FAULT_CODE_PIDS = 901003017;
    public static final int FAULT_CODE_RECEIVER = 901003013;
    public static final int MONTHLY_BIGDATA_INFO_UPLOAD_COUNT_LIMIT = (android.rms.utils.Utils.DEBUG ? 20 : 5000);
    public static final java.lang.String MONTHLY_BIGDATA_INFO_UPLOAD_LIMIT = "rmsUploadLimit";
    public static final java.lang.String RMS_SHARED_PREFERENCES = "rms_shared_preferences";
    private static final java.lang.String TAG = "RMS.ResourceUtils";
    private static java.lang.String[] defaultPermissionList = new java.lang.String[]{"android.permission.CAMERA"};
    private static com.android.server.HwBinderMonitor mIBinderM = new com.android.server.HwBinderMonitor();
    private static java.lang.String[] mResourceNameList = new java.lang.String[]{"NOTIFICATION", "BROADCAST", "RECEIVER", "ALARM", "APPOPS", "PIDS", "CURSOR", "APPSERVICE", "APP", "CPU", "IO", "SCHEDGROUP", "ANR", "DELAY", "FRAMELOST", "IOABN_WR_UID", "APPMNGMEMNORMALNATIVE", "APPMNGMEMNORMALPERS", "APPMNGWHITELIST", "CONTENTOBSERVER", "ACTIVITY", "ORDEREDBROADCAST", "AWAREBRPROXY", "IPCTIMEOUT"};

    public static long getResourceId(int callingUid, int pid, int resourceType) {
        long id = ((resourceType == 15 ? (long) pid : (long) resourceType) << 32) + ((long) callingUid);
        if (android.rms.utils.Utils.DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getResourceId  resourceType/");
            stringBuilder.append(resourceType);
            stringBuilder.append(" callingUid/");
            stringBuilder.append(callingUid);
            stringBuilder.append(" id/");
            stringBuilder.append(id);
            android.util.Log.d("RMS.ResourceUtils", stringBuilder.toString());
        }
        return id;
    }

    public static java.lang.String getResourceName(int resourceType) {
        if (resourceType >= 10) {
            if (resourceType <= 33) {
                if (resourceType - 10 >= mResourceNameList.length) {
                    android.util.Log.w("RMS.ResourceUtils", "fail to get resourceName");
                    return null;
                }
                java.lang.String resourceName = mResourceNameList[resourceType - 10];
                if (android.rms.utils.Utils.DEBUG || android.rms.utils.Utils.HWFLOW) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append(" getResourceName: resourceName:");
                    stringBuilder.append(resourceName);
                    android.util.Log.w("RMS.ResourceUtils", stringBuilder.toString());
                }
                return resourceName;
            }
        }
        return null;
    }

    public static int getResourcesType(java.lang.String resourceName) {
        if ("pids".equals(resourceName)) {
            return 15;
        }
        return 0;
    }

    public static java.lang.String composeName(java.lang.String pkg, int resourceType) {
        if (pkg == null) {
            return getResourceName(resourceType);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(pkg);
        stringBuilder.append("__");
        stringBuilder.append(getResourceName(resourceType));
        return stringBuilder.toString();
    }

    public static int checkSysProcPermission(int pid, int uid) {
        if (!(pid == android.os.Process.myPid() || uid == 0)) {
            if (uid != 1000) {
                return -1;
            }
        }
        return 0;
    }

    public static int checkAppUidPermission(int uid) {
        if (uid != 0) {
            if (uid != 1000) {
                if (android.os.UserHandle.isIsolated(uid)) {
                    return -1;
                }
                try {
                    for (java.lang.String s : defaultPermissionList) {
                        if (android.app.ActivityManager.checkUidPermission(s, uid) == 0) {
                            return 0;
                        }
                    }
                } catch (java.lang.Exception e) {
                    android.util.Slog.e("RMS.ResourceUtils", "PackageManager exception", e);
                }
                return -1;
            }
        }
        return 0;
    }

    public static int getProcessTypeId(int callingUid, java.lang.String pkg, int processTpye) {
        int typeID = processTpye;
        if (-1 == processTpye && pkg != null) {
            try {
                int i = 0;
                android.content.pm.ApplicationInfo appInfo = android.app.AppGlobals.getPackageManager().getApplicationInfo(pkg, 0, 0);
                if (appInfo == null) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("get appInfo is null from package: ");
                    stringBuilder.append(pkg);
                    android.util.Log.w("RMS.ResourceUtils", stringBuilder.toString());
                    return -1;
                }
                if ((appInfo.flags & 1) != 0 && (appInfo.hwFlags & 33554432) == 0 && (appInfo.hwFlags & 67108864) == 0) {
                    i = 2;
                }
                typeID = i;
            } catch (android.os.RemoteException e) {
                android.util.Log.w("RMS.ResourceUtils", " get PacakgeManager failed!");
            }
        }
        if (android.rms.utils.Utils.DEBUG) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("third app packageName: ");
            stringBuilder2.append(pkg);
            stringBuilder2.append(", uid: ");
            stringBuilder2.append(callingUid);
            stringBuilder2.append(", typeID: ");
            stringBuilder2.append(typeID);
            android.util.Log.d("RMS.ResourceUtils", stringBuilder2.toString());
        }
        return typeID;
    }

    public static long getAppTime(android.content.Context context, java.lang.String pkg) {
        java.util.Calendar calendar = java.util.Calendar.getInstance();
        long endTime = calendar.getTimeInMillis();
        calendar.add(2, -1);
        java.util.List<android.app.usage.UsageStats> queryUsageStats = ((android.app.usage.UsageStatsManager) context.getSystemService("usagestats")).queryUsageStats(2, calendar.getTimeInMillis(), endTime);
        if (!(queryUsageStats == null || queryUsageStats.isEmpty())) {
            for (android.app.usage.UsageStats usageStats : queryUsageStats) {
                if (pkg != null && pkg.equals(usageStats.getPackageName())) {
                    return usageStats.getTotalTimeInForeground();
                }
            }
        }
        return 0;
    }

    public static void uploadBigDataLogToIMonitor(int resType, java.lang.String pkgName, int overloadNum, int currentNum) {
        if (pkgName == null) {
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.e("RMS.ResourceUtils", "uploadBigDataLogToIMonitor! failed due to Null pkgName");
            }
        } else if (android.rms.utils.Utils.IS_DEBUG_VERSION) {
            int resFaultNum;
            short resFaultKey_PName;
            short resFaultKey_ResType;
            short resFaultKey_OverloadNum;
            short resFaultKey_CurrentCount;
            if (resType == 16) {
                resFaultNum = 901003018;
                resFaultKey_PName = (short) 0;
                resFaultKey_ResType = (short) 1;
                resFaultKey_OverloadNum = (short) 2;
                resFaultKey_CurrentCount = (short) 3;
            } else if (resType == 18) {
                resFaultNum = 901003016;
                resFaultKey_PName = (short) 0;
                resFaultKey_ResType = (short) 1;
                resFaultKey_OverloadNum = (short) 2;
                resFaultKey_CurrentCount = (short) 3;
            } else if (resType == 25) {
                resFaultNum = 901003019;
                resFaultKey_PName = (short) 0;
                resFaultKey_ResType = (short) 1;
                resFaultKey_OverloadNum = (short) 2;
                resFaultKey_CurrentCount = (short) 3;
            } else if (resType == 30) {
                resFaultNum = 901003020;
                resFaultKey_PName = (short) 0;
                resFaultKey_ResType = (short) 1;
                resFaultKey_OverloadNum = (short) 2;
                resFaultKey_CurrentCount = (short) 3;
            } else if (resType != 33) {
                switch (resType) {
                    case 10:
                        resFaultNum = 901003011;
                        resFaultKey_PName = (short) 0;
                        resFaultKey_ResType = (short) 1;
                        resFaultKey_OverloadNum = (short) 2;
                        resFaultKey_CurrentCount = (short) 3;
                        break;
                    case 11:
                        resFaultNum = 901003012;
                        resFaultKey_PName = (short) 0;
                        resFaultKey_ResType = (short) 1;
                        resFaultKey_OverloadNum = (short) 2;
                        resFaultKey_CurrentCount = (short) 3;
                        break;
                    case 12:
                        resFaultNum = 901003013;
                        resFaultKey_PName = (short) 0;
                        resFaultKey_ResType = (short) 1;
                        resFaultKey_OverloadNum = (short) 2;
                        resFaultKey_CurrentCount = (short) 3;
                        break;
                    case 13:
                        resFaultNum = 901003014;
                        resFaultKey_PName = (short) 0;
                        resFaultKey_ResType = (short) 1;
                        resFaultKey_OverloadNum = (short) 2;
                        resFaultKey_CurrentCount = (short) 3;
                        break;
                    case 14:
                        resFaultNum = 901003015;
                        resFaultKey_PName = (short) 0;
                        resFaultKey_ResType = (short) 1;
                        resFaultKey_OverloadNum = (short) 2;
                        resFaultKey_CurrentCount = (short) 3;
                        break;
                    default:
                        if (android.rms.utils.Utils.DEBUG) {
                            android.util.Log.w("RMS.ResourceUtils", "uploadBigDataLogToIMonitor! failed due to No such resource Type");
                        }
                        return;
                }
            } else {
                resFaultNum = 901003021;
                resFaultKey_PName = (short) 0;
                resFaultKey_ResType = (short) 1;
                resFaultKey_OverloadNum = (short) 2;
                resFaultKey_CurrentCount = (short) 3;
            }
            android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(resFaultNum);
            if (eStream != null) {
                eStream.setParam(resFaultKey_PName, pkgName);
                eStream.setParam(resFaultKey_ResType, resType);
                eStream.setParam(resFaultKey_OverloadNum, overloadNum);
                eStream.setParam(resFaultKey_CurrentCount, currentNum);
                android.util.IMonitor.sendEvent(eStream);
                android.util.IMonitor.closeEventStream(eStream);
                if (android.rms.utils.Utils.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("uploadBigDataLogToIMonitor! pkgName:");
                    stringBuilder.append(pkgName);
                    stringBuilder.append(" resType:");
                    stringBuilder.append(resType);
                    stringBuilder.append(" overloadNum:");
                    stringBuilder.append(overloadNum);
                    stringBuilder.append(" currentNum");
                    stringBuilder.append(currentNum);
                    android.util.Log.i("RMS.ResourceUtils", stringBuilder.toString());
                }
            } else if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.i("RMS.ResourceUtils", "uploadBigDataLogToIMonitor! failed due to null eStream");
            }
        } else {
            if (android.rms.utils.Utils.DEBUG) {
                android.util.Log.i("RMS.ResourceUtils", "uploadBigDataLogToIMonitor! failed due to !IS_DEBUG_VERSION");
            }
        }
    }

    public static android.content.SharedPreferences getPinnedSharedPrefs(android.content.Context context) {
        android.content.SharedPreferences sp = null;
        if (context == null) {
            return null;
        }
        try {
            sp = context.getSharedPreferences(new java.io.File(new java.io.File(android.os.Environment.getDataUserCePackageDirectory(android.os.storage.StorageManager.UUID_PRIVATE_INTERNAL, context.getUserId(), context.getPackageName()), "shared_prefs"), "rms_shared_preferences.xml"), 0);
        } catch (java.lang.Exception e) {
            android.util.Log.w("RMS.ResourceUtils", "getPinnedSharedPrefs failed");
        }
        return sp;
    }

    public static boolean killApplicationProcess(int pid) {
        if (pid <= 0) {
            return false;
        }
        android.os.Process.killProcess(pid);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("kill process pid:");
        stringBuilder.append(pid);
        android.util.Log.e("RMS.ResourceUtils", stringBuilder.toString());
        return true;
    }

    public static int getLockOwnerPid(java.lang.Object lock) {
        if (lock == null) {
            return -1;
        }
        int lock_holder_tid = java.lang.Thread.getLockOwnerThreadId(lock);
        int pid = mIBinderM.catchBadproc(lock_holder_tid, 1);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("blocking in thread:");
        stringBuilder.append(lock_holder_tid);
        stringBuilder.append(" remote:");
        stringBuilder.append(pid);
        android.util.Log.i("RMS.ResourceUtils", stringBuilder.toString());
        return pid;
    }

    public static int isNativeProcess(int pid) {
        if (pid <= 0) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("pid less than 0, pid is ");
            stringBuilder.append(pid);
            android.util.Slog.w("RMS.ResourceUtils", stringBuilder.toString());
            return -1;
        }
        java.lang.String pidAdj = getAdjForPid(pid);
        if (pidAdj == null) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("no such oom_score file and pid is");
            stringBuilder2.append(pid);
            android.util.Slog.w("RMS.ResourceUtils", stringBuilder2.toString());
            return -1;
        }
        try {
            if (java.lang.Integer.parseInt(pidAdj.trim()) == 0) {
                return 1;
            }
            return 0;
        } catch (java.lang.NumberFormatException e) {
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("isNativeProcess NumberFormatException: ");
            stringBuilder3.append(e.toString());
            android.util.Slog.e("RMS.ResourceUtils", stringBuilder3.toString());
            return -1;
        }
    }

    private static final java.lang.String getAdjForPid(int pid) {
        java.lang.String[] outStrings = new java.lang.String[1];
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("/proc/");
        stringBuilder.append(pid);
        stringBuilder.append("/oom_score");
        android.os.Process.readProcFile(stringBuilder.toString(), new int[]{4128}, outStrings, null, null);
        return outStrings[0];
    }
}
