package com.android.server.security;

public class HwSecurityService extends com.android.server.SystemService {
    private static final int CCMODE_PLUGIN_ID = 9;
    private static final int DEFAULT_PLUGIN_ID = 0;
    private static final int DEFAULT_RESIDENT_PRIORITY = 0;
    private static final int DEVICE_SECURE_DIAGNOSE_ID = 2;
    private static final int DEVICE_USAGE_PLUGIN_ID = 1;
    private static final int DYNAMIC_PLUGIN_FLAG = 0;
    private static final int FILEPROTECT_PLUGIN_ID = 11;
    private static final int HWSYSTEMMANAGER_PLUGIN_ID = 13;
    private static final int HW_ANTIMAL_PLUGIN_ID = 16;
    private static final boolean HW_DEBUG;
    private static final int HW_EID_PLUGIN_ID = 15;
    private static final int HW_INSE_PLUGIN_ID = 14;
    private static final int HW_KEYCHAIN_PLUGIN_ID = 20;
    private static final int IFAA_PLUGIN_ID = 3;
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    private static final java.lang.String MANAGE_USE_SECURITY = "com.huawei.permission.MANAGE_USE_SECURITY";
    private static final int PAN_PAY_PLUGIN_ID = 12;
    private static final java.lang.String PROPERTIES_CC_MODE_SUPPORTED = "ro.config.support_ccmode";
    private static final int PWDPROTECT_PLUGIN_ID = 10;
    private static final int RESIDENT_PLUGIN_FLAG = 1;
    private static int SEAPP_RESIDENT_PRIORITY = 100;
    private static final int SECURITYPROFILE_PLUGIN_ID = 8;
    private static final java.lang.String SECURITY_SERVICE = "securityserver";
    private static final boolean SUPPORT_HW_IUDF = "true".equalsIgnoreCase(android.os.SystemProperties.get("ro.config.support_iudf", "false"));
    private static final boolean SUPPORT_HW_SEAPP = "true".equalsIgnoreCase(android.os.SystemProperties.get("ro.config.support_iseapp", "false"));
    private static final boolean SUPPORT_PRIVSPACE = "true".equalsIgnoreCase(android.os.SystemProperties.get("ro.config.support_privacyspace", "false"));
    private static final java.lang.String TAG = "HwSecurityService";
    private static final int TRUSTCIRCLE_PLUGIN_ID = 5;
    private static final int TRUSTSPACE_PLUGIN_ID = 4;
    private static final int TSMAGENT_PLUGIN_ID = 7;
    private static final int UKEY_PLUGIN_ID = 6;
    private android.content.Context mContext;
    private android.util.ArrayMap<java.lang.Integer, com.android.server.security.HwSecurityService.HwSecurityPluginObj> mMapPlugins = new android.util.ArrayMap();

    private static class HwSecurityPluginObj {
        public boolean isRequiredPermission;
        public com.android.server.security.core.IHwSecurityPlugin.Creator mCreator;
        public int mFlag;
        public java.lang.Object mLock;
        public com.android.server.security.HwSecurityService.IHwPluginRef mPluginRef;
        public int mStartupTiming;
        public int residentPriorityLevel;

        private HwSecurityPluginObj() {
            this.isRequiredPermission = true;
        }
    }

    private final class HwSecurityServiceWrapper extends huawei.android.security.IHwSecurityService.Stub {
        private HwSecurityServiceWrapper() {
        }

        public android.os.IBinder querySecurityInterface(int pluginId) {
            return com.android.server.security.HwSecurityService.this.queryInterface(pluginId);
        }

        public void unBind(int pluginId, android.os.IBinder client) {
            com.android.server.security.HwSecurityService.this.unBindDynamicPlugin(pluginId, client, false);
        }

        public android.os.IBinder bind(int pluginId, android.os.IBinder client) {
            return com.android.server.security.HwSecurityService.this.bindDynamicPlugin(pluginId, client);
        }
    }

    public interface IHwPluginRef {
        void bind(android.os.IBinder iBinder);

        com.android.server.security.core.IHwSecurityPlugin get();

        void set(com.android.server.security.core.IHwSecurityPlugin iHwSecurityPlugin);

        boolean unBind(android.os.IBinder iBinder);
    }

    private static class ResidentPriorityComparator implements java.util.Comparator<com.android.server.security.HwSecurityService.HwSecurityPluginObj>, java.io.Serializable {
        private ResidentPriorityComparator() {
        }

        public int compare(com.android.server.security.HwSecurityService.HwSecurityPluginObj plugin1, com.android.server.security.HwSecurityService.HwSecurityPluginObj plugin2) {
            if (plugin1.residentPriorityLevel == plugin2.residentPriorityLevel) {
                return 0;
            }
            if (plugin1.residentPriorityLevel < plugin2.residentPriorityLevel) {
                return 1;
            }
            return -1;
        }
    }

    public static class HwSecurityDynamicPluginRef implements com.android.server.security.HwSecurityService.IHwPluginRef {
        private static final java.lang.String TAG = "HwSecurityDynamicPluginRef";
        private java.util.HashMap<android.os.IBinder, com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef.Death> mClient = new java.util.HashMap();
        private com.android.server.security.HwSecurityService mParentService;
        private int mPlugInID;
        private com.android.server.security.core.IHwSecurityPlugin mPlugin;

        private class Death implements android.os.IBinder.DeathRecipient {
            android.os.IBinder token;

            Death(android.os.IBinder token) {
                this.token = token;
            }

            public void binderDied() {
                com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef.this.onClientBinderDie(this.token);
            }
        }

        public HwSecurityDynamicPluginRef(int pluginId, com.android.server.security.HwSecurityService service) {
            this.mPlugInID = pluginId;
            this.mParentService = service;
        }

        public com.android.server.security.core.IHwSecurityPlugin get() {
            return this.mPlugin;
        }

        public void set(com.android.server.security.core.IHwSecurityPlugin plugIn) {
            this.mPlugin = plugIn;
        }

        public void bind(android.os.IBinder client) {
            if (client != null) {
                if (com.android.server.security.HwSecurityService.HW_DEBUG) {
                    android.util.Slog.d("HwSecurityDynamicPluginRef", "HwSecurityDynamicPluginRef, bind");
                }
                com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef.Death d = new com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef.Death(client);
                try {
                    client.linkToDeath(d, 0);
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("HwSecurityDynamicPluginRef", "error");
                }
                this.mClient.put(client, d);
                if (com.android.server.security.HwSecurityService.HW_DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("HwSecurityDynamicPluginRef mClient size:");
                    stringBuilder.append(this.mClient.size());
                    stringBuilder.append(", client");
                    stringBuilder.append(client);
                    android.util.Slog.d("HwSecurityDynamicPluginRef", stringBuilder.toString());
                }
            }
        }

        public boolean unBind(android.os.IBinder client) {
            if (com.android.server.security.HwSecurityService.HW_DEBUG) {
                android.util.Slog.d("HwSecurityDynamicPluginRef", "HwSecurityDynamicPluginRef, unBind");
            }
            client.unlinkToDeath((com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef.Death) this.mClient.remove(client), 0);
            if (com.android.server.security.HwSecurityService.HW_DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("HwSecurityDynamicPluginRef mClient size:");
                stringBuilder.append(this.mClient.size());
                stringBuilder.append(", client");
                stringBuilder.append(client);
                android.util.Slog.d("HwSecurityDynamicPluginRef", stringBuilder.toString());
            }
            return this.mClient.isEmpty();
        }

        public void onClientBinderDie(android.os.IBinder client) {
            this.mParentService.onClientBinderDie(this.mPlugInID, client);
        }
    }

    public static class HwSecurityPluginRef implements com.android.server.security.HwSecurityService.IHwPluginRef {
        private com.android.server.security.core.IHwSecurityPlugin mPlugin;

        public com.android.server.security.core.IHwSecurityPlugin get() {
            return this.mPlugin;
        }

        public void set(com.android.server.security.core.IHwSecurityPlugin plugIn) {
            this.mPlugin = plugIn;
        }

        public void bind(android.os.IBinder binder) {
        }

        public boolean unBind(android.os.IBinder binder) {
            return false;
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwSecurityService", 4)) {
                z = false;
                HW_DEBUG = z;
            }
        }
        z = true;
        HW_DEBUG = z;
    }

    public HwSecurityService(android.content.Context context) {
        super(context);
        this.mContext = context;
    }

    public void onStart() {
        if (HW_DEBUG) {
            android.util.Slog.d("HwSecurityService", "Start HwSecurityService");
        }
        publishBinderService("securityserver", new com.android.server.security.HwSecurityService.HwSecurityServiceWrapper());
        registerPlugin(1, 1, 1000, com.android.server.security.deviceusage.HwDeviceUsagePlugin.CREATOR, null);
        registerPlugin(2, 1, 500, com.android.server.security.securitydiagnose.HwSecurityDiagnosePlugin.CREATOR, null);
        registerPlugin(3, 0, 1000, com.android.server.security.IFAA.IFAAPlugin.CREATOR, com.android.server.security.IFAA.IFAAPlugin.BINDLOCK);
        android.util.Slog.d("HwSecurityService", "is add IFAAPlugin");
        registerPlugin(4, 1, 500, com.android.server.security.trustspace.TrustSpaceManagerService.CREATOR, null);
        registerPlugin(5, 1, 1000, com.android.server.security.trustcircle.TrustCirclePlugin.CREATOR, com.android.server.security.trustcircle.TrustCirclePlugin.BINDLOCK);
        registerPlugin(6, 1, 1000, com.android.server.security.ukey.UKeyManagerService.CREATOR, null, false);
        registerPlugin(7, 1, 1000, com.android.server.security.tsmagent.service.TSMAgentService.CREATOR, com.android.server.security.tsmagent.service.TSMAgentService.BINDLOCK, false);
        registerPlugin(12, 1, 1000, com.android.server.security.panpay.PanPayService.CREATOR, com.android.server.security.panpay.PanPayService.BINDLOCK, false);
        if (SUPPORT_HW_SEAPP && IS_CHINA_AREA) {
            registerPlugin(8, 1, 500, com.android.server.security.securityprofile.SecurityProfileService.CREATOR, null, false, SEAPP_RESIDENT_PRIORITY);
        }
        if (android.os.SystemProperties.getBoolean("ro.config.support_ccmode", false)) {
            registerPlugin(9, 1, 1000, com.android.server.security.ccmode.HwCCModePlugin.CREATOR, com.android.server.security.ccmode.HwCCModePlugin.BINDLOCK);
        }
        if (SUPPORT_PRIVSPACE) {
            registerPlugin(10, 1, 1000, com.android.server.security.pwdprotect.PwdProtectService.CREATOR, null, false);
        }
        if (SUPPORT_HW_IUDF) {
            registerPlugin(11, 1, 500, com.android.server.security.fileprotect.HwSfpService.CREATOR, null, false);
        }
        registerPlugin(13, 1, 500, com.android.server.security.hsm.HwSystemManagerPlugin.CREATOR, null, false);
        registerPlugin(14, 1, 500, com.android.server.security.inseservice.InSEService.CREATOR, com.android.server.security.inseservice.InSEService.BINDLOCK);
        android.util.Slog.d("HwSecurityService", "is add inEService");
        registerPlugin(20, 1, 1000, com.android.server.security.hwkeychain.HwKeychainService.CREATOR, null, false);
        if (IS_CHINA_AREA) {
            registerPlugin(16, 1, 1000, com.android.server.security.antimal.HwAntiMalPlugin.CREATOR, null, false);
        }
        registerPlugin(15, 1, 500, com.android.server.security.eidservice.HwEidPlugin.CREATOR, com.android.server.security.eidservice.HwEidPlugin.BINDLOCK);
        android.util.Slog.d("HwSecurityService", "is add HwEidPlugin");
    }

    public void onBootPhase(int phase) {
        startResidentPlugin(phase);
    }

    private void startResidentPlugin(int startupTiming) {
        if (!this.mMapPlugins.isEmpty()) {
            java.util.List<com.android.server.security.HwSecurityService.HwSecurityPluginObj> pluginList = new java.util.ArrayList();
            for (java.lang.Integer key : this.mMapPlugins.keySet()) {
                com.android.server.security.HwSecurityService.HwSecurityPluginObj obj = (com.android.server.security.HwSecurityService.HwSecurityPluginObj) this.mMapPlugins.get(java.lang.Integer.valueOf(key.intValue()));
                if (obj.mStartupTiming == startupTiming && obj.mFlag == 1) {
                    pluginList.add(obj);
                }
            }
            java.util.Collections.sort(pluginList, new com.android.server.security.HwSecurityService.ResidentPriorityComparator());
            for (com.android.server.security.HwSecurityService.HwSecurityPluginObj obj2 : pluginList) {
                com.android.server.security.core.IHwSecurityPlugin plugIn = obj2.mCreator.createPlugin(this.mContext);
                if (HW_DEBUG) {
                    android.util.Slog.d("HwSecurityService", "createPlugin");
                }
                obj2.mPluginRef.set(plugIn);
                if (plugIn != null) {
                    if (HW_DEBUG) {
                        android.util.Slog.d("HwSecurityService", "Plugin start");
                    }
                    plugIn.onStart();
                } else if (HW_DEBUG) {
                    android.util.Slog.d("HwSecurityService", "plugIn is null");
                }
            }
        }
    }

    private void checkPluginPermission(com.android.server.security.HwSecurityService.HwSecurityPluginObj obj) {
        if (!(obj == null || obj.mCreator == null)) {
            if (obj.isRequiredPermission) {
                java.lang.String pluginPermission = obj.mCreator.getPluginPermission();
                if (pluginPermission != null) {
                    checkPermission(pluginPermission);
                } else {
                    checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
                }
            }
        }
    }

    private android.os.IBinder bindDynamicPlugin(int pluginId, android.os.IBinder client) {
        android.util.Slog.d("HwSecurityService", "bindDynamicPlugin");
        if (!(client == null || this.mMapPlugins == null)) {
            if (this.mMapPlugins.containsKey(java.lang.Integer.valueOf(pluginId))) {
                com.android.server.security.HwSecurityService.HwSecurityPluginObj obj = (com.android.server.security.HwSecurityService.HwSecurityPluginObj) this.mMapPlugins.get(java.lang.Integer.valueOf(pluginId));
                if (obj != null) {
                    if (obj.mFlag == 0) {
                        android.os.IBinder asBinder;
                        checkPluginPermission(obj);
                        synchronized (obj.mLock) {
                            com.android.server.security.core.IHwSecurityPlugin plugIn = obj.mPluginRef.get();
                            if (plugIn == null) {
                                plugIn = obj.mCreator.createPlugin(this.mContext);
                                plugIn.onStart();
                                obj.mPluginRef.set(plugIn);
                            }
                            obj.mPluginRef.bind(client);
                            asBinder = plugIn.asBinder();
                        }
                        return asBinder;
                    }
                }
                return null;
            }
        }
        android.util.Slog.e("HwSecurityService", "client is null or no this dynamic Plugin");
        return null;
    }

    private android.os.IBinder queryInterface(int pluginId) {
        android.util.Slog.d("HwSecurityService", "find this Resident Plugin");
        if (this.mMapPlugins != null) {
            if (this.mMapPlugins.containsKey(java.lang.Integer.valueOf(pluginId))) {
                com.android.server.security.HwSecurityService.HwSecurityPluginObj obj = (com.android.server.security.HwSecurityService.HwSecurityPluginObj) this.mMapPlugins.get(java.lang.Integer.valueOf(pluginId));
                if (obj != null) {
                    if (obj.mFlag == 1) {
                        checkPluginPermission(obj);
                        com.android.server.security.core.IHwSecurityPlugin plugIn = obj.mPluginRef.get();
                        if (plugIn != null) {
                            return plugIn.asBinder();
                        }
                        return null;
                    }
                }
                android.util.Slog.e("HwSecurityService", "obj == null");
                return null;
            }
        }
        android.util.Slog.e("HwSecurityService", "not find this Resident Plugin");
        return null;
    }

    private void registerPlugin(int pluginId, int flag, int startupTiming, com.android.server.security.core.IHwSecurityPlugin.Creator creator, java.lang.Object lockObj) {
        registerPlugin(pluginId, flag, startupTiming, creator, lockObj, true, 0);
    }

    private void registerPlugin(int pluginId, int flag, int startupTiming, com.android.server.security.core.IHwSecurityPlugin.Creator creator, java.lang.Object lockObj, boolean isRequiredPermission) {
        registerPlugin(pluginId, flag, startupTiming, creator, lockObj, isRequiredPermission, 0);
    }

    private void registerPlugin(int pluginId, int flag, int startupTiming, com.android.server.security.core.IHwSecurityPlugin.Creator creator, java.lang.Object lockObj, boolean isRequiredPermission, int residentPriorityLevel) {
        if (HW_DEBUG) {
            android.util.Slog.d("HwSecurityService", "addPlugin");
        }
        if (creator != null) {
            com.android.server.security.HwSecurityService.HwSecurityPluginObj obj = new com.android.server.security.HwSecurityService.HwSecurityPluginObj();
            obj.mFlag = flag;
            obj.mCreator = creator;
            obj.mLock = lockObj;
            obj.mStartupTiming = startupTiming;
            obj.isRequiredPermission = isRequiredPermission;
            obj.residentPriorityLevel = residentPriorityLevel;
            if (1 == flag) {
                obj.mPluginRef = new com.android.server.security.HwSecurityService.HwSecurityPluginRef();
            } else if (flag == 0) {
                obj.mPluginRef = new com.android.server.security.HwSecurityService.HwSecurityDynamicPluginRef(pluginId, this);
            }
            this.mMapPlugins.put(java.lang.Integer.valueOf(pluginId), obj);
        }
    }

    public void onClientBinderDie(int pluginId, android.os.IBinder client) {
        if (client != null) {
            unBindDynamicPlugin(pluginId, client, true);
        }
    }

    private void unBindDynamicPlugin(int pluginId, android.os.IBinder client, boolean isInnerCalling) {
        if (HW_DEBUG) {
            android.util.Slog.d("HwSecurityService", "unBindDynamicPlugin");
        }
        if (this.mMapPlugins != null) {
            if (this.mMapPlugins.containsKey(java.lang.Integer.valueOf(pluginId))) {
                com.android.server.security.HwSecurityService.HwSecurityPluginObj obj = (com.android.server.security.HwSecurityService.HwSecurityPluginObj) this.mMapPlugins.get(java.lang.Integer.valueOf(pluginId));
                if (obj != null) {
                    if (obj.mFlag == 0) {
                        if (!isInnerCalling) {
                            checkPluginPermission(obj);
                        }
                        synchronized (obj.mLock) {
                            com.android.server.security.core.IHwSecurityPlugin plugIn = obj.mPluginRef.get();
                            if (obj.mPluginRef.unBind(client)) {
                                plugIn.onStop();
                                obj.mPluginRef.set(null);
                            }
                        }
                    }
                }
            }
        }
    }

    private void checkPermission(java.lang.String permission) {
        android.content.Context context = getContext();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Must have ");
        stringBuilder.append(permission);
        stringBuilder.append(" permission.");
        context.enforceCallingOrSelfPermission(permission, stringBuilder.toString());
    }
}
