package com.android.server.security.IFAA;

public class IFAAPlugin extends huawei.android.security.IIFAAPlugin.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    private static final java.lang.String ACTION_TRUSTSPACE_APP_SECURE_HINT = "com.huawei.trustspace.action.TRUSTSPACE_SECURE_HINT";
    public static final java.lang.Object BINDLOCK = new java.lang.Object();
    private static final int CERTIFICATE_SIGN_CMD_ID = 2048;
    private static final int CERTIFICATE_SIGN_PROMPTION_VALUE = 10;
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            if (com.android.server.security.IFAA.IFAAPlugin.HW_DEBUG) {
                android.util.Slog.d("IFAAPlugin", "createPlugin");
            }
            return new com.android.server.security.IFAA.IFAAPlugin(context);
        }

        public java.lang.String getPluginPermission() {
            return "cn.org.ifaa.permission.USE_IFAA_MANAGER";
        }
    };
    private static final int FAILED = 1;
    private static final boolean HW_DEBUG;
    private static final int IFAA_CMD_AUTHENTICATE = 4;
    private static final int IFAA_CMD_REGISTER = 2;
    private static final int IFAA_FAIL = -1;
    private static final int IFAA_RET_OFFSET = 0;
    private static final int IFAA_SUCCESS = 0;
    private static final int MAX_INT = 2130706432;
    private static final int PROCESS_CMD_TYPE = 1;
    private static final int SIZE_OF_INT = 4;
    private static final int SUCCESS = 0;
    private static final java.lang.String SYSTEMUI_PACKAGE_NAME = "com.android.systemui";
    private static final java.lang.String TAG = "IFAAPlugin";
    private static final java.lang.String USE_IFAA_MANAGER = "cn.org.ifaa.permission.USE_IFAA_MANAGER";
    private android.content.Context mContext;
    private android.os.Handler mHandler;
    private android.os.HandlerThread mHandlerThread;

    private static class MessageData {
        android.os.IBinder mCallBack;
        byte[] mData;

        MessageData(byte[] data, android.os.IBinder callBack) {
            this.mData = data;
            this.mCallBack = callBack;
        }
    }

    public native byte[] nativeProcessCmd(android.content.Context context, byte[] bArr);

    public native int nativeStart();

    public native void nativeStop();

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("IFAAPlugin", 4)) {
                z = false;
                HW_DEBUG = z;
                java.lang.System.loadLibrary("ifaajni_ca");
            }
        }
        z = true;
        HW_DEBUG = z;
        try {
            java.lang.System.loadLibrary("ifaajni_ca");
        } catch (java.lang.UnsatisfiedLinkError e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("LoadLibrary is error ");
            stringBuilder.append(e.toString());
            android.util.Slog.e("IFAAPlugin", stringBuilder.toString());
        }
    }

    private int decodeByteToInt(byte[] ary, int offset) {
        if (ary != null) {
            if (ary.length - 4 >= offset) {
                return (((ary[offset] & 255) | ((ary[offset + 1] << 8) & 65280)) | ((ary[offset + 2] << 16) & 16711680)) | ((ary[offset + 3] << 24) & -16777216);
            }
        }
        return -1;
    }

    private int getCmdId(byte[] data) {
        if (data == null) {
            android.util.Slog.e("IFAAPlugin", "getCmdId bad param");
            return -1;
        }
        int dataLen = data.length;
        if (dataLen < 4) {
            return -1;
        }
        int position = 0 + 4;
        int signLen = decodeByteToInt(data, position);
        position += 4;
        if (signLen >= 0 && 2130706432 - position >= signLen) {
            if (dataLen >= position + signLen) {
                position += signLen;
                int pkgLen = decodeByteToInt(data, position);
                position += 4;
                if (pkgLen >= 0 && 2130706432 - position >= pkgLen) {
                    if (dataLen >= position + pkgLen) {
                        return decodeByteToInt(data, position + pkgLen);
                    }
                }
                return -1;
            }
        }
        return -1;
    }

    public void processCmd(huawei.android.security.IIFAAPluginCallBack callBack, byte[] data) {
        if (HW_DEBUG) {
            android.util.Slog.d("IFAAPlugin", "processCmd in IFAAPlugin");
        }
        checkPermission("cn.org.ifaa.permission.USE_IFAA_MANAGER");
        if (callBack != null) {
            if (data != null) {
                com.android.server.security.IFAA.IFAAPlugin.MessageData messageData = new com.android.server.security.IFAA.IFAAPlugin.MessageData(data, callBack.asBinder());
                android.os.Message msg = android.os.Message.obtain();
                msg.what = 1;
                msg.obj = messageData;
                this.mHandler.sendMessage(msg);
                return;
            }
        }
        android.util.Slog.e("IFAAPlugin", "parameters is error");
    }

    public IFAAPlugin(android.content.Context context) {
        this.mContext = context;
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public void onStart() {
        if (HW_DEBUG) {
            android.util.Slog.d("IFAAPlugin", "is start");
        }
        try {
            if (HW_DEBUG) {
                android.util.Slog.d("IFAAPlugin", "close session");
            }
            nativeStart();
        } catch (java.lang.UnsatisfiedLinkError e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("start error");
            stringBuilder.append(e.toString());
            android.util.Slog.e("IFAAPlugin", stringBuilder.toString());
        }
        this.mHandlerThread = new android.os.HandlerThread("IFAAPluginThread");
        this.mHandlerThread.start();
        this.mHandler = new android.os.Handler(this.mHandlerThread.getLooper()) {
            public void handleMessage(android.os.Message msg) {
                if (msg.what == 1) {
                    com.android.server.security.IFAA.IFAAPlugin.this.handleProcessCmd(msg);
                }
            }
        };
    }

    private void showHardwareSupportPrompt(byte[] reqData, byte[] resData) {
        if (reqData == null || resData == null) {
            android.util.Slog.e("IFAAPlugin", "showHardwareSupportPrompt bad param");
        }
        int cmdID = getCmdId(reqData);
        int retCode = decodeByteToInt(resData, 0);
        if (2 == cmdID && retCode == 0) {
            android.util.Flog.bdReport(this.mContext, 901);
        }
        if (4 == cmdID && retCode == 0) {
            android.util.Flog.bdReport(this.mContext, 902);
        }
        if (2048 == cmdID && retCode == 0) {
            long identity = android.os.Binder.clearCallingIdentity();
            try {
                if (HW_DEBUG) {
                    android.util.Slog.d("IFAAPlugin", "sending msg to call secure hint");
                }
                android.content.Intent intent = new android.content.Intent("com.huawei.trustspace.action.TRUSTSPACE_SECURE_HINT");
                intent.setPackage("com.android.systemui");
                intent.putExtra("type", 10);
                this.mContext.sendBroadcast(intent);
            } finally {
                android.os.Binder.restoreCallingIdentity(identity);
            }
        }
    }

    private void handleProcessCmd(android.os.Message msg) {
        byte[] retData;
        if (HW_DEBUG) {
            android.util.Slog.d("IFAAPlugin", "handleProcessCmd in IFAAPlugin ");
        }
        com.android.server.security.IFAA.IFAAPlugin.MessageData messageData = msg.obj;
        android.os.IBinder callBack = messageData.mCallBack;
        byte[] data = messageData.mData;
        if (HW_DEBUG) {
            android.util.Slog.d("IFAAPlugin", "call JNI  processCmd ");
        }
        try {
            retData = nativeProcessCmd(this.mContext, data);
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.e("IFAAPlugin", e.toString());
            retData = null;
        }
        showHardwareSupportPrompt(data, retData);
        huawei.android.security.IIFAAPluginCallBack mCallBackService = huawei.android.security.IIFAAPluginCallBack.Stub.asInterface(callBack);
        if (mCallBackService != null) {
            if (retData != null) {
                try {
                    if (HW_DEBUG) {
                        android.util.Slog.d("IFAAPlugin", "call processCmdResult in IIFAAPluginCallBack ");
                    }
                    mCallBackService.processCmdResult(0, retData);
                } catch (android.os.RemoteException e2) {
                    android.util.Slog.e("IFAAPlugin", "Error in send processCmdResult to callback.");
                }
            } else {
                if (HW_DEBUG) {
                    android.util.Slog.d("IFAAPlugin", "retData is null ");
                }
                mCallBackService.processCmdResult(1, new byte[0]);
            }
            return;
        }
        android.util.Slog.e("IFAAPlugin", "callback is invalid!!!");
    }

    public void onStop() {
        if (this.mHandler != null) {
            this.mHandler = null;
        }
        if (this.mHandlerThread != null) {
            this.mHandlerThread.quitSafely();
            this.mHandlerThread = null;
        }
        try {
            android.util.Slog.d("IFAAPlugin", "close session");
            nativeStop();
        } catch (java.lang.UnsatisfiedLinkError e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("stop error");
            stringBuilder.append(e.toString());
            android.util.Slog.e("IFAAPlugin", stringBuilder.toString());
        }
    }

    private void checkPermission(java.lang.String permission) {
        android.content.Context context = this.mContext;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Must have ");
        stringBuilder.append(permission);
        stringBuilder.append(" permission.");
        context.enforceCallingOrSelfPermission(permission, stringBuilder.toString());
    }
}
