package com.android.server.security.antimal;

public class HwAntiMalPlugin extends huawei.android.security.IHwAntiMalPlugin.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    private static final java.lang.String ANTIMAL_KEY_LAUNCHER_NAME = "launcher_name";
    private static final java.lang.String ANTIMAL_KEY_PROTECT_TYPE = "protect_type";
    private static final int ANTIMAL_PROTECT_TYPE_DEFAULT = 0;
    private static final int ANTIMAL_PROTECT_TYPE_LAUNCHER = 2;
    private static final int ANTIMAL_PROTECT_TYPE_NEW_DIVECE = 1;
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            android.util.Slog.d("HwAntiMalPlugin", "createPlugin");
            return new com.android.server.security.antimal.HwAntiMalPlugin(context);
        }

        public java.lang.String getPluginPermission() {
            return "com.huawei.permission.MANAGE_USE_SECURITY";
        }
    };
    private static final java.lang.String DEFAULT_HW_LAUNCHER = "com.huawei.android.launcher";
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    private static final boolean IS_DOMESTIC_RELEASE = "1".equalsIgnoreCase(android.os.SystemProperties.get("ro.logsystem.usertype", "3"));
    private static final boolean IS_ROOT = "0".equalsIgnoreCase(android.os.SystemProperties.get("ro.secure", "1"));
    private static final boolean IS_TABLET = "tablet".equalsIgnoreCase(android.os.SystemProperties.get("ro.build.characteristics", "default"));
    private static final java.lang.String MANAGE_USE_SECURITY = "com.huawei.permission.MANAGE_USE_SECURITY";
    private static final java.lang.String TAG = "HwAntiMalPlugin";
    private static final boolean mAntimalProtection = "true".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.antimal_protection", "true"));
    private android.content.Context mContext;
    private com.android.server.security.antimal.HwAntiMalStatus mHwAntiMalStatus = null;

    public HwAntiMalPlugin(android.content.Context context) {
        this.mContext = context;
        this.mHwAntiMalStatus = new com.android.server.security.antimal.HwAntiMalStatus(this.mContext);
        this.mHwAntiMalStatus.checkIfTopAppsDisabled();
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public void onStart() {
    }

    public void onStop() {
    }

    public boolean isAntiMalProtectionOn(android.os.Bundle params) {
        if (params == null) {
            android.util.Slog.e("HwAntiMalPlugin", "Invalid input params!");
            return false;
        } else if (!IS_CHINA_AREA) {
            android.util.Slog.d("HwAntiMalPlugin", "Not in valid area!");
            return false;
        } else if (mAntimalProtection) {
            int protect_type = params.getInt("protect_type", 0);
            java.lang.String launcher = params.getString("launcher_name", "");
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("protect_type:");
            stringBuilder.append(protect_type);
            stringBuilder.append(" launcher:");
            stringBuilder.append(launcher);
            android.util.Slog.d("HwAntiMalPlugin", stringBuilder.toString());
            return isAntiMalProtectionOnByType(protect_type, launcher);
        } else {
            android.util.Slog.d("HwAntiMalPlugin", "AntimalProtection control is close!");
            return false;
        }
    }

    private boolean isAntiMalProtectionOnByType(int type, java.lang.String launcher) {
        if (type == 2) {
            if (android.text.TextUtils.isEmpty(launcher)) {
                android.util.Slog.d("HwAntiMalPlugin", "Input is empty!");
                launcher = "com.huawei.android.launcher";
            }
            try {
                return !this.mHwAntiMalStatus.isAllowedSetHomeActivityForAntiMalInternal(this.mContext.getPackageManager().getPackageInfo(launcher, 0), 0, false);
            } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Not found name:");
                stringBuilder.append(launcher);
                android.util.Slog.d("HwAntiMalPlugin", stringBuilder.toString());
                return true;
            }
        } else if (IS_ROOT) {
            android.util.Slog.d("HwAntiMalPlugin", "Device is root !");
            return false;
        } else if (!IS_DOMESTIC_RELEASE) {
            android.util.Slog.d("HwAntiMalPlugin", "Beta version !");
            return false;
        } else if (!IS_TABLET) {
            return this.mHwAntiMalStatus.isNeedRestrictForAntimal(true);
        } else {
            android.util.Slog.d("HwAntiMalPlugin", "Is tablet!");
            return false;
        }
    }
}
