package com.android.server.security.antimal;

public class HwAntiMalStatus {
    private static final int ANTIMAL_TYPE_ALLOWED_BY_PASSWORD = 10;
    private static final int ANTIMAL_TYPE_ALLOWED_BY_SYSTEMAPP = 11;
    private static final int ANTIMAL_TYPE_NOT_ALLOWED_SET_HOME = 20;
    private static final int ANTIMAL_TYPE_RESTORE_DEFAULT_LAUNCHER = 30;
    private static final long CALL_ENOUGH_TIME = 300;
    private static final long CHARGING_ENOUGH_TIME = 20;
    private static final java.lang.String DEFAULT_HW_LAUNCHER = "com.huawei.android.launcher";
    private static final boolean IS_CHINA_AREA = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    private static final java.lang.String[] NOT_ALLOWED_DISABLE_WHITELIST = new java.lang.String[]{"com.huawei.android.launcher", "com.huawei.systemmanager"};
    private static final long SCREENON_ENOUGH_TIME = 36000;
    private static final java.lang.String TAG = "HwAntiMalStatus";
    private static final boolean mAntimalProtection = "true".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.antimal_protection", "true"));
    private static com.android.server.pm.HwCustPackageManagerService mCpms = ((com.android.server.pm.HwCustPackageManagerService) com.huawei.cust.HwCustUtils.createObj(com.android.server.pm.HwCustPackageManagerService.class, new java.lang.Object[0]));
    private java.lang.String DEFAULT_CUST_LAUNCHER = "";
    private android.content.Context mContext;

    public HwAntiMalStatus(android.content.Context ctx) {
        this.mContext = ctx;
    }

    public boolean isAllowedSetHomeActivityForAntiMal(android.content.pm.PackageInfo pkgInfo, int userId) {
        if (isAllowedSetHomeActivityForAntiMalInternal(pkgInfo, userId, true)) {
            return true;
        }
        if (!hasMDMPermission(pkgInfo)) {
            return false;
        }
        android.util.Slog.d("HwAntiMalStatus", "found MDM permission!");
        return true;
    }

    private boolean hasMDMPermission(android.content.pm.PackageInfo pkgInfo) {
        if (pkgInfo == null) {
            android.util.Slog.d("HwAntiMalStatus", "Invalid params.");
            return true;
        }
        int uid = pkgInfo.applicationInfo.uid;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("uid:");
        stringBuilder.append(uid);
        android.util.Slog.i("HwAntiMalStatus", stringBuilder.toString());
        if (android.app.ActivityManager.checkUidPermission("com.huawei.permission.sec.SDK_LAUNCHER", uid) != 0) {
            return false;
        }
        android.util.Slog.i("HwAntiMalStatus", "have launcher permission!");
        return true;
    }

    public boolean isAllowedSetHomeActivityForAntiMalInternal(android.content.pm.PackageInfo pkgInfo, int userId, boolean internal) {
        if (this.mContext != null) {
            if (pkgInfo != null) {
                if (!IS_CHINA_AREA) {
                    android.util.Slog.d("HwAntiMalStatus", "Not in valid area !");
                    return true;
                } else if (!mAntimalProtection) {
                    android.util.Slog.d("HwAntiMalStatus", "AntimalProtection control is close!");
                    return true;
                } else if (isSupportHomeScreen()) {
                    android.util.Slog.d("HwAntiMalStatus", "Support home screen.");
                    return true;
                } else {
                    if (internal) {
                        if ((pkgInfo.applicationInfo.flags & 1) == 1) {
                            android.util.Slog.d("HwAntiMalStatus", "System app.");
                            android.content.Context context = this.mContext;
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("{package:");
                            stringBuilder.append(pkgInfo.packageName);
                            stringBuilder.append(",type:");
                            stringBuilder.append(11);
                            stringBuilder.append("}");
                            android.util.Flog.bdReport(context, 128, stringBuilder.toString());
                            return true;
                        } else if (isCustDefaultLauncher(pkgInfo.packageName)) {
                            android.util.Slog.d("HwAntiMalStatus", "Cust default launcher.");
                            return true;
                        }
                    }
                    android.content.Context context2 = this.mContext;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("{package:");
                    stringBuilder2.append(pkgInfo.packageName);
                    stringBuilder2.append(",type:");
                    stringBuilder2.append(20);
                    stringBuilder2.append("}");
                    android.util.Flog.bdReport(context2, 128, stringBuilder2.toString());
                    android.util.Slog.d("HwAntiMalStatus", "not allowed to set home activity at normal state.");
                    return false;
                }
            }
        }
        android.util.Slog.d("HwAntiMalStatus", "Invalid params.");
        return true;
    }

    public void handleUserClearLockForAntiMal(int userId) {
        if (this.mContext == null) {
            android.util.Slog.d("HwAntiMalStatus", "invalid params.");
        } else if (android.app.ActivityManager.getCurrentUser() != 0) {
            android.util.Slog.d("HwAntiMalStatus", "not owner.");
        } else if (!isNeedRestrictForAntimal(false)) {
            android.util.Slog.d("HwAntiMalStatus", "no need restrict for antimal.");
        } else if (isDefaultHwLauncher()) {
            android.util.Slog.d("HwAntiMalStatus", "current launcher is default launcher.");
        } else {
            checkIfDefaultLauncherIsDisabled();
            android.util.Slog.d("HwAntiMalStatus", "No need to set default launcher.");
        }
    }

    private boolean hasSetPassword() {
        return new com.android.internal.widget.LockPatternUtils(this.mContext).isSecure(android.app.ActivityManager.getCurrentUser());
    }

    public boolean isNeedRestrictForAntimal(boolean needRestrict) {
        if (!needRestrict) {
            return false;
        }
        com.android.server.security.deviceusage.HwDeviceUsageOEMINFO mHwDeviceUsageOEMINFO = com.android.server.security.deviceusage.HwDeviceUsageOEMINFO.getInstance();
        if (mHwDeviceUsageOEMINFO.getScreenOnTime() < 36000 && mHwDeviceUsageOEMINFO.getTalkTime() < 300 && mHwDeviceUsageOEMINFO.getChargeTime() < 20) {
            if (!hasSimCard()) {
                return true;
            }
        }
        android.util.Slog.d("HwAntiMalStatus", "No need to restrict");
        return false;
    }

    private static android.content.Intent getMainIntent() {
        android.content.Intent mainIntent = new android.content.Intent("android.intent.action.MAIN");
        mainIntent.addCategory("android.intent.category.HOME");
        mainIntent.addCategory("android.intent.category.DEFAULT");
        return mainIntent;
    }

    private boolean isDefaultHwLauncher() {
        android.content.pm.ResolveInfo res = this.mContext.getPackageManager().resolveActivity(getMainIntent(), 0);
        if (!(res == null || res.activityInfo == null)) {
            if (!android.text.TextUtils.isEmpty(res.activityInfo.packageName)) {
                if (!res.activityInfo.packageName.equals("com.huawei.android.launcher")) {
                    if (android.text.TextUtils.isEmpty(getCustDefaultLauncher()) || !res.activityInfo.packageName.equals(getCustDefaultLauncher())) {
                        return false;
                    }
                }
                return true;
            }
        }
        android.util.Slog.e("HwAntiMalStatus", "isDefaultHwLauncher param is null.");
        return false;
    }

    private boolean isCustDefaultLauncher(java.lang.String pkgName) {
        if (android.text.TextUtils.equals(pkgName, getCustDefaultLauncher())) {
            return true;
        }
        return false;
    }

    public void checkIfTopAppsDisabled() {
        for (java.lang.String checkIfDisabled : NOT_ALLOWED_DISABLE_WHITELIST) {
            checkIfDisabled(checkIfDisabled);
        }
        if (!android.text.TextUtils.isEmpty(getCustDefaultLauncher())) {
            checkIfDisabled(getCustDefaultLauncher());
        }
    }

    private void checkIfDefaultLauncherIsDisabled() {
        android.content.pm.PackageManager packageManager = this.mContext.getPackageManager();
        int currState = packageManager.getApplicationEnabledSetting("com.huawei.android.launcher");
        if (currState == 2 || currState == 3 || currState == 4) {
            android.util.Slog.i("HwAntiMalStatus", "Huawei Launcher is Disabled! enable it!");
            packageManager.setApplicationEnabledSetting("com.huawei.android.launcher", 1, 1);
        }
        if (!android.text.TextUtils.isEmpty(getCustDefaultLauncher())) {
            currState = packageManager.getApplicationEnabledSetting(getCustDefaultLauncher());
            if (currState == 2 || currState == 3 || currState == 4) {
                android.util.Slog.i("HwAntiMalStatus", "Cust Launcher is Disabled! enable it!");
                packageManager.setApplicationEnabledSetting(getCustDefaultLauncher(), 1, 1);
            }
        }
    }

    private void checkIfDisabled(java.lang.String pkgName) {
        android.content.pm.PackageManager packageManager = this.mContext.getPackageManager();
        java.lang.StringBuilder stringBuilder;
        try {
            int currState = packageManager.getApplicationEnabledSetting(pkgName);
            if (currState == 2 || currState == 3 || currState == 4) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(pkgName);
                stringBuilder.append(" is Disabled! enable it!");
                android.util.Slog.i("HwAntiMalStatus", stringBuilder.toString());
                packageManager.setApplicationEnabledSetting(pkgName, 1, 1);
            }
        } catch (java.lang.Exception e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getApplicationEnabledSetting fail:");
            stringBuilder.append(e.getMessage());
            android.util.Slog.d("HwAntiMalStatus", stringBuilder.toString());
        }
    }

    private void setDefaultLauncher() {
        int i = 0;
        java.util.List<android.content.pm.ResolveInfo> resolveInfos = this.mContext.getPackageManager().queryIntentActivities(getMainIntent(), 0);
        if (resolveInfos != null) {
            int i2;
            int infoSize = resolveInfos.size();
            for (i2 = 0; i2 < infoSize; i2++) {
                android.content.pm.ResolveInfo resolveInfo = (android.content.pm.ResolveInfo) resolveInfos.get(i2);
                if (resolveInfo != null) {
                    this.mContext.getPackageManager().clearPackagePreferredActivities(resolveInfo.activityInfo.packageName);
                }
            }
            i2 = -1;
            android.content.ComponentName[] set = new android.content.ComponentName[infoSize];
            while (i < infoSize) {
                android.content.pm.ResolveInfo info = (android.content.pm.ResolveInfo) resolveInfos.get(i);
                set[i] = new android.content.ComponentName(info.activityInfo.packageName, info.activityInfo.name);
                if (!info.activityInfo.packageName.equals("com.huawei.android.launcher")) {
                    if (android.text.TextUtils.isEmpty(getCustDefaultLauncher()) || !info.activityInfo.packageName.equals(getCustDefaultLauncher())) {
                        i++;
                    }
                }
                i2 = i;
                break;
            }
            if (i2 != -1) {
                android.content.IntentFilter inf = new android.content.IntentFilter("android.intent.action.MAIN");
                inf.addCategory("android.intent.category.HOME");
                inf.addCategory("android.intent.category.DEFAULT");
                this.mContext.getPackageManager().addPreferredActivity(inf, 1048576, set, set[i2]);
            }
        }
    }

    private java.lang.String getCustDefaultLauncher() {
        if (android.text.TextUtils.isEmpty(this.DEFAULT_CUST_LAUNCHER)) {
            this.DEFAULT_CUST_LAUNCHER = mCpms.getCustDefaultLauncher(this.mContext, this.DEFAULT_CUST_LAUNCHER);
        }
        return this.DEFAULT_CUST_LAUNCHER;
    }

    public boolean isSupportHomeScreen() {
        return this.mContext.getPackageManager().hasSystemFeature("android.software.home_screen");
    }

    private boolean hasSimCard() {
        int simState = ((android.telephony.TelephonyManager) this.mContext.getSystemService("phone")).getSimState();
        if (simState != 1) {
            if (simState != 0) {
                return true;
            }
        }
        android.util.Slog.i("HwAntiMalStatus", "no SIM card!");
        return false;
    }
}
