package com.android.server.security.deviceusage;

public class ActivationMonitor {
    private static final int MSG_START_MONITOR = 10;
    public static final long SIX_HOURS_MS = 21600000;
    private static final long START_DELAY = 60000;
    private static final java.lang.String TAG = "ActivationMonitor";
    private long ACTIVATION_DURATION_MS = 21600000;
    private boolean hasSimCard = false;
    private android.app.AlarmManager.OnAlarmListener mAlarmListener = new android.app.AlarmManager.OnAlarmListener() {
        public void onAlarm() {
            android.util.Slog.i("ActivationMonitor", "Report Activation");
            com.android.server.security.deviceusage.ActivationMonitor.ActivationRecorder.record();
            com.android.server.security.deviceusage.ActivationMonitor.ActivationRecorder.report(com.android.server.security.deviceusage.ActivationMonitor.this.mContext);
            com.android.server.security.deviceusage.ActivationMonitor.this.mContext.unregisterReceiver(com.android.server.security.deviceusage.ActivationMonitor.this.mSimReceiver);
            com.android.server.security.deviceusage.ActivationMonitor.this.mHandler.removeMessages(10);
        }
    };
    private android.content.Context mContext;
    private android.os.Handler mHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message msg) {
            if (10 == msg.what) {
                android.util.Slog.i("ActivationMonitor", "start monitor");
                com.android.server.security.deviceusage.ActivationMonitor.this.mContext.registerReceiver(com.android.server.security.deviceusage.ActivationMonitor.this.mSimReceiver, new android.content.IntentFilter("android.intent.action.SIM_STATE_CHANGED"));
                com.android.server.security.deviceusage.ActivationMonitor.this.countDownIfHasSim();
                removeMessages(10);
            }
        }
    };
    private com.android.server.security.deviceusage.ActivationMonitor.SimReceiver mSimReceiver = new com.android.server.security.deviceusage.ActivationMonitor.SimReceiver(this, null);

    private static class ActivationRecorder {
        private static final java.lang.String ACTION_WARRANTY_DETECTED = "com.huawei.action.ACTION_ACTIVATION_DETECTED";
        private static final java.lang.String RECEIVER_CLASS_NAME = "com.huawei.android.hwouc.biz.impl.reveiver.DeviceActivatedReceiver";
        private static final java.lang.String RECEIVER_PACKAGE_NAME = "com.huawei.android.hwouc";
        private static final java.lang.String RECEIVE_WARRANTY_REPORT = "com.huawei.permission.RECEIVE_ACTIVATION_REPORT";

        private ActivationRecorder() {
        }

        static void record() {
            com.android.server.security.deviceusage.HwOEMInfoUtil.setActivated();
        }

        static boolean isActivated() {
            return com.android.server.security.deviceusage.HwOEMInfoUtil.getActivationStatus();
        }

        static void report(android.content.Context context) {
            android.content.Intent intent = new android.content.Intent("com.huawei.action.ACTION_ACTIVATION_DETECTED");
            intent.setClassName("com.huawei.android.hwouc", "com.huawei.android.hwouc.biz.impl.reveiver.DeviceActivatedReceiver");
            context.sendBroadcast(intent, "com.huawei.permission.RECEIVE_ACTIVATION_REPORT");
        }
    }

    private class SimReceiver extends android.content.BroadcastReceiver {
        static final java.lang.String ACTION_SIM_STATE_CHANGED = "android.intent.action.SIM_STATE_CHANGED";

        private SimReceiver() {
        }

        /* synthetic */ SimReceiver(com.android.server.security.deviceusage.ActivationMonitor x0, com.android.server.security.deviceusage.ActivationMonitor.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if (intent.getAction() != null) {
                    if (intent.getAction().equals("android.intent.action.SIM_STATE_CHANGED")) {
                        com.android.server.security.deviceusage.ActivationMonitor.this.countDownIfHasSim();
                    }
                    return;
                }
            }
            android.util.Slog.w("ActivationMonitor", "Intent or Action is null");
        }
    }

    public ActivationMonitor(android.content.Context context) {
        this.mContext = context;
    }

    public void start() {
        if (com.android.server.security.deviceusage.ActivationMonitor.ActivationRecorder.isActivated()) {
            android.util.Slog.i("ActivationMonitor", "Device already activated");
        } else {
            this.mHandler.sendEmptyMessageDelayed(10, 60000);
        }
    }

    public void reStart(long duration) {
        if (duration <= 21600000) {
            if (duration >= 0) {
                this.ACTIVATION_DURATION_MS = duration;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("reStart : ");
                stringBuilder.append(this.ACTIVATION_DURATION_MS);
                android.util.Slog.i("ActivationMonitor", stringBuilder.toString());
                this.mHandler.sendEmptyMessage(10);
            }
        }
    }

    public boolean isActivated() {
        return com.android.server.security.deviceusage.ActivationMonitor.ActivationRecorder.isActivated();
    }

    public void resetActivation() {
        com.android.server.security.deviceusage.HwOEMInfoUtil.resetActivation();
    }

    private void countDownIfHasSim() {
        android.telephony.TelephonyManager tm = (android.telephony.TelephonyManager) this.mContext.getSystemService("phone");
        if (tm == null) {
            android.util.Slog.e("ActivationMonitor", "SIM state cannot be detected");
            return;
        }
        android.app.AlarmManager am = (android.app.AlarmManager) this.mContext.getSystemService("alarm");
        if (1 == tm.getSimState()) {
            am.cancel(this.mAlarmListener);
            this.hasSimCard = false;
        } else if (!this.hasSimCard) {
            android.app.AlarmManager alarmManager = am;
            alarmManager.set(2, this.ACTIVATION_DURATION_MS + android.os.SystemClock.elapsedRealtime(), "ACTIVATION_COUNTING", this.mAlarmListener, this.mHandler);
            this.hasSimCard = true;
        }
    }
}
