package com.android.server.security.deviceusage;

public class HwDeviceUsagePlugin extends huawei.android.security.IHwDeviceUsagePlugin.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    public static final boolean CHINA_RELEASE_VERSION = "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            if (com.android.server.security.deviceusage.HwDeviceUsagePlugin.HW_DEBUG) {
                android.util.Slog.d("HwDeviceUsagePlugin", "createPlugin");
            }
            return new com.android.server.security.deviceusage.HwDeviceUsagePlugin(context);
        }

        public java.lang.String getPluginPermission() {
            return "com.huawei.permission.MANAGE_USE_SECURITY";
        }
    };
    private static final boolean HW_DEBUG;
    public static final boolean IS_PHONE = android.os.SystemProperties.get("ro.build.characteristics").equals("default");
    private static final java.lang.String MANAGE_USE_SECURITY = "com.huawei.permission.MANAGE_USE_SECURITY";
    private static final java.lang.String TAG = "HwDeviceUsagePlugin";
    private android.content.Context mContext;
    private com.android.server.security.deviceusage.HwDeviceUsageCollection mHwDeviceUsageCollection;
    private com.android.server.security.deviceusage.ActivationMonitor mMonitor = new com.android.server.security.deviceusage.ActivationMonitor(this.mContext);

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("HwDeviceUsagePlugin", 4)) {
                z = false;
                HW_DEBUG = z;
            }
        }
        z = true;
        HW_DEBUG = z;
    }

    public HwDeviceUsagePlugin(android.content.Context context) {
        this.mContext = context;
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public void onStart() {
        if (HW_DEBUG) {
            android.util.Slog.d("HwDeviceUsagePlugin", "HwDeviceUsagePlugin is Start");
        }
        this.mMonitor.start();
        this.mHwDeviceUsageCollection = new com.android.server.security.deviceusage.HwDeviceUsageCollection(this.mContext);
        if (CHINA_RELEASE_VERSION && IS_PHONE) {
            if (this.mHwDeviceUsageCollection.getOpenFlag()) {
                this.mHwDeviceUsageCollection.onStart();
            }
        }
    }

    public void onStop() {
    }

    public long getScreenOnTime() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection == null) {
            return -1;
        }
        return this.mHwDeviceUsageCollection.getScreenOnTime();
    }

    public long getChargeTime() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection == null) {
            return -1;
        }
        return this.mHwDeviceUsageCollection.getChargeTime();
    }

    public long getTalkTime() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection == null) {
            return -1;
        }
        return this.mHwDeviceUsageCollection.getTalkTime();
    }

    public long getFristUseTime() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection == null) {
            return -1;
        }
        return this.mHwDeviceUsageCollection.getFristUseTime();
    }

    public void setOpenFlag(int flag) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection != null) {
            this.mHwDeviceUsageCollection.setOpenFlag(flag);
        }
    }

    public void setScreenOnTime(long time) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection != null) {
            this.mHwDeviceUsageCollection.setScreenOnTime(time);
        }
    }

    public void setChargeTime(long time) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection != null) {
            this.mHwDeviceUsageCollection.setChargeTime(time);
        }
    }

    public void setTalkTime(long time) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection != null) {
            this.mHwDeviceUsageCollection.setTalkTime(time);
        }
    }

    public void setFristUseTime(long time) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mHwDeviceUsageCollection != null) {
            this.mHwDeviceUsageCollection.setFristUseTime(time);
        }
    }

    private void checkPermission(java.lang.String permission) {
        android.content.Context context = this.mContext;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Must have ");
        stringBuilder.append(permission);
        stringBuilder.append(" permission.");
        context.enforceCallingOrSelfPermission(permission, stringBuilder.toString());
    }

    public boolean isDeviceActivated() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        if (this.mMonitor.isActivated()) {
            return true;
        }
        this.mMonitor.reStart(21600000);
        return false;
    }

    public void resetActivation() {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        this.mMonitor.resetActivation();
    }

    public void detectActivationWithDuration(long duration) {
        checkPermission("com.huawei.permission.MANAGE_USE_SECURITY");
        this.mMonitor.reStart(duration);
    }
}
