package com.android.server.security.fileprotect;

public class HwSfpService extends huawei.android.security.IHwSfpService.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    private static final java.lang.String ACTION_LOCK_SCREEN = "lockScreen";
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            return new com.android.server.security.fileprotect.HwSfpService(context);
        }

        public java.lang.String getPluginPermission() {
            return null;
        }
    };
    private static final java.lang.String INTENT_SLIDE_UNLOCK = "slideUnlock";
    private static final java.lang.String INTENT_SMART_UNLOCK = "smartUnlock";
    private static final java.lang.String INTENT_USER_ID = "userId";
    private static final int INVALID_PRELOAD_STATUS = -1;
    private static final java.lang.String LOCK_PERMISSION = "com.isec.lockScreenBroadcast";
    private static final java.lang.String POLICY_CONFIG_FILE = "sfpconfig.json";
    private static final int PRELOAD_STATUS = 1;
    private static final java.lang.String TAG = "HwSfpService";
    private static final java.lang.String[] multipleUserPath = new java.lang.String[]{"/data/user/0/", "/storage/emulated/0/"};
    private android.content.Context mContext;
    private android.os.IInstalld mInstalld;
    private java.util.List<com.android.server.security.fileprotect.PackStoragePolicy> mPackagePolicies = new java.util.ArrayList();
    private android.os.storage.IStorageManager mStorageManager;

    class LockScreenReceiver extends android.content.BroadcastReceiver {
        LockScreenReceiver() {
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if ("lockScreen".equals(intent.getAction())) {
                boolean smartUnlock = intent.getBooleanExtra("smartUnlock", false);
                boolean slideUnlock = intent.getBooleanExtra("slideUnlock", false);
                if (!smartUnlock) {
                    if (!slideUnlock) {
                        int userId = intent.getIntExtra("userId", -1);
                        if (userId == -1) {
                            android.util.Slog.d("HwSfpService", "skip the broadcast: userId=null");
                            return;
                        }
                        android.content.pm.UserInfo userInfo = com.android.server.security.fileprotect.HwSfpService.this.getUserInfo(userId);
                        if (userInfo != null) {
                            new com.android.server.security.fileprotect.HwSfpService.PolicyTask(userId, userInfo.serialNumber).start();
                        } else {
                            return;
                        }
                    }
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("skip the broadcast: smartUnlock=");
                stringBuilder.append(smartUnlock);
                stringBuilder.append(" and slideUnlock=");
                stringBuilder.append(slideUnlock);
                android.util.Slog.d("HwSfpService", stringBuilder.toString());
            }
        }
    }

    private class PolicyTask extends java.lang.Thread {
        private int serialNumber;
        private int userId;

        public PolicyTask(int userId, int serialNumber) {
            this.userId = userId;
            this.serialNumber = serialNumber;
        }

        public void run() {
            com.android.server.security.fileprotect.HwSfpService.this.execPolicies(this.userId, this.serialNumber);
            com.android.server.security.fileprotect.HwSfpService.this.deleteKey(this.userId, this.serialNumber);
        }
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public HwSfpService(android.content.Context context) {
        this.mContext = context;
    }

    public void onStart() {
        android.util.Slog.d("HwSfpService", "onStart");
        this.mPackagePolicies = com.android.server.security.fileprotect.PackStoragePolicy.parse(this.mContext, "sfpconfig.json");
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("policy size: ");
        stringBuilder.append(this.mPackagePolicies.size());
        android.util.Slog.d("HwSfpService", stringBuilder.toString());
        android.content.IntentFilter filter = new android.content.IntentFilter();
        filter.addAction("lockScreen");
        this.mContext.registerReceiverAsUser(new com.android.server.security.fileprotect.HwSfpService.LockScreenReceiver(), android.os.UserHandle.ALL, filter, "com.isec.lockScreenBroadcast", null);
    }

    public void onStop() {
    }

    public java.lang.String getKeyDesc(int userId, int storageType) {
        java.lang.String result = null;
        long token = android.os.Binder.clearCallingIdentity();
        try {
            android.content.pm.UserInfo userInfo = getUserInfo(userId);
            if (userInfo != null) {
                result = getKeyDesc(userId, userInfo.serialNumber, storageType);
            }
            android.os.Binder.restoreCallingIdentity(token);
            return result;
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(token);
        }
    }

    public java.util.List<java.lang.String> getSensitiveDataPolicyList() {
        java.util.List<java.lang.String> result = new java.util.ArrayList();
        for (com.android.server.security.fileprotect.PackStoragePolicy packPolicy : this.mPackagePolicies) {
            result.add(packPolicy.packageName);
        }
        return result;
    }

    private android.content.pm.UserInfo getUserInfo(int userId) {
        android.os.UserManager userManager = (android.os.UserManager) this.mContext.getSystemService("user");
        if (userManager == null) {
            android.util.Slog.e("HwSfpService", "UserManager is not found");
            return null;
        }
        android.content.pm.UserInfo userInfo = userManager.getUserInfo(userId);
        if (userInfo == null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("cannot get the UserInfo: userId=");
            stringBuilder.append(userId);
            android.util.Slog.e("HwSfpService", stringBuilder.toString());
        }
        return userInfo;
    }

    private void deleteKey(int userId, int serialNumber) {
        try {
            getStorageManager().lockUserScreenISec(userId, serialNumber);
        } catch (android.os.RemoteException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("fialed to delete key: ");
            stringBuilder.append(e.getMessage());
            android.util.Slog.e("HwSfpService", stringBuilder.toString());
        }
    }

    private synchronized android.os.storage.IStorageManager getStorageManager() {
        if (this.mStorageManager == null) {
            try {
                this.mStorageManager = android.os.storage.IStorageManager.Stub.asInterface(android.os.ServiceManager.getService("mount"));
            } catch (java.lang.Exception e) {
                android.util.Slog.v("HwSfpService", e.getMessage());
            }
        }
        return this.mStorageManager;
    }

    private synchronized android.os.IInstalld getInstalld() {
        if (this.mInstalld == null) {
            this.mInstalld = android.os.IInstalld.Stub.asInterface(android.os.ServiceManager.getService("installd"));
        }
        return this.mInstalld;
    }

    private java.lang.String convertPathToUser(java.lang.String path, int userId) {
        for (java.lang.String subPath : multipleUserPath) {
            if (path.startsWith(subPath)) {
                return path.replaceFirst("0", java.lang.String.valueOf(userId));
            }
        }
        return null;
    }

    public void execPolicies(int userId, int serialNumber) {
        int i = userId;
        int i2 = serialNumber;
        java.util.HashMap keyDescMap = new java.util.HashMap();
        java.lang.String eceKeyDesc = getKeyDesc(i, i2, 2);
        java.lang.String seceKeyDesc = getKeyDesc(i, i2, 3);
        if (eceKeyDesc != null) {
            if (seceKeyDesc != null) {
                keyDescMap.put(java.lang.Integer.valueOf(2), eceKeyDesc);
                keyDescMap.put(java.lang.Integer.valueOf(3), seceKeyDesc);
                android.os.storage.IStorageManager storageManager = getStorageManager();
                if (storageManager != null) {
                    for (com.android.server.security.fileprotect.PackStoragePolicy packagePolicy : this.mPackagePolicies) {
                        int i3 = -1;
                        int preloadStatus = -1;
                        try {
                            if (storageManager.getPreLoadPolicyFlag(i, i2) == 1) {
                                if (isInstalledApp(packagePolicy.packageName, i)) {
                                    for (com.android.server.security.fileprotect.PathPolicy pathPolicy : packagePolicy.policies) {
                                        if (pathPolicy.encryptionType != i3) {
                                            java.lang.String path = convertPathToUser(pathPolicy.path, i);
                                            if (path != null) {
                                                setFileXattr(path, (java.lang.String) keyDescMap.get(java.lang.Integer.valueOf(pathPolicy.encryptionType)), pathPolicy.encryptionType, pathPolicy.fileType);
                                                i3 = -1;
                                            }
                                        }
                                    }
                                } else {
                                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                    stringBuilder.append("package is not found: ");
                                    stringBuilder.append(packagePolicy.packageName);
                                    android.util.Slog.d("HwSfpService", stringBuilder.toString());
                                }
                            } else {
                                return;
                            }
                        } catch (android.os.RemoteException e) {
                            android.os.RemoteException remoteException = e;
                            android.util.Slog.e("HwSfpService", e.getMessage());
                            return;
                        }
                    }
                    return;
                }
                return;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("cannot get the eceKeyDesc or seceKeyDesc: userId=");
        stringBuilder2.append(i);
        android.util.Slog.d("HwSfpService", stringBuilder2.toString());
    }

    private boolean isInstalledApp(java.lang.String packageName, int userId) {
        try {
            this.mContext.getPackageManager().getApplicationInfoAsUser(packageName, 0, userId);
            return true;
        } catch (android.content.pm.PackageManager.NameNotFoundException e) {
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001f A:{ExcHandler: android.os.RemoteException (r2_2 'e' java.lang.Exception), Splitter: B:4:0x000f} */
    /* JADX WARNING: Missing block: B:11:0x001f, code:
            r2 = move-exception;
     */
    /* JADX WARNING: Missing block: B:12:0x0020, code:
            r4 = new java.lang.StringBuilder();
            r4.append("Failed to getKeyDesc: ");
            r4.append(r2.getMessage());
            android.util.Slog.e("HwSfpService", r4.toString());
     */
    /* JADX WARNING: Missing block: B:13:0x003a, code:
            return null;
     */
    private java.lang.String getKeyDesc(int r7, int r8, int r9) {
        /*
        r6 = this;
        r0 = r6.getStorageManager();
        r1 = 0;
        if (r0 != 0) goto L_0x000f;
    L_0x0007:
        r2 = "HwSfpService";
        r3 = "StorageManager is not found";
        android.util.Slog.e(r2, r3);
        return r1;
    L_0x000f:
        r2 = r0.getKeyDesc(r7, r8, r9);	 Catch:{ RemoteException -> 0x001f, RemoteException -> 0x001f }
        if (r2 == 0) goto L_0x001e;
    L_0x0015:
        r3 = "V1[keydesc_ERR:";
        r3 = r2.startsWith(r3);	 Catch:{ RemoteException -> 0x001f, RemoteException -> 0x001f }
        if (r3 == 0) goto L_0x001e;
    L_0x001d:
        return r1;
    L_0x001e:
        return r2;
    L_0x001f:
        r2 = move-exception;
        r3 = "HwSfpService";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "Failed to getKeyDesc: ";
        r4.append(r5);
        r5 = r2.getMessage();
        r4.append(r5);
        r4 = r4.toString();
        android.util.Slog.e(r3, r4);
        return r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.fileprotect.HwSfpService.getKeyDesc(int, int, int):java.lang.String");
    }

    private void setFileXattr(java.lang.String path, java.lang.String keyDesc, int storageType, int fileType) {
        java.lang.String errorMsg;
        java.lang.StringBuilder stringBuilder;
        android.os.IInstalld installd = getInstalld();
        if (installd == null) {
            android.util.Slog.e("HwSfpService", "IInstalld is not found");
            return;
        }
        try {
            installd.setFileXattr(path, keyDesc, storageType, fileType);
        } catch (android.os.RemoteException e) {
            errorMsg = e.getMessage();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException");
            stringBuilder.append(errorMsg);
            android.util.Slog.e("HwSfpService", stringBuilder.toString());
        } catch (java.lang.Exception e2) {
            errorMsg = e2.getMessage();
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Exception");
            stringBuilder.append(errorMsg);
            android.util.Slog.e("HwSfpService", stringBuilder.toString());
        }
    }
}
