package com.android.server.security.hsm;

public class HwAddViewManager {
    private static final int ACTIVITY_BG_DENIED = 4;
    private static final int ACTIVITY_lS_DENIED = 8;
    private static final int HANDLER_ADD = 0;
    private static final int HANDLER_DELETE = 1;
    private static final int HANDLER_UNKNOW = -1;
    private static final int OPERATION_ADD = 0;
    private static final int OPERATION_DELETE = 1;
    private static final int OPS_ACTIVITY_BG_DENIED = 5;
    private static final int OPS_ACTIVITY_LS_DENIED = 9;
    private static final int OPS_ALLOW = 0;
    private static final int OPS_DENIED_ORG = 1;
    private static final int OPS_TOAST_DENIED = 3;
    private static final java.lang.String PACKAGENAME = "packagename";
    private static final int PER_USER_RANGE = 100000;
    private static final int RET_DIRTY_DATA = 2;
    private static final int RET_FAIL = 1;
    private static final int RET_SUCCESS = 0;
    private static final java.lang.String TAG = "HwAddViewManager";
    private static final int TOAST_DENIED = 2;
    private static final java.lang.String USERID = "userid";
    private static final java.lang.String VALUE = "value";
    private static volatile com.android.server.security.hsm.HwAddViewManager sInstance;
    private static final java.lang.Object serviceLock = new java.lang.Object();
    private java.util.Map<java.lang.Integer, java.util.Map<java.lang.String, java.lang.Integer>> addviewMapWithUser = new java.util.HashMap();
    private android.content.Context mContext;
    private android.os.Handler mHandler = null;
    private android.os.HandlerThread mHandlerThread = new android.os.HandlerThread("HwAddViewManagerHandleThread");

    private class InnerHandler extends android.os.Handler {
        public InnerHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("handleMessage msg=");
            stringBuilder.append(msg.what);
            android.util.Slog.d("HwAddViewManager", stringBuilder.toString());
            super.handleMessage(msg);
            switch (msg.what) {
                case 0:
                    com.android.server.security.hsm.HwAddViewManager.this.addListInfo(msg.getData());
                    return;
                case 1:
                    com.android.server.security.hsm.HwAddViewManager.this.deleteListInfo(msg.getData());
                    return;
                default:
                    return;
            }
        }
    }

    private HwAddViewManager(android.content.Context context) {
        this.mContext = context;
        this.mHandlerThread.start();
        this.mHandler = new com.android.server.security.hsm.HwAddViewManager.InnerHandler(this.mHandlerThread.getLooper());
    }

    public static com.android.server.security.hsm.HwAddViewManager getInstance(android.content.Context context) {
        com.android.server.security.hsm.HwAddViewManager hwAddViewManager;
        synchronized (serviceLock) {
            if (sInstance == null) {
                sInstance = new com.android.server.security.hsm.HwAddViewManager(context);
            }
            hwAddViewManager = sInstance;
        }
        return hwAddViewManager;
    }

    public int updateAddViewData(android.os.Bundle data, int operation) {
        android.os.Message msg = this.mHandler.obtainMessage();
        switch (operation) {
            case 0:
                msg.what = 0;
                break;
            case 1:
                msg.what = 1;
                break;
            default:
                return 1;
        }
        msg.setData(data);
        this.mHandler.sendMessage(msg);
        return 0;
    }

    public boolean addViewPermissionCheck(java.lang.String packageName, int type, int uid) {
        if (packageName == null) {
            android.util.Slog.e("HwAddViewManager", "param error");
            return false;
        } else if (uid == 0) {
            android.util.Slog.i("HwAddViewManager", "param uid info error, true default");
            return true;
        } else {
            synchronized (serviceLock) {
                int userid = uid / 100000;
                if (this.addviewMapWithUser.size() != 0) {
                    if (this.addviewMapWithUser.get(java.lang.Integer.valueOf(userid)) != null) {
                        if (((android.app.AppOpsManager) this.mContext.getSystemService("appops")).checkOpNoThrow("android:system_alert_window", uid, packageName) == 0) {
                            android.util.Slog.d("HwAddViewManager", "permission allow");
                            return true;
                        }
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("addViewPermissionCheck: ");
                        stringBuilder.append(packageName);
                        stringBuilder.append(" type: ");
                        stringBuilder.append(type);
                        android.util.Slog.d("HwAddViewManager", stringBuilder.toString());
                        java.util.Map<java.lang.String, java.lang.Integer> currentUserPermissionMap = (java.util.Map) this.addviewMapWithUser.get(java.lang.Integer.valueOf(userid));
                        if (currentUserPermissionMap == null || !currentUserPermissionMap.containsKey(packageName)) {
                            android.util.Slog.d("HwAddViewManager", "not in blacklist, return default result-success");
                            return true;
                        }
                        boolean permissionResult = getPermissionResult(type, ((java.lang.Integer) currentUserPermissionMap.get(packageName)).intValue());
                        return permissionResult;
                    }
                }
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("list not ready, return allow, uid:");
                stringBuilder2.append(uid);
                android.util.Slog.i("HwAddViewManager", stringBuilder2.toString());
                return true;
            }
        }
    }

    private boolean getPermissionResult(int compareValue, int sourceValue) {
        if (!(sourceValue == 0 || sourceValue == 1)) {
            if ((compareValue & sourceValue) != 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("permission: ");
                stringBuilder.append(compareValue);
                stringBuilder.append(" denied");
                android.util.Slog.d("HwAddViewManager", stringBuilder.toString());
                return false;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("permission: ");
        stringBuilder2.append(compareValue);
        stringBuilder2.append(" allow");
        android.util.Slog.d("HwAddViewManager", stringBuilder2.toString());
        return true;
    }

    private void addListInfo(android.os.Bundle data) {
        if (data == null) {
            android.util.Slog.e("HwAddViewManager", "error of null bundle");
            return;
        }
        int userid = data.getInt("userid", -1);
        java.util.Map<java.lang.String, java.lang.Integer> blackListMap = arrayConvertMap(data.getStringArrayList("packagename"), data.getIntegerArrayList("value"));
        if (!(blackListMap == null || userid == -1)) {
            synchronized (serviceLock) {
                java.util.Map<java.lang.String, java.lang.Integer> currentUserPermissionMap = (java.util.Map) this.addviewMapWithUser.get(java.lang.Integer.valueOf(userid));
                if (currentUserPermissionMap != null) {
                    currentUserPermissionMap.putAll(blackListMap);
                } else {
                    currentUserPermissionMap = blackListMap;
                }
                this.addviewMapWithUser.put(java.lang.Integer.valueOf(userid), currentUserPermissionMap);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("update data ok, user=");
                stringBuilder.append(userid);
                android.util.Slog.i("HwAddViewManager", stringBuilder.toString());
            }
        }
    }

    private void deleteListInfo(android.os.Bundle data) {
        if (data != null) {
            int userid = data.getInt("userid", -1);
            java.util.ArrayList<java.lang.String> PackageNameList = data.getStringArrayList("packagename");
            if (PackageNameList != null) {
                if (userid != -1) {
                    int packagenameSize = PackageNameList.size();
                    synchronized (serviceLock) {
                        java.util.Map<java.lang.String, java.lang.Integer> currentUserPermissionMap = (java.util.Map) this.addviewMapWithUser.get(java.lang.Integer.valueOf(userid));
                        if (currentUserPermissionMap != null) {
                            for (int i = 0; i < packagenameSize; i++) {
                                currentUserPermissionMap.remove(PackageNameList.get(i));
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("index:");
                                stringBuilder.append(i);
                                stringBuilder.append(" remove package:");
                                stringBuilder.append((java.lang.String) PackageNameList.get(i));
                                android.util.Slog.d("HwAddViewManager", stringBuilder.toString());
                            }
                            this.addviewMapWithUser.put(java.lang.Integer.valueOf(userid), currentUserPermissionMap);
                        }
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("remove done, size ");
                        stringBuilder2.append(packagenameSize);
                        android.util.Slog.i("HwAddViewManager", stringBuilder2.toString());
                    }
                }
            }
        }
    }

    private java.util.Map<java.lang.String, java.lang.Integer> arrayConvertMap(java.util.ArrayList<java.lang.String> packageNameList, java.util.ArrayList<java.lang.Integer> valueList) {
        if (packageNameList != null) {
            if (valueList != null) {
                int packagenameSize = packageNameList.size();
                if (packagenameSize != valueList.size()) {
                    android.util.Slog.e("HwAddViewManager", "dirty list");
                    return null;
                }
                java.util.Map<java.lang.String, java.lang.Integer> listMap = new java.util.HashMap();
                for (int i = 0; i < packagenameSize; i++) {
                    listMap.put((java.lang.String) packageNameList.get(i), (java.lang.Integer) valueList.get(i));
                }
                android.util.Slog.d("HwAddViewManager", "comvert array over");
                return listMap;
            }
        }
        android.util.Slog.e("HwAddViewManager", "null list or map");
        return null;
    }
}
