package com.android.server.security.hwkeychain;

public final class DecisionUtil {
    private static final java.lang.String CATEGORY_KEY = "category";
    private static final java.lang.String DECISION_ACTION = "com.huawei.securitymgr.intent.action.KeychainAutoFillEvent";
    private static final java.lang.String ID_KEY = "id";
    private static final java.lang.String TAG = com.android.server.security.hwkeychain.DecisionUtil.class.getSimpleName();
    private static java.util.concurrent.ConcurrentHashMap<java.lang.String, com.android.server.security.hwkeychain.DecisionCallback> mCallbackList = new java.util.concurrent.ConcurrentHashMap();
    private static com.huawei.common.service.IDecision mDecisionApi = null;
    private static android.content.ServiceConnection mDecisionConnection = new android.content.ServiceConnection() {
        public void onServiceConnected(android.content.ComponentName name, android.os.IBinder service) {
            android.util.Log.d(com.android.server.security.hwkeychain.DecisionUtil.TAG, "service connected.");
            com.android.server.security.hwkeychain.DecisionUtil.mDecisionApi = com.huawei.common.service.IDecision.Stub.asInterface(service);
            if (com.android.server.security.hwkeychain.DecisionUtil.sExtras != null) {
                android.util.Log.d(com.android.server.security.hwkeychain.DecisionUtil.TAG, "execute again.");
                if (com.android.server.security.hwkeychain.DecisionUtil.executeEvent("com.huawei.securitymgr.intent.action.KeychainAutoFillEvent", com.android.server.security.hwkeychain.DecisionUtil.sExtras)) {
                    android.util.Log.d(com.android.server.security.hwkeychain.DecisionUtil.TAG, "unbind service.");
                    com.android.server.security.hwkeychain.DecisionUtil.unbindService(android.app.ActivityThread.currentActivityThread().getSystemUiContext());
                }
            }
        }

        public void onServiceDisconnected(android.content.ComponentName name) {
            com.android.server.security.hwkeychain.DecisionUtil.mDecisionApi = null;
            android.util.Log.i(com.android.server.security.hwkeychain.DecisionUtil.TAG, "service disconnect.");
        }
    };
    private static android.os.Handler mHander = null;
    private static java.util.Map<java.lang.String, java.lang.Object> sExtras;

    private static class DecisionAyncTask extends android.os.AsyncTask<java.lang.Void, java.lang.Void, java.lang.Void> {
        private DecisionAyncTask() {
        }

        /* synthetic */ DecisionAyncTask(com.android.server.security.hwkeychain.DecisionUtil.AnonymousClass1 x0) {
            this();
        }

        protected java.lang.Void doInBackground(java.lang.Void... voids) {
            com.android.server.security.hwkeychain.DecisionUtil.bindService(android.app.ActivityThread.currentActivityThread().getSystemUiContext());
            android.util.Log.d(com.android.server.security.hwkeychain.DecisionUtil.TAG, "execute event.");
            if (com.android.server.security.hwkeychain.DecisionUtil.executeEvent("com.huawei.securitymgr.intent.action.KeychainAutoFillEvent", com.android.server.security.hwkeychain.DecisionUtil.sExtras)) {
                android.util.Log.d(com.android.server.security.hwkeychain.DecisionUtil.TAG, "unbind service.");
                com.android.server.security.hwkeychain.DecisionUtil.unbindService(android.app.ActivityThread.currentActivityThread().getSystemUiContext());
            }
            return null;
        }
    }

    public static void bindService(android.content.Context context) {
        java.lang.String ACTION_PACKAGE_NAME = "com.huawei.recsys";
        java.lang.String ACTION_COMMON_SERVICE_NAME = "com.huawei.recsys.decision.action.BIND_DECISION_SERVICE";
        if (context == null || mDecisionApi != null) {
            android.util.Log.i(TAG, "service already binded");
            return;
        }
        if (mHander == null) {
            mHander = new android.os.Handler(context.getMainLooper());
        }
        android.content.Intent actionService = new android.content.Intent("com.huawei.recsys.decision.action.BIND_DECISION_SERVICE");
        actionService.setPackage("com.huawei.recsys");
        try {
            context.bindService(actionService, mDecisionConnection, 1);
        } catch (java.lang.Exception e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("bind service error: ");
            stringBuilder.append(e.getMessage());
            android.util.Log.e(str, stringBuilder.toString());
        }
    }

    public static void unbindService(android.content.Context context) {
        if (context != null) {
            try {
                context.unbindService(mDecisionConnection);
            } catch (java.lang.Exception e) {
                android.util.Log.e(TAG, "unbind service error");
                android.util.Log.e(TAG, e.getMessage());
            }
            mDecisionApi = null;
            sExtras = null;
        }
    }

    public static boolean executeEvent(java.lang.String eventName, java.util.Map<java.lang.String, java.lang.Object> extras) {
        return executeEvent(eventName, null, extras, null);
    }

    public static boolean executeEvent(java.lang.String eventName, java.lang.String dataId, java.util.Map<java.lang.String, java.lang.Object> extras, com.android.server.security.hwkeychain.DecisionCallback callback) {
        return executeEvent(eventName, dataId, extras, callback, -1);
    }

    public static boolean executeEvent(java.lang.String eventName, java.lang.String dataId, java.util.Map<java.lang.String, java.lang.Object> extras, com.android.server.security.hwkeychain.DecisionCallback callback, long timeout) {
        if (mDecisionApi == null) {
            return false;
        }
        java.lang.String key;
        android.util.ArrayMap<java.lang.String, java.lang.Object> extra2 = new android.util.ArrayMap();
        if (extras != null) {
            extra2.putAll(extras);
        }
        extra2.put("id", dataId != null ? dataId : "");
        if (!(eventName == null || eventName.equals(dataId))) {
            extra2.put("category", eventName);
        }
        if (callback != null) {
            key = callback.toString();
        } else {
            key = null;
        }
        final com.android.server.security.hwkeychain.DecisionCallback innerCallback = new com.android.server.security.hwkeychain.DecisionCallback() {
            public void onResult(java.util.Map result) throws android.os.RemoteException {
                if (key != null) {
                    com.android.server.security.hwkeychain.DecisionUtil.mCallbackList.remove(key);
                }
                if (this.mReversed1 != null) {
                    this.mReversed1.onResult(result);
                }
            }
        };
        innerCallback.setReversed1(callback);
        if (callback != null && timeout > 0) {
            mCallbackList.put(key, callback);
            mHander.postDelayed(new java.lang.Runnable() {
                public void run() {
                    com.android.server.security.hwkeychain.DecisionCallback userCallback = (com.android.server.security.hwkeychain.DecisionCallback) com.android.server.security.hwkeychain.DecisionUtil.mCallbackList.remove(key);
                    if (userCallback != null) {
                        innerCallback.clearReversed1();
                        try {
                            userCallback.onTimeout();
                        } catch (java.lang.Exception e) {
                        }
                    }
                }
            }, timeout);
        }
        try {
            mDecisionApi.executeEvent(extra2, innerCallback);
            return true;
        } catch (java.lang.Exception e) {
            return false;
        }
    }

    public static void autoExecuteEvent(java.util.Map<java.lang.String, java.lang.Object> extras) {
        sExtras = extras;
        if (sExtras != null) {
            new com.android.server.security.hwkeychain.DecisionUtil.DecisionAyncTask().executeOnExecutor(android.os.AsyncTask.THREAD_POOL_EXECUTOR, new java.lang.Void[0]);
        }
    }
}
