package com.android.server.security.hwkeychain;

public class HwKeychainService extends huawei.android.security.IHwKeychainManager.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    private static final java.lang.String AUTOFILL_FLAG_FILE_NAME = "autofill_flag";
    private static final java.lang.String AUTOFILL_SERVICE_KEY = "autofill_service";
    private static final java.lang.String AUTOFILL_SERVICE_VALUE_HW = "com.huawei.securitymgr/com.huawei.keychain.service.HwAutofillService";
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            android.util.Log.d("HwKeychainService", "create HwKeychainService");
            return new com.android.server.security.hwkeychain.HwKeychainService(context);
        }

        public java.lang.String getPluginPermission() {
            return null;
        }
    };
    private static final java.lang.String IS_DECISION_REPORT_KEY = "isDecisionReport";
    private static final java.lang.String IS_FILLING_USED_KEY = "isFillingUsed";
    private static final java.lang.String IS_FIRST_REMIND_KEY = "isFirstRemind";
    private static final java.lang.String IS_KEYCHAIN_ENABLE_KEY = "isKeychainEnable";
    private static final java.lang.String IS_PRIMARY_USER_KEY = "isPrimaryUser";
    private static final java.lang.String IS_ROOT_KEY = "isroot";
    private static final java.lang.String IS_USED_KEY = "isUsed";
    private static final java.lang.String OP_KEY = "OP";
    private static final java.lang.String SYSTEM_DATA_PATH = "system";
    private static final java.lang.String TAG = "HwKeychainService";
    private static final java.lang.String WEEK_REMIND_KEY = "weekRemind";
    private android.content.Context mContext;

    public HwKeychainService(android.content.Context context) {
        this.mContext = context;
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public void onStart() {
    }

    public void onStop() {
    }

    private boolean isHwAutofillService(android.content.Context context) {
        if (context == null) {
            android.util.Log.e("HwKeychainService", "context is null in isHwAutofillService");
            return false;
        }
        boolean resultValue = false;
        java.lang.String setting = android.provider.Settings.Secure.getString(context.getContentResolver(), "autofill_service");
        if (setting != null) {
            android.content.ComponentName componentName = android.content.ComponentName.unflattenFromString(setting);
            if (componentName != null) {
                resultValue = "com.huawei.securitymgr/com.huawei.keychain.service.HwAutofillService".equals(componentName.flattenToString());
            } else {
                resultValue = false;
            }
        }
        return resultValue;
    }

    public void recordCurrentInfo(int userId) {
        android.util.Log.d("HwKeychainService", "start recordCurrentInfo");
        org.json.JSONObject dict = getConfigureDictionary();
        boolean isHwAutofillService = isHwAutofillService(this.mContext);
        boolean isChanged = false;
        if (checkFirstRemind(this.mContext, dict, isHwAutofillService)) {
            isChanged = true;
        }
        if (checkWeekRemind(this.mContext, dict, isHwAutofillService)) {
            isChanged = true;
        }
        if (isDecisionReport(dict)) {
            android.util.Log.d("HwKeychainService", "DecisionUtil: bindservice");
            java.util.Map<java.lang.String, java.lang.Object> extras = new java.util.HashMap();
            extras.put("isPrimaryUser", java.lang.Boolean.valueOf(userId == 0));
            extras.put("isKeychainEnable", java.lang.Boolean.valueOf(isHwAutofillService));
            extras.put("isFillingUsed", java.lang.Boolean.valueOf(isUsedFlag(dict)));
            com.android.server.security.hwkeychain.DecisionUtil.autoExecuteEvent(extras);
            setDecisionReport(dict);
            isChanged = true;
        }
        if (isChanged) {
            saveConfigureDictionary(dict);
        }
    }

    private java.io.File getAutofillFlagFile() {
        return new java.io.File(new java.io.File(android.os.Environment.getDataDirectory(), "system"), "autofill_flag");
    }

    private org.json.JSONObject getConfigureDictionary() {
        java.lang.StringBuilder stringBuilder;
        java.lang.StringBuilder stringBuilder2;
        java.io.IOException e;
        java.lang.String str;
        java.lang.StringBuilder stringBuilder3;
        java.io.File file = getAutofillFlagFile();
        if (!file.exists()) {
            return new org.json.JSONObject();
        }
        java.io.InputStreamReader inputStreamReader = null;
        java.io.BufferedReader bufferedReader = null;
        java.io.FileInputStream fileInputStream = null;
        try {
            java.lang.String readLine;
            fileInputStream = new java.io.FileInputStream(file);
            inputStreamReader = new java.io.InputStreamReader(fileInputStream, "utf-8");
            bufferedReader = new java.io.BufferedReader(inputStreamReader);
            java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
            while (true) {
                readLine = bufferedReader.readLine();
                java.lang.String line = readLine;
                if (readLine == null) {
                    break;
                }
                stringBuilder4.append(line);
                stringBuilder4.append("\n");
            }
            readLine = stringBuilder4.toString();
            bufferedReader.close();
            bufferedReader = null;
            inputStreamReader.close();
            inputStreamReader = null;
            fileInputStream.close();
            fileInputStream = null;
            org.json.JSONObject jSONObject = new org.json.JSONObject(readLine);
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (java.io.IOException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("close bufferedReader IOException in getConfigureDictionary: ");
                    stringBuilder.append(e2.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder.toString());
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e22) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("close fileReader IOException in getConfigureDictionary: ");
                    stringBuilder.append(e22.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder.toString());
                }
            }
            if (fileInputStream != null) {
                try {
                    fileInputStream.close();
                } catch (java.io.IOException e222) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("close fileInputStream IOException in getConfigureDictionary: ");
                    stringBuilder.append(e222.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder.toString());
                }
            }
            return jSONObject;
        } catch (java.io.FileNotFoundException e3) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("FileNotFoundException in getConfigureDictionary: ");
            stringBuilder2.append(e3.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder2.toString());
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (java.io.IOException e4) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close bufferedReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e4.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e42) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close fileReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e42.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (fileInputStream != null) {
                try {
                    fileInputStream.close();
                } catch (java.io.IOException e5) {
                    e42 = e5;
                    str = "HwKeychainService";
                    stringBuilder2 = new java.lang.StringBuilder();
                }
            }
            return new org.json.JSONObject();
        } catch (java.io.IOException e422) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("IOException in getConfigureDictionary: ");
            stringBuilder2.append(e422.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder2.toString());
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (java.io.IOException e4222) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close bufferedReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e4222.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e42222) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close fileReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e42222.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (fileInputStream != null) {
                try {
                    fileInputStream.close();
                } catch (java.io.IOException e6) {
                    e42222 = e6;
                    str = "HwKeychainService";
                    stringBuilder2 = new java.lang.StringBuilder();
                }
            }
            return new org.json.JSONObject();
        } catch (org.json.JSONException e7) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("JSONException in getConfigureDictionary: ");
            stringBuilder2.append(e7.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder2.toString());
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (java.io.IOException e422222) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close bufferedReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e422222.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e4222222) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close fileReader IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e4222222.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
            if (fileInputStream != null) {
                try {
                    fileInputStream.close();
                } catch (java.io.IOException e8) {
                    e4222222 = e8;
                    str = "HwKeychainService";
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close fileInputStream IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e4222222.getMessage());
                    android.util.Log.e(str, stringBuilder2.toString());
                    return new org.json.JSONObject();
                }
            }
            return new org.json.JSONObject();
        } catch (Throwable th) {
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (java.io.IOException e9) {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("close bufferedReader IOException in getConfigureDictionary: ");
                    stringBuilder3.append(e9.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder3.toString());
                }
            }
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (java.io.IOException e92) {
                    stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("close fileReader IOException in getConfigureDictionary: ");
                    stringBuilder3.append(e92.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder3.toString());
                }
            }
            if (fileInputStream != null) {
                try {
                    fileInputStream.close();
                } catch (java.io.IOException e922) {
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("close fileInputStream IOException in getConfigureDictionary: ");
                    stringBuilder2.append(e922.getMessage());
                    android.util.Log.e("HwKeychainService", stringBuilder2.toString());
                }
            }
        }
    }

    private void saveConfigureDictionary(org.json.JSONObject dict) {
        java.io.IOException e;
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        if (dict != null) {
            java.io.FileOutputStream outputStream = null;
            try {
                outputStream = new java.io.FileOutputStream(getAutofillFlagFile());
                outputStream.write(dict.toString().getBytes("utf-8"));
                outputStream.flush();
                outputStream.close();
                outputStream = null;
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (java.io.IOException e2) {
                        e = e2;
                        str = "HwKeychainService";
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("close outputStream IOException in saveConfigureDictionary: ");
                        stringBuilder.append(e.getMessage());
                        android.util.Log.e(str, stringBuilder.toString());
                    }
                }
            } catch (java.io.FileNotFoundException e3) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("FileNotFoundException in saveConfigureDictionary: ");
                stringBuilder.append(e3.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder.toString());
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (java.io.IOException e4) {
                        e = e4;
                        str = "HwKeychainService";
                        stringBuilder = new java.lang.StringBuilder();
                    }
                }
            } catch (java.io.IOException e5) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("IOException in saveConfigureDictionary: ");
                stringBuilder.append(e5.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder.toString());
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (java.io.IOException e6) {
                        e5 = e6;
                        str = "HwKeychainService";
                        stringBuilder = new java.lang.StringBuilder();
                    }
                }
            } catch (Throwable th) {
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (java.io.IOException e7) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("close outputStream IOException in saveConfigureDictionary: ");
                        stringBuilder.append(e7.getMessage());
                        android.util.Log.e("HwKeychainService", stringBuilder.toString());
                    }
                }
            }
        }
    }

    private boolean checkFirstRemind(android.content.Context context, org.json.JSONObject dict, boolean isHwAutofillService) {
        java.lang.StringBuilder stringBuilder;
        boolean isFirstRemind = true;
        if (dict.has("isFirstRemind")) {
            try {
                isFirstRemind = dict.getBoolean("isFirstRemind");
            } catch (org.json.JSONException e) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("JSON exception in checkFirstRemind get isFirstRemind: ");
                stringBuilder2.append(e.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder2.toString());
            }
        }
        if (isFirstRemind) {
            org.json.JSONObject eventDict = new org.json.JSONObject();
            try {
                eventDict.put("OP", isHwAutofillService);
                eventDict.put("isroot", isRoot());
            } catch (org.json.JSONException e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON exception in checkFirstRemind event isFirstRemind: ");
                stringBuilder.append(e2.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder.toString());
            }
            android.util.Flog.bdReport(context, 700, eventDict);
            try {
                dict.put("isFirstRemind", false);
            } catch (org.json.JSONException e22) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON exception in checkFirstRemind update isFirstRemind: ");
                stringBuilder.append(e22.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder.toString());
            }
        }
        return isFirstRemind;
    }

    private boolean checkWeekRemind(android.content.Context context, org.json.JSONObject dict, boolean isHwAutofillService) {
        java.lang.StringBuilder stringBuilder;
        java.lang.String weekRemind = null;
        if (dict.has("weekRemind")) {
            try {
                weekRemind = dict.getString("weekRemind");
            } catch (org.json.JSONException e) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("JSON exception in checkWeekRemind get weekRemind: ");
                stringBuilder2.append(e.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder2.toString());
            }
        }
        java.util.Calendar calendar = java.util.Calendar.getInstance();
        int week = calendar.get(3);
        int year = calendar.get(1);
        java.lang.String currentWeekRemind = new java.lang.StringBuilder();
        currentWeekRemind.append(year);
        currentWeekRemind.append("-");
        currentWeekRemind.append(week);
        currentWeekRemind = currentWeekRemind.toString();
        if (currentWeekRemind.equals(weekRemind)) {
            return false;
        }
        org.json.JSONObject eventDict = new org.json.JSONObject();
        try {
            eventDict.put("OP", isHwAutofillService);
            eventDict.put("isroot", isRoot());
        } catch (org.json.JSONException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("JSON exception in checkWeekRemind event: ");
            stringBuilder.append(e2.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder.toString());
        }
        android.util.Flog.bdReport(context, 701, eventDict);
        try {
            dict.put("weekRemind", currentWeekRemind);
        } catch (org.json.JSONException e22) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("JSON exception in checkWeekRemind update: ");
            stringBuilder.append(e22.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder.toString());
        }
        return true;
    }

    private boolean isUsedFlag(org.json.JSONObject dict) {
        try {
            if (dict.has("isUsed") && dict.getBoolean("isUsed")) {
                return true;
            }
            return false;
        } catch (org.json.JSONException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("JSON exception in isUsedFlag: ");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder.toString());
        }
    }

    private boolean isDecisionReport(org.json.JSONObject dict) {
        java.lang.String decisionReport = null;
        if (dict.has("isDecisionReport")) {
            try {
                decisionReport = dict.getString("isDecisionReport");
            } catch (org.json.JSONException e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON exception in isDecisionReport get decisionReport: ");
                stringBuilder.append(e.getMessage());
                android.util.Log.e("HwKeychainService", stringBuilder.toString());
            }
        }
        java.util.Calendar calendar = java.util.Calendar.getInstance();
        int year = calendar.get(1);
        int month = calendar.get(2);
        int day = calendar.get(5);
        java.lang.String currentDecisionReport = new java.lang.StringBuilder();
        currentDecisionReport.append(year);
        currentDecisionReport.append("-");
        currentDecisionReport.append(month);
        currentDecisionReport.append("-");
        currentDecisionReport.append(day);
        return 1 ^ currentDecisionReport.toString().equals(decisionReport);
    }

    private void setDecisionReport(org.json.JSONObject dict) {
        java.util.Calendar calendar = java.util.Calendar.getInstance();
        int year = calendar.get(1);
        int month = calendar.get(2);
        int day = calendar.get(5);
        java.lang.String currentDecisionReport = new java.lang.StringBuilder();
        currentDecisionReport.append(year);
        currentDecisionReport.append("-");
        currentDecisionReport.append(month);
        currentDecisionReport.append("-");
        currentDecisionReport.append(day);
        try {
            dict.put("isDecisionReport", currentDecisionReport.toString());
        } catch (org.json.JSONException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("JSON exception in setDecisionReport: ");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder.toString());
        }
    }

    private boolean isRoot() {
        long identity = android.os.Binder.clearCallingIdentity();
        boolean z = true;
        int rootstatus = 1;
        try {
            android.securitydiagnose.HwSecurityDiagnoseManager mSdm = android.securitydiagnose.HwSecurityDiagnoseManager.getInstance();
            if (mSdm == null) {
                android.os.Binder.restoreCallingIdentity(identity);
                return true;
            }
            rootstatus = mSdm.getRootStatusSync();
            android.os.Binder.restoreCallingIdentity(identity);
            if (rootstatus == 0) {
                z = false;
            }
            return z;
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("isRoot error: ");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("HwKeychainService", stringBuilder.toString());
        } catch (Throwable th) {
            android.os.Binder.restoreCallingIdentity(identity);
        }
    }
}
