package com.android.server.security.inseservice;

public class InSEService extends huawei.android.security.inse.IInSEService.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    public static final java.lang.Object BINDLOCK = new java.lang.Object();
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            if (com.android.server.security.inseservice.InSEService.HW_DEBUG) {
                android.util.Log.d("InSEServicePlugin", "create InSEService");
            }
            return new com.android.server.security.inseservice.InSEService(context);
        }

        public java.lang.String getPluginPermission() {
            return "huawei.android.permission.INSE_PERMISSION";
        }
    };
    private static final boolean HW_DEBUG;
    private static final java.lang.String INSE_HIDL_SERVICE_NAME = "HwInSExtNode";
    private static final java.lang.String INSE_MANAGER_PERMISSION = "huawei.android.permission.INSE_PERMISSION";
    private static final int MAX_INSE_HIDL_DEAMON_REGISTER_TIMES = 10;
    private static final int MSG_INSE_HIDL_DEAMON_SERVIE_REGISTER = 1;
    private static final int RET_DEFAULT_ERROR_VALUE = -1001;
    private static final int RET_EXCEPTION_WHEN_INSE_CALL = -1002;
    private static final int RET_INSE_HIDL_DEAMON_IS_NOT_READY = -1000;
    private static final java.lang.String TAG = "InSEServicePlugin";
    private static final int TRY_GET_HIDL_DEAMON_DEALY_MILLIS = 1000;
    private static com.android.server.security.inseservice.InSEService.HwInSEHidlHandler mHwInSEHidlHandler;
    private static android.os.HandlerThread mHwInSEThread;
    private android.content.Context mContext = null;
    private android.os.IHwBinder.DeathRecipient mInSEHidlDeamonDeathRecipient = new android.os.IHwBinder.DeathRecipient() {
        public void serviceDied(long cookie) {
            if (com.android.server.security.inseservice.InSEService.mHwInSEHidlHandler != null) {
                android.util.Log.e("InSEServicePlugin", "inse hidl deamon service has died, try to reconnect it later.");
                com.android.server.security.inseservice.InSEService.this.vNode = null;
                com.android.server.security.inseservice.InSEService.mHwInSEHidlHandler.sendEmptyMessageDelayed(1, 1000);
            }
        }
    };
    private int mInSEHidlDeamonRegisterTryTimes = 0;
    private vendor.huawei.hardware.huawei_security_vnode.V1_0.IHwSecurityVNode vNode;

    private final class HwInSEHidlHandler extends android.os.Handler {
        public HwInSEHidlHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what != 1) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("handler thread received unknown message : ");
                stringBuilder.append(msg.what);
                android.util.Log.e("InSEServicePlugin", stringBuilder.toString());
                return;
            }
            try {
                com.android.server.security.inseservice.InSEService.this.vNode = vendor.huawei.hardware.huawei_security_vnode.V1_0.IHwSecurityVNode.getService("HwInSExtNode", true);
            } catch (java.lang.Exception e) {
                android.util.Log.e("InSEServicePlugin", "Try get inse hidl deamon servcie failed in handler message.");
            }
            if (com.android.server.security.inseservice.InSEService.this.vNode != null) {
                com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonRegisterTryTimes = 0;
                try {
                    com.android.server.security.inseservice.InSEService.this.vNode.linkToDeath(com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonDeathRecipient, 0);
                } catch (java.lang.Exception e2) {
                    android.util.Log.e("InSEServicePlugin", "Exception occured when linkToDeath in handle message");
                }
            } else {
                com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonRegisterTryTimes = com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonRegisterTryTimes + 1;
                if (com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonRegisterTryTimes < 10) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("inse hidl daemon service is not ready, try times : ");
                    stringBuilder2.append(com.android.server.security.inseservice.InSEService.this.mInSEHidlDeamonRegisterTryTimes);
                    android.util.Log.e("InSEServicePlugin", stringBuilder2.toString());
                    com.android.server.security.inseservice.InSEService.mHwInSEHidlHandler.sendEmptyMessageDelayed(1, 1000);
                } else {
                    android.util.Log.e("InSEServicePlugin", "inse hidl daemon service connection failed.");
                }
            }
            if (com.android.server.security.inseservice.InSEService.HW_DEBUG) {
                android.util.Log.d("InSEServicePlugin", "handler thread received request inse hidl deamon message.");
            }
        }
    }

    static {
        boolean z;
        if (!(android.os.SystemProperties.get("ro.secure", "1").equals("0") || android.util.Log.HWINFO)) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("InSEServicePlugin", 4)) {
                z = false;
                HW_DEBUG = z;
            }
        }
        z = true;
        HW_DEBUG = z;
    }

    public InSEService(android.content.Context context) {
        this.mContext = context;
    }

    public android.os.IBinder asBinder() {
        checkPermission("huawei.android.permission.INSE_PERMISSION");
        return this;
    }

    public void onStart() {
        if (HW_DEBUG) {
            android.util.Log.d("InSEServicePlugin", "InSEService start");
        }
        mHwInSEThread = new android.os.HandlerThread("InSEServicePlugin");
        mHwInSEThread.start();
        mHwInSEHidlHandler = new com.android.server.security.inseservice.InSEService.HwInSEHidlHandler(mHwInSEThread.getLooper());
    }

    public void onStop() {
        if (mHwInSEHidlHandler != null) {
            mHwInSEHidlHandler = null;
        }
        if (mHwInSEThread != null) {
            mHwInSEThread.quitSafely();
            mHwInSEThread = null;
        }
        try {
            if (HW_DEBUG) {
                android.util.Log.d("InSEServicePlugin", "close InSEService");
            }
        } catch (java.lang.UnsatisfiedLinkError e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("stop error");
            stringBuilder.append(e.toString());
            android.util.Log.e("InSEServicePlugin", stringBuilder.toString());
        }
    }

    private void checkPermission(java.lang.String permission) {
        android.content.Context context = this.mContext;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Must have ");
        stringBuilder.append(permission);
        stringBuilder.append(" permission.");
        context.enforceCallingOrSelfPermission(permission, stringBuilder.toString());
    }

    public int inSE_PowerOnDelayed(int time, int id) {
        checkPermission("huawei.android.permission.INSE_PERMISSION");
        if (HW_DEBUG) {
            android.util.Log.d("InSEServicePlugin", "current inse feature is a stub function now");
        }
        return id < 0 ? -1 : 1;
    }
}
