package com.android.server.security.pwdprotect;

public class PwdProtectService extends huawei.android.security.IPwdProtectManager.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            android.util.Log.d("PwdProtectService", "create PwdProtectService");
            return new com.android.server.security.pwdprotect.PwdProtectService(context);
        }

        public java.lang.String getPluginPermission() {
            return null;
        }
    };
    private static final java.lang.String DB_KEY_PRIVACY_USER_PWD_PROTECT = "privacy_user_pwd_protect";
    private static final java.lang.String PRIV_SPACE_PWD_PROTECT_PERMISSION = "com.huawei.privacyspace.permission.PASSWORD_RESET";
    private static final java.lang.String TAG = "PwdProtectService";
    private android.content.Context mContext;

    public PwdProtectService(android.content.Context context) {
        this.mContext = context;
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    public void onStart() {
    }

    public void onStop() {
    }

    public boolean hasKeyFileExisted() throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (!(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PIN2.exists() || com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2.exists() || com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQANSWER.exists())) {
            if (!com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQ.exists()) {
                return false;
            }
        }
        return true;
    }

    public boolean removeKeyFile() throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (!hasKeyFileExisted()) {
            android.util.Log.e("PwdProtectService", "removeKeyFile fail, files do not exist");
            return false;
        } else if (!com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PIN2.delete() || !com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2.delete() || !com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQANSWER.delete() || !com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQ.delete()) {
            return false;
        } else {
            android.util.Log.i("PwdProtectService", "removeKeyFile success");
            return true;
        }
    }

    public boolean modifyPrivPwd(java.lang.String password) throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (!android.text.TextUtils.isEmpty(password)) {
            return com.android.server.security.pwdprotect.logic.ModifyPassWord.modifyPrivSpacePw(password);
        }
        android.util.Log.e("PwdProtectService", "modifyPrivPwd failed,str is null");
        return false;
    }

    public boolean modifyMainPwd(java.lang.String origPassword, java.lang.String newPassword) throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (!android.text.TextUtils.isEmpty(origPassword) || !android.text.TextUtils.isEmpty(newPassword)) {
            return com.android.server.security.pwdprotect.logic.ModifyPassWord.modifyMainSpacePw(origPassword, newPassword);
        }
        android.util.Log.e("PwdProtectService", "modifyMainPwd failed,str is null");
        return false;
    }

    public java.lang.String decodeCurrentPwd(java.lang.String mainSpacePin, java.lang.String answer) throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (android.text.TextUtils.isEmpty(mainSpacePin) && android.text.TextUtils.isEmpty(answer)) {
            android.util.Log.e("PwdProtectService", "decodeCurrentPwd failed,str is null");
            return null;
        }
        java.lang.String origPwd = com.android.server.security.pwdprotect.logic.ResetPassWord.decodeCurrentPwd(mainSpacePin, answer);
        if (android.text.TextUtils.isEmpty(origPwd)) {
            android.util.Flog.bdReport(this.mContext, 132);
        }
        return origPwd;
    }

    public boolean startPwdProtect(java.lang.String privSpacePin, java.lang.String question, java.lang.String answer, java.lang.String mainSpacePin) throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (android.text.TextUtils.isEmpty(privSpacePin) && android.text.TextUtils.isEmpty(question) && android.text.TextUtils.isEmpty(answer) && android.text.TextUtils.isEmpty(mainSpacePin)) {
            android.util.Log.e("PwdProtectService", "startPwdProtect failed,str is null");
            return false;
        } else if (java.lang.Boolean.valueOf(new com.android.server.security.pwdprotect.logic.StartPwdProtect().turnOnPwdProtect(privSpacePin, question, answer, mainSpacePin)).booleanValue()) {
            android.util.Log.i("PwdProtectService", "startPwdProtect success");
            if (isPrivSpacePwdProtectOpened()) {
                android.util.Flog.bdReport(this.mContext, 133);
            } else {
                android.util.Flog.bdReport(this.mContext, 130);
            }
            return true;
        } else {
            android.util.Log.e("PwdProtectService", "startPwdProtect failed");
            return false;
        }
    }

    public java.lang.String getPwdQuestion() throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        return com.android.server.security.pwdprotect.logic.ResetPassWord.getPwdQuestion();
    }

    public boolean pwdQAnswerVertify(byte[] pwQuestion) throws android.os.RemoteException {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.privacyspace.permission.PASSWORD_RESET", "does not have privSpace pwd protect permission!");
        if (pwQuestion != null) {
            return com.android.server.security.pwdprotect.logic.ResetPassWord.pwdQAnswerVertify(pwQuestion).booleanValue();
        }
        android.util.Log.e("PwdProtectService", "pwdQAnswerVertify failed,str is null");
        return false;
    }

    private boolean isPrivSpacePwdProtectOpened() {
        boolean z = false;
        if (this.mContext == null) {
            return false;
        }
        if (android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "privacy_user_pwd_protect", 0) == 1) {
            z = true;
        }
        return z;
    }
}
