package com.android.server.security.pwdprotect.logic;

public class ResetPassWord {
    private static final byte[] HMACKEY = "HMACKEY".getBytes(java.nio.charset.Charset.forName("UTF-8"));
    private static final java.lang.String TAG = "PwdProtectService";

    public static java.lang.String decodeCurrentPwd(java.lang.String mainSpacePin, java.lang.String pwdQuestionAnswer) {
        if (!(android.text.TextUtils.isEmpty(mainSpacePin) || android.text.TextUtils.isEmpty(pwdQuestionAnswer))) {
            if (com.android.server.security.pwdprotect.utils.FileUtils.verifyFile().booleanValue()) {
                byte[] E_SK1 = decodeE_SK2(mainSpacePin);
                if (E_SK1.length == 0) {
                    android.util.Log.e("PwdProtectService", "decode E_SK2 failed");
                    return null;
                }
                byte[] delZeroSk = decodeE_SK1(E_SK1, pwdQuestionAnswer);
                if (delZeroSk.length == 0) {
                    android.util.Log.e("PwdProtectService", "decode E_SK1 failed");
                    return null;
                }
                byte[] origPwd = decodeE_PIN2(delZeroSk);
                if (origPwd.length == 0) {
                    android.util.Log.e("PwdProtectService", "decode E_PIN2 failed");
                    return null;
                }
                android.util.Log.i("PwdProtectService", "decode origPd success");
                java.lang.String origCredential = "";
                try {
                    origCredential = new java.lang.String(origPwd, "UTF-8");
                } catch (java.io.UnsupportedEncodingException e) {
                    android.util.Log.e("PwdProtectService", "UnsupportedEncodingException");
                }
                return origCredential;
            }
        }
        android.util.Log.e("PwdProtectService", "verifyFile failed ");
        return null;
    }

    public static java.lang.Boolean pwdQAnswerVertify(byte[] pwQuestion) {
        byte[] pwdQAnswerHash = com.android.server.security.pwdprotect.utils.HashUtils.calHash256(pwQuestion);
        byte[] pwdAnswerHashDecode = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceDecode(com.android.server.security.pwdprotect.utils.FileUtils.readKeys(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQANSWER), com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQANSWER, 0));
        if (pwdAnswerHashDecode.length != 0) {
            return java.lang.Boolean.valueOf(java.util.Arrays.equals(pwdAnswerHashDecode, pwdQAnswerHash));
        }
        android.util.Log.e("PwdProtectService", "deviceDecode pwdAnswerHashDecode failed");
        return java.lang.Boolean.valueOf(false);
    }

    public static java.lang.String getPwdQuestion() {
        try {
            byte[] pwdQuestionDecode = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceDecode(com.android.server.security.pwdprotect.utils.FileUtils.readKeys(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQ), com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQ, 0));
            if (pwdQuestionDecode.length != 0) {
                return new java.lang.String(pwdQuestionDecode, "utf-8");
            }
            android.util.Log.e("PwdProtectService", "getPwdQuestion failed pwdQuestionDecode is null");
            return null;
        } catch (java.io.UnsupportedEncodingException e) {
            android.util.Log.e("PwdProtectService", "getPwdQuestion failed  UnsupportedEncodingException");
            return null;
        }
    }

    public static byte[] decodeE_SK2(java.lang.String mainSpacePin) {
        byte[] mainSpacePinPkdf = com.android.server.security.pwdprotect.utils.HashUtils.pkdfEncry(mainSpacePin, com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2, 2));
        if (mainSpacePinPkdf.length == 0) {
            android.util.Log.e("PwdProtectService", "decodeE_SK2 failed mainSpacePinPkdf is null ");
            return new byte[0];
        }
        byte[] E_SK2_Decode = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceDecode(com.android.server.security.pwdprotect.utils.FileUtils.readKeys(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2), com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2, 3));
        if (E_SK2_Decode.length != 0) {
            return com.android.server.security.pwdprotect.utils.EncryptUtils.aesCbcDecode(E_SK2_Decode, mainSpacePinPkdf, com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2, 1));
        }
        android.util.Log.e("PwdProtectService", "decodeE_SK2 device encrypt failed");
        return new byte[0];
    }

    public static byte[] decodeE_SK1(byte[] E_SK1, java.lang.String pwdQuestionAnswer) {
        byte[] k1 = com.android.server.security.pwdprotect.utils.HashUtils.encryHmacSha256(pwdQuestionAnswer.getBytes(java.nio.charset.Charset.forName("UTF-8")), HMACKEY);
        if (k1.length != 0) {
            return com.android.server.security.pwdprotect.utils.EncryptUtils.aesCbcDecode(E_SK1, k1, com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2, 0));
        }
        android.util.Log.e("PwdProtectService", "decodeE_SK1 HmacSha256 failed ");
        return new byte[0];
    }

    private static byte[] decodeE_PIN2(byte[] delZeroSk) {
        byte[] E_PIN2_decode = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceDecode(com.android.server.security.pwdprotect.utils.FileUtils.readKeys(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PIN2), com.android.server.security.pwdprotect.utils.FileUtils.readIvs(com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PIN2, 0));
        if (E_PIN2_decode.length != 0) {
            return com.android.server.security.pwdprotect.utils.EncryptUtils.decryptData(E_PIN2_decode, com.android.server.security.pwdprotect.utils.EncryptUtils.getPrivateKey(delZeroSk));
        }
        android.util.Log.e("PwdProtectService", "decodeE_PIN2 deviceDecode failed ");
        return new byte[0];
    }
}
