package com.android.server.security.pwdprotect.logic;

public class StartPwdProtect {
    private static final byte[] HMACKEY = "HMACKEY".getBytes(java.nio.charset.Charset.forName("UTF-8"));
    private static final java.lang.String TAG = "PwdProtectService";
    private byte[] mPin2Iv;
    private java.security.PrivateKey mPrivateKey;
    private byte[] mSalt;
    private byte[] mSecretKeyIV;

    private void init() {
        this.mSecretKeyIV = com.android.server.security.pwdprotect.utils.StringUtils.createRandomIvBytes();
        this.mPin2Iv = com.android.server.security.pwdprotect.utils.StringUtils.createRandomIvBytes();
        this.mSalt = com.android.server.security.pwdprotect.utils.StringUtils.createRandomIvBytes();
        com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.createKey();
        com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.createHmacKey();
    }

    public boolean turnOnPwdProtect(java.lang.String privSpacePw, java.lang.String pwQuestion, java.lang.String pwQuestionAnswer, java.lang.String mainSpacePin) {
        if (android.text.TextUtils.isEmpty(privSpacePw)) {
            return false;
        }
        init();
        java.security.KeyPair keyPair = com.android.server.security.pwdprotect.utils.EncryptUtils.generateRSAKeyPair(2048);
        java.security.PublicKey publicKey = keyPair.getPublic();
        this.mPrivateKey = keyPair.getPrivate();
        byte[] enPrivSpaceValues = com.android.server.security.pwdprotect.utils.EncryptUtils.encryptData(privSpacePw.getBytes(java.nio.charset.Charset.forName("UTF-8")), publicKey);
        if (enPrivSpaceValues.length == 0) {
            android.util.Log.e("PwdProtectService", "RSA encrypt PrivSpacePwd failed");
            return false;
        } else if (savePrivSpaceEncryFile(enPrivSpaceValues, publicKey.getEncoded())) {
            android.util.Log.i("PwdProtectService", "begin savePwQ success");
            if (savePwQ(pwQuestion)) {
                android.util.Log.i("PwdProtectService", "begin savePwdQAnswer success");
                if (savePwdQAnswer(pwQuestionAnswer)) {
                    android.util.Log.i("PwdProtectService", "begin saveMainSpaceEncryFile success");
                    if (saveMainSpaceEncryFile(mainSpacePin, pwQuestionAnswer)) {
                        return true;
                    }
                    android.util.Log.e("PwdProtectService", "save saveMainSpaceEncryFile failed");
                    return false;
                }
                android.util.Log.e("PwdProtectService", "save savePwdQAnswer failed");
                return false;
            }
            android.util.Log.e("PwdProtectService", "save savePwQ failed");
            return false;
        } else {
            android.util.Log.e("PwdProtectService", "save PrivSpaceEncryFile failed");
            return false;
        }
    }

    private byte[] calPwQuestionHash(java.lang.String pwQuestionAnswer) {
        return com.android.server.security.pwdprotect.utils.HashUtils.calHash256(pwQuestionAnswer.getBytes(java.nio.charset.Charset.forName("UTF-8")));
    }

    private byte[] encrySecretKey(java.lang.String pwQuestionAnswer) {
        byte[] k1 = com.android.server.security.pwdprotect.utils.HashUtils.encryHmacSha256(pwQuestionAnswer.getBytes(java.nio.charset.Charset.forName("UTF-8")), HMACKEY);
        byte[] E_SK1 = new byte[null];
        if (this.mPrivateKey != null) {
            E_SK1 = com.android.server.security.pwdprotect.utils.EncryptUtils.aesCbcEncode(this.mPrivateKey.getEncoded(), k1, this.mSecretKeyIV);
        }
        if (E_SK1.length == 0) {
            android.util.Log.e("PwdProtectService", "AES encrypt SecretKey failed");
        }
        return E_SK1;
    }

    private byte[] encryMainSpacePin(java.lang.String mainSpacePin, java.lang.String pwQuestionAnswer) {
        byte[] E_SK2_value = com.android.server.security.pwdprotect.utils.EncryptUtils.aesCbcEncode(encrySecretKey(pwQuestionAnswer), com.android.server.security.pwdprotect.utils.HashUtils.pkdfEncry(mainSpacePin, this.mSalt), this.mPin2Iv);
        if (E_SK2_value.length != 0) {
            return E_SK2_value;
        }
        android.util.Log.e("PwdProtectService", "AES encrypt E_SK1 failed");
        return new byte[0];
    }

    private boolean saveMainSpaceEncryFile(java.lang.String mainSpacePin, java.lang.String pwQuestionAnswer) {
        if (com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(encryMainSpacePin(mainSpacePin, pwQuestionAnswer)).length == 0) {
            android.util.Log.e("PwdProtectService", "Device encrypt E_SK2 failed");
            return false;
        }
        byte[] fileHashs = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.hmacSign(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(this.mSecretKeyIV, this.mPin2Iv, this.mSalt, com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(encryMainSpacePin(mainSpacePin, pwQuestionAnswer))));
        com.android.server.security.pwdprotect.utils.FileUtils.writeFile(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(IvKeyVales, fileHashs), com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_SK2);
        return true;
    }

    private boolean savePrivSpaceEncryFile(byte[] ePrivSpaceValues, byte[] publicKey) {
        if (com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(ePrivSpaceValues).length == 0) {
            android.util.Log.e("PwdProtectService", "Device encrypt E_PIN2 failed");
            return false;
        }
        byte[] fileHashs = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.hmacSign(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(ePrivSpaceValues), publicKey));
        com.android.server.security.pwdprotect.utils.FileUtils.writeFile(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(IvKeyVales, fileHashs), com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PIN2);
        return true;
    }

    private boolean savePwdQAnswer(java.lang.String pwQuestionAnswer) {
        byte[] pwdQAnswerHashEncry = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(calPwQuestionHash(pwQuestionAnswer));
        if (pwdQAnswerHashEncry.length == 0) {
            android.util.Log.e("PwdProtectService", "Device encrypt PwdQAnswer failed");
            return false;
        }
        byte[] fileHashs = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.hmacSign(pwdQAnswerHashEncry);
        com.android.server.security.pwdprotect.utils.FileUtils.writeFile(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(pwdQAnswerHashEncry, fileHashs), com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQANSWER);
        return true;
    }

    private boolean savePwQ(java.lang.String pwQuestion) {
        byte[] pwdQHashEncry = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.deviceEncode(pwQuestion.getBytes(java.nio.charset.Charset.forName("UTF-8")));
        if (pwdQHashEncry.length == 0) {
            android.util.Log.e("PwdProtectService", "Device encrypt PwQ failed");
            return false;
        }
        byte[] fileHashs = com.android.server.security.pwdprotect.utils.DeviceEncryptUtils.hmacSign(pwdQHashEncry);
        com.android.server.security.pwdprotect.utils.FileUtils.writeFile(com.android.server.security.pwdprotect.utils.StringUtils.byteMerger(pwdQHashEncry, fileHashs), com.android.server.security.pwdprotect.model.PasswordIvsCache.FILE_E_PWDQ);
        return true;
    }
}
