package com.android.server.security.pwdprotect.utils;

public class HashUtils {
    private static final int CRYPTO_ALGORITHM_KEY_SIZE = 256;
    private static final java.lang.String HASH_SHA256 = "SHA-256";
    private static final java.lang.String HMAC_MD5 = "HmacMD5";
    private static final int PBKDF2_HASH_ROUNDS = 5000;
    private static final java.lang.String PBKDF2_HmacSHA1 = "PBKDF2WithHmacSHA1";
    private static final java.lang.String TAG = "PwdProtectService";

    public static byte[] encryHmacSha256(byte[] data, byte[] key) {
        if (data != null) {
            if (key != null) {
                try {
                    javax.crypto.Mac mac = javax.crypto.Mac.getInstance("HmacMD5");
                    mac.init(new javax.crypto.spec.SecretKeySpec(key, "HmacMD5"));
                    return mac.doFinal(data);
                } catch (java.security.NoSuchAlgorithmException e) {
                    android.util.Log.e("PwdProtectService", "encryptedHmacSha256 no such algorithm exception");
                    return new byte[0];
                } catch (java.security.InvalidKeyException e2) {
                    android.util.Log.e("PwdProtectService", "encryptedHmacSha256 invalid key exception");
                    return new byte[0];
                }
            }
        }
        return new byte[0];
    }

    public static byte[] calHash256(byte[] data) {
        if (data == null) {
            return new byte[0];
        }
        try {
            java.security.MessageDigest md = java.security.MessageDigest.getInstance("SHA-256");
            md.update(data);
            return md.digest();
        } catch (java.security.NoSuchAlgorithmException e) {
            android.util.Log.e("PwdProtectService", "calculate sha256 failed");
            return new byte[0];
        }
    }

    public static byte[] pkdfEncry(java.lang.String password, byte[] salt) {
        if (password == null) {
            return new byte[0];
        }
        byte[] key_result = new byte[1024];
        try {
            return javax.crypto.SecretKeyFactory.getInstance("PBKDF2WithHmacSHA1").generateSecret(new javax.crypto.spec.PBEKeySpec(password.toCharArray(), salt, 5000, 256)).getEncoded();
        } catch (java.security.NoSuchAlgorithmException e) {
            android.util.Log.e("PwdProtectService", "pkdfEncry no such algorithm exception");
            return key_result;
        } catch (java.security.spec.InvalidKeySpecException e2) {
            android.util.Log.e("PwdProtectService", "pkdfEncry invalid key exception");
            return key_result;
        }
    }
}
