package com.android.server.security.securitydiagnose;

public class MalAppDetectReport {
    private static final int EVT_MALAPP_REPORT = 2000;
    private static final int EVT_MALAPP_REPORT_ID = 940000004;
    private static final boolean HW_DEBUG;
    private static final java.lang.String ROOT_STATE_MATCH = "DEVPATH=/kernel/oases_attack";
    private static final java.lang.String TAG = "MalAppDetectReport";
    private static com.android.server.security.securitydiagnose.MalAppDetectReport mInstance;
    private android.content.Context mContext;
    private com.android.server.security.securitydiagnose.MalAppDetectReport.UEventHandler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private final android.os.UEventObserver mUEventObserver = new android.os.UEventObserver() {
        public void onUEvent(android.os.UEventObserver.UEvent event) {
            if (com.android.server.security.securitydiagnose.MalAppDetectReport.HW_DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onUEvent event: ");
                stringBuilder.append(event);
                android.util.Log.d("MalAppDetectReport", stringBuilder.toString());
            }
            com.android.server.security.securitydiagnose.MalAppDetectReport.this.mHandler.sendMessage(com.android.server.security.securitydiagnose.MalAppDetectReport.this.mHandler.obtainMessage(2000, event));
        }
    };

    private class UEventHandler extends android.os.Handler {
        public UEventHandler(android.os.Looper looper) {
            super(looper);
        }

        public void handleMessage(android.os.Message msg) {
            if (msg.what == 2000) {
                com.android.server.security.securitydiagnose.MalAppDetectReport.this.reportData((android.os.UEventObserver.UEvent) msg.obj);
            }
        }
    }

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("MalAppDetectReport", 4)) {
                z = false;
                HW_DEBUG = z;
            }
        }
        z = true;
        HW_DEBUG = z;
    }

    private void reportData(android.os.UEventObserver.UEvent event) {
        if (event != null) {
            try {
                int UID = java.lang.Integer.parseInt(event.get("uid"));
                java.lang.String PATCH_ID = event.get("patch_id");
                if (UID != -1) {
                    org.json.JSONObject json = getApkInfo(UID, PATCH_ID);
                    if (json != null) {
                        onMalAppReport(json);
                    }
                }
            } catch (java.lang.NumberFormatException e) {
                android.util.Log.e("MalAppDetectReport", "some data is not of the type Integer during parsing UEvent");
            }
        }
    }

    public void onMalAppReport(org.json.JSONObject json) {
        org.json.JSONArray arraypks = null;
        try {
            arraypks = json.getJSONArray("packages");
        } catch (org.json.JSONException e) {
            android.util.Log.e("MalAppDetectReport", "getJSONArray JSONException!");
        }
        if (arraypks == null) {
            android.util.Log.w("MalAppDetectReport", "arraypks is null!");
            return;
        }
        int arraypksLength = arraypks.length();
        for (int index = 0; index < arraypksLength; index++) {
            org.json.JSONObject object = null;
            try {
                object = arraypks.getJSONObject(index);
                if (object == null) {
                    android.util.Log.w("MalAppDetectReport", "object is null!");
                } else {
                    android.util.Log.i("MalAppDetectReport", object.toString());
                    android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(940000004);
                    eStream.setParam((short) 0, object.optString("apkName"));
                    eStream.setParam((short) 1, object.optString("apkHash"));
                    eStream.setParam((short) 2, object.optString("apkSignature"));
                    eStream.setParam((short) 3, object.optString("patchId"));
                    if (android.util.IMonitor.sendEvent(eStream)) {
                        android.util.Log.i("MalAppDetectReport", "sendEvent data success");
                    }
                    android.util.IMonitor.closeEventStream(eStream);
                }
            } catch (org.json.JSONException e2) {
                android.util.Log.e("MalAppDetectReport", "getJSONObject JSONException!");
            }
        }
    }

    private MalAppDetectReport(android.content.Context context) {
        this.mContext = context;
        this.mUEventObserver.startObserving("DEVPATH=/kernel/oases_attack");
        this.mHandlerThread = new android.os.HandlerThread("uevent handler : MalAppDetect");
        this.mHandlerThread.start();
        this.mHandler = new com.android.server.security.securitydiagnose.MalAppDetectReport.UEventHandler(this.mHandlerThread.getLooper());
    }

    public static void init(android.content.Context context) {
        synchronized (com.android.server.security.securitydiagnose.MalAppDetectReport.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.security.securitydiagnose.MalAppDetectReport(context);
            }
        }
    }

    public java.lang.String calculateApkHash(java.lang.String apkName) {
        java.io.InputStream manifest = null;
        java.util.zip.ZipFile zf = null;
        java.lang.String apkDigest = null;
        boolean flag = false;
        try {
            byte[] buffer = new byte[8192];
            java.security.MessageDigest msgDigest = java.security.MessageDigest.getInstance("SHA256");
            zf = new java.util.zip.ZipFile(this.mContext.getPackageManager().getApplicationInfo(apkName, 0).sourceDir);
            manifest = zf.getInputStream(zf.getEntry("META-INF/MANIFEST.MF"));
            while (true) {
                int read = manifest.read(buffer);
                int numRead = read;
                if (read == -1) {
                    break;
                }
                msgDigest.update(buffer, 0, numRead);
                flag = true;
            }
            if (flag) {
                apkDigest = byteArray2Hex(msgDigest.digest());
            }
            try {
                zf.close();
                if (manifest != null) {
                    manifest.close();
                }
            } catch (java.io.IOException e) {
                android.util.Log.e("MalAppDetectReport", "InputStream close failure!");
            }
        } catch (android.content.pm.PackageManager.NameNotFoundException e2) {
            android.util.Log.e("MalAppDetectReport", "PackageManager NameNotFoundException!");
            if (zf != null) {
                zf.close();
            }
            if (manifest != null) {
                manifest.close();
            }
        } catch (java.security.NoSuchAlgorithmException e3) {
            android.util.Log.e("MalAppDetectReport", "SHA1 NoSuchAlgorithmException!");
            if (zf != null) {
                zf.close();
            }
            if (manifest != null) {
                manifest.close();
            }
        } catch (java.io.FileNotFoundException e4) {
            android.util.Log.e("MalAppDetectReport", "sourceDir file notfound!");
            if (zf != null) {
                zf.close();
            }
            if (manifest != null) {
                manifest.close();
            }
        } catch (java.io.IOException e5) {
            android.util.Log.e("MalAppDetectReport", "InputStream ZipFile failure!");
            if (zf != null) {
                zf.close();
            }
            if (manifest != null) {
                manifest.close();
            }
        } catch (Throwable th) {
            if (zf != null) {
                try {
                    zf.close();
                } catch (java.io.IOException e6) {
                    android.util.Log.e("MalAppDetectReport", "InputStream close failure!");
                }
            }
            if (manifest != null) {
                manifest.close();
            }
        }
        return apkDigest;
    }

    public java.lang.String calculateCertHash(java.lang.String apkName) {
        java.lang.String certDigest = null;
        try {
            android.content.pm.Signature[] signatures = this.mContext.getPackageManager().getPackageInfo(apkName, 64).signatures;
            java.security.MessageDigest msgDigest = java.security.MessageDigest.getInstance("SHA256");
            int k = 0;
            if (signatures.length == 1) {
                certDigest = byteArray2Hex(msgDigest.digest(signatures[0].toByteArray()));
            } else {
                java.util.List<java.lang.String> sigList = new java.util.ArrayList();
                for (android.content.pm.Signature toByteArray : signatures) {
                    msgDigest.reset();
                    sigList.add(byteArray2Hex(msgDigest.digest(toByteArray.toByteArray())));
                }
                java.util.Collections.sort(sigList);
                java.lang.StringBuffer mergeBuffer = new java.lang.StringBuffer();
                int sigListSize = sigList.size();
                while (k < sigListSize) {
                    mergeBuffer.append((java.lang.String) sigList.get(k));
                    k++;
                }
                java.lang.String mergeString = mergeBuffer.toString();
                msgDigest.reset();
                certDigest = byteArray2Hex(msgDigest.digest(mergeString.getBytes("UTF-8")));
            }
        } catch (java.io.UnsupportedEncodingException e) {
            android.util.Log.e("MalAppDetectReport", "getBytes UnsupportedEncodingException!");
        } catch (android.content.pm.PackageManager.NameNotFoundException e2) {
            android.util.Log.e("MalAppDetectReport", "PackageManager NameNotFoundException!");
        } catch (java.security.NoSuchAlgorithmException e3) {
            android.util.Log.e("MalAppDetectReport", "SHA1 NoSuchAlgorithmException!");
        } catch (java.io.IOException e4) {
            android.util.Log.e("MalAppDetectReport", "IOException !");
        }
        return certDigest;
    }

    public org.json.JSONObject getApkInfo(int UID, java.lang.String PATCHID) {
        java.lang.String[] pkgs = this.mContext.getPackageManager().getPackagesForUid(UID);
        org.json.JSONObject pakjson = new org.json.JSONObject();
        org.json.JSONArray jsonArray = new org.json.JSONArray();
        if (pkgs == null) {
            try {
                org.json.JSONObject infojson = new org.json.JSONObject();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("uid = ");
                stringBuilder.append(UID);
                infojson.put("apkName", stringBuilder.toString());
                infojson.put("apkHash", "");
                infojson.put("apkSignature", "");
                infojson.put("patchId", PATCHID);
                jsonArray.put(infojson);
            } catch (org.json.JSONException e) {
                android.util.Log.e("MalAppDetectReport", "JSON put JSONException!");
            }
        } else {
            for (int i = 0; i < pkgs.length; i++) {
                java.lang.String apkDigest = calculateApkHash(pkgs[i]);
                java.lang.String certDigest = calculateCertHash(pkgs[i]);
                if (!(apkDigest == null || certDigest == null)) {
                    try {
                        org.json.JSONObject infojson2 = new org.json.JSONObject();
                        infojson2.put("apkName", pkgs[i]);
                        infojson2.put("apkHash", apkDigest);
                        infojson2.put("apkSignature", certDigest);
                        infojson2.put("patchId", PATCHID);
                        jsonArray.put(infojson2);
                    } catch (org.json.JSONException e2) {
                        android.util.Log.e("MalAppDetectReport", "JSON put JSONException!");
                    }
                }
            }
        }
        try {
            pakjson.put("packages", jsonArray);
        } catch (org.json.JSONException e3) {
            android.util.Log.e("MalAppDetectReport", "pakjson put JSONException!");
        }
        return pakjson;
    }

    public static java.lang.String byteArray2Hex(byte[] byteArray) {
        char[] hexDigits = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
        char[] resultCharArray = new char[(byteArray.length * 2)];
        int index = 0;
        for (byte b : byteArray) {
            int index2 = index + 1;
            resultCharArray[index] = hexDigits[(b >>> 4) & 15];
            index = index2 + 1;
            resultCharArray[index2] = hexDigits[b & 15];
        }
        return new java.lang.String(resultCharArray);
    }
}
