package com.android.server.security.securitydiagnose;

public class RootDetectReport {
    private static final int BIT_RPROC_CLEAR = -1025;
    private static final int FILE_NOT_FOUND_ERR = -3;
    private static final java.lang.String FILE_PROC_ROOT_SCAN = "/proc/root_scan";
    private static final int GENERIC_ERR = -1;
    private static final boolean HW_DEBUG;
    private static final int IO_EXCEPTION = -4;
    private static final java.lang.String KERNEL_ROOT_STATUS_PATTER_MATCHER = "^\\d{1,5}$";
    private static final boolean RS_DEBUG = android.os.SystemProperties.get("ro.secure", "1").equals("0");
    private static final java.lang.String TAG = "RootDetectReport";
    private static long mEndTime = 0;
    private static com.android.server.security.securitydiagnose.RootDetectReport mInstance;
    private static long mStartTime = 0;
    private android.content.Context mContext;
    private com.android.server.security.securitydiagnose.RootDetectReport.Listener mListener;
    private boolean rootScanHasTrigger = false;

    public interface Listener {
        void onRootReport(org.json.JSONObject jSONObject, boolean z);
    }

    private static class RootDataBundle {
        private static final int GID_UNCHANGED = -1;
        private static final int MAX_DATA_RECORDS = 100;
        private static final java.lang.String RSCAN_LIST_FILE = "root_scan.list";
        private static final int RSCAN_LIST_FILE_MODE = 384;
        private static final java.lang.String SYSTEM_DIR = "system/";
        private static final int UID_UNCHANGED = -1;
        private java.util.ArrayList<java.lang.String> mRootDataList;

        public RootDataBundle() {
            this.mRootDataList = null;
            this.mRootDataList = new java.util.ArrayList();
        }

        private java.io.File getRootDataFile() {
            return new java.io.File(android.os.Environment.getDataDirectory(), "system/root_scan.list");
        }

        private java.lang.String sha256(byte[] data) {
            if (data == null) {
                return null;
            }
            try {
                java.security.MessageDigest md = java.security.MessageDigest.getInstance("SHA-256");
                md.update(data);
                return bytesToString(md.digest());
            } catch (java.security.NoSuchAlgorithmException e) {
                android.util.Log.e("RootDetectReport", "sha256 algorithm failed");
                return null;
            }
        }

        private java.lang.String bytesToString(byte[] bytes) {
            if (bytes == null) {
                return null;
            }
            char[] hexChars = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
            char[] chars = new char[(bytes.length * 2)];
            for (int j = 0; j < bytes.length; j++) {
                int byteValue = bytes[j] & 255;
                chars[j * 2] = hexChars[byteValue >>> 4];
                chars[(j * 2) + 1] = hexChars[byteValue & 15];
            }
            return new java.lang.String(chars).toUpperCase(java.util.Locale.US);
        }

        private void writeRootData() {
            synchronized (this.mRootDataList) {
                java.io.FileOutputStream fos = null;
                try {
                    fos = new java.io.FileOutputStream(getRootDataFile());
                    java.io.BufferedOutputStream bos = new java.io.BufferedOutputStream(fos);
                    java.lang.StringBuilder sb = new java.lang.StringBuilder();
                    java.util.Iterator it = this.mRootDataList.iterator();
                    while (it.hasNext()) {
                        java.lang.String data = (java.lang.String) it.next();
                        sb.setLength(0);
                        sb.append(data);
                        sb.append(10);
                        bos.write(sb.toString().getBytes(java.nio.charset.StandardCharsets.UTF_8));
                    }
                    bos.flush();
                    libcore.io.IoUtils.closeQuietly(bos);
                } catch (java.io.IOException e) {
                    try {
                        android.util.Log.e("RootDetectReport", "Failed to write root result data");
                        libcore.io.IoUtils.closeQuietly(null);
                    } catch (Throwable th) {
                        libcore.io.IoUtils.closeQuietly(null);
                        libcore.io.IoUtils.closeQuietly(null);
                    }
                }
                libcore.io.IoUtils.closeQuietly(fos);
            }
        }

        /* JADX WARNING: Missing block: B:9:0x0020, code:
            return;
     */
        private void readRootData() {
            /*
            r8 = this;
            r0 = r8.mRootDataList;
            monitor-enter(r0);
            r1 = r8.mRootDataList;	 Catch:{ all -> 0x006c }
            r1.clear();	 Catch:{ all -> 0x006c }
            r1 = r8.getRootDataFile();	 Catch:{ all -> 0x006c }
            r2 = r1.exists();	 Catch:{ all -> 0x006c }
            if (r2 != 0) goto L_0x0021;
        L_0x0012:
            r2 = com.android.server.security.securitydiagnose.RootDetectReport.HW_DEBUG;	 Catch:{ all -> 0x006c }
            if (r2 == 0) goto L_0x001f;
        L_0x0018:
            r2 = "RootDetectReport";
            r3 = "readRootData file NOT exist!";
            android.util.Log.e(r2, r3);	 Catch:{ all -> 0x006c }
        L_0x001f:
            monitor-exit(r0);	 Catch:{ all -> 0x006c }
            return;
        L_0x0021:
            r2 = 0;
            r3 = r2;
            r4 = new java.io.BufferedReader;	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r5 = new java.io.InputStreamReader;	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r6 = new java.io.FileInputStream;	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r6.<init>(r1);	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r7 = "UTF-8";
            r5.<init>(r6, r7);	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r4.<init>(r5);	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r3 = r4;
        L_0x0036:
            r4 = r3.readLine();	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r2 = r4;
            r4 = android.text.TextUtils.isEmpty(r2);	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            if (r4 != 0) goto L_0x0046;
        L_0x0041:
            r4 = r8.mRootDataList;	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
            r4.add(r2);	 Catch:{ FileNotFoundException -> 0x005a, IOException -> 0x004e }
        L_0x0046:
            if (r2 != 0) goto L_0x0036;
        L_0x0048:
            libcore.io.IoUtils.closeQuietly(r3);	 Catch:{ all -> 0x006c }
            goto L_0x0065;
        L_0x004c:
            r2 = move-exception;
            goto L_0x0068;
        L_0x004e:
            r2 = move-exception;
            r4 = "RootDetectReport";
            r5 = "Failed to read root result list";
            android.util.Log.e(r4, r5);	 Catch:{ all -> 0x004c }
            libcore.io.IoUtils.closeQuietly(r3);	 Catch:{ all -> 0x006c }
            goto L_0x0065;
        L_0x005a:
            r2 = move-exception;
            r4 = "RootDetectReport";
            r5 = "file root result list cannot be found";
            android.util.Log.e(r4, r5);	 Catch:{ all -> 0x004c }
            libcore.io.IoUtils.closeQuietly(r3);	 Catch:{ all -> 0x006c }
            monitor-exit(r0);	 Catch:{ all -> 0x006c }
            return;
        L_0x0068:
            libcore.io.IoUtils.closeQuietly(r3);	 Catch:{ all -> 0x006c }
            throw r2;	 Catch:{ all -> 0x006c }
        L_0x006c:
            r1 = move-exception;
            monitor-exit(r0);	 Catch:{ all -> 0x006c }
            throw r1;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.securitydiagnose.RootDetectReport.RootDataBundle.readRootData():void");
        }

        public boolean hasSame(org.json.JSONObject data) {
            if (data == null) {
                android.util.Log.e("RootDetectReport", "hasSame The data is NULL!");
                return false;
            }
            readRootData();
            java.lang.String rootDataHash = null;
            try {
                rootDataHash = sha256(data.toString().getBytes("UTF-8"));
            } catch (java.io.UnsupportedEncodingException e) {
                android.util.Log.e("RootDetectReport", "hasSame encoding unsupported");
            }
            if (android.text.TextUtils.isEmpty(rootDataHash)) {
                android.util.Log.e("RootDetectReport", "hasSame HASHCODE is null!");
                return false;
            }
            if (com.android.server.security.securitydiagnose.RootDetectReport.HW_DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("hasSame rootDataHash = ");
                stringBuilder.append(rootDataHash);
                android.util.Log.d("RootDetectReport", stringBuilder.toString());
            }
            synchronized (this.mRootDataList) {
                if (!this.mRootDataList.isEmpty() && this.mRootDataList.contains(rootDataHash)) {
                    if (com.android.server.security.securitydiagnose.RootDetectReport.HW_DEBUG) {
                        android.util.Log.d("RootDetectReport", "addDataList has existed");
                    }
                    return true;
                } else if (this.mRootDataList.size() < 100) {
                    this.mRootDataList.add(rootDataHash);
                } else {
                    try {
                        this.mRootDataList.remove(0);
                        this.mRootDataList.add(rootDataHash);
                    } catch (java.lang.IndexOutOfBoundsException e2) {
                        android.util.Log.e("RootDetectReport", "IndexOutOfBoundsException");
                    }
                }
            }
            writeRootData();
            return false;
        }
    }

    static {
        boolean z;
        if (!(android.util.Log.HWINFO || RS_DEBUG)) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable("RootDetectReport", 4)) {
                z = false;
                HW_DEBUG = z;
            }
        }
        z = true;
        HW_DEBUG = z;
    }

    private void setRootStatusProperty(int rootstatus) {
        try {
            android.os.SystemProperties.set("persist.sys.root.status", java.lang.Integer.toString(rootstatus & -1025));
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setRootStatusProperty failed, stpGetStatusAllIDRetValue = ");
            stringBuilder.append(rootstatus & -1025);
            android.util.Log.e("RootDetectReport", stringBuilder.toString());
        }
    }

    public org.json.JSONObject parcelStpHidlRootData(int rootstatus) {
        org.json.JSONObject json = new org.json.JSONObject();
        try {
            json.put("ROOT_STATUS", rootstatus & -1025);
            int i = 0;
            json.put("ERR_CODE", 0);
            json.put("KCODE", (rootstatus & 1) > 0 ? 1 : 0);
            json.put("SYS_CALL", (rootstatus & 2) > 0 ? 1 : 0);
            json.put("SE_HOOKS", (rootstatus & 4) > 0 ? 1 : 0);
            json.put("SE_STATUS", (rootstatus & 8) > 0 ? 1 : 0);
            json.put("CHECK_SU", (rootstatus & 16) > 0 ? 1 : 0);
            json.put("SYS_RW", (rootstatus & 32) > 0 ? 1 : 0);
            json.put("CHECK_ADBD", (rootstatus & 64) > 0 ? 1 : 0);
            json.put("VB_STATUS", (rootstatus & 128) > 0 ? 1 : 0);
            json.put("CHECK_PROP", (rootstatus & 256) > 0 ? 1 : 0);
            java.lang.String str = "CHECK_SETIDS";
            if ((rootstatus & 512) > 0) {
                i = 1;
            }
            json.put(str, i);
            return json;
        } catch (org.json.JSONException e) {
            android.util.Log.e("RootDetectReport", "parcel root data, something wrong with the json object");
            return null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:59:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x011c  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0105  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0105  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x011c  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x011c  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0105  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0105  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x011c  */
    public int triggerRootScan() {
        /*
        r12 = this;
        r0 = 0;
        r1 = 1;
        r2 = 0;
        r3 = java.lang.System.currentTimeMillis();
        mStartTime = r3;
        r3 = r12.rootScanHasTrigger;
        r4 = 1;
        if (r3 != 0) goto L_0x00fb;
    L_0x000e:
        r3 = 0;
        r5 = new java.io.File;
        r6 = "/proc/root_scan";
        r5.<init>(r6);
        r6 = 0;
        r7 = 0;
        r8 = 0;
        r9 = new java.io.FileInputStream;	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r9.<init>(r5);	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r8 = r9;
        r9 = new java.io.InputStreamReader;	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r10 = "UTF-8";
        r9.<init>(r8, r10);	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r7 = r9;
        r9 = new java.io.BufferedReader;	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r9.<init>(r7);	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r6 = r9;
        r9 = r6.readLine();	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r3 = r9;
        if (r9 == 0) goto L_0x0043;
    L_0x0034:
        r9 = "^\\d{1,5}$";
        r9 = r3.matches(r9);	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        if (r9 == 0) goto L_0x0043;
    L_0x003c:
        r9 = java.lang.Integer.parseInt(r3);	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r0 = r9;
        r12.rootScanHasTrigger = r4;	 Catch:{ FileNotFoundException -> 0x0091, IOException -> 0x0075, NumberFormatException -> 0x0058 }
        r8.close();	 Catch:{ IOException -> 0x0048 }
        goto L_0x004b;
    L_0x0048:
        r9 = move-exception;
        goto L_0x00ae;
        r7.close();	 Catch:{ IOException -> 0x0048 }
        r6.close();	 Catch:{ IOException -> 0x0048 }
        goto L_0x00b8;
    L_0x0055:
        r4 = move-exception;
        goto L_0x00d8;
    L_0x0058:
        r9 = move-exception;
        r10 = "RootDetectReport";
        r11 = "some data is not of the type Integer during parsing trigger file";
        android.util.Log.e(r10, r11);	 Catch:{ all -> 0x0055 }
        r0 = -1;
        if (r8 == 0) goto L_0x006a;
    L_0x0064:
        r8.close();	 Catch:{ IOException -> 0x0068 }
        goto L_0x006a;
    L_0x0068:
        r9 = move-exception;
        goto L_0x00ae;
    L_0x006a:
        if (r7 == 0) goto L_0x006f;
    L_0x006c:
        r7.close();	 Catch:{ IOException -> 0x0068 }
    L_0x006f:
        if (r6 == 0) goto L_0x00b8;
    L_0x0071:
        r6.close();	 Catch:{ IOException -> 0x0068 }
        goto L_0x00b8;
    L_0x0075:
        r9 = move-exception;
        r10 = "RootDetectReport";
        r11 = "failed to read the trigger proc file";
        android.util.Log.e(r10, r11);	 Catch:{ all -> 0x0055 }
        r0 = -4;
        if (r8 == 0) goto L_0x0086;
    L_0x0080:
        r8.close();	 Catch:{ IOException -> 0x0084 }
        goto L_0x0086;
    L_0x0084:
        r9 = move-exception;
        goto L_0x00ae;
    L_0x0086:
        if (r7 == 0) goto L_0x008b;
    L_0x0088:
        r7.close();	 Catch:{ IOException -> 0x0084 }
    L_0x008b:
        if (r6 == 0) goto L_0x00b8;
    L_0x008d:
        r6.close();	 Catch:{ IOException -> 0x0084 }
        goto L_0x00b8;
    L_0x0091:
        r9 = move-exception;
        r10 = "RootDetectReport";
        r11 = "triggerRootScan, trigger file cannot be found";
        android.util.Log.e(r10, r11);	 Catch:{ all -> 0x0055 }
        r0 = -3;
        if (r8 == 0) goto L_0x00a3;
    L_0x009d:
        r8.close();	 Catch:{ IOException -> 0x00a1 }
        goto L_0x00a3;
    L_0x00a1:
        r9 = move-exception;
        goto L_0x00ae;
    L_0x00a3:
        if (r7 == 0) goto L_0x00a8;
    L_0x00a5:
        r7.close();	 Catch:{ IOException -> 0x00a1 }
    L_0x00a8:
        if (r6 == 0) goto L_0x00b8;
    L_0x00aa:
        r6.close();	 Catch:{ IOException -> 0x00a1 }
        goto L_0x00b8;
        r10 = "RootDetectReport";
        r11 = "failed to close the trigger proc file";
        android.util.Log.e(r10, r11);
        r0 = -4;
        goto L_0x00b9;
    L_0x00b9:
        libcore.io.IoUtils.closeQuietly(r6);
        r9 = HW_DEBUG;
        if (r9 == 0) goto L_0x00fb;
    L_0x00c1:
        r9 = "RootDetectReport";
        r10 = new java.lang.StringBuilder;
        r10.<init>();
        r11 = "bootcompleted trigger return value = ";
        r10.append(r11);
        r10.append(r0);
        r10 = r10.toString();
        android.util.Log.d(r9, r10);
        goto L_0x00fb;
        if (r8 == 0) goto L_0x00e1;
    L_0x00db:
        r8.close();	 Catch:{ IOException -> 0x00df }
        goto L_0x00e1;
    L_0x00df:
        r9 = move-exception;
        goto L_0x00ec;
    L_0x00e1:
        if (r7 == 0) goto L_0x00e6;
    L_0x00e3:
        r7.close();	 Catch:{ IOException -> 0x00df }
    L_0x00e6:
        if (r6 == 0) goto L_0x00f6;
    L_0x00e8:
        r6.close();	 Catch:{ IOException -> 0x00df }
        goto L_0x00f6;
        r10 = "RootDetectReport";
        r11 = "failed to close the trigger proc file";
        android.util.Log.e(r10, r11);
        r0 = -4;
        goto L_0x00f7;
    L_0x00f7:
        libcore.io.IoUtils.closeQuietly(r6);
        throw r4;
    L_0x00fb:
        r3 = com.android.server.security.securitydiagnose.AppLayerStpProxy.getInstance();
        r0 = r3.getRootStatusSync();
        if (r0 >= 0) goto L_0x011c;
    L_0x0105:
        r3 = "RootDetectReport";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "get root status by category failed. ret = ";
        r4.append(r5);
        r4.append(r0);
        r4 = r4.toString();
        android.util.Log.e(r3, r4);
        return r0;
    L_0x011c:
        if (r0 != 0) goto L_0x014c;
    L_0x011e:
        r12.setRootStatusProperty(r0);
        r3 = java.lang.System.currentTimeMillis();
        mEndTime = r3;
        r3 = HW_DEBUG;
        if (r3 == 0) goto L_0x014b;
    L_0x012b:
        r3 = "RootDetectReport";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "root status is ok, whole rootscan run TIME = ";
        r4.append(r5);
        r5 = mEndTime;
        r7 = mStartTime;
        r5 = r5 - r7;
        r4.append(r5);
        r5 = "ms";
        r4.append(r5);
        r4 = r4.toString();
        android.util.Log.d(r3, r4);
    L_0x014b:
        return r0;
    L_0x014c:
        r3 = com.android.server.security.securitydiagnose.AppLayerStpProxy.getInstance();
        r0 = r3.getEachItemRootStatus();
        if (r0 >= 0) goto L_0x016d;
    L_0x0156:
        r3 = "RootDetectReport";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "get each item root status failed. ret = ";
        r4.append(r5);
        r4.append(r0);
        r4 = r4.toString();
        android.util.Log.e(r3, r4);
        return r0;
    L_0x016d:
        r3 = HW_DEBUG;
        if (r3 == 0) goto L_0x0187;
    L_0x0171:
        r3 = "RootDetectReport";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "all item root scan result from hidl is:";
        r5.append(r6);
        r5.append(r0);
        r5 = r5.toString();
        android.util.Log.d(r3, r5);
    L_0x0187:
        r5 = java.lang.System.currentTimeMillis();
        mEndTime = r5;
        r3 = HW_DEBUG;
        if (r3 == 0) goto L_0x01b1;
    L_0x0191:
        r3 = "RootDetectReport";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "from trigger to receive the result run TIME =";
        r5.append(r6);
        r6 = mEndTime;
        r8 = mStartTime;
        r6 = r6 - r8;
        r5.append(r6);
        r6 = "ms";
        r5.append(r6);
        r5 = r5.toString();
        android.util.Log.d(r3, r5);
    L_0x01b1:
        r12.setRootStatusProperty(r0);
        r3 = r12.parcelStpHidlRootData(r0);
        if (r0 <= 0) goto L_0x01e8;
    L_0x01ba:
        r5 = new com.android.server.security.securitydiagnose.RootDetectReport$RootDataBundle;
        r5.<init>();
        r1 = r5.hasSame(r3);
        r6 = r1 ^ 1;
        r2 = r6;
        r6 = HW_DEBUG;
        if (r6 == 0) goto L_0x01e8;
    L_0x01ca:
        r6 = "RootDetectReport";
        r7 = new java.lang.StringBuilder;
        r7.<init>();
        r8 = "parcelStpHidlRootData hasSame = ";
        r7.append(r8);
        r7.append(r1);
        r8 = " needReport = ";
        r7.append(r8);
        r7.append(r2);
        r7 = r7.toString();
        android.util.Log.d(r6, r7);
    L_0x01e8:
        r5 = "RPROCS";
        r6 = r0 & 1024;
        if (r6 <= 0) goto L_0x01ef;
    L_0x01ee:
        goto L_0x01f0;
    L_0x01ef:
        r4 = 0;
    L_0x01f0:
        r3.put(r5, r4);	 Catch:{ JSONException -> 0x023f }
        r4 = HW_DEBUG;
        if (r4 == 0) goto L_0x020e;
    L_0x01f8:
        r4 = "RootDetectReport";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "parcelStpHidlRootData json = ";
        r5.append(r6);
        r5.append(r3);
        r5 = r5.toString();
        android.util.Log.d(r4, r5);
    L_0x020e:
        r4 = r12.mListener;
        r4.onRootReport(r3, r2);
        r4 = java.lang.System.currentTimeMillis();
        mEndTime = r4;
        r4 = HW_DEBUG;
        if (r4 == 0) goto L_0x023e;
    L_0x021d:
        r4 = "RootDetectReport";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "trigger root scan success!, whole rootscan run TIME = ";
        r5.append(r6);
        r6 = mEndTime;
        r8 = mStartTime;
        r6 = r6 - r8;
        r5.append(r6);
        r6 = "ms";
        r5.append(r6);
        r5 = r5.toString();
        android.util.Log.d(r4, r5);
    L_0x023e:
        return r0;
    L_0x023f:
        r4 = move-exception;
        r5 = "RootDetectReport";
        r6 = "proclist put error";
        android.util.Log.e(r5, r6);
        return r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.securitydiagnose.RootDetectReport.triggerRootScan():int");
    }

    void setListener(com.android.server.security.securitydiagnose.RootDetectReport.Listener listener) {
        this.mListener = listener;
    }

    private RootDetectReport(android.content.Context context) {
        this.mContext = context;
    }

    public static void init(android.content.Context context) {
        synchronized (com.android.server.security.securitydiagnose.RootDetectReport.class) {
            if (mInstance == null) {
                mInstance = new com.android.server.security.securitydiagnose.RootDetectReport(context);
            }
        }
    }

    public static com.android.server.security.securitydiagnose.RootDetectReport getInstance() {
        com.android.server.security.securitydiagnose.RootDetectReport rootDetectReport;
        synchronized (com.android.server.security.securitydiagnose.RootDetectReport.class) {
            rootDetectReport = mInstance;
        }
        return rootDetectReport;
    }
}
