package com.android.server.security.securityprofile;

public class PolicyEngine {
    private static final java.lang.String TAG = "SecurityProfileService";
    java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.Action> mActions = new java.util.HashMap();
    private com.android.server.security.securityprofile.PolicyDatabase mPolicyDatabase = null;
    java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.State> mStates = new java.util.HashMap();
    private java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.BBDNode> objectSubsystemOperationBBDNodes = new java.util.HashMap();
    private java.util.Map<java.lang.String, java.util.Set<java.lang.String>> subjectAndObjectLabels = new java.util.HashMap();
    private java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.BBDNode> subsystemOperationBBDNodes = new java.util.HashMap();

    public interface Action {
        void execute(int i);
    }

    abstract class BBDNode {
        public abstract void dump(java.lang.String str);

        abstract boolean evaluate(java.util.Set<java.lang.String> set, java.util.Set<java.lang.String> set2, boolean z, int i);

        abstract com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> map, java.util.Map<java.lang.String, java.lang.Boolean> map2, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> map3);

        BBDNode() {
        }

        protected java.util.Map bindValue(java.util.Map map, java.lang.Object key, java.lang.Boolean value) {
            java.util.Map result = new java.util.HashMap(map);
            result.put(key, value);
            return result;
        }
    }

    interface RuleToFallthrough {
        com.android.server.security.securityprofile.PolicyEngine.BBDNode getFallthrough(org.json.JSONObject jSONObject) throws org.json.JSONException;
    }

    interface RuleToKey {
        java.lang.String getKey(org.json.JSONObject jSONObject) throws org.json.JSONException;
    }

    public interface State {
        boolean evaluate();
    }

    class ActionNode extends com.android.server.security.securityprofile.PolicyEngine.BBDNode {
        com.android.server.security.securityprofile.PolicyEngine.Action action;
        com.android.server.security.securityprofile.PolicyEngine.BBDNode afterNode;

        public ActionNode(com.android.server.security.securityprofile.PolicyEngine.Action a, com.android.server.security.securityprofile.PolicyEngine.BBDNode an) {
            super();
            this.action = a;
            this.afterNode = an;
        }

        boolean evaluate(java.util.Set<java.lang.String> subjectLabels, java.util.Set<java.lang.String> objectLabels, boolean sideEffectsAllowed, int timeout) {
            if (sideEffectsAllowed) {
                this.action.execute(timeout);
            }
            return this.afterNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
        }

        com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> subjectLabelBindings, java.util.Map<java.lang.String, java.lang.Boolean> objectLabelBindings, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> map) {
            return new com.android.server.security.securityprofile.PolicyEngine.ActionNode(this.action, this.afterNode.optimize(subjectLabelBindings, objectLabelBindings, new java.util.HashMap()));
        }

        public void dump(java.lang.String indent) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(java.lang.String.valueOf(this.action.getClass()));
            android.util.Slog.d("SecurityProfileService", stringBuilder.toString());
            com.android.server.security.securityprofile.PolicyEngine.BBDNode bBDNode = this.afterNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
        }

        public boolean equals(java.lang.Object o) {
            return (o instanceof com.android.server.security.securityprofile.PolicyEngine.ActionNode) && ((com.android.server.security.securityprofile.PolicyEngine.ActionNode) o).action.equals(this.action) && ((com.android.server.security.securityprofile.PolicyEngine.ActionNode) o).afterNode.equals(this.afterNode);
        }
    }

    class BooleanNode extends com.android.server.security.securityprofile.PolicyEngine.BBDNode {
        boolean value;

        public BooleanNode(boolean v) {
            super();
            this.value = v;
        }

        boolean evaluate(java.util.Set<java.lang.String> set, java.util.Set<java.lang.String> set2, boolean sideEffectsAllowed, int timeout) {
            return this.value;
        }

        com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> map, java.util.Map<java.lang.String, java.lang.Boolean> map2, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> map3) {
            return this;
        }

        public void dump(java.lang.String indent) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(java.lang.String.valueOf(this.value));
            android.util.Slog.d("SecurityProfileService", stringBuilder.toString());
        }

        public boolean equals(java.lang.Object o) {
            return (o instanceof com.android.server.security.securityprofile.PolicyEngine.BooleanNode) && ((com.android.server.security.securityprofile.PolicyEngine.BooleanNode) o).value == this.value;
        }
    }

    class ObjectNode extends com.android.server.security.securityprofile.PolicyEngine.BBDNode {
        com.android.server.security.securityprofile.PolicyEngine.BBDNode falseNode;
        java.lang.String label;
        com.android.server.security.securityprofile.PolicyEngine.BBDNode trueNode;

        public ObjectNode(java.lang.String l, com.android.server.security.securityprofile.PolicyEngine.BBDNode tn, com.android.server.security.securityprofile.PolicyEngine.BBDNode fn) {
            super();
            this.label = l;
            this.trueNode = tn;
            this.falseNode = fn;
        }

        boolean evaluate(java.util.Set<java.lang.String> subjectLabels, java.util.Set<java.lang.String> objectLabels, boolean sideEffectsAllowed, int timeout) {
            if (objectLabels.contains(this.label)) {
                return this.trueNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
            }
            return this.falseNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
        }

        com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> subjectLabelBindings, java.util.Map<java.lang.String, java.lang.Boolean> objectLabelBindings, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> stateBindings) {
            if (!objectLabelBindings.containsKey(this.label)) {
                com.android.server.security.securityprofile.PolicyEngine.BBDNode t = this.trueNode.optimize(subjectLabelBindings, bindValue(objectLabelBindings, this.label, java.lang.Boolean.valueOf(true)), stateBindings);
                com.android.server.security.securityprofile.PolicyEngine.BBDNode f = this.falseNode.optimize(subjectLabelBindings, bindValue(objectLabelBindings, this.label, java.lang.Boolean.valueOf(false)), stateBindings);
                if (t.equals(f)) {
                    return t;
                }
                return new com.android.server.security.securityprofile.PolicyEngine.ObjectNode(this.label, t, f);
            } else if (((java.lang.Boolean) objectLabelBindings.get(this.label)).booleanValue()) {
                return this.trueNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            } else {
                return this.falseNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            }
        }

        public void dump(java.lang.String indent) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(java.lang.String.valueOf(this.label));
            android.util.Slog.d("SecurityProfileService", stringBuilder.toString());
            com.android.server.security.securityprofile.PolicyEngine.BBDNode bBDNode = this.trueNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
            bBDNode = this.falseNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
        }

        public boolean equals(java.lang.Object o) {
            return (o instanceof com.android.server.security.securityprofile.PolicyEngine.ObjectNode) && ((com.android.server.security.securityprofile.PolicyEngine.ObjectNode) o).label.equals(this.label) && ((com.android.server.security.securityprofile.PolicyEngine.ObjectNode) o).trueNode.equals(this.trueNode) && ((com.android.server.security.securityprofile.PolicyEngine.ObjectNode) o).falseNode.equals(this.falseNode);
        }
    }

    class StateNode extends com.android.server.security.securityprofile.PolicyEngine.BBDNode {
        com.android.server.security.securityprofile.PolicyEngine.BBDNode falseNode;
        com.android.server.security.securityprofile.PolicyEngine.State state;
        com.android.server.security.securityprofile.PolicyEngine.BBDNode trueNode;

        public StateNode(com.android.server.security.securityprofile.PolicyEngine.State s, com.android.server.security.securityprofile.PolicyEngine.BBDNode tn, com.android.server.security.securityprofile.PolicyEngine.BBDNode fn) {
            super();
            this.state = s;
            this.trueNode = tn;
            this.falseNode = fn;
        }

        boolean evaluate(java.util.Set<java.lang.String> subjectLabels, java.util.Set<java.lang.String> objectLabels, boolean sideEffectsAllowed, int timeout) {
            if (this.state.evaluate()) {
                return this.trueNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
            }
            return this.falseNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
        }

        com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> subjectLabelBindings, java.util.Map<java.lang.String, java.lang.Boolean> objectLabelBindings, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> stateBindings) {
            if (!stateBindings.containsKey(this.state)) {
                com.android.server.security.securityprofile.PolicyEngine.BBDNode t = this.trueNode.optimize(subjectLabelBindings, objectLabelBindings, bindValue(stateBindings, this.state, java.lang.Boolean.valueOf(true)));
                com.android.server.security.securityprofile.PolicyEngine.BBDNode f = this.falseNode.optimize(subjectLabelBindings, objectLabelBindings, bindValue(stateBindings, this.state, java.lang.Boolean.valueOf(false)));
                if (t.equals(f)) {
                    return t;
                }
                return new com.android.server.security.securityprofile.PolicyEngine.StateNode(this.state, t, f);
            } else if (((java.lang.Boolean) stateBindings.get(this.state)).booleanValue()) {
                return this.trueNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            } else {
                return this.falseNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            }
        }

        public void dump(java.lang.String indent) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(java.lang.String.valueOf(this.state.getClass()));
            android.util.Slog.d("SecurityProfileService", stringBuilder.toString());
            com.android.server.security.securityprofile.PolicyEngine.BBDNode bBDNode = this.trueNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
            bBDNode = this.falseNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
        }

        public boolean equals(java.lang.Object o) {
            return (o instanceof com.android.server.security.securityprofile.PolicyEngine.StateNode) && ((com.android.server.security.securityprofile.PolicyEngine.StateNode) o).state.equals(this.state) && ((com.android.server.security.securityprofile.PolicyEngine.StateNode) o).trueNode.equals(this.trueNode) && ((com.android.server.security.securityprofile.PolicyEngine.StateNode) o).falseNode.equals(this.falseNode);
        }
    }

    class SubjectNode extends com.android.server.security.securityprofile.PolicyEngine.BBDNode {
        com.android.server.security.securityprofile.PolicyEngine.BBDNode falseNode;
        java.lang.String label;
        com.android.server.security.securityprofile.PolicyEngine.BBDNode trueNode;

        public SubjectNode(java.lang.String l, com.android.server.security.securityprofile.PolicyEngine.BBDNode tn, com.android.server.security.securityprofile.PolicyEngine.BBDNode fn) {
            super();
            this.label = l;
            this.trueNode = tn;
            this.falseNode = fn;
        }

        boolean evaluate(java.util.Set<java.lang.String> subjectLabels, java.util.Set<java.lang.String> objectLabels, boolean sideEffectsAllowed, int timeout) {
            if (subjectLabels.contains(this.label)) {
                return this.trueNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
            }
            return this.falseNode.evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
        }

        com.android.server.security.securityprofile.PolicyEngine.BBDNode optimize(java.util.Map<java.lang.String, java.lang.Boolean> subjectLabelBindings, java.util.Map<java.lang.String, java.lang.Boolean> objectLabelBindings, java.util.Map<com.android.server.security.securityprofile.PolicyEngine.State, java.lang.Boolean> stateBindings) {
            if (!subjectLabelBindings.containsKey(this.label)) {
                com.android.server.security.securityprofile.PolicyEngine.BBDNode t = this.trueNode.optimize(bindValue(subjectLabelBindings, this.label, java.lang.Boolean.valueOf(true)), objectLabelBindings, stateBindings);
                com.android.server.security.securityprofile.PolicyEngine.BBDNode f = this.falseNode.optimize(bindValue(subjectLabelBindings, this.label, java.lang.Boolean.valueOf(false)), objectLabelBindings, stateBindings);
                if (t.equals(f)) {
                    return t;
                }
                return new com.android.server.security.securityprofile.PolicyEngine.SubjectNode(this.label, t, f);
            } else if (((java.lang.Boolean) subjectLabelBindings.get(this.label)).booleanValue()) {
                return this.trueNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            } else {
                return this.falseNode.optimize(subjectLabelBindings, objectLabelBindings, stateBindings);
            }
        }

        public void dump(java.lang.String indent) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(java.lang.String.valueOf(this.label));
            android.util.Slog.d("SecurityProfileService", stringBuilder.toString());
            com.android.server.security.securityprofile.PolicyEngine.BBDNode bBDNode = this.trueNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
            bBDNode = this.falseNode;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(indent);
            stringBuilder.append(" ");
            bBDNode.dump(stringBuilder.toString());
        }

        public boolean equals(java.lang.Object o) {
            return (o instanceof com.android.server.security.securityprofile.PolicyEngine.SubjectNode) && ((com.android.server.security.securityprofile.PolicyEngine.SubjectNode) o).label.equals(this.label) && ((com.android.server.security.securityprofile.PolicyEngine.SubjectNode) o).trueNode.equals(this.trueNode) && ((com.android.server.security.securityprofile.PolicyEngine.SubjectNode) o).falseNode.equals(this.falseNode);
        }
    }

    private void addLabeltoLookup(java.lang.String subjectOrObject, java.lang.String label) {
        if (!this.subjectAndObjectLabels.containsKey(subjectOrObject)) {
            this.subjectAndObjectLabels.put(subjectOrObject, new java.util.HashSet());
        }
        ((java.util.Set) this.subjectAndObjectLabels.get(subjectOrObject)).add(label);
    }

    private void addRuleSubjectAndObjectToLabelLookup(org.json.JSONObject rule) throws org.json.JSONException {
        java.lang.String subject = rule.getString("subject");
        java.lang.String object = rule.getString("object");
        addLabeltoLookup(subject, subject);
        addLabeltoLookup(object, object);
    }

    private void addRulesToLookup(org.json.JSONArray rules, com.android.server.security.securityprofile.PolicyEngine.RuleToFallthrough ruleToFallthrough, java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.BBDNode> lookup, com.android.server.security.securityprofile.PolicyEngine.RuleToKey ruleToKey) {
        org.json.JSONArray jSONArray = rules;
        java.util.Map<java.lang.String, com.android.server.security.securityprofile.PolicyEngine.BBDNode> map = lookup;
        com.android.server.security.securityprofile.PolicyEngine.RuleToKey ruleToKey2 = ruleToKey;
        int i = rules.length() - 1;
        while (true) {
            int i2 = i;
            if (i2 >= 0) {
                try {
                    java.lang.String key = ruleToKey2.getKey(jSONArray.getJSONObject(i2));
                    if (!map.containsKey(key)) {
                        com.android.server.security.securityprofile.PolicyEngine.BBDNode fallThrough = ruleToFallthrough.getFallthrough(jSONArray.getJSONObject(i2));
                        int j = i2;
                        while (j >= 0) {
                            org.json.JSONObject rule = jSONArray.getJSONObject(j);
                            addRuleSubjectAndObjectToLabelLookup(rule);
                            java.lang.String decision = rule.getString("decision");
                            java.lang.String ruleSubject = rule.getString("subject");
                            java.lang.String ruleObject = rule.getString("object");
                            if (key.equals(ruleToKey2.getKey(rule))) {
                                com.android.server.security.securityprofile.PolicyEngine.BBDNode match;
                                if (decision.equals("deny")) {
                                    match = new com.android.server.security.securityprofile.PolicyEngine.BooleanNode(false);
                                } else {
                                    match = new com.android.server.security.securityprofile.PolicyEngine.BooleanNode(true);
                                }
                                if (decision.equals("allowafter") || decision.equals("allowif")) {
                                    com.android.server.security.securityprofile.PolicyEngine.State state = (com.android.server.security.securityprofile.PolicyEngine.State) this.mStates.get(rule.getJSONObject("conditions").getString("state"));
                                    if (state == null) {
                                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                        stringBuilder.append("Missing state handler for ");
                                        stringBuilder.append(rule.getJSONObject("conditions").getString("state"));
                                        android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
                                    } else {
                                        match = new com.android.server.security.securityprofile.PolicyEngine.StateNode(state, match, fallThrough);
                                    }
                                }
                                if (decision.equals("allowafter")) {
                                    com.android.server.security.securityprofile.PolicyEngine.Action action = (com.android.server.security.securityprofile.PolicyEngine.Action) this.mActions.get(rule.getJSONObject("conditions").getJSONObject("action").getString("name"));
                                    if (action == null) {
                                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                        stringBuilder2.append("Missing state handler for ");
                                        stringBuilder2.append(rule.getJSONObject("conditions").getJSONObject("action").getString("name"));
                                        android.util.Slog.e("SecurityProfileService", stringBuilder2.toString());
                                    } else {
                                        match = new com.android.server.security.securityprofile.PolicyEngine.ActionNode(action, match);
                                    }
                                }
                                if (!ruleObject.equals("ANY")) {
                                    match = new com.android.server.security.securityprofile.PolicyEngine.ObjectNode(ruleObject, match, fallThrough);
                                }
                                if (!ruleSubject.equals("ANY")) {
                                    match = new com.android.server.security.securityprofile.PolicyEngine.SubjectNode(ruleSubject, match, fallThrough);
                                }
                                fallThrough = match;
                            }
                            j--;
                            jSONArray = rules;
                            ruleToKey2 = ruleToKey;
                            com.android.server.security.securityprofile.PolicyEngine.RuleToFallthrough ruleToFallthrough2 = ruleToFallthrough;
                        }
                        map.put(key, fallThrough.optimize(new java.util.HashMap(), new java.util.HashMap(), new java.util.HashMap()));
                    }
                } catch (org.json.JSONException e) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("addRulesToLookup err:");
                    stringBuilder3.append(e.getMessage());
                    android.util.Slog.e("SecurityProfileService", stringBuilder3.toString());
                }
                i = i2 - 1;
                jSONArray = rules;
                ruleToKey2 = ruleToKey;
            } else {
                return;
            }
        }
    }

    public void createLookup() {
        java.lang.StringBuilder stringBuilder;
        synchronized (this.mPolicyDatabase) {
            this.subsystemOperationBBDNodes = new java.util.HashMap();
            this.objectSubsystemOperationBBDNodes = new java.util.HashMap();
            this.subjectAndObjectLabels = new java.util.HashMap();
            org.json.JSONObject activePolicy = this.mPolicyDatabase.getPolicy();
            try {
                addRulesToLookup(activePolicy.getJSONArray("rules"), new com.android.server.security.securityprofile.-$$Lambda$PolicyEngine$Ev97TXuQjn_50nSgWsrnm2ZJAmk(this), this.subsystemOperationBBDNodes, com.android.server.security.securityprofile.-$$Lambda$PolicyEngine$y8ZWBmdZk6eAk13PmjJk7plltsI.INSTANCE);
                try {
                    java.util.Iterator<java.lang.String> keys = activePolicy.getJSONObject("domains").keys();
                    while (keys.hasNext()) {
                        java.lang.String packageName = (java.lang.String) keys.next();
                        try {
                            org.json.JSONArray labels = activePolicy.getJSONObject("domains").getJSONObject(packageName).getJSONArray("labels");
                            for (int i = 0; i < labels.length(); i++) {
                                addLabeltoLookup(packageName, labels.getString(i));
                            }
                            org.json.JSONArray rules = activePolicy.getJSONObject("domains").getJSONObject(packageName).optJSONArray("rules");
                            if (rules != null) {
                                addRulesToLookup(rules, new com.android.server.security.securityprofile.-$$Lambda$PolicyEngine$x44nI3x7YQL8Bb-A3B4e32udp1g(this), this.objectSubsystemOperationBBDNodes, com.android.server.security.securityprofile.-$$Lambda$PolicyEngine$5_CQ6157GdeIWUC0jG5xZWuUJZM.INSTANCE);
                            }
                        } catch (org.json.JSONException e) {
                            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                            stringBuilder2.append("packageName:");
                            stringBuilder2.append(packageName);
                            stringBuilder2.append(",err:");
                            stringBuilder2.append(e.getMessage());
                            android.util.Slog.e("SecurityProfileService", stringBuilder2.toString());
                        }
                    }
                } catch (org.json.JSONException e2) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("rules err:");
                    stringBuilder.append(e2.getMessage());
                    android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
                }
            } catch (java.lang.Exception e3) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("createLookup err:");
                stringBuilder.append(e3.getMessage());
                android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
            }
        }
    }

    static /* synthetic */ java.lang.String lambda$createLookup$1(org.json.JSONObject rule) throws org.json.JSONException {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(rule.getString("subsystem"));
        stringBuilder.append(rule.getString("operation"));
        return stringBuilder.toString();
    }

    public static /* synthetic */ com.android.server.security.securityprofile.PolicyEngine.BBDNode lambda$createLookup$2(com.android.server.security.securityprofile.PolicyEngine policyEngine, org.json.JSONObject rule) throws org.json.JSONException {
        java.util.Map map = policyEngine.subsystemOperationBBDNodes;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(rule.getString("subsystem"));
        stringBuilder.append(rule.getString("operation"));
        return (com.android.server.security.securityprofile.PolicyEngine.BBDNode) map.getOrDefault(stringBuilder.toString(), new com.android.server.security.securityprofile.PolicyEngine.BooleanNode(false));
    }

    static /* synthetic */ java.lang.String lambda$createLookup$3(org.json.JSONObject rule) throws org.json.JSONException {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(rule.getString("object"));
        stringBuilder.append(rule.getString("subsystem"));
        stringBuilder.append(rule.getString("operation"));
        return stringBuilder.toString();
    }

    public PolicyEngine(android.content.Context context) {
        this.mPolicyDatabase = new com.android.server.security.securityprofile.PolicyDatabase(context);
    }

    public void start() {
        createLookup();
    }

    public void addPolicy(org.json.JSONObject policy) {
        synchronized (this.mPolicyDatabase) {
            this.mPolicyDatabase.addPolicy(policy);
            createLookup();
        }
    }

    public void addBlackApp(java.util.List<java.lang.String> packageList) {
        if (packageList != null) {
            if (this.mPolicyDatabase != null) {
                synchronized (this.mPolicyDatabase) {
                    this.mPolicyDatabase.addLabel(packageList, "Black");
                    createLookup();
                }
            }
        }
    }

    public void removeBlackApp(java.util.List<java.lang.String> packageList) {
        if (packageList != null) {
            if (this.mPolicyDatabase != null) {
                synchronized (this.mPolicyDatabase) {
                    this.mPolicyDatabase.removeLabel(packageList, "Black");
                    createLookup();
                }
            }
        }
    }

    public void updateBlackApp(java.util.List<java.lang.String> packageList) {
        if (packageList != null) {
            if (this.mPolicyDatabase != null) {
                synchronized (this.mPolicyDatabase) {
                    this.mPolicyDatabase.removeLabel("Black");
                    this.mPolicyDatabase.addLabel(packageList, "Black");
                    createLookup();
                }
            }
        }
    }

    public void updatePackageInformation(java.lang.String packageName) {
        synchronized (this.mPolicyDatabase) {
            this.mPolicyDatabase.updatePackageInformation(packageName);
            createLookup();
        }
    }

    protected void setPackageSigned(java.lang.String packageName, boolean isPackageSigned) {
        this.mPolicyDatabase.setPackageSigned(packageName, isPackageSigned);
    }

    private boolean hasLabel(java.lang.String packageName, java.lang.String label) {
        return ((java.util.Set) this.subjectAndObjectLabels.getOrDefault(packageName, new java.util.HashSet())).contains(label);
    }

    public void addState(java.lang.String name, com.android.server.security.securityprofile.PolicyEngine.State state) {
        this.mStates.put(name, state);
    }

    public void addAction(java.lang.String name, com.android.server.security.securityprofile.PolicyEngine.Action action) {
        this.mActions.put(name, action);
    }

    private boolean findRulesAndEvaluate(java.lang.String subject, java.lang.String object, java.lang.String extraObjectLabel, java.lang.String subsystem, java.lang.String operation, boolean sideEffectsAllowed, int timeout) {
        try {
            java.util.Set<java.lang.String> subjectLabels = (java.util.Set) this.subjectAndObjectLabels.getOrDefault(subject, new java.util.HashSet());
            java.util.Set<java.lang.String> objectLabels = (java.util.Set) this.subjectAndObjectLabels.getOrDefault(object, new java.util.HashSet());
            if (extraObjectLabel != null) {
                objectLabels.add(extraObjectLabel);
            }
            java.util.Map map = this.objectSubsystemOperationBBDNodes;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(object);
            stringBuilder.append(subsystem);
            stringBuilder.append(operation);
            if (map.containsKey(stringBuilder.toString())) {
                map = this.objectSubsystemOperationBBDNodes;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(object);
                stringBuilder.append(subsystem);
                stringBuilder.append(operation);
                return ((com.android.server.security.securityprofile.PolicyEngine.BBDNode) map.get(stringBuilder.toString())).evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
            }
            map = this.subsystemOperationBBDNodes;
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(subsystem);
            stringBuilder.append(operation);
            if (map.containsKey(stringBuilder.toString())) {
                map = this.subsystemOperationBBDNodes;
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(subsystem);
                stringBuilder.append(operation);
                return ((com.android.server.security.securityprofile.PolicyEngine.BBDNode) map.get(stringBuilder.toString())).evaluate(subjectLabels, objectLabels, sideEffectsAllowed, timeout);
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(subsystem);
            stringBuilder.append(operation);
            android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
            return true;
        } catch (java.lang.Exception e) {
            android.util.Slog.e("SecurityProfileService", e.getMessage());
            return true;
        }
    }

    public boolean checkAccess(java.lang.String subject, java.lang.String object, java.lang.String subsystem, java.lang.String operation) {
        return findRulesAndEvaluate(subject, object, null, subsystem, operation, false, 0);
    }

    public boolean requestAccessWithExtraLabel(java.lang.String subject, java.lang.String object, java.lang.String extraObjectLabel, java.lang.String subsystem, java.lang.String operation, int timeout) {
        return findRulesAndEvaluate(subject, object, extraObjectLabel, subsystem, operation, true, timeout);
    }

    public boolean requestAccess(java.lang.String subject, java.lang.String object, java.lang.String subsystem, java.lang.String operation, int timeout) {
        return requestAccessWithExtraLabel(subject, object, null, subsystem, operation, timeout);
    }

    public java.util.List<java.lang.String> getLabels(java.lang.String packageName, huawei.android.security.securityprofile.ApkDigest apkDigest) {
        return this.mPolicyDatabase.getLabels(packageName, apkDigest);
    }

    public boolean isBlackApp(java.lang.String packageName) {
        return hasLabel(packageName, "Black");
    }

    public boolean isNewVersionFirstBoot() {
        return this.mPolicyDatabase.isNewVersionFirstBoot();
    }

    public boolean isPackageSigned(java.lang.String packageName) {
        return this.mPolicyDatabase.isPackageSigned(packageName);
    }
}
