package com.android.server.security.securityprofile;

class PolicyStorage {
    private static final java.lang.String HMAC_SHA_ALGORITHM = "HmacSHA256";
    private static final java.lang.String KEY_PREFIX = "SecurityProfileDB";
    private static final int PIECE_SIZE = 16384;
    public static final java.lang.String TAG = "SecurityProfileDB";
    private static final java.lang.String TRANSFORMATION = "AES/GCM/NoPadding";
    private java.lang.String databaseName = "/data/system/securityprofile.json";
    private java.lang.String defaultContent;
    private javax.crypto.SecretKey key;
    private java.lang.String keyName = null;
    private java.nio.file.Path mFile;

    public PolicyStorage(java.lang.String dbName, java.lang.String content) {
        this.databaseName = dbName;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("SecurityProfileDB");
        stringBuilder.append(dbName);
        this.keyName = stringBuilder.toString();
        this.defaultContent = content;
        this.mFile = java.nio.file.Paths.get(this.databaseName, new java.lang.String[0]);
        initKey();
    }

    private void initKey() {
        if (!getKey(false)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("initKey get no old key , I must delete file:");
            stringBuilder.append(this.mFile);
            android.util.Slog.e("SecurityProfileDB", stringBuilder.toString());
            try {
                if (java.nio.file.Files.exists(this.mFile, new java.nio.file.LinkOption[0])) {
                    java.nio.file.Files.delete(this.mFile);
                }
            } catch (java.lang.Exception e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("initKey delete file error exception: ");
                stringBuilder.append(e.getMessage());
                android.util.Slog.e("SecurityProfileDB", stringBuilder.toString());
            }
            if (getKey(true)) {
                android.util.Slog.i("SecurityProfileDB", "initKey create new key Succ!");
            } else {
                android.util.Slog.e("SecurityProfileDB", "initKey create new key failed!");
            }
        }
        android.util.Slog.i("SecurityProfileDB", "initKey end!");
    }

    private boolean getKey(boolean create) {
        boolean z = false;
        if (create) {
            try {
                javax.crypto.KeyGenerator kg = javax.crypto.KeyGenerator.getInstance("AES");
                kg.init(new java.security.SecureRandom());
                java.security.KeyStore ks = java.security.KeyStore.getInstance("AndroidKeyStore");
                ks.load(null);
                ks.deleteEntry(this.keyName);
                ks.setEntry(this.keyName, new java.security.KeyStore.SecretKeyEntry(kg.generateKey()), new android.security.keystore.KeyProtection.Builder(3).setBlockModes(new java.lang.String[]{"GCM"}).setEncryptionPaddings(new java.lang.String[]{"NoPadding"}).setCriticalToDeviceEncryption(true).build());
                this.key = (javax.crypto.SecretKey) ks.getKey(this.keyName, null);
                android.util.Slog.i("SecurityProfileDB", "getKey create new key end!");
            } catch (java.lang.Exception e) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getKey exception");
                stringBuilder.append(e.getMessage());
                android.util.Slog.e("SecurityProfileDB", stringBuilder.toString());
                this.key = null;
                return false;
            }
        }
        java.security.KeyStore ks2 = java.security.KeyStore.getInstance("AndroidKeyStore");
        ks2.load(null);
        this.key = (javax.crypto.SecretKey) ks2.getKey(this.keyName, null);
        if (this.key != null) {
            z = true;
        }
        return z;
    }

    private static java.lang.String toHexString(byte[] bytes) {
        java.util.Formatter formatter = new java.util.Formatter();
        int length = bytes.length;
        for (int i = 0; i < length; i++) {
            formatter.format("%02x", new java.lang.Object[]{java.lang.Byte.valueOf(bytes[i])});
        }
        return formatter.toString();
    }

    private byte[] bufferedDoFinal(javax.crypto.Cipher cipher, byte[] data) throws java.io.IOException, javax.crypto.BadPaddingException, javax.crypto.IllegalBlockSizeException {
        byte[] out;
        java.io.ByteArrayOutputStream output = new java.io.ByteArrayOutputStream();
        int offset = 0;
        while (offset + 16384 <= data.length) {
            out = cipher.update(data, offset, 16384);
            if (out != null) {
                output.write(out);
            }
            offset += 16384;
        }
        out = cipher.doFinal(data, offset, data.length - offset);
        if (out != null) {
            output.write(out);
        }
        return output.toByteArray();
    }

    public void writeDatabase(org.json.JSONObject policy) {
        try {
            java.lang.String json = policy.toString(4);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("writing: ");
            stringBuilder.append(json);
            android.util.Slog.d("SecurityProfileDB", stringBuilder.toString());
            javax.crypto.Cipher cipher = javax.crypto.Cipher.getInstance("AES/GCM/NoPadding");
            cipher.init(1, this.key);
            byte[] iv = cipher.getIV();
            byte[] cipherText = bufferedDoFinal(cipher, json.getBytes(java.nio.charset.StandardCharsets.UTF_8));
            java.nio.ByteBuffer byteBuffer = java.nio.ByteBuffer.allocate((4 + iv.length) + cipherText.length);
            byteBuffer.putInt(iv.length);
            byteBuffer.put(iv);
            byteBuffer.put(cipherText);
            java.nio.file.Files.write(this.mFile, byteBuffer.array(), new java.nio.file.OpenOption[0]);
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("write database exception");
            stringBuilder2.append(e.getMessage());
            android.util.Slog.e("SecurityProfileDB", stringBuilder2.toString());
        }
    }

    private java.lang.String readAndVerifyDatabase() throws java.lang.Exception {
        java.nio.ByteBuffer byteBuffer = java.nio.ByteBuffer.wrap(java.nio.file.Files.readAllBytes(this.mFile));
        int ivLength = byteBuffer.getInt();
        if (ivLength < 0 || ivLength > 64) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("readAndVerifyDatabase too large IV length err,ivLength:");
            stringBuilder.append(ivLength);
            stringBuilder.append(", mFile:");
            stringBuilder.append(this.mFile);
            android.util.Slog.e("SecurityProfileDB", stringBuilder.toString());
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("Too large IV length:");
            stringBuilder2.append(ivLength);
            throw new java.security.InvalidAlgorithmParameterException(stringBuilder2.toString());
        }
        byte[] iv = new byte[ivLength];
        byteBuffer.get(iv);
        byte[] cipherText = new byte[byteBuffer.remaining()];
        byteBuffer.get(cipherText);
        javax.crypto.Cipher cipher = javax.crypto.Cipher.getInstance("AES/GCM/NoPadding");
        cipher.init(2, this.key, new javax.crypto.spec.GCMParameterSpec(128, iv));
        return new java.lang.String(bufferedDoFinal(cipher, cipherText), java.nio.charset.StandardCharsets.UTF_8);
    }

    public org.json.JSONObject parseJSON(java.lang.String json) {
        if (json == null) {
            return null;
        }
        try {
            return new org.json.JSONObject(json);
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("parseJSON err:");
            stringBuilder.append(e.getMessage());
            android.util.Slog.e("SecurityProfileDB", stringBuilder.toString());
            return null;
        }
    }

    public org.json.JSONObject readDatabase() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("readDabase file:");
        stringBuilder.append(this.mFile);
        android.util.Slog.d("SecurityProfileDB", stringBuilder.toString());
        java.lang.StringBuilder stringBuilder2;
        try {
            if (java.nio.file.Files.exists(this.mFile, new java.nio.file.LinkOption[0])) {
                java.lang.String json = readAndVerifyDatabase();
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append(this.mFile);
                stringBuilder2.append(" read:\n");
                stringBuilder2.append(json);
                android.util.Slog.d("SecurityProfileDB", stringBuilder2.toString());
                return parseJSON(json);
            } else if (this.defaultContent == null) {
                return null;
            } else {
                org.json.JSONObject policy = parseJSON(this.defaultContent);
                writeDatabase(policy);
                return policy;
            }
        } catch (java.lang.Exception e) {
            stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("readDabase exception: ");
            stringBuilder2.append(e.getMessage());
            android.util.Slog.e("SecurityProfileDB", stringBuilder2.toString());
            return parseJSON(this.defaultContent);
        }
    }
}
