package com.android.server.security.securityprofile;

public class PolicyVerifier {
    private static final java.lang.String TAG = "SecurityProfileService";

    public static boolean packageHasValidPolicy(java.lang.String packageName, java.lang.String apkPath) {
        java.lang.StringBuilder stringBuilder;
        if (apkPath == null) {
            return false;
        }
        try {
            byte[] jws = huawei.android.security.securityprofile.PolicyExtractor.getPolicy(apkPath);
            huawei.android.security.securityprofile.ApkDigest apkDigest = huawei.android.security.securityprofile.PolicyExtractor.getDigest(packageName, jws);
            if (verifyAndDecodePolicy(jws) == null) {
                android.util.Slog.e("SecurityProfileService", "Policy verification failed");
                return false;
            } else if (huawei.android.security.securityprofile.DigestMatcher.packageMatchesDigest(apkPath, apkDigest)) {
                return true;
            } else {
                android.util.Slog.e("SecurityProfileService", "Package digest did not match policy digest");
                return false;
            }
        } catch (huawei.android.security.securityprofile.PolicyExtractor.PolicyNotFoundException e) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Not found Exception ");
            stringBuilder.append(e.getMessage());
            android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
            return false;
        } catch (java.io.IOException e2) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("packageHasValidPolicy IOException:");
            stringBuilder.append(e2.getMessage());
            android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
            return false;
        } catch (java.lang.Exception e3) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("packageHasValidPolicy Exception:");
            stringBuilder.append(e3.getMessage());
            android.util.Slog.e("SecurityProfileService", stringBuilder.toString());
            return false;
        }
    }

    public static org.json.JSONObject verifyAndDecodePolicy(byte[] policyBlock) {
        try {
            java.lang.String[] parts = java.lang.StringFactory.newStringFromBytes(policyBlock, java.nio.charset.StandardCharsets.UTF_8).split("\\.");
            if (parts.length != 3) {
                return null;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(parts[0]);
            stringBuilder.append(".");
            stringBuilder.append(parts[1]);
            byte[] signedData = stringBuilder.toString().getBytes();
            byte[] signature = java.util.Base64.getUrlDecoder().decode(parts[2]);
            org.json.JSONObject header = new org.json.JSONObject(java.lang.StringFactory.newStringFromBytes(java.util.Base64.getUrlDecoder().decode(parts[0]), java.nio.charset.StandardCharsets.UTF_8));
            java.io.ByteArrayInputStream bis = new java.io.ByteArrayInputStream(java.util.Base64.getDecoder().decode((java.lang.String) header.getJSONArray("x5c").get(0)));
            java.util.Date timestamp = new java.util.Date();
            timestamp.setTime(header.optLong("timestamp", java.lang.System.currentTimeMillis()));
            java.security.Signature sig = java.security.Signature.getInstance("SHA256withRSA");
            java.security.cert.Certificate cert = java.security.cert.CertificateFactory.getInstance("X.509").generateCertificate(bis);
            if (!new com.android.server.security.securityprofile.CertificateVerifier().verifyCertificateChain(java.util.Arrays.asList(new java.security.cert.Certificate[]{cert}), timestamp)) {
                return null;
            }
            java.lang.String valueofou = getSubjectAttr(cert, "OU");
            if (valueofou.equals("Huawei APK Production")) {
                sig.initVerify(cert);
                sig.update(signedData);
                if (sig.verify(signature)) {
                    return new org.json.JSONObject(new java.lang.String(java.util.Base64.getUrlDecoder().decode(parts[1].getBytes())));
                }
                return null;
            }
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("the OU field:");
            stringBuilder2.append(valueofou);
            stringBuilder2.append(" of the subject is not correct");
            android.util.Slog.e("SecurityProfileService", stringBuilder2.toString());
            return null;
        } catch (java.security.NoSuchAlgorithmException e) {
            android.util.Slog.e("SecurityProfileService", e.getMessage());
            return null;
        } catch (java.security.cert.CertificateException e2) {
            android.util.Slog.e("SecurityProfileService", e2.getMessage());
            return null;
        } catch (org.json.JSONException e3) {
            android.util.Slog.e("SecurityProfileService", e3.getMessage());
            return null;
        } catch (java.security.SignatureException e4) {
            android.util.Slog.e("SecurityProfileService", e4.getMessage());
            return null;
        } catch (java.security.InvalidKeyException e5) {
            android.util.Slog.e("SecurityProfileService", e5.getMessage());
            return null;
        }
    }

    public static java.lang.String getSubjectAttr(java.security.cert.Certificate cert, java.lang.String field) {
        for (java.lang.String attr : ((java.security.cert.X509Certificate) cert).getSubjectDN().getName().split(",")) {
            java.lang.String[] nameandvalue = attr.split("=");
            if (nameandvalue[0].equals(field)) {
                return nameandvalue[1];
            }
        }
        return null;
    }
}
