package com.android.server.security.trustcircle;

public class TrustCirclePlugin extends huawei.android.security.ITrustCircleManager.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    public static final java.lang.Object BINDLOCK = new java.lang.Object();
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            com.android.server.security.trustcircle.utils.LogHelper.d(com.android.server.security.trustcircle.TrustCirclePlugin.TAG, "createTrustCirclePlugin");
            return new com.android.server.security.trustcircle.TrustCirclePlugin(context);
        }

        public java.lang.String getPluginPermission() {
            return "com.huawei.permission.USE_TRUSTCIRCLE_MANAGER";
        }
    };
    private static final java.lang.String MANAGE_TRUSTCIRCLE = "com.huawei.permission.USE_TRUSTCIRCLE_MANAGER";
    private static final int MSG_PROCESS_CMD = 10;
    private static final java.lang.String TAG = com.android.server.security.trustcircle.TrustCirclePlugin.class.getSimpleName();
    private android.content.Context mContext;
    private com.android.server.security.trustcircle.lifecycle.NetworkChangeReceiver mNetworkReceiver;

    public TrustCirclePlugin(android.content.Context context) {
        this.mContext = context;
    }

    public void onStart() {
        registerNetworkReceiver();
        listenForUserSwitches();
        com.android.server.security.trustcircle.task.HwSecurityMsgCenter.createInstance();
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.createInstance();
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.getInstance().startThread();
        com.android.server.security.trustcircle.jni.TcisJNI.start();
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().setContext(this.mContext);
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().initTcisOfCurrentUser();
    }

    public void onStop() {
        unregisterNetworkReceiver();
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.getInstance().stopThread();
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.destroyInstance();
        com.android.server.security.trustcircle.task.HwSecurityMsgCenter.destroyInstance();
        com.android.server.security.trustcircle.task.HwSecurityTimer.destroyInstance();
        com.android.server.security.trustcircle.jni.TcisJNI.stop();
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    private void registerNetworkReceiver() {
        if (this.mContext != null) {
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
            filter.addCategory("android.net.conn.CONNECTIVITY_CHANGE@hwBrExpand@ConnectStatus=WIFIDATACON|ConnectStatus=MOBILEDATACON");
            this.mNetworkReceiver = new com.android.server.security.trustcircle.lifecycle.NetworkChangeReceiver();
            this.mContext.registerReceiver(this.mNetworkReceiver, filter);
            com.android.server.security.trustcircle.utils.LogHelper.d(TAG, "registerNetworkReceiver successed");
            return;
        }
        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error:registerNetworkReceiver failed - Context is null");
    }

    private void unregisterNetworkReceiver() {
        if (this.mContext != null) {
            this.mContext.unregisterReceiver(this.mNetworkReceiver);
            this.mNetworkReceiver = null;
            com.android.server.security.trustcircle.utils.LogHelper.d(TAG, "unregisterNetworkReceiver successed");
            return;
        }
        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error:unregisterNetworkReceiver failed - Context is null");
    }

    public boolean checkCallingAcrossUser() {
        int callingUserId = android.os.UserHandle.getUserId(android.os.Binder.getCallingUid());
        int currentUserId = com.android.server.security.trustcircle.utils.Utils.getCurrentUserId();
        if (callingUserId == currentUserId) {
            return false;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("calling from [user: ");
        stringBuilder.append(callingUserId);
        stringBuilder.append(",pid: ");
        stringBuilder.append(android.os.Binder.getCallingPid());
        stringBuilder.append("] ,current user: ");
        stringBuilder.append(currentUserId);
        com.android.server.security.trustcircle.utils.LogHelper.w(str, stringBuilder.toString());
        return true;
    }

    public android.os.Bundle getTcisInfo() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return null;
        }
        return com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().getTcisInfo();
    }

    public int getCurrentState() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return -1;
        }
        return com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().getCurrentState();
    }

    public void loginServerRequest(huawei.android.security.ILifeCycleCallback callback, long userID, int serverRegisterStatus, java.lang.String sessionID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            return;
        }
        if (checkCallingAcrossUser()) {
            if (serverRegisterStatus == com.android.server.security.trustcircle.utils.Status.LifeCycleStauts.NOT_REGISTER.ordinal()) {
                com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onRegisterResponse(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value(), -1, -1, null, null, null);
            } else {
                com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onLoginResponse(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value(), -1, null);
            }
            return;
        }
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().loginServerRequest(userID, serverRegisterStatus, sessionID);
    }

    public void updateServerRequest(huawei.android.security.ILifeCycleCallback callback, long userID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            return;
        }
        if (checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onUpdateResponse(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value(), -1, null);
        } else {
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().updateServerRequest(userID);
        }
    }

    public void finalRegister(huawei.android.security.ILifeCycleCallback callback, java.lang.String authPKData, java.lang.String authPKDataSign, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid() && !com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            return;
        }
        if (checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onFinalRegisterResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value());
        } else {
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().finalRegister(authPKData, authPKDataSign, updateIndexInfo, updateIndexSignature);
        }
    }

    public void finalLogin(huawei.android.security.ILifeCycleCallback callback, int updateResult, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid() && !com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            return;
        }
        if (checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onFinalLoginResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value());
        } else {
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().finalLogin(updateResult, updateIndexInfo, updateIndexSignature);
        }
    }

    public void logout(huawei.android.security.ILifeCycleCallback callback, long userID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error:ILifeCycleCallback is null in logout");
        } else if (checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onLogoutResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value());
        } else {
            com.android.server.security.trustcircle.auth.IOTController.getInstance().cancelAuth(-2);
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().logout(userID);
        }
    }

    public void cancelRegOrLogin(huawei.android.security.ILifeCycleCallback callback, long userID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if ((com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid() || com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) && !checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().cancelRegOrLogin(userID);
        }
    }

    public void unregister(huawei.android.security.ILifeCycleCallback callback, long userID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!com.android.server.security.trustcircle.CallbackManager.getInstance().registerILifeCycleCallback(callback)) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error:ILifeCycleCallback is null in unregister");
        } else if (checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.onUnregisterResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.CROSS_USER.value());
        } else {
            com.android.server.security.trustcircle.auth.IOTController.getInstance().cancelAuth(-2);
            com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().unregister(userID);
        }
    }

    private void listenForUserSwitches() {
        try {
            android.app.ActivityManager.getService().registerUserSwitchObserver(new android.app.SynchronousUserSwitchObserver() {
                public void onUserSwitching(int newUserId) throws android.os.RemoteException {
                    java.lang.String access$000 = com.android.server.security.trustcircle.TrustCirclePlugin.TAG;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onUserSwitching- newUserId: ");
                    stringBuilder.append(newUserId);
                    com.android.server.security.trustcircle.utils.LogHelper.d(access$000, stringBuilder.toString());
                    com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(false);
                    com.android.server.security.trustcircle.auth.IOTController.getInstance().cancelAuth(-2);
                }

                public void onUserSwitchComplete(int newUserId) throws android.os.RemoteException {
                    java.lang.String access$000 = com.android.server.security.trustcircle.TrustCirclePlugin.TAG;
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onUserSwitchComplete- newUserId: ");
                    stringBuilder.append(newUserId);
                    com.android.server.security.trustcircle.utils.LogHelper.d(access$000, stringBuilder.toString());
                    com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().initTcisByUserHandle(newUserId);
                }

                public void onForegroundProfileSwitch(int newProfileId) {
                }
            }, TAG);
        } catch (android.os.RemoteException e) {
            com.android.server.security.trustcircle.utils.LogHelper.w(TAG, "Failed to listen for user switching event");
        }
    }

    public long initAuthenticate(huawei.android.security.IAuthCallback callback, int authType, int authVersion, int policy, long userID, byte[] AESTmpKey) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return -1;
        }
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance();
        if (com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.isReadyForIot(userID)) {
            return com.android.server.security.trustcircle.auth.IOTController.getInstance().initAuth(callback, authType, authVersion, policy, userID, AESTmpKey);
        }
        return -1;
    }

    public long receiveAuthSync(huawei.android.security.IAuthCallback callback, int authType, int authVersion, int taVersion, int policy, long userID, byte[] AESTmpKey, byte[] tcisId, int pkVersion, long nonce, int authKeyAlgoType, byte[] authKeyInfo, byte[] authKeyInfoSign) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return -1;
        }
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance();
        if (com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.isReadyForIot(userID)) {
            return com.android.server.security.trustcircle.auth.IOTController.getInstance().receiveAuthSync(callback, authType, authVersion, taVersion, policy, userID, AESTmpKey, tcisId, pkVersion, nonce, authKeyAlgoType, authKeyInfo, authKeyInfoSign);
        }
        return -1;
    }

    public boolean receiveAuthSyncAck(long authID, byte[] tcisIdSlave, int pkVersionSlave, long nonceSlave, byte[] mac, int authKeyAlgoTypeSlave, byte[] authKeyInfoSlave, byte[] authKeyInfoSignSlave) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return false;
        }
        return com.android.server.security.trustcircle.auth.IOTController.getInstance().receiveAuthSyncAck(authID, tcisIdSlave, pkVersionSlave, nonceSlave, mac, authKeyAlgoTypeSlave, authKeyInfoSlave, authKeyInfoSignSlave);
    }

    public boolean receiveAck(long authID, byte[] mac) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return false;
        }
        return com.android.server.security.trustcircle.auth.IOTController.getInstance().receiveAck(authID, mac);
    }

    public boolean requestPK(long authID, long userID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return false;
        }
        return com.android.server.security.trustcircle.auth.IOTController.getInstance().requestPK(authID, userID);
    }

    public boolean receivePK(long authID, int authKeyAlgoType, byte[] authKeyData, byte[] authKeyDataSign) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return false;
        }
        return com.android.server.security.trustcircle.auth.IOTController.getInstance().receivePK(authID, authKeyAlgoType, authKeyData, authKeyDataSign);
    }

    public void cancelAuthentication(long authID) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (!checkCallingAcrossUser()) {
            com.android.server.security.trustcircle.auth.IOTController.getInstance().cancelAuth(authID);
        }
    }

    public long initKeyAgreement(huawei.android.security.IKaCallback callBack, int kaVersion, long userId, byte[] aesTmpKey, java.lang.String kaInfo) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.USE_TRUSTCIRCLE_MANAGER", null);
        if (checkCallingAcrossUser()) {
            return -1;
        }
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance();
        if (!com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.isReadyForIot(userId)) {
            return -1;
        }
        return com.android.server.security.trustcircle.auth.IOTController.getInstance().initKeyAgreement(callBack, kaVersion, userId, aesTmpKey, kaInfo, this.mContext);
    }
}
