package com.android.server.security.trustcircle.auth;

public class IOTController {
    public static final int AUTH_ID_ERROR = -1;
    public static final int EV_CANCEL_AUTH = 100;
    public static final int EV_CANCEL_AUTH_ALL = 104;
    public static final int EV_IOT_AUTH_ACK = 101;
    public static final int EV_IOT_REC_ACK = 103;
    public static final int EV_IOT_REC_PK = 102;
    public static final int ID_CANCEL_ALL = -2;
    public static final int RESULT_OK = 0;
    public static final int RESULT_REQ_PK = 1;
    private static final java.lang.String TAG = com.android.server.security.trustcircle.auth.IOTController.class.getSimpleName();
    public static final int TYPE_MASTER = 1000;
    public static final int TYPE_SLAVE = 1001;
    private static java.lang.Object mLock = new java.lang.Object();
    private static long sGenAuthID;
    private static volatile com.android.server.security.trustcircle.auth.IOTController sInstance;
    java.util.Map<java.lang.Long, com.android.server.security.trustcircle.auth.AuthPara.InitAuthInfo> mClientsMaster = new java.util.concurrent.ConcurrentHashMap();
    java.util.Map<java.lang.Long, com.android.server.security.trustcircle.auth.AuthPara.RecAuthInfo> mClientsSlave = new java.util.concurrent.ConcurrentHashMap();
    com.android.server.security.trustcircle.task.HwSecurityTaskBase.RetCallback mInitCallback = new com.android.server.security.trustcircle.task.HwSecurityTaskBase.RetCallback() {
        public void onTaskCallback(com.android.server.security.trustcircle.task.HwSecurityTaskBase base, int ret) {
            java.lang.String access$000 = com.android.server.security.trustcircle.auth.IOTController.TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("auth onTaskCallback, ret: ");
            stringBuilder.append(ret);
            com.android.server.security.trustcircle.utils.LogHelper.d(access$000, stringBuilder.toString());
            long authID = ((com.android.server.security.trustcircle.auth.IOTAuthTask) base).getAuthID();
            if (ret == 2 || ret == 1) {
                com.android.server.security.trustcircle.utils.AuthUtils.processCancelAuth(authID);
                com.android.server.security.trustcircle.auth.IOTController.this.notifyAuthExited(authID, ret, 1000);
            }
            com.android.server.security.trustcircle.auth.IOTController.this.mClientsMaster.remove(java.lang.Long.valueOf(authID));
        }
    };
    com.android.server.security.trustcircle.task.HwSecurityTaskBase.RetCallback mRecCallback = new com.android.server.security.trustcircle.task.HwSecurityTaskBase.RetCallback() {
        public void onTaskCallback(com.android.server.security.trustcircle.task.HwSecurityTaskBase base, int ret) {
            java.lang.String access$000 = com.android.server.security.trustcircle.auth.IOTController.TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("receive auth onTaskCallback, ret: ");
            stringBuilder.append(ret);
            com.android.server.security.trustcircle.utils.LogHelper.d(access$000, stringBuilder.toString());
            long authID = ((com.android.server.security.trustcircle.auth.RecAuthTask) base).getAuthID();
            if (ret == 2 || ret == 1) {
                com.android.server.security.trustcircle.utils.AuthUtils.processCancelAuth(authID);
                com.android.server.security.trustcircle.auth.IOTController.this.notifyAuthExited(authID, ret, 1001);
            }
            com.android.server.security.trustcircle.auth.IOTController.this.mClientsSlave.remove(java.lang.Long.valueOf(authID));
        }
    };

    public static class KaInfoRequest {
        public byte[] aesTmpKey;
        public long authId;
        public java.lang.String kaInfo;
        public int kaVersion;
        public long userId;

        public KaInfoRequest(long authId, int kaVersion, long userId, byte[] aesTmpKey, java.lang.String kaInfo) {
            this.authId = authId;
            this.kaVersion = kaVersion;
            this.userId = userId;
            this.aesTmpKey = (byte[]) aesTmpKey.clone();
            this.kaInfo = kaInfo;
        }
    }

    public static class KaInfoResponse {
        public byte[] iv;
        public byte[] payload;
        public int result;

        public KaInfoResponse(int result, byte[] iv, byte[] payload) {
            this.result = result;
            this.iv = (byte[]) iv.clone();
            this.payload = (byte[]) payload.clone();
        }
    }

    private IOTController() {
    }

    public static com.android.server.security.trustcircle.auth.IOTController getInstance() {
        if (sInstance == null) {
            synchronized (com.android.server.security.trustcircle.auth.IOTController.class) {
                if (sInstance == null) {
                    sInstance = new com.android.server.security.trustcircle.auth.IOTController();
                }
            }
        }
        return sInstance;
    }

    public long initKeyAgreement(huawei.android.security.IKaCallback callback, int kaVersion, long userId, byte[] aesTmpKey, java.lang.String kaInfo, android.content.Context context) {
        long authId = generateAuthID();
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.auth.KaRequestTask(null, null, context, new com.android.server.security.trustcircle.auth.IOTController.KaInfoRequest(authId, kaVersion, userId, aesTmpKey, kaInfo), callback), 1);
        return authId;
    }

    public long initAuth(huawei.android.security.IAuthCallback callback, int authType, int authVersion, int policy, long userID, byte[] AESTmpKey) {
        long authID = generateAuthID();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("start auth, authId: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.auth.AuthPara.InitAuthInfo info = new com.android.server.security.trustcircle.auth.AuthPara.InitAuthInfo(callback, authID, authType, authVersion, policy, userID, AESTmpKey);
        this.mClientsMaster.put(java.lang.Long.valueOf(authID), info);
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.auth.IOTAuthTask(null, this.mInitCallback, info), 1);
        return authID;
    }

    public long receiveAuthSync(huawei.android.security.IAuthCallback callback, int authType, int authVersion, int taVersion, int policy, long userID, byte[] AESTmpKey, byte[] tcisId, int pkVersion, long nonce, int authKeyAlgoType, byte[] authKeyInfo, byte[] authKeyInfoSign) {
        long authID = generateAuthID();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("receive auth, authID: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        long authID2 = authID;
        com.android.server.security.trustcircle.auth.AuthPara.RecAuthInfo info = new com.android.server.security.trustcircle.auth.AuthPara.RecAuthInfo(authID, callback, authType, authVersion, (short) taVersion, policy, userID, AESTmpKey, tcisId, pkVersion, nonce, (short) authKeyAlgoType, authKeyInfo, authKeyInfoSign);
        long authID3 = authID2;
        this.mClientsSlave.put(java.lang.Long.valueOf(authID3), info);
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.auth.RecAuthTask(null, this.mRecCallback, info), 1);
        return authID3;
    }

    public boolean receiveAuthSyncAck(long authID, byte[] tcisIdSlave, int pkVersionSlave, long nonceSlave, byte[] mac, int authKeyAlgoTypeSlave, byte[] authKeyInfoSlave, byte[] authKeyInfoSignSlave) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("receive authAck, authID: ");
        long j = authID;
        stringBuilder.append(j);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.task.HwSecurityEventTask(new com.android.server.security.trustcircle.auth.AuthSyncAckEv(101, new com.android.server.security.trustcircle.auth.AuthPara.RecAuthAckInfo(j, tcisIdSlave, pkVersionSlave, nonceSlave, mac, (short) authKeyAlgoTypeSlave, authKeyInfoSlave, authKeyInfoSignSlave))), 1);
        return true;
    }

    public boolean requestPK(long authID, long userID) {
        int type;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("IOT requestPK, authID: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.auth.AuthPara.ReqPkInfo reqPkInfo = new com.android.server.security.trustcircle.auth.AuthPara.ReqPkInfo(userID, authID);
        if (this.mClientsMaster.containsKey(java.lang.Long.valueOf(authID))) {
            type = 1000;
        } else if (!this.mClientsSlave.containsKey(java.lang.Long.valueOf(authID))) {
            return false;
        } else {
            type = 1001;
        }
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.auth.IOTReqPkTask(null, null, reqPkInfo, type), 1);
        return true;
    }

    public boolean receivePK(long authID, int authKeyAlgoType, byte[] authKeyData, byte[] authKeyDataSign) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("receivePK, authID: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.task.HwSecurityEventTask(new com.android.server.security.trustcircle.auth.ReceivePkEv(102, new com.android.server.security.trustcircle.auth.AuthPara.RespPkInfo(authID, (short) authKeyAlgoType, authKeyData, authKeyDataSign, 0))), 1);
        return true;
    }

    public boolean receiveAck(long authID, byte[] mac) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("receiveAck, authID: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.task.HwSecurityEventTask(new com.android.server.security.trustcircle.auth.ReceiveAckEv(103, new com.android.server.security.trustcircle.auth.AuthPara.RecAckInfo(authID, mac))), 1);
        return true;
    }

    public boolean cancelAuth(long authID) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("cancelAuth, authID: ");
        stringBuilder.append(authID);
        com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
        com.android.server.security.trustcircle.task.HwSecurityTaskThread.staticPushTask(new com.android.server.security.trustcircle.task.HwSecurityEventTask(new com.android.server.security.trustcircle.auth.CancelAuthEv(100, authID)), 0);
        return true;
    }

    private long generateAuthID() {
        long j;
        synchronized (mLock) {
            j = sGenAuthID + 1;
            sGenAuthID = j;
        }
        return j;
    }

    public huawei.android.security.IAuthCallback getIOTCallback(long authID, int type) {
        huawei.android.security.IAuthCallback result = null;
        if (type == 1000 && this.mClientsMaster != null) {
            com.android.server.security.trustcircle.auth.AuthPara.InitAuthInfo info = (com.android.server.security.trustcircle.auth.AuthPara.InitAuthInfo) this.mClientsMaster.get(java.lang.Long.valueOf(authID));
            if (info != null) {
                result = info.mCallback;
            }
            return result;
        } else if (type != 1001 || this.mClientsSlave == null) {
            return null;
        } else {
            com.android.server.security.trustcircle.auth.AuthPara.RecAuthInfo info2 = (com.android.server.security.trustcircle.auth.AuthPara.RecAuthInfo) this.mClientsSlave.get(java.lang.Long.valueOf(authID));
            if (info2 != null) {
                return info2.mCallback;
            }
            return null;
        }
    }

    private void notifyAuthExited(long authID, int ret, int type) {
        java.lang.String str;
        java.lang.StringBuilder stringBuilder;
        huawei.android.security.IAuthCallback callback = getIOTCallback(authID, type);
        if (callback != null) {
            if (ret == 2) {
                try {
                    callback.onAuthExited(authID, 2046820389);
                } catch (android.os.RemoteException e) {
                    str = TAG;
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("notifyAuthExited failed, ");
                    stringBuilder.append(e.toString());
                    com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
                } catch (android.os.RemoteException e2) {
                    str = TAG;
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("notifyAuthExited failed, ");
                    stringBuilder.append(e2.toString());
                    com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
                }
            } else if (ret == 1) {
                callback.onAuthExited(authID, 2046820388);
            }
        }
    }
}
