package com.android.server.security.trustcircle.lifecycle;

public class LifeCycleProcessor {
    public static final long INVALID_USER_ID = -1;
    private static final java.lang.String KEY_TCIS_STATUS = "tcis_error_step";
    public static final byte LOGINED = (byte) 1;
    private static final java.lang.String SERVICE_NAME = "com.huawei.trustcircle.tcis.TCUpdateService";
    public static final java.lang.String TAG = com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.class.getSimpleName();
    private static final java.lang.String TCIS_PKG_NAME = "com.huawei.trustcircle";
    private static volatile long currentUserId = -1;

    public static class UsersState {
        private int state;
        private long userHandle;

        public UsersState(long userHandle, int state) {
            this.userHandle = userHandle;
            this.state = state;
        }

        public long getUserId() {
            return this.userHandle;
        }

        public void setUserHandle(int userHandle) {
            this.userHandle = (long) userHandle;
        }

        public int getState() {
            return this.state;
        }

        public void setState(int state) {
            this.state = state;
        }

        public java.lang.String getString() {
            short status = (short) this.state;
            java.lang.StringBuffer sb = new java.lang.StringBuffer();
            sb.append(com.android.server.security.trustcircle.utils.ByteUtil.long2StrictHexString(this.userHandle));
            sb.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(status));
            return sb.toString();
        }
    }

    public static void updateTime(long time) {
        com.android.server.security.trustcircle.lifecycle.NetworkChangeReceiver.updateTime(time);
    }

    public static long initAndroidUser(int userHandle) {
        com.android.server.security.trustcircle.tlv.command.query.CMD_INIT_REQ reqTLV = new com.android.server.security.trustcircle.tlv.command.query.CMD_INIT_REQ();
        reqTLV.userHandle.setTLVStruct(java.lang.Integer.valueOf(userHandle));
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = sendCmd(reqTLV);
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        long userID = -1;
        boolean z = true;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.query.RET_INIT_REQ) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            com.android.server.security.trustcircle.tlv.command.query.RET_INIT_REQ respTLV = (com.android.server.security.trustcircle.tlv.command.query.RET_INIT_REQ) respTree;
            java.lang.Byte[] loginState = (java.lang.Byte[]) respTLV.loginState.getTLVStruct();
            if (loginState != null && loginState.length == 1 && loginState[0].byteValue() == (byte) 1) {
                userID = ((java.lang.Long) respTLV.userID.getTLVStruct()).longValue();
            }
        }
        if (userID == -1) {
            z = false;
        }
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(z);
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.SWITCH_USER, false);
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("initAndroidUser-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        return userID;
    }

    public static android.os.Bundle getTcisInfo() {
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = sendCmd(new com.android.server.security.trustcircle.tlv.command.query.CMD_GET_TCIS_ID());
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        android.os.Bundle tcisInfo = null;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.query.RET_GET_TCIS_ID) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            com.android.server.security.trustcircle.tlv.command.query.RET_GET_TCIS_ID respTLV = (com.android.server.security.trustcircle.tlv.command.query.RET_GET_TCIS_ID) respTree;
            java.lang.String tcisIDString = com.android.server.security.trustcircle.utils.ByteUtil.byteArray2ServerHexString((java.lang.Byte[]) respTLV.tcisID.getTLVStruct());
            short taVersion = ((java.lang.Short) respTLV.TAVersion.getTLVStruct()).shortValue();
            tcisInfo = new android.os.Bundle();
            tcisInfo.putString("tcisID", tcisIDString);
            tcisInfo.putShort("TAVersion", taVersion);
            long hwUserId = getLoginedUserID();
            tcisInfo.putString("hwUserId", hwUserId <= 0 ? null : java.lang.String.valueOf(hwUserId));
        }
        return tcisInfo;
    }

    public static boolean checkNeedRegister(int serverRegisterStatus, long userID) {
        if (serverRegisterStatus != com.android.server.security.trustcircle.utils.Status.LifeCycleStauts.NOT_REGISTER.ordinal()) {
            if (checkTARegisterStatus(userID) != com.android.server.security.trustcircle.utils.Status.LifeCycleStauts.NOT_REGISTER.ordinal()) {
                return false;
            }
        }
        return true;
    }

    public static boolean checkUserIDLogined(long userID) {
        if (getLoginedUserID() == userID) {
            return true;
        }
        return false;
    }

    public static long getLoginedUserID() {
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = sendCmd(new com.android.server.security.trustcircle.tlv.command.query.CMD_GET_LOGIN_STATUS());
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        long userID = -1;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.query.RET_GET_LOGIN_STATUS) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            userID = ((java.lang.Long) ((com.android.server.security.trustcircle.tlv.command.query.RET_GET_LOGIN_STATUS) respTree).userID.getTLVStruct()).longValue();
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getLoginedUser-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        return userID;
    }

    public static int checkTARegisterStatus(long userID) {
        com.android.server.security.trustcircle.tlv.command.register.CMD_CHECK_REG_STATUS reqTLV = new com.android.server.security.trustcircle.tlv.command.register.CMD_CHECK_REG_STATUS();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        int resultCode = sendCmd(reqTLV).getResultCode();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loginServerRequest-TARegisterStatus: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            return com.android.server.security.trustcircle.utils.Status.LifeCycleStauts.REGISTERED.ordinal();
        }
        return com.android.server.security.trustcircle.utils.Status.LifeCycleStauts.NOT_REGISTER.ordinal();
    }

    public static boolean register(long userID, java.lang.String sessionID) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(false);
        currentUserId = userID;
        boolean globalKeyID = false;
        com.android.server.security.trustcircle.tlv.command.register.CMD_REG_REQ reqTLV = new com.android.server.security.trustcircle.tlv.command.register.CMD_REG_REQ();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        reqTLV.sessionID.setTLVStruct(com.android.server.security.trustcircle.utils.ByteUtil.hexString2ByteArray(sessionID));
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = sendCmd(reqTLV);
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("register-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        int globalKeyID2 = -1;
        short authKeyAlgoEncode = (short) -1;
        java.lang.String regAuthKeyData = null;
        java.lang.String regAuthKeyDataSign = null;
        java.lang.String clientChallenge = null;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.register.RET_REG_REQ) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            com.android.server.security.trustcircle.tlv.command.register.RET_REG_REQ respTLV = (com.android.server.security.trustcircle.tlv.command.register.RET_REG_REQ) respTree;
            globalKeyID = true;
            globalKeyID2 = ((java.lang.Integer) respTLV.glogbalKeyID.getTLVStruct()).intValue();
            authKeyAlgoEncode = ((java.lang.Short) respTLV.authKeyAlgoEncode.getTLVStruct()).shortValue();
            regAuthKeyData = com.android.server.security.trustcircle.utils.ByteUtil.byteArray2ServerHexString(respTLV.regAuthKeyData.encapsulate());
            regAuthKeyDataSign = respTLV.regAuthKeyDataSign.byteArray2ServerHexString();
            clientChallenge = respTLV.clientChallenge.byteArray2ServerHexString();
        }
        boolean valid = globalKeyID;
        if (onRegisterResponse(resultCode, globalKeyID2, authKeyAlgoEncode, regAuthKeyData, regAuthKeyDataSign, clientChallenge) && valid) {
            return true;
        }
        return false;
    }

    public static boolean onRegisterResponse(int resultCode, int globalKeyID, int authKeyAlgoType, java.lang.String regAuthKeyData, java.lang.String regAuthKeyDataSign, java.lang.String clientChallenge) {
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.REG, false);
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onRegisterResponse(resultCode, globalKeyID, (short) authKeyAlgoType, regAuthKeyData, regAuthKeyDataSign, clientChallenge);
                return true;
            }
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onRegisterResponse: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        }
    }

    public static boolean finalRegister(java.lang.String authPKInfo, java.lang.String authPKInfoSign, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        boolean valid = false;
        com.android.server.security.trustcircle.tlv.core.TLVTree authPkInfoTree = com.android.server.security.trustcircle.tlv.core.TLVEngine.decodeTLV(com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(authPKInfo));
        java.lang.Byte[] authPKInfoSignBytes = com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(authPKInfoSign);
        com.android.server.security.trustcircle.tlv.core.TLVTree updateIndexInfoTree = com.android.server.security.trustcircle.tlv.core.TLVEngine.decodeTLV(com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(updateIndexInfo));
        java.lang.Byte[] updateIndexSignBytes = com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(updateIndexSignature);
        boolean z = false;
        if (authPkInfoTree instanceof com.android.server.security.trustcircle.tlv.tree.AuthPkInfo) {
            if (updateIndexInfoTree instanceof com.android.server.security.trustcircle.tlv.tree.UpdateIndexInfo) {
                com.android.server.security.trustcircle.tlv.command.register.CMD_REG_RESULT reqTLV = new com.android.server.security.trustcircle.tlv.command.register.CMD_REG_RESULT();
                reqTLV.authPkInfo.setTLVStruct(authPkInfoTree);
                reqTLV.authPKInfoSign.setTLVStruct(authPKInfoSignBytes);
                reqTLV.updateIndexInfo.setTLVStruct(updateIndexInfoTree);
                reqTLV.updateIndexInfoSign.setTLVStruct(updateIndexSignBytes);
                int resultCode = sendCmd(reqTLV).getResultCode();
                if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
                    com.android.server.security.trustcircle.utils.LogHelper.i(TAG, "register tcis to TA successfully");
                    valid = true;
                } else {
                    com.android.server.security.trustcircle.utils.LogHelper.w(TAG, "register tcis to TA failed");
                }
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("finalRegister-resultCode: ");
                stringBuilder.append(resultCode);
                com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
                if (onFinalRegisterResult(resultCode) && valid) {
                    z = true;
                }
                return z;
            }
        }
        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error decode in finalRegister");
        onFinalRegisterResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.UNKNOWN_CMD.value());
        return false;
    }

    public static boolean onFinalRegisterResult(int resultCode) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnableByResultCode(resultCode);
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.REG, false);
        boolean result = false;
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onFinalRegisterResult(resultCode);
                result = true;
            } else {
                result = false;
            }
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onFinalRegisterResult: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            result = false;
        }
        com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
        return result;
    }

    public static boolean loginAndUpdate(long userID) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(false);
        currentUserId = userID;
        boolean valid = false;
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = updateCmd(userID);
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loginAndUpdate-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        int indexVersion = -1;
        java.lang.String clientChallenge = null;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ respTLV = (com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ) respTree;
            valid = true;
            indexVersion = ((java.lang.Integer) respTLV.indexVersion.getTLVStruct()).intValue();
            clientChallenge = respTLV.clientChallenge.byteArray2ServerHexString();
        }
        if (onLoginResponse(resultCode, indexVersion, clientChallenge) && valid) {
            return true;
        }
        return false;
    }

    private static com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> updateCmd(long userID) {
        com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_REQ reqTLV = new com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_REQ();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        return sendCmd(reqTLV);
    }

    public static boolean onLoginResponse(int resultCode, int indexVersion, java.lang.String clientChallenge) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnableByResultCode(resultCode);
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.LOGIN, false);
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onLoginResponse(resultCode, indexVersion, clientChallenge);
                return true;
            }
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onLoginResponse: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        }
    }

    public static boolean updateOnly(long userID) {
        boolean valid = false;
        currentUserId = userID;
        com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<?> result = updateCmd(userID);
        com.android.server.security.trustcircle.tlv.core.TLVTree respTree = result.getResultTLV();
        int resultCode = result.getResultCode();
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateServerRequest-updateOnly-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        int indexVersion = -1;
        java.lang.String clientChallenge = null;
        if (respTree != null && (respTree instanceof com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ) && resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ respTLV = (com.android.server.security.trustcircle.tlv.command.login.RET_LOGIN_REQ) respTree;
            valid = true;
            indexVersion = ((java.lang.Integer) respTLV.indexVersion.getTLVStruct()).intValue();
            clientChallenge = respTLV.clientChallenge.byteArray2ServerHexString();
        }
        return onUpdateResponse(resultCode, indexVersion, clientChallenge) && valid;
    }

    public static boolean onUpdateResponse(int resultCode, int indexVersion, java.lang.String clientChallenge) {
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.UPDATE, false);
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onUpdateResponse(resultCode, indexVersion, clientChallenge);
                return true;
            }
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onUpdateResponse: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        }
    }

    public static boolean finalLogin(int updateResult, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        boolean valid = false;
        int resultCode = com.android.server.security.trustcircle.utils.Status.TCIS_Result.BAD_PARAM.value();
        if (updateResult == com.android.server.security.trustcircle.utils.Status.UpdateStauts.NO_NEED_UPDATE.ordinal()) {
            com.android.server.security.trustcircle.utils.LogHelper.i(TAG, "finalLogin-nothing to update");
            resultCode = com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value();
            valid = true;
        } else {
            if (!android.text.TextUtils.isEmpty(updateIndexInfo)) {
                if (!android.text.TextUtils.isEmpty(updateIndexSignature)) {
                    com.android.server.security.trustcircle.utils.LogHelper.i(TAG, "finalLogin-need to update tcis data");
                    com.android.server.security.trustcircle.tlv.core.TLVTree updateIndexInfoTree = com.android.server.security.trustcircle.tlv.core.TLVEngine.decodeTLV(com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(updateIndexInfo));
                    if (updateIndexInfoTree instanceof com.android.server.security.trustcircle.tlv.tree.UpdateIndexInfo) {
                        java.lang.Byte[] updateIndexSignBytes = com.android.server.security.trustcircle.utils.ByteUtil.serverHexString2ByteArray(updateIndexSignature);
                        com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_RESULT_UPDATE reqTLV = new com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_RESULT_UPDATE();
                        reqTLV.updateIndexInfo.setTLVStruct(updateIndexInfoTree);
                        reqTLV.updateIndexInfoSign.setTLVStruct(updateIndexSignBytes);
                        resultCode = sendCmd(reqTLV).getResultCode();
                        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
                            valid = true;
                        }
                    } else {
                        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error decode in finalLogin");
                        onFinalLoginResult(com.android.server.security.trustcircle.utils.Status.TCIS_Result.BAD_PARAM.value());
                        return false;
                    }
                }
            }
            com.android.server.security.trustcircle.utils.LogHelper.w(TAG, "error:finalLogin-update data is not complete");
            resultCode = com.android.server.security.trustcircle.utils.Status.TCIS_Result.BAD_PARAM.value();
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("finalLogin-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        boolean z = onFinalLoginResult(resultCode) && valid;
        return z;
    }

    public static boolean onFinalLoginResult(int resultCode) {
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.LOGIN, false);
        boolean result = false;
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onFinalLoginResult(resultCode);
                result = true;
            } else {
                result = false;
            }
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onFinalLoginResult: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            result = false;
        }
        com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
        return result;
    }

    public static boolean cancelRegOrLogin(com.android.internal.util.State state, long userID) {
        if (state == null) {
            com.android.server.security.trustcircle.utils.LogHelper.w(TAG, "nothing to cancel");
            return false;
        } else if (com.android.server.security.trustcircle.lifecycle.LifeCycleStateMachine.RegisteringState.class == state.getClass()) {
            return cancelReg(userID);
        } else {
            if (com.android.server.security.trustcircle.lifecycle.LifeCycleStateMachine.LoginingState.class == state.getClass()) {
                return cancelLogin(userID);
            }
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("unknown cancel state: ");
            stringBuilder.append(state.getName());
            com.android.server.security.trustcircle.utils.LogHelper.w(str, stringBuilder.toString());
            return false;
        }
    }

    private static boolean cancelReg(long userID) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(false);
        boolean valid = false;
        com.android.server.security.trustcircle.tlv.command.register.CMD_REG_CANCEL reqTLV = new com.android.server.security.trustcircle.tlv.command.register.CMD_REG_CANCEL();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        int resultCode = sendCmd(reqTLV).getResultCode();
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            currentUserId = -1;
            valid = true;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("cancelRegister-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
        return valid;
    }

    private static boolean cancelLogin(long userID) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnable(false);
        boolean valid = false;
        com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_CANCEL reqTLV = new com.android.server.security.trustcircle.tlv.command.login.CMD_LOGIN_CANCEL();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        int resultCode = sendCmd(reqTLV).getResultCode();
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            currentUserId = -1;
            valid = true;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("cancelLogin-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
        return valid;
    }

    public static boolean logout(long userID) {
        boolean valid = false;
        com.android.server.security.trustcircle.tlv.command.logout.CMD_LOGOUT_REQ reqTLV = new com.android.server.security.trustcircle.tlv.command.logout.CMD_LOGOUT_REQ();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        int resultCode = sendCmd(reqTLV).getResultCode();
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            currentUserId = -1;
            valid = true;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("logout-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        return onLogoutResult(resultCode) && valid;
    }

    public static boolean onLogoutResult(int resultCode) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnableByResultCodeReverse(resultCode);
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.LOGOUT, false);
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onLogoutResult(resultCode);
                com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
                return true;
            }
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onLogoutResult: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        }
    }

    public static boolean unregister(long userID) {
        boolean valid = false;
        currentUserId = userID;
        com.android.server.security.trustcircle.tlv.command.register.CMD_UNREG_REQ reqTLV = new com.android.server.security.trustcircle.tlv.command.register.CMD_UNREG_REQ();
        reqTLV.userID.setTLVStruct(java.lang.Long.valueOf(userID));
        int resultCode = sendCmd(reqTLV).getResultCode();
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            valid = true;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("unregister-resultCode: ");
        stringBuilder.append(resultCode);
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        return onUnregisterResult(resultCode) && valid;
    }

    public static boolean onUnregisterResult(int resultCode) {
        com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.setIotEnableByResultCodeReverse(resultCode);
        updateExceptionStepOfCurrentUser(resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep.UNREG, true);
        if (resultCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            currentUserId = -1;
        }
        try {
            if (com.android.server.security.trustcircle.CallbackManager.getInstance().isILifeCycleCallbackValid()) {
                com.android.server.security.trustcircle.CallbackManager.getInstance().getILifeCycleCallback().onUnregisterResult(resultCode);
                com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
                return true;
            }
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        } catch (android.os.RemoteException e) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("RemoteException in onUnregisterResult: ");
            stringBuilder.append(e.getMessage());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            com.android.server.security.trustcircle.CallbackManager.getInstance().unregisterILifeCycleCallback();
            return false;
        }
    }

    public static <T extends com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree> com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<T> sendCmd(T reqTLV) {
        return com.android.server.security.trustcircle.tlv.core.TLVEngine.decodeCmdTLV(processCmd(com.android.server.security.trustcircle.tlv.core.TLVEngine.encode2CmdTLV(reqTLV)));
    }

    private static byte[] processCmd(byte[] request) {
        return com.android.server.security.trustcircle.jni.TcisJNI.processCmd(null, request);
    }

    public static android.content.ComponentName startTcisService(android.content.Context context) {
        if (context == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error- startTcisService: Context is null");
            return null;
        }
        android.content.Intent serviceIntent = new android.content.Intent();
        serviceIntent.setComponent(new android.content.ComponentName("com.huawei.trustcircle", "com.huawei.trustcircle.tcis.TCUpdateService"));
        serviceIntent.putExtra("taLoginedUserId", getLoginedUserID());
        return context.startServiceAsUser(serviceIntent, android.os.UserHandle.of(com.android.server.security.trustcircle.utils.Utils.getCurrentUserId()));
    }

    public static void updateExceptionStepOfCurrentUser(int resultCode, com.android.server.security.trustcircle.utils.Status.ExceptionStep step, boolean delete) {
        if (step != null) {
            if (currentUserId != -1) {
                com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState newState;
                java.lang.StringBuffer sb = new java.lang.StringBuffer();
                if (resultCode != com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
                    newState = new com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState(currentUserId, step.ordinal());
                } else {
                    newState = new com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState(currentUserId, com.android.server.security.trustcircle.utils.Status.ExceptionStep.NO_EXCEPTION.ordinal());
                }
                com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[] states = getUsersState();
                int number = states.length;
                boolean hasData = false;
                for (int j = 0; j < states.length; j++) {
                    if (states[j].getUserId() == currentUserId) {
                        hasData = true;
                        if (delete) {
                        } else {
                            states[j] = newState;
                        }
                    }
                    sb.append(states[j].getString());
                }
                if (!(hasData || delete)) {
                    sb.append(newState.getString());
                    number++;
                }
                com.android.server.security.trustcircle.utils.Utils.setProperty(com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().getContext(), "tcis_error_step", com.android.server.security.trustcircle.utils.ByteUtil.byteArrayOri2HexString(com.android.server.security.trustcircle.tlv.core.TLVEngine.encode2TLV(new com.android.server.security.trustcircle.tlv.command.query.DATA_TCIS_ERROR_STEP((short) number, new com.android.server.security.trustcircle.tlv.tree.StatesInfo(com.android.server.security.trustcircle.utils.ByteUtil.hexString2ByteArray(sb.toString()))))));
            }
        }
    }

    public static java.lang.String getExceptionSteps() {
        return com.android.server.security.trustcircle.utils.Utils.getProperty(com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.getInstance().getContext(), "tcis_error_step");
    }

    public static com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[] getUsersState() {
        int i = 0;
        com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[] userInfos = new com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[0];
        com.android.server.security.trustcircle.tlv.core.TLVTree oriData = com.android.server.security.trustcircle.tlv.core.TLVEngine.decodeTLV(com.android.server.security.trustcircle.utils.ByteUtil.hexString2byteArray(getExceptionSteps()));
        if (oriData != null && (oriData instanceof com.android.server.security.trustcircle.tlv.command.query.DATA_TCIS_ERROR_STEP)) {
            com.android.server.security.trustcircle.tlv.command.query.DATA_TCIS_ERROR_STEP data = (com.android.server.security.trustcircle.tlv.command.query.DATA_TCIS_ERROR_STEP) oriData;
            int number = ((java.lang.Short) data.numbers.getTLVStruct()).shortValue();
            byte[] infos = com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray((java.lang.Byte[]) ((com.android.server.security.trustcircle.tlv.tree.StatesInfo) data.info.getTLVStruct()).infos.getTLVStruct());
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("tcis number: ");
            stringBuilder.append(number);
            com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
            if (number != 0 && infos.length == 10 * number) {
                userInfos = new com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[number];
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.wrap(infos);
                buffer.order(java.nio.ByteOrder.BIG_ENDIAN);
                while (buffer.remaining() >= 10 && i <= number) {
                    userInfos[i] = new com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState(buffer.getLong(), buffer.getShort());
                    i++;
                }
            }
        }
        return userInfos;
    }

    public static int getExceptionStepOfCurrentUserId() {
        com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.UsersState[] states = getUsersState();
        for (int j = 0; j < states.length; j++) {
            if (states[j].getUserId() == currentUserId) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("tcis user ");
                stringBuilder.append(currentUserId);
                stringBuilder.append(" ,exception step: ");
                stringBuilder.append(states[j].getState());
                com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
                return states[j].getState();
            }
        }
        java.lang.String str2 = TAG;
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("no exception data in tcis user ");
        stringBuilder2.append(currentUserId);
        com.android.server.security.trustcircle.utils.LogHelper.w(str2, stringBuilder2.toString());
        return com.android.server.security.trustcircle.utils.Status.ExceptionStep.NO_EXCEPTION.ordinal();
    }
}
