package com.android.server.security.trustcircle.lifecycle;

public class NetworkChangeReceiver extends android.content.BroadcastReceiver {
    private static final java.lang.String TAG = com.android.server.security.trustcircle.lifecycle.NetworkChangeReceiver.class.getSimpleName();
    private static volatile long lastNetworkAvailableTime = java.lang.System.currentTimeMillis();

    public void onReceive(android.content.Context context, android.content.Intent intent) {
        if (intent != null) {
            if (context != null) {
                if ("android.net.conn.CONNECTIVITY_CHANGE".equals(intent.getAction())) {
                    android.net.NetworkInfo info = (android.net.NetworkInfo) intent.getParcelableExtra("networkInfo");
                    java.lang.String str;
                    java.lang.StringBuilder stringBuilder;
                    if (info == null) {
                        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error: NetworkInfo is null");
                    } else if (android.net.NetworkInfo.State.CONNECTED != info.getState() || !info.isAvailable()) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(getConnectionType(info.getType()));
                        stringBuilder.append(" disconnected");
                        com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
                    } else if (info.getType() == 1 || info.getType() == 0) {
                        str = TAG;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(getConnectionType(info.getType()));
                        stringBuilder.append(" connected");
                        com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
                        long currentTime = java.lang.System.currentTimeMillis();
                        if (!(isHwIdAndTaLoginedStateConsistent(context) && com.android.server.security.trustcircle.utils.Status.ExceptionStep.NO_EXCEPTION.ordinal() == com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getExceptionStepOfCurrentUserId())) {
                            if (com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.startTcisService(context) == null) {
                                com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error: could not start tcis service");
                            } else {
                                updateTime(currentTime);
                            }
                        }
                    }
                } else {
                    java.lang.String str2 = TAG;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("error: receive unexpected intent ");
                    stringBuilder2.append(intent.getAction());
                    com.android.server.security.trustcircle.utils.LogHelper.e(str2, stringBuilder2.toString());
                }
                return;
            }
        }
        com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error: intent or context is null");
    }

    private java.lang.String getConnectionType(int type) {
        if (type == 0) {
            return "mobile network";
        }
        if (type == 1) {
            return "WIFI network";
        }
        return "unknown network";
    }

    public static void updateTime(long time) {
        synchronized (com.android.server.security.trustcircle.lifecycle.NetworkChangeReceiver.class) {
            lastNetworkAvailableTime = time;
        }
    }

    public static boolean isHwIdAndTaLoginedStateConsistent(android.content.Context context) {
        return com.android.server.security.trustcircle.utils.Utils.hasLoginAccount(context) == ((com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getLoginedUserID() > -1 ? 1 : (com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getLoginedUserID() == -1 ? 0 : -1)) != 0);
    }
}
