package com.android.server.security.trustcircle.lifecycle;

public class TcisLifeCycleDispatcher {
    private static final java.lang.String TAG = com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.class.getSimpleName();
    private static volatile boolean isReadyForIot;
    private static volatile com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher sInstance;
    private android.content.Context mContext;
    private volatile com.android.server.security.trustcircle.lifecycle.LifeCycleStateMachine stateMachine = new com.android.server.security.trustcircle.lifecycle.LifeCycleStateMachine();

    public static class CancelData {
        long userID;

        public CancelData(long userID) {
            this.userID = userID;
        }
    }

    public static class LoginServerRequestData {
        int serverRegisterStatus;
        java.lang.String sessionID;
        long userID;

        public LoginServerRequestData(long userID, int serverRegisterStatus, java.lang.String sessionID) {
            this.userID = userID;
            this.serverRegisterStatus = serverRegisterStatus;
            this.sessionID = sessionID;
        }
    }

    public static class LogoutData {
        long userID;

        public LogoutData(long userID) {
            this.userID = userID;
        }
    }

    public static class RegisterData {
        java.lang.String authPKInfo;
        java.lang.String authPKInfoSign;
        java.lang.String updateIndexInfo;
        java.lang.String updateIndexSignature;

        public RegisterData(java.lang.String authPKInfo, java.lang.String authPKInfoSign, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
            this.authPKInfo = authPKInfo;
            this.authPKInfoSign = authPKInfoSign;
            this.updateIndexInfo = updateIndexInfo;
            this.updateIndexSignature = updateIndexSignature;
        }
    }

    public static class UnregData {
        long userID;

        public UnregData(long userID) {
            this.userID = userID;
        }
    }

    public static class UpdateData {
        java.lang.String updateIndexInfo;
        java.lang.String updateIndexSignature;
        int updateResult;

        public UpdateData(int updateResult, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
            this.updateResult = updateResult;
            this.updateIndexInfo = updateIndexInfo;
            this.updateIndexSignature = updateIndexSignature;
        }
    }

    public static class UpdateRequestData {
        long userID;

        public UpdateRequestData(long userID) {
            this.userID = userID;
        }
    }

    private TcisLifeCycleDispatcher() {
    }

    public static com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher getInstance() {
        if (sInstance == null) {
            synchronized (com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.class) {
                if (sInstance == null) {
                    sInstance = new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher();
                }
            }
        }
        return sInstance;
    }

    public void setContext(android.content.Context context) {
        this.mContext = context;
    }

    public android.content.Context getContext() {
        return this.mContext;
    }

    public static boolean isReadyForIot(long targetUserId) {
        return checkUserIDLogined(targetUserId);
    }

    public static void setIotEnable(boolean ready) {
        isReadyForIot = ready;
    }

    public static void setIotEnableByResultCode(int errorCode) {
        if (errorCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            setIotEnable(true);
        } else {
            setIotEnable(false);
        }
    }

    public static void setIotEnableByResultCodeReverse(int errorCode) {
        if (errorCode == com.android.server.security.trustcircle.utils.Status.TCIS_Result.SUCCESS.value()) {
            setIotEnable(false);
        } else {
            setIotEnable(true);
        }
    }

    public android.os.Bundle getTcisInfo() {
        return com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getTcisInfo();
    }

    public int getCurrentState() {
        return this.stateMachine.getCurrentLifeState();
    }

    public void switchUser(int newUserHandle) {
        this.stateMachine.switchUser(newUserHandle);
    }

    public void initTcisOfCurrentUser() {
        initTcisByUserHandle(com.android.server.security.trustcircle.utils.Utils.getCurrentUserId());
    }

    public void initTcisByUserHandle(int userHandle) {
        switchUser(userHandle);
    }

    public static boolean checkUserIDLogined(long userID) {
        return com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getLoginedUserID() == userID;
    }

    public static long getLoginedUserID() {
        return com.android.server.security.trustcircle.lifecycle.LifeCycleProcessor.getLoginedUserID();
    }

    public void loginServerRequest(long userID, int serverRegisterStatus, java.lang.String sessionID) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("serverRegisterStatus: ");
        stringBuilder.append(serverRegisterStatus == 0 ? "not registered" : "registered");
        com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
        this.stateMachine.checkRegisterStatus(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.LoginServerRequestData(userID, serverRegisterStatus, sessionID));
    }

    public void finalRegister(java.lang.String authPKInfo, java.lang.String authPKInfoSign, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        this.stateMachine.getRegData(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.RegisterData(authPKInfo, authPKInfoSign, updateIndexInfo, updateIndexSignature));
    }

    public void updateServerRequest(long userID) {
        this.stateMachine.checkLoginStatus(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.UpdateRequestData(userID));
    }

    public void finalLogin(int updateResult, java.lang.String updateIndexInfo, java.lang.String updateIndexSignature) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("updateResult: ");
        stringBuilder.append(updateResult == 0 ? "no need update" : "need update");
        com.android.server.security.trustcircle.utils.LogHelper.d(str, stringBuilder.toString());
        this.stateMachine.getUpdateData(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.UpdateData(updateResult, updateIndexInfo, updateIndexSignature));
    }

    public void cancelRegOrLogin(long userID) {
        this.stateMachine.cancelRegOrLogin(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.CancelData(userID));
    }

    public void logout(long userID) {
        this.stateMachine.logout(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.LogoutData(userID));
    }

    public void unregister(long userID) {
        this.stateMachine.delAccount(new com.android.server.security.trustcircle.lifecycle.TcisLifeCycleDispatcher.UnregData(userID));
    }
}
