package com.android.server.security.trustcircle.task;

public class HwSecurityTaskThread extends java.lang.Thread {
    public static final int PRIORITY_HIGH = 0;
    public static final int PRIORITY_LOW = 2;
    public static final int PRIORITY_NORMAL = 1;
    private static final java.lang.String TAG = com.android.server.security.trustcircle.task.HwSecurityTaskThread.class.getSimpleName();
    private static com.android.server.security.trustcircle.task.HwSecurityTaskThread gInstance = null;
    private static java.lang.Object mInstanceLock = new java.lang.Object();
    private java.util.ArrayList<com.android.server.security.trustcircle.task.HwSecurityTaskBase> mHighPriorityTasks = new java.util.ArrayList();
    private java.util.ArrayList<com.android.server.security.trustcircle.task.HwSecurityTaskBase> mLowPriorityTasks = new java.util.ArrayList();
    private java.util.ArrayList<com.android.server.security.trustcircle.task.HwSecurityTaskBase> mNormalPriorityTasks = new java.util.ArrayList();
    private boolean mNotified = false;
    private java.lang.Object mSignal = new java.lang.Object();
    private boolean mStop = false;
    private java.lang.Object mTaskLock = new java.lang.Object();

    public void startThread() {
        synchronized (this.mSignal) {
            this.mStop = false;
            this.mNotified = false;
            start();
        }
    }

    public void stopThread() {
        synchronized (this.mSignal) {
            this.mStop = true;
            this.mNotified = true;
            this.mSignal.notifyAll();
        }
        try {
            join(0);
        } catch (java.lang.InterruptedException e) {
        }
    }

    public void notifyThread() {
        synchronized (this.mSignal) {
            this.mNotified = true;
            this.mSignal.notifyAll();
        }
    }

    public void waitThread() {
        try {
            synchronized (this.mSignal) {
                if (!this.mNotified) {
                    this.mSignal.wait();
                }
                this.mNotified = false;
            }
        } catch (java.lang.InterruptedException e) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "security taskthread wait failed.");
        }
    }

    public boolean checkQuit() {
        boolean z;
        synchronized (this.mSignal) {
            z = this.mStop;
        }
        return z;
    }

    public void run() {
        while (!checkQuit()) {
            com.android.server.security.trustcircle.task.HwSecurityTaskBase task = getNextTask();
            if (task != null) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("run: ");
                stringBuilder.append(task.getClass().getSimpleName());
                stringBuilder.append(", status: ");
                stringBuilder.append(task.getTaskStatus());
                com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
                if (task.getTaskStatus() == 0) {
                    task.execute();
                }
            } else {
                waitThread();
            }
        }
    }

    public boolean pushTask(com.android.server.security.trustcircle.task.HwSecurityTaskBase task, int priority) {
        boolean pushSucceed;
        synchronized (this.mTaskLock) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("pushTask: ");
            stringBuilder.append(task.getClass().getSimpleName());
            com.android.server.security.trustcircle.utils.LogHelper.i(str, stringBuilder.toString());
            switch (priority) {
                case 0:
                    pushSucceed = this.mHighPriorityTasks.add(task);
                    break;
                case 1:
                    pushSucceed = this.mNormalPriorityTasks.add(task);
                    break;
                case 2:
                    pushSucceed = this.mLowPriorityTasks.add(task);
                    break;
                default:
                    pushSucceed = this.mNormalPriorityTasks.add(task);
                    break;
            }
            if (pushSucceed) {
                task.onStart();
                notifyThread();
            } else {
                java.lang.String str2 = TAG;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("pushTask: ");
                stringBuilder2.append(task.getClass().getSimpleName());
                stringBuilder2.append(" failed, priority: ");
                stringBuilder2.append(priority);
                com.android.server.security.trustcircle.utils.LogHelper.w(str2, stringBuilder2.toString());
            }
        }
        return pushSucceed;
    }

    protected com.android.server.security.trustcircle.task.HwSecurityTaskBase getNextTask() {
        synchronized (this.mTaskLock) {
            com.android.server.security.trustcircle.task.HwSecurityTaskBase hwSecurityTaskBase;
            if (this.mHighPriorityTasks != null && !this.mHighPriorityTasks.isEmpty()) {
                hwSecurityTaskBase = (com.android.server.security.trustcircle.task.HwSecurityTaskBase) this.mHighPriorityTasks.remove(0);
                return hwSecurityTaskBase;
            } else if (this.mNormalPriorityTasks != null && !this.mNormalPriorityTasks.isEmpty()) {
                hwSecurityTaskBase = (com.android.server.security.trustcircle.task.HwSecurityTaskBase) this.mNormalPriorityTasks.remove(0);
                return hwSecurityTaskBase;
            } else if (this.mLowPriorityTasks == null || this.mLowPriorityTasks.isEmpty()) {
                return null;
            } else {
                hwSecurityTaskBase = (com.android.server.security.trustcircle.task.HwSecurityTaskBase) this.mLowPriorityTasks.remove(0);
                return hwSecurityTaskBase;
            }
        }
    }

    public static void staticPushTask(com.android.server.security.trustcircle.task.HwSecurityTaskBase task, int priority) {
        com.android.server.security.trustcircle.task.HwSecurityTaskThread gThread = getInstance();
        if (gThread != null) {
            gThread.pushTask(task, priority);
        }
    }

    public static void createInstance() {
        synchronized (mInstanceLock) {
            if (gInstance == null) {
                gInstance = new com.android.server.security.trustcircle.task.HwSecurityTaskThread();
            }
        }
    }

    public static com.android.server.security.trustcircle.task.HwSecurityTaskThread getInstance() {
        com.android.server.security.trustcircle.task.HwSecurityTaskThread hwSecurityTaskThread;
        synchronized (mInstanceLock) {
            hwSecurityTaskThread = gInstance;
        }
        return hwSecurityTaskThread;
    }

    public static void destroyInstance() {
        synchronized (mInstanceLock) {
            if (gInstance != null) {
                gInstance = null;
            }
        }
    }
}
