package com.android.server.security.trustcircle.tlv.core;

public class TLVEngine {
    public static final java.lang.String TAG = com.android.server.security.trustcircle.tlv.core.TLVEngine.class.getSimpleName();

    public static class TLVResult<T extends com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree> {
        private int resultCode;
        private T tlv;

        public TLVResult(int resultCode, T tlv) {
            this.resultCode = resultCode;
            this.tlv = tlv;
        }

        public int getResultCode() {
            return this.resultCode;
        }

        public <T extends com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree> T getResultTLV() {
            return this.tlv;
        }
    }

    public static byte[] encode2CmdTLV(com.android.server.security.trustcircle.tlv.core.TLVTree tree) {
        if (tree == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error_tlv: tlv is null");
            return new byte[0];
        } else if (tree instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) {
            return com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray(new com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.TLVRootTreeInvokerWrapper(new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker((com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) tree)).encapsulate());
        } else {
            if (tree instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVChildTree) {
                com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error_tlv: child tree can't be encapsulated to cmd");
                return new byte[0];
            }
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error_tlv: unknown tlv type - ");
            stringBuilder.append(tree.getClass().getSimpleName());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            return new byte[0];
        }
    }

    public static <T extends com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree> com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult<T> decodeCmdTLV(byte[] tlv) {
        com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.TLVRootTreeInvokerWrapper<com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree> wrapper = new com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.TLVRootTreeInvokerWrapper(null);
        T targetTree = null;
        int result = com.android.server.security.trustcircle.utils.Status.TCIS_Result.UNKNOWN.value();
        if (wrapper.parse(tlv)) {
            targetTree = (com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) wrapper.getTLVStruct();
            result = wrapper.getRetResult();
        } else {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error_tlv: parse failed");
        }
        return new com.android.server.security.trustcircle.tlv.core.TLVEngine.TLVResult(result, targetTree);
    }

    public static byte[] encode2TLV(com.android.server.security.trustcircle.tlv.core.TLVTree tree) {
        if (tree == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e(TAG, "error_tlv: tlv is null");
            return new byte[0];
        }
        com.android.server.security.trustcircle.tlv.core.TLVInvoker<?> invoker;
        if (tree instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) {
            invoker = new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker((com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) tree);
        } else if (tree instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVChildTree) {
            invoker = new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVChildTreeInvoker((com.android.server.security.trustcircle.tlv.core.TLVTree.TLVChildTree) tree);
        } else {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error_tlv: unknown tlv type - ");
            stringBuilder.append(tree.getClass().getSimpleName());
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
            return new byte[0];
        }
        return com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray(invoker.encapsulate());
    }

    public static <T extends com.android.server.security.trustcircle.tlv.core.TLVTree> T decodeTLV(byte[] tlv) {
        com.android.server.security.trustcircle.tlv.core.TLVInvoker<com.android.server.security.trustcircle.tlv.core.TLVTree> invoker = new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker();
        if (invoker.parse(tlv)) {
            return (com.android.server.security.trustcircle.tlv.core.TLVTree) invoker.getTLVStruct();
        }
        return null;
    }

    public static <T extends com.android.server.security.trustcircle.tlv.core.TLVTree> T decodeTLV(java.lang.Byte[] tlv) {
        return decodeTLV(com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray(tlv));
    }
}
