package com.android.server.security.trustcircle.tlv.core;

public abstract class TLVInvoker<T> implements com.android.server.security.trustcircle.tlv.core.ICommand {
    protected int mID;
    protected java.lang.Byte[] mOriginalByteArray;
    protected short mTag;
    protected T mType;
    protected java.lang.Byte[] zeroLength;

    public abstract <T> T byteArray2Type(java.lang.Byte[] bArr);

    public abstract <T> T findTypeByTag(short s);

    public abstract int getID();

    protected abstract short getTagByType(T t);

    public abstract boolean isTypeExists(int i);

    public abstract boolean isTypeExists(short s);

    public abstract <T> java.lang.Byte[] type2ByteArray(T t);

    public TLVInvoker() {
        this.mID = 0;
        this.mTag = (short) 0;
        this.mType = null;
        this.mOriginalByteArray = null;
        this.zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};
    }

    public TLVInvoker(int id) {
        this.mID = 0;
        this.mTag = (short) 0;
        this.mType = null;
        this.mOriginalByteArray = null;
        this.zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};
        this.mID = id;
    }

    public TLVInvoker(short tag) {
        this.mID = 0;
        this.mTag = (short) 0;
        this.mType = null;
        this.mOriginalByteArray = null;
        this.zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};
        this.mTag = tag;
    }

    public TLVInvoker(T t) {
        this.mID = 0;
        this.mTag = (short) 0;
        this.mType = null;
        this.mOriginalByteArray = null;
        this.zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};
        this.mType = t;
    }

    public TLVInvoker(short tag, T t) {
        this.mID = 0;
        this.mTag = (short) 0;
        this.mType = null;
        this.mOriginalByteArray = null;
        this.zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};
        this.mTag = tag;
        this.mType = t;
    }

    public boolean parse(java.lang.Byte[] bytes) {
        return parse(com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray(bytes));
    }

    public boolean parse(byte[] bytes) {
        com.android.server.security.trustcircle.utils.LogHelper.d("TLV", "************parseTLV************");
        if (bytes != null) {
            if (bytes.length != 0) {
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.wrap(bytes);
                buffer.order(java.nio.ByteOrder.BIG_ENDIAN);
                return parse(buffer);
            }
        }
        com.android.server.security.trustcircle.utils.LogHelper.d("TLV", "parsed tlv with no content");
        return false;
    }

    public boolean parse(java.nio.ByteBuffer buffer) {
        return parseTLVInternal(buffer);
    }

    private boolean parseTLVInternal(java.nio.ByteBuffer buffer) {
        java.lang.StringBuilder stringBuilder;
        if (buffer != null) {
            if (buffer.remaining() >= 4) {
                short tag = buffer.getShort();
                if (isTypeExists(tag)) {
                    this.mType = findTypeByTag(tag);
                    this.mTag = tag;
                    this.mID = getID();
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("parse tag: 0x");
                    stringBuilder2.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(tag));
                    com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder2.toString());
                    short claimedValueLength = buffer.getShort();
                    if (claimedValueLength >= (short) 0) {
                        if (buffer.remaining() >= claimedValueLength) {
                            byte[] originalValue = new byte[claimedValueLength];
                            buffer.get(originalValue, 0, claimedValueLength);
                            this.mOriginalByteArray = com.android.server.security.trustcircle.utils.ByteUtil.boxbyteArray(originalValue);
                            if (byteArray2Type(this.mOriginalByteArray) == null) {
                                com.android.server.security.trustcircle.utils.LogHelper.e("TLV", "error_tlv in TLVInvoker.parseTLVInternal");
                                return false;
                            }
                            java.lang.Class clazz = com.android.server.security.trustcircle.utils.ByteUtil.getType(this.mType);
                            java.lang.String classTypeString = clazz == null ? "null" : clazz.getSimpleName();
                            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                            stringBuilder3.append("Vlength:");
                            stringBuilder3.append(claimedValueLength);
                            stringBuilder3.append(" type:");
                            stringBuilder3.append(classTypeString);
                            stringBuilder3.append("\nvalue: ");
                            stringBuilder3.append(com.android.server.security.trustcircle.utils.ByteUtil.type2HexString(this.mType));
                            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder3.toString());
                            return true;
                        }
                    }
                    java.lang.StringBuilder stringBuilder4 = new java.lang.StringBuilder();
                    stringBuilder4.append("error_tlv: Invalid TLV-- tag: 0x");
                    stringBuilder4.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(tag));
                    stringBuilder4.append(" length: ");
                    stringBuilder4.append(claimedValueLength);
                    com.android.server.security.trustcircle.utils.LogHelper.e("TLV", stringBuilder4.toString());
                    return false;
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("error_tlv: unknown tag: 0x");
                stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(tag));
                com.android.server.security.trustcircle.utils.LogHelper.d(stringBuilder.toString(), new java.lang.String[0]);
                return false;
            }
        }
        java.lang.String str = "TLV";
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("error_tlv: remaining tlv is too short: ");
        stringBuilder.append(buffer == null ? "buffer is null" : java.lang.Integer.valueOf(buffer.remaining()));
        com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
        return false;
    }

    public java.lang.Byte[] encapsulate() {
        com.android.server.security.trustcircle.utils.LogHelper.d("TLV", "************encapsulate to TLV************");
        if (this.mType == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e("TLV", "error_tlv in encapsulate: no encapsulated tlv");
            return new java.lang.Byte[0];
        } else if (this.mTag == (short) 0) {
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", "encapsulated TLV has no content");
            return new java.lang.Byte[0];
        } else {
            java.lang.Byte[] length;
            java.lang.Byte[] targetTLV;
            java.lang.StringBuilder stringBuilder;
            this.mTag = getTagByType(this.mType);
            java.lang.Byte[] tag = com.android.server.security.trustcircle.utils.ByteUtil.short2ByteArray(this.mTag);
            java.lang.Byte[] value = type2ByteArray(this.mType);
            if (value != null) {
                if (value.length != 0) {
                    length = com.android.server.security.trustcircle.utils.ByteUtil.short2ByteArray((short) value.length);
                    targetTLV = new java.lang.Byte[((tag.length + length.length) + value.length)];
                    java.lang.System.arraycopy(tag, 0, targetTLV, 0, tag.length);
                    java.lang.System.arraycopy(length, 0, targetTLV, tag.length, length.length);
                    java.lang.System.arraycopy(value, 0, targetTLV, tag.length + length.length, value.length);
                    java.lang.System.arraycopy(value, 0, targetTLV, tag.length + length.length, value.length);
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("[T, L]: [0x");
                    stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(this.mTag));
                    stringBuilder.append(", ");
                    stringBuilder.append(targetTLV.length);
                    stringBuilder.append(" bytes]");
                    com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("[T, L, V]: [");
                    stringBuilder.append(tag.length);
                    stringBuilder.append(", ");
                    stringBuilder.append(length.length);
                    stringBuilder.append(", ");
                    stringBuilder.append(value.length);
                    stringBuilder.append("]");
                    com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Value: ");
                    stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.type2HexString(value));
                    com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
                    return targetTLV;
                }
            }
            length = this.zeroLength;
            value = new java.lang.Byte[0];
            targetTLV = new java.lang.Byte[((tag.length + length.length) + value.length)];
            java.lang.System.arraycopy(tag, 0, targetTLV, 0, tag.length);
            java.lang.System.arraycopy(length, 0, targetTLV, tag.length, length.length);
            java.lang.System.arraycopy(value, 0, targetTLV, tag.length + length.length, value.length);
            java.lang.System.arraycopy(value, 0, targetTLV, tag.length + length.length, value.length);
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[T, L]: [0x");
            stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.short2HexString(this.mTag));
            stringBuilder.append(", ");
            stringBuilder.append(targetTLV.length);
            stringBuilder.append(" bytes]");
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[T, L, V]: [");
            stringBuilder.append(tag.length);
            stringBuilder.append(", ");
            stringBuilder.append(length.length);
            stringBuilder.append(", ");
            stringBuilder.append(value.length);
            stringBuilder.append("]");
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Value: ");
            stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.type2HexString(value));
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
            return targetTLV;
        }
    }

    public short getTag() {
        return this.mTag;
    }

    com.android.server.security.trustcircle.tlv.core.TLVInvoker<T> setTag(short tag) {
        this.mTag = tag;
        return this;
    }

    public T getTLVStruct() {
        return this.mType;
    }

    public com.android.server.security.trustcircle.tlv.core.TLVInvoker<T> setTLVStruct(T value) {
        this.mType = value;
        return this;
    }

    public int getSize() {
        return com.android.server.security.trustcircle.utils.ByteUtil.getSizeofType(this.mType);
    }

    public java.lang.String toString() {
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        if (this.mOriginalByteArray == null) {
            return sb.toString();
        }
        for (byte b : this.mOriginalByteArray) {
            sb.append(b.byteValue());
            sb.append(" ");
        }
        return sb.toString();
    }
}
