package com.android.server.security.trustcircle.tlv.core;

public abstract class TLVTreeInvokerWrapper<T extends com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker<com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree>> implements com.android.server.security.trustcircle.tlv.core.ICommand {
    private static java.util.HashMap<java.lang.Integer, com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker> CMD_MAP = new java.util.HashMap();
    private int mRetResult = com.android.server.security.trustcircle.utils.Status.TCIS_Result.UNKNOWN_CMD.value();
    T wrappedInvoker;

    public static class TLVRootTreeInvokerWrapper<TLVRootTreeInvoker> extends com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper<com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker<com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree>> {
        private static final int CMD_SIZE = 4;
        private static final int TLV_LENGT_SIZE = 4;
        private static final int TLV_RET_RESULT_LENGTH = 4;
        private java.lang.Byte[] zeroLength = new java.lang.Byte[]{java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0), java.lang.Byte.valueOf((byte) 0)};

        public TLVRootTreeInvokerWrapper(TLVRootTreeInvoker wrappedInvoker) {
            super((com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker) wrappedInvoker);
        }

        public boolean parse(java.nio.ByteBuffer buffer) {
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", ">>>>parse cmd<<<<");
            this.wrappedInvoker = getLegalTLVRootTreeCmd(buffer);
            if (this.wrappedInvoker != null) {
                if (this.wrappedInvoker.getTLVStruct() != null) {
                    if (this.wrappedInvoker.getTag() != (short) 0) {
                        return this.wrappedInvoker.parse(buffer);
                    }
                    com.android.server.security.trustcircle.utils.LogHelper.d("TLV", "the cmd has no tlv");
                    return true;
                }
            }
            return false;
        }

        public java.lang.Byte[] encapsulate() {
            com.android.server.security.trustcircle.utils.LogHelper.d("TLV", ">>>>encapsulate to cmd<<<<");
            if (this.wrappedInvoker == null) {
                com.android.server.security.trustcircle.utils.LogHelper.e("TLV", "error_tlv:encapsulated wrappedInvoker invalid");
                return new java.lang.Byte[0];
            } else if (this.wrappedInvoker.getTLVStruct() instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) {
                int cmdID = ((com.android.server.security.trustcircle.tlv.core.TLVTree) this.wrappedInvoker.getTLVStruct()).getCmdID();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("encapsulated cmd id: 0x");
                stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.int2StrictHexString(cmdID));
                stringBuilder.append(", TLV:");
                stringBuilder.append(com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.getInvokerName(cmdID));
                com.android.server.security.trustcircle.utils.LogHelper.d("TLV", stringBuilder.toString());
                if (getRootTreeInvokerByCmdID(cmdID) == null) {
                    return new java.lang.Byte[0];
                }
                java.lang.Byte[] tlvLengthBytes;
                java.lang.Byte[] cmdIDBytes = com.android.server.security.trustcircle.utils.ByteUtil.int2ByteArray(cmdID);
                java.lang.Byte[] tlvBytes = this.wrappedInvoker.encapsulate();
                if (tlvBytes.length == 0) {
                    tlvLengthBytes = this.zeroLength;
                    tlvBytes = new java.lang.Byte[0];
                } else {
                    tlvLengthBytes = com.android.server.security.trustcircle.utils.ByteUtil.int2ByteArray((short) tlvBytes.length);
                }
                java.lang.Byte[] targetCmd = new java.lang.Byte[((cmdIDBytes.length + tlvLengthBytes.length) + tlvBytes.length)];
                java.lang.System.arraycopy(cmdIDBytes, 0, targetCmd, 0, cmdIDBytes.length);
                java.lang.System.arraycopy(tlvLengthBytes, 0, targetCmd, cmdIDBytes.length, tlvLengthBytes.length);
                java.lang.System.arraycopy(tlvBytes, 0, targetCmd, cmdIDBytes.length + tlvLengthBytes.length, tlvBytes.length);
                return targetCmd;
            } else {
                com.android.server.security.trustcircle.utils.LogHelper.e("TLV", "error_tlv:encapsulated tlv root tree invalid");
                return new java.lang.Byte[0];
            }
        }

        private com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker getLegalTLVRootTreeCmd(java.nio.ByteBuffer buffer) {
            if (buffer != null) {
                if (buffer.remaining() >= 8) {
                    int cmdID = buffer.getInt();
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("parsed cmd id: 0x");
                    stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.int2StrictHexString(cmdID));
                    stringBuilder.append(", TLV:");
                    stringBuilder.append(com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.getInvokerName(cmdID));
                    com.android.server.security.trustcircle.utils.LogHelper.i("TLV", stringBuilder.toString());
                    if (isCmdLegal(buffer, cmdID)) {
                        return getRootTreeInvokerByCmdID(cmdID);
                    }
                    return null;
                }
            }
            java.lang.String str = "TLV";
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("error_tlv:return cmd length invalid: ");
            stringBuilder2.append(buffer == null ? "buffer is null" : java.lang.Integer.valueOf(buffer.remaining()));
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder2.toString());
            return null;
        }

        private boolean isCmdLegal(java.nio.ByteBuffer buffer, int cmdID) {
            if (buffer != null) {
                if (buffer.remaining() >= 4) {
                    setRetResult(buffer.getInt());
                    if (buffer.remaining() >= 4) {
                        int claimedTLVLength = buffer.getInt();
                        int realTLVLength = buffer.remaining();
                        if (isInvokerExisted(cmdID)) {
                            if (claimedTLVLength == realTLVLength) {
                                return true;
                            }
                        }
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("error_tlv: cmd tlv length claimed: ");
                        stringBuilder.append(claimedTLVLength);
                        stringBuilder.append(", actual:");
                        stringBuilder.append(realTLVLength);
                        com.android.server.security.trustcircle.utils.LogHelper.e("TLV", stringBuilder.toString());
                        return false;
                    }
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("error_tlv: cmd tlv length description field length illegal:");
                    stringBuilder2.append(buffer.remaining());
                    com.android.server.security.trustcircle.utils.LogHelper.e("TLV", stringBuilder2.toString());
                    return false;
                }
            }
            java.lang.String str = "TLV";
            java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
            stringBuilder3.append("error_tlv:cmd result description field length illegal:");
            stringBuilder3.append(buffer == null ? "ByteBuffer is null" : java.lang.Integer.valueOf(buffer.remaining()));
            com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder3.toString());
            return false;
        }

        public boolean isInvokerExisted(int cmdID) {
            if (com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.getInvoker(cmdID) != null) {
                return true;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("error_tlv: unknown TLV cmd id:");
            stringBuilder.append(com.android.server.security.trustcircle.utils.ByteUtil.int2StrictHexString(cmdID));
            com.android.server.security.trustcircle.utils.LogHelper.e("TLV", stringBuilder.toString());
            return false;
        }

        private <T extends com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker> T getRootTreeInvokerByCmdID(int cmdID) {
            com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker invoker = com.android.server.security.trustcircle.tlv.core.TLVTreeInvokerWrapper.getInvoker(cmdID);
            if (invoker != null) {
                return invoker;
            }
            com.android.server.security.trustcircle.utils.LogHelper.e("TLV", "error_tlv: unknown TLV invoker");
            return null;
        }
    }

    public TLVTreeInvokerWrapper(T wrappedInvoker) {
        this.wrappedInvoker = wrappedInvoker;
    }

    public boolean parse(java.lang.Byte[] bytes) {
        return parse(com.android.server.security.trustcircle.utils.ByteUtil.unboxByteArray(bytes));
    }

    public boolean parse(byte[] bytes) {
        if (bytes != null) {
            if (bytes.length != 0) {
                java.nio.ByteBuffer buffer = java.nio.ByteBuffer.wrap(bytes);
                buffer.order(java.nio.ByteOrder.BIG_ENDIAN);
                return parse(buffer);
            }
        }
        return false;
    }

    public <T extends com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker<com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree>> T getWrappedInvoker() {
        return this.wrappedInvoker;
    }

    public com.android.server.security.trustcircle.tlv.core.TLVTree getTLVStruct() {
        return this.wrappedInvoker != null ? (com.android.server.security.trustcircle.tlv.core.TLVTree) this.wrappedInvoker.getTLVStruct() : null;
    }

    static {
        CMD_MAP.put(java.lang.Integer.valueOf(1), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(1));
        CMD_MAP.put(java.lang.Integer.valueOf(2), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(2));
        CMD_MAP.put(java.lang.Integer.valueOf(3), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(3));
        CMD_MAP.put(java.lang.Integer.valueOf(4), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(4));
        CMD_MAP.put(java.lang.Integer.valueOf(5), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(5));
        CMD_MAP.put(java.lang.Integer.valueOf(6), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(6));
        CMD_MAP.put(java.lang.Integer.valueOf(7), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(7));
        CMD_MAP.put(java.lang.Integer.valueOf(8), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(8));
        CMD_MAP.put(java.lang.Integer.valueOf(9), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(9));
        CMD_MAP.put(java.lang.Integer.valueOf(10), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(10));
        CMD_MAP.put(java.lang.Integer.valueOf(11), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(11));
        CMD_MAP.put(java.lang.Integer.valueOf(12), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(12));
        CMD_MAP.put(java.lang.Integer.valueOf(13), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(13));
        CMD_MAP.put(java.lang.Integer.valueOf(14), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(14));
        CMD_MAP.put(java.lang.Integer.valueOf(15), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(15));
        CMD_MAP.put(java.lang.Integer.valueOf(16), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(16));
        CMD_MAP.put(java.lang.Integer.valueOf(17), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(17));
        CMD_MAP.put(java.lang.Integer.valueOf(18), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(18));
        CMD_MAP.put(java.lang.Integer.valueOf(19), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(19));
        CMD_MAP.put(java.lang.Integer.valueOf(12), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(12));
        CMD_MAP.put(java.lang.Integer.valueOf(20), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(20));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483647), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483647));
        CMD_MAP.put(java.lang.Integer.valueOf(21), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(21));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483646), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483646));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483645), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483645));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483644), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483644));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483643), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483643));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483642), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483642));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483641), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483641));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483640), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483640));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483639), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483639));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483638), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483638));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483637), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483637));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483636), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483636));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483629), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483629));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483635), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483635));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483634), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483634));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483633), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483633));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483632), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483632));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483631), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483631));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483630), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483630));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483628), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483628));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483627), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483627));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483616), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483616));
        CMD_MAP.put(java.lang.Integer.valueOf(-2147483615), new com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker(-2147483615));
    }

    public int getRetResult() {
        return this.mRetResult;
    }

    protected void setRetResult(int mRetResult) {
        this.mRetResult = mRetResult;
    }

    private static com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker getInvoker(int id) {
        return (com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker) CMD_MAP.get(java.lang.Integer.valueOf(id));
    }

    private static java.lang.String getInvokerName(int id) {
        com.android.server.security.trustcircle.tlv.core.TLVTreeInvoker.TLVRootTreeInvoker invoker = getInvoker(id);
        if (invoker != null) {
            com.android.server.security.trustcircle.tlv.core.TLVTree tlv = invoker.getInvokeredTLVById(invoker.mID);
            if (tlv != null) {
                return tlv.getClass().getSimpleName();
            }
        }
        return "unknown";
    }
}
