package com.android.server.security.trustcircle.utils;

public class ByteUtil {
    public static final int BYTE_SIZE = 1;
    public static final java.lang.String CHECK_TABLE = "0123456789ABCDEFabcdef";
    public static final java.lang.String HEX_TABLE = "0123456789ABCDEF";
    public static final int INT_SIZE = 4;
    public static final int LONG_SIZE = 8;
    public static final int SHORT_SIZE = 2;
    public static final java.lang.String TAG = "ByteUtil";

    public static java.lang.String byte2HexString(byte raw) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("0123456789ABCDEF".charAt((raw & 240) >> 4));
        stringBuilder.append("0123456789ABCDEF".charAt(raw & 15));
        return stringBuilder.toString();
    }

    public static java.lang.String short2HexString(short raw) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("0123456789ABCDEF".charAt((61440 & raw) >> 12));
        stringBuilder.append("0123456789ABCDEF".charAt((raw & 3840) >> 8));
        stringBuilder.append("0123456789ABCDEF".charAt((raw & 240) >> 4));
        stringBuilder.append("0123456789ABCDEF".charAt(raw & 15));
        return stringBuilder.toString();
    }

    public static java.lang.Byte[] hexString2ByteArray(java.lang.String hexString) {
        int c = 0;
        if (!isLegalHexString(hexString)) {
            return new java.lang.Byte[0];
        }
        java.lang.StringBuffer sb = new java.lang.StringBuffer(hexString);
        if (sb.length() % 2 != 0) {
            sb.insert(0, "0");
        }
        java.lang.String hexs = sb.toString();
        java.lang.Byte[] res = new java.lang.Byte[(hexs.length() / 2)];
        char[] chs = hexs.toCharArray();
        int i = 0;
        while (i < chs.length) {
            try {
                res[c] = java.lang.Byte.valueOf((byte) java.lang.Integer.parseInt(new java.lang.String(chs, i, 2), 16));
            } catch (java.lang.NumberFormatException e) {
                com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "NumberFormatException in hexString2ByteArray");
            }
            i += 2;
            c++;
        }
        return res;
    }

    public static byte[] hexString2byteArray(java.lang.String hexString) {
        return unboxByteArray(hexString2ByteArray(hexString));
    }

    public static boolean isLegalHexString(java.lang.String input) {
        if (android.text.TextUtils.isEmpty(input)) {
            return false;
        }
        int length = input.length();
        if (length <= 1 || length % 2 != 0) {
            return false;
        }
        int i = 0;
        while (i < length) {
            java.lang.String s = input.substring(i, i + 1);
            if ("0123456789ABCDEFabcdef".contains(s)) {
                i++;
            } else {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("input string is not hex string, at position:");
                stringBuilder.append(i + 1);
                stringBuilder.append("value: ");
                stringBuilder.append(s);
                com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", stringBuilder.toString());
                return false;
            }
        }
        return true;
    }

    public static java.lang.Byte[] short2ByteArray(short raw) {
        return hexString2ByteArray(short2HexString(raw));
    }

    public static java.lang.Byte[] int2ByteArray(int raw) {
        return hexString2ByteArray(int2StrictHexString(raw));
    }

    public static java.lang.String byteArray2HexString(java.lang.Byte[] raw) {
        if (raw != null) {
            if (raw.length != 0) {
                java.lang.StringBuilder hex = new java.lang.StringBuilder();
                for (byte b : raw) {
                    hex.append(byte2HexString(b.byteValue()));
                }
                return hex.toString();
            }
        }
        return null;
    }

    public static java.lang.String byteArrayOri2HexString(byte[] raw) {
        return byteArray2HexString(boxbyteArray(raw));
    }

    public static java.lang.Integer byteArray2Int(java.lang.Byte[] raw) {
        int result = -1;
        if (!(raw == null || raw.length == 0)) {
            if (raw.length == 4) {
                try {
                    result = java.lang.Integer.parseInt(byteArray2HexString(raw), 16);
                } catch (java.lang.NumberFormatException e) {
                    com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "NumberFormatException in byteArray2Int");
                }
                return java.lang.Integer.valueOf(result);
            }
        }
        java.lang.String str = "ByteUtil";
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("error: wrong int byte array size: ");
        stringBuilder.append(raw == null ? "0" : java.lang.Integer.valueOf(raw.length));
        com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
        return java.lang.Integer.valueOf(-1);
    }

    public static java.lang.Short byteArray2Short(java.lang.Byte[] raw) {
        short result = (short) -1;
        if (!(raw == null || raw.length == 0)) {
            if (raw.length == 2) {
                try {
                    result = java.lang.Short.parseShort(byteArray2HexString(raw), 16);
                } catch (java.lang.NumberFormatException e) {
                    com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "NumberFormatException in byteArray2Short");
                }
                return java.lang.Short.valueOf(result);
            }
        }
        java.lang.String str = "ByteUtil";
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("error: wrong short byte array size ");
        stringBuilder.append(raw == null ? "0" : java.lang.Integer.valueOf(raw.length));
        com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
        return java.lang.Short.valueOf((short) -1);
    }

    public static java.lang.Long byteArray2Long(java.lang.Byte[] raw) {
        long result = -1;
        if (!(raw == null || raw.length == 0)) {
            if (raw.length == 8) {
                try {
                    result = java.lang.Long.parseLong(byteArray2HexString(raw), 16);
                } catch (java.lang.NumberFormatException e) {
                    com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "NumberFormatException in byteArray2Long");
                }
                return java.lang.Long.valueOf(result);
            }
        }
        java.lang.String str = "ByteUtil";
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("error: wrong long byte array size ");
        stringBuilder.append(raw == null ? "0" : java.lang.Integer.valueOf(raw.length));
        com.android.server.security.trustcircle.utils.LogHelper.e(str, stringBuilder.toString());
        return java.lang.Long.valueOf(-1);
    }

    public static <T> java.lang.String getStringFormatOfTypeContent(T obj) {
        if (obj == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "getStringFormatOfTypeContent: input type is mull");
            return null;
        }
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        if (obj instanceof java.lang.Byte[]) {
            byte[] bytes = unboxByteArray((java.lang.Byte[]) obj);
            sb.append("{");
            for (int i = 0; i < bytes.length; i++) {
                sb.append(bytes[i]);
                if (i != bytes.length - 1) {
                    sb.append(", ");
                }
            }
            sb.append("}");
        } else {
            sb.append(obj.toString());
            sb.append(" ");
        }
        return sb.toString();
    }

    public static <T> java.lang.String printObjContent(T obj) {
        if (obj == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "printObjContent: input type is mull");
            return null;
        }
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        if (obj instanceof java.lang.Byte[]) {
            for (byte b : (byte[]) obj) {
                sb.append(b);
                sb.append(" ");
            }
        } else {
            sb.append(obj.toString());
            sb.append(" ");
        }
        return sb.toString();
    }

    public static <T> java.lang.Class getType(T t) {
        if (t == null) {
            return null;
        }
        if (t instanceof java.lang.Integer) {
            return java.lang.Integer.class;
        }
        if (t instanceof java.lang.Long) {
            return java.lang.Long.class;
        }
        if (t instanceof java.lang.Short) {
            return java.lang.Short.class;
        }
        if (t instanceof java.lang.Byte[]) {
            return java.lang.Byte[].class;
        }
        if (t instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree) {
            return com.android.server.security.trustcircle.tlv.core.TLVTree.TLVRootTree.class;
        }
        if (t instanceof com.android.server.security.trustcircle.tlv.core.TLVTree.TLVChildTree) {
            return com.android.server.security.trustcircle.tlv.core.TLVTree.TLVChildTree.class;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getType: unsupported type ");
        stringBuilder.append(t.getClass().getSimpleName());
        com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", stringBuilder.toString());
        return null;
    }

    public static <T> java.lang.Byte[] type2ByteArray(T t) {
        if (t == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "type2ByteArray: input is null");
            return new java.lang.Byte[0];
        } else if (t instanceof java.lang.Byte[]) {
            return (java.lang.Byte[]) t;
        } else {
            if (t instanceof java.lang.Short) {
                return hexString2ByteArray(type2HexString((java.lang.Short) t));
            }
            if (t instanceof java.lang.Integer) {
                return hexString2ByteArray(type2HexString((java.lang.Integer) t));
            }
            if (t instanceof java.lang.Long) {
                return hexString2ByteArray(type2HexString((java.lang.Long) t));
            }
            if (t instanceof com.android.server.security.trustcircle.tlv.core.TLVTree) {
                return ((com.android.server.security.trustcircle.tlv.core.TLVTree) t).encapsulate();
            }
            if (t instanceof java.lang.String) {
                return hexString2ByteArray(type2HexString((java.lang.String) t));
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("type2ByteArray: unsupported type ");
            stringBuilder.append(t.getClass().getSimpleName());
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", stringBuilder.toString());
            return new java.lang.Byte[0];
        }
    }

    public static <T> java.lang.String type2HexString(T t) {
        if (t == null) {
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", "type2HexString: input is null");
            return null;
        } else if (t instanceof java.lang.Short) {
            return short2HexString(((java.lang.Short) t).shortValue());
        } else {
            if (t instanceof java.lang.Byte[]) {
                return byteArray2HexString((java.lang.Byte[]) t);
            }
            if (t instanceof java.lang.Integer) {
                return int2StrictHexString(((java.lang.Integer) t).intValue());
            }
            if (t instanceof java.lang.Long) {
                return long2StrictHexString(((java.lang.Long) t).longValue());
            }
            if (t instanceof java.lang.String) {
                return (java.lang.String) t;
            }
            if (t instanceof com.android.server.security.trustcircle.tlv.core.TLVTree) {
                return com.android.server.security.trustcircle.tlv.core.TLVTree.class.getSimpleName();
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("type2HexString: unsupported type ");
            stringBuilder.append(t.getClass().getSimpleName());
            com.android.server.security.trustcircle.utils.LogHelper.e("ByteUtil", stringBuilder.toString());
            return null;
        }
    }

    public static java.lang.String int2StrictHexString(int src) {
        java.lang.StringBuffer sb = new java.lang.StringBuffer(java.lang.Integer.toHexString(src));
        while (sb.length() < 8) {
            sb.insert(0, "0");
        }
        return sb.toString();
    }

    public static java.lang.String long2StrictHexString(long src) {
        java.lang.StringBuffer sb = new java.lang.StringBuffer(java.lang.Long.toHexString(src));
        while (sb.length() < 16) {
            sb.insert(0, "0");
        }
        return sb.toString();
    }

    public static <T> int getSizeofType(T t) {
        if (t == null) {
            return 0;
        }
        java.lang.Class clazz = t.getClass();
        if (clazz == java.lang.Integer.class) {
            return 4;
        }
        if (clazz == java.lang.Long.class) {
            return 8;
        }
        if (clazz == java.lang.Short.class) {
            return 2;
        }
        if (clazz == java.lang.Byte[].class) {
            return ((byte[]) t).length;
        }
        return -1;
    }

    public static byte[] unboxByteArray(java.lang.Byte[] oBytes) {
        int i = 0;
        if (oBytes == null) {
            return new byte[0];
        }
        byte[] bytes = new byte[oBytes.length];
        while (i < oBytes.length) {
            bytes[i] = oBytes[i].byteValue();
            i++;
        }
        return bytes;
    }

    public static java.lang.Byte[] boxbyteArray(byte[] bytesPrim) {
        int i = 0;
        if (bytesPrim == null) {
            return new java.lang.Byte[0];
        }
        java.lang.Byte[] bytes = new java.lang.Byte[bytesPrim.length];
        int i2 = 0;
        int length = bytesPrim.length;
        while (i < length) {
            int i3 = i2 + 1;
            bytes[i2] = java.lang.Byte.valueOf(bytesPrim[i]);
            i++;
            i2 = i3;
        }
        return bytes;
    }

    public static java.lang.String byteArray2ServerHexString(byte[] bytes) {
        if (bytes != null) {
            if (bytes.length != 0) {
                java.lang.StringBuffer sb = new java.lang.StringBuffer();
                for (byte b : bytes) {
                    java.lang.String hex = java.lang.Integer.toHexString(b & 255);
                    if (hex.length() == 1) {
                        sb.append("0");
                    }
                    sb.append(hex.toLowerCase(java.util.Locale.US));
                }
                return sb.toString();
            }
        }
        return null;
    }

    public static java.lang.String byteArray2ServerHexString(java.lang.Byte[] bytes) {
        if (bytes != null) {
            if (bytes.length != 0) {
                java.lang.StringBuffer sb = new java.lang.StringBuffer();
                for (java.lang.Byte byteValue : bytes) {
                    java.lang.String hex = java.lang.Integer.toHexString(byteValue.byteValue() & 255);
                    if (hex.length() == 1) {
                        sb.append("0");
                    }
                    sb.append(hex.toLowerCase(java.util.Locale.US));
                }
                return sb.toString();
            }
        }
        return null;
    }

    public static java.lang.Byte[] serverHexString2ByteArray(java.lang.String string) {
        return hexString2ByteArray(string);
    }

    public static java.lang.Byte[] longToByteArray(long value) {
        long temp = value;
        java.lang.Byte[] b = new java.lang.Byte[8];
        for (int i = 0; i < b.length; i++) {
            b[i] = java.lang.Byte.valueOf((byte) ((int) java.lang.Long.valueOf(255 & temp).longValue()));
            temp >>= 8;
        }
        return b;
    }

    public static long byteArrayToLongDirect(java.lang.Byte[] b) {
        java.lang.Byte[] bArr = b;
        if (bArr != null) {
            if (bArr.length == 8) {
                long s = 0;
                long s0 = (long) (bArr[0].byteValue() & 255);
                long byteValue = s0 | (((long) (bArr[1].byteValue() & 255)) << 8);
                byteValue |= ((long) (bArr[2].byteValue() & 255)) << 16;
                byteValue |= ((long) (bArr[3].byteValue() & 255)) << 24;
                byteValue |= ((long) (bArr[4].byteValue() & 255)) << 32;
                byteValue |= ((long) (bArr[5].byteValue() & 255)) << 40;
                return (byteValue | (((long) (bArr[6].byteValue() & 255)) << 48)) | (((long) (bArr[7].byteValue() & 255)) << 56);
            }
        }
        return 0;
    }
}
