package com.android.server.security.trustspace;

public class TrustSpaceManagerService extends android.trustspace.ITrustSpaceManager.Stub implements com.android.server.security.core.IHwSecurityPlugin {
    private static final java.lang.String ACTION_INTENT_PREVENTED = "huawei.intent.action.TRUSTSPACE_INTENT_PREVENTED";
    private static final java.lang.String ACTION_PACKAGE_ADDED = "huawei.intent.action.TRUSTSPACE_PACKAGE_ADDED";
    private static final java.lang.String ACTION_PACKAGE_REMOVED = "huawei.intent.action.TRUSTSPACE_PACKAGE_REMOVED";
    public static final com.android.server.security.core.IHwSecurityPlugin.Creator CREATOR = new com.android.server.security.core.IHwSecurityPlugin.Creator() {
        public com.android.server.security.core.IHwSecurityPlugin createPlugin(android.content.Context context) {
            if (com.android.server.security.trustspace.TrustSpaceManagerService.HW_DEBUG) {
                android.util.Slog.d("TrustSpaceManagerService", "createPlugin");
            }
            return new com.android.server.security.trustspace.TrustSpaceManagerService(context);
        }

        public java.lang.String getPluginPermission() {
            return "com.huawei.permission.MANAGE_TRUSTSPACE";
        }
    };
    private static final java.lang.String HW_APPMARKET_PACKAGENAME = "com.huawei.appmarket";
    private static final boolean HW_DEBUG = android.util.Log.HWINFO;
    private static final java.lang.String HW_TRUSTSPACE_LAUNCHER = "com.huawei.trustspace.mainscreen.LoadActivity";
    private static final java.lang.String HW_TRUSTSPACE_PACKAGENAME = "com.huawei.trustspace";
    private static final int INVALID_CLONED_PROFILE = -1000;
    private static final boolean IS_SUPPORT_CLONE_APP = android.os.SystemProperties.getBoolean("ro.config.hw_support_clone_app", false);
    private static final java.lang.String MANAGE_TRUSTSPACE = "com.huawei.permission.MANAGE_TRUSTSPACE";
    private static final int RESULT_CODE_ERROR = -1;
    private static final java.lang.String SETTINGS_TRUSTSPACE_CONTROL = "trust_space_switch";
    private static final java.lang.String SETTINGS_TRUSTSPACE_SWITCH = "is_trustspace_enabled";
    private static final java.lang.String TAG = "TrustSpaceManagerService";
    private static final int TYPE_RISK = 303;
    private static final int TYPE_VIRUS = 305;
    private int mClonedProfileUserId;
    private android.content.Context mContext;
    private boolean mEnableTrustSpace = false;
    private final com.android.server.security.trustspace.TrustSpaceManagerService.MyPackageMonitor mMyPackageMonitor = new com.android.server.security.trustspace.TrustSpaceManagerService.MyPackageMonitor(this, null);
    private com.android.server.security.trustspace.TrustSpaceSettings mSettings;
    private final com.android.server.security.trustspace.TrustSpaceManagerService.MySettingsObserver mSettingsObserver = new com.android.server.security.trustspace.TrustSpaceManagerService.MySettingsObserver();
    private boolean mSupportTrustSpace = false;
    private final android.util.ArraySet<java.lang.String> mSystemApps = new android.util.ArraySet();
    private volatile boolean mSystemReady = false;
    private final android.util.ArraySet<java.lang.Integer> mSystemUids = new android.util.ArraySet();
    private final android.util.ArrayMap<java.lang.String, java.lang.Integer> mVirusScanResult = new android.util.ArrayMap();
    private com.android.server.security.securityprofile.SecurityProfileInternal securityProfileInternal = null;

    class MyBroadcastReceiver extends android.content.BroadcastReceiver {
        MyBroadcastReceiver() {
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if ("android.intent.action.USER_ADDED".equals(intent.getAction())) {
                int userId = intent.getIntExtra("android.intent.extra.user_handle", -10000);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("action add user");
                stringBuilder.append(userId);
                android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                if (!(userId == -10000 || userId == 0)) {
                    com.android.server.security.trustspace.TrustSpaceManagerService.this.enableTrustSpaceApp(false, false, userId);
                }
                if (com.android.server.security.trustspace.TrustSpaceManagerService.this.isClonedProfile(userId)) {
                    com.android.server.security.trustspace.TrustSpaceManagerService.this.updateClonedProfileUserId(userId);
                }
            }
        }
    }

    private final class MyPackageMonitor extends com.android.internal.content.PackageMonitor {
        private MyPackageMonitor() {
        }

        /* synthetic */ MyPackageMonitor(com.android.server.security.trustspace.TrustSpaceManagerService x0, com.android.server.security.trustspace.TrustSpaceManagerService.AnonymousClass1 x1) {
            this();
        }

        public void onPackageAdded(java.lang.String packageName, int uid) {
            com.android.server.security.trustspace.TrustSpaceManagerService.this.handlePackageAppeared(packageName, 3, uid);
        }

        public void onPackageRemoved(java.lang.String packageName, int uid) {
            com.android.server.security.trustspace.TrustSpaceManagerService.this.handlePackageDisappeared(packageName, 3, uid);
        }

        public void onPackageUpdateStarted(java.lang.String packageName, int uid) {
        }

        public void onPackageUpdateFinished(java.lang.String packageName, int uid) {
            com.android.server.security.trustspace.TrustSpaceManagerService.this.handlePackageAppeared(packageName, 1, uid);
        }
    }

    private class MySettingsObserver extends android.database.ContentObserver {
        private final android.net.Uri TRUSTSPACE_SWITCH_URI = android.provider.Settings.Secure.getUriFor("is_trustspace_enabled");

        public MySettingsObserver() {
            super(new android.os.Handler());
        }

        public void registerContentObserver() {
            com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.getContentResolver().registerContentObserver(this.TRUSTSPACE_SWITCH_URI, false, this, 0);
        }

        public void onChange(boolean selfChange, android.net.Uri uri) {
            if (this.TRUSTSPACE_SWITCH_URI.equals(uri)) {
                int i = 0;
                boolean enable = android.provider.Settings.Secure.getIntForUser(com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.getContentResolver(), "is_trustspace_enabled", 1, 0) == 1;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("TrustSpace Enabled = ");
                stringBuilder.append(enable);
                android.util.Slog.i("TrustSpaceManagerService", stringBuilder.toString());
                com.android.server.security.trustspace.TrustSpaceManagerService.this.mEnableTrustSpace = enable;
                if (com.android.server.security.trustspace.TrustSpaceManagerService.this.mSupportTrustSpace) {
                    com.android.server.security.trustspace.TrustSpaceManagerService.this.enableTrustSpaceApp(true, enable, 0);
                    android.content.ContentResolver contentResolver = com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.getContentResolver();
                    java.lang.String str = "trust_space_switch";
                    if (enable) {
                        i = 1;
                    }
                    android.provider.Settings.System.putInt(contentResolver, str, i);
                }
            }
        }
    }

    private final class LocalServiceImpl implements com.android.server.security.trustspace.TrustSpaceManagerInternal {
        private LocalServiceImpl() {
        }

        /* synthetic */ LocalServiceImpl(com.android.server.security.trustspace.TrustSpaceManagerService x0, com.android.server.security.trustspace.TrustSpaceManagerService.AnonymousClass1 x1) {
            this();
        }

        public boolean checkIntent(int type, java.lang.String calleePackage, int callerUid, int callerPid, java.lang.String callingPackage, int userId) {
            return com.android.server.security.trustspace.TrustSpaceManagerService.this.checkIntent(type, calleePackage, callerUid, callerPid, callingPackage, userId);
        }

        public void initTrustSpace() {
            com.android.server.security.trustspace.TrustSpaceManagerService.this.initTrustSpace();
        }

        public boolean isIntentProtectedApp(java.lang.String pkg) {
            return com.android.server.security.trustspace.TrustSpaceManagerService.this.isIntentProtectedAppInner(pkg);
        }

        public int getProtectionLevel(java.lang.String packageName) {
            return com.android.server.security.trustspace.TrustSpaceManagerService.this.getProtectionLevel(packageName);
        }
    }

    private class ScreenshotProtector extends com.android.server.security.securityprofile.ScreenshotProtectorCallback {
        private ScreenshotProtector() {
        }

        /* synthetic */ ScreenshotProtector(com.android.server.security.trustspace.TrustSpaceManagerService x0, com.android.server.security.trustspace.TrustSpaceManagerService.AnonymousClass1 x1) {
            this();
        }

        public boolean isProtectedApp(java.lang.String packageName) {
            if (android.app.ActivityManager.getCurrentUser() == 0 && com.android.server.security.trustspace.TrustSpaceManagerService.this.getProtectionLevel(packageName) == 2) {
                return true;
            }
            return false;
        }

        public void notifyInfo(java.lang.String projectionPack) {
            java.lang.String text = com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.getResources().getString(33686188);
            if (text != null) {
                java.lang.String packageLabel = projectionPack;
                android.content.pm.PackageManager pm = com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.getPackageManager();
                if (pm != null) {
                    try {
                        android.content.pm.ApplicationInfo info = pm.getApplicationInfoAsUser(projectionPack, 0, 0);
                        if (info != null) {
                            java.lang.CharSequence seq = pm.getApplicationLabel(info);
                            packageLabel = seq == null ? null : seq.toString();
                        }
                    } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("can not find ");
                        stringBuilder.append(projectionPack);
                        android.util.Slog.e("TrustSpaceManagerService", stringBuilder.toString());
                    }
                }
                if (packageLabel != null) {
                    text = text.replace("%s", packageLabel);
                }
                showToast(text);
            }
        }

        private void showToast(final java.lang.String text) {
            com.android.server.UiThread.getHandler().post(new java.lang.Runnable() {
                public void run() {
                    android.widget.Toast toast = android.widget.Toast.makeText(com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext, text, 1);
                    android.view.WindowManager.LayoutParams windowParams = toast.getWindowParams();
                    windowParams.privateFlags |= 16;
                    toast.show();
                }
            });
        }
    }

    public TrustSpaceManagerService(android.content.Context context) {
        this.mContext = context;
        this.mSettings = new com.android.server.security.trustspace.TrustSpaceSettings();
    }

    public void onStart() {
        android.util.Slog.d("TrustSpaceManagerService", "TrustSpaceManagerService Start");
        com.android.server.LocalServices.addService(com.android.server.security.trustspace.TrustSpaceManagerInternal.class, new com.android.server.security.trustspace.TrustSpaceManagerService.LocalServiceImpl(this, null));
        this.securityProfileInternal = (com.android.server.security.securityprofile.SecurityProfileInternal) com.android.server.LocalServices.getService(com.android.server.security.securityprofile.SecurityProfileInternal.class);
        if (this.securityProfileInternal != null) {
            this.securityProfileInternal.registerScreenshotProtector(new com.android.server.security.trustspace.TrustSpaceManagerService.ScreenshotProtector(this, null));
        }
    }

    public void onStop() {
    }

    public android.os.IBinder asBinder() {
        return this;
    }

    private void handlePackageAppeared(java.lang.String packageName, int reason, int uid) {
        if (isUseTrustSpace()) {
            int userId = android.os.UserHandle.getUserId(uid);
            if (userId == 0 || isClonedProfile(userId)) {
                if (HW_DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onPackageAppeared:");
                    stringBuilder.append(packageName);
                    stringBuilder.append(" reason=");
                    stringBuilder.append(reason);
                    stringBuilder.append(" uid=");
                    stringBuilder.append(uid);
                    android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                }
                if (userId == 0) {
                    removeVirusScanResult(packageName);
                }
                android.content.Intent intent = new android.content.Intent("huawei.intent.action.TRUSTSPACE_PACKAGE_ADDED");
                intent.putExtra("packageName", packageName);
                intent.putExtra("reason", reason);
                intent.putExtra("userId", userId);
                intent.setPackage("com.huawei.trustspace");
                this.mContext.startService(intent);
            }
        }
    }

    private void handlePackageDisappeared(java.lang.String packageName, int reason, int uid) {
        if (isUseTrustSpace()) {
            int userId = android.os.UserHandle.getUserId(uid);
            if (userId == 0 || isClonedProfile(userId)) {
                if (HW_DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onPackageDisappeared:");
                    stringBuilder.append(packageName);
                    stringBuilder.append(" reason=");
                    stringBuilder.append(reason);
                    stringBuilder.append(" uid=");
                    stringBuilder.append(uid);
                    android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                }
                if (userId == 0) {
                    removeVirusScanResult(packageName);
                    synchronized (this) {
                        boolean configChange = false;
                        boolean isProtectedApp = this.mSettings.isIntentProtectedApp(packageName);
                        boolean isTrustApp = this.mSettings.isTrustApp(packageName);
                        if (isProtectedApp && reason == 3) {
                            this.mSettings.removeIntentProtectedApp(packageName);
                            configChange = true;
                        }
                        if (isTrustApp && reason == 3) {
                            this.mSettings.removeTrustApp(packageName);
                            configChange = true;
                        }
                        if (configChange) {
                            this.mSettings.writePackages();
                        }
                    }
                }
                android.content.Intent intent = new android.content.Intent("huawei.intent.action.TRUSTSPACE_PACKAGE_REMOVED");
                intent.putExtra("packageName", packageName);
                intent.putExtra("reason", reason);
                intent.putExtra("userId", userId);
                intent.setPackage("com.huawei.trustspace");
                this.mContext.startService(intent);
            }
        }
    }

    private boolean isTrustSpaceEnable() {
        return android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "trust_space_switch", 1, 0) == 1;
    }

    private boolean isUseTrustSpace() {
        return this.mSupportTrustSpace && this.mEnableTrustSpace;
    }

    private boolean calledFromValidUser() {
        int uid = android.os.Binder.getCallingUid();
        int userId = android.os.UserHandle.getUserId(uid);
        if (uid != 1000) {
            if (userId != 0) {
                return false;
            }
        }
        return true;
    }

    private void removeVirusScanResult(java.lang.String packageName) {
        synchronized (this.mVirusScanResult) {
            this.mVirusScanResult.remove(packageName);
        }
    }

    private void addVirusScanResult(java.lang.String packageName, int type) {
        synchronized (this.mVirusScanResult) {
            this.mVirusScanResult.put(packageName, java.lang.Integer.valueOf(type));
        }
    }

    /* JADX WARNING: Missing block: B:18:0x0040, code:
            r1 = android.os.SystemClock.uptimeMillis();
            r6 = com.huawei.hsm.permission.StubController.getHoldService();
     */
    /* JADX WARNING: Missing block: B:19:0x0048, code:
            if (r6 != null) goto L_0x0056;
     */
    /* JADX WARNING: Missing block: B:21:0x004c, code:
            if (HW_DEBUG == false) goto L_0x0055;
     */
    /* JADX WARNING: Missing block: B:22:0x004e, code:
            android.util.Slog.e("TrustSpaceManagerService", "isMaliciousApp, service is null!");
     */
    /* JADX WARNING: Missing block: B:23:0x0055, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:24:0x0056, code:
            r7 = new android.os.Bundle();
            r7.putString("packageName", r15);
            r8 = null;
     */
    /* JADX WARNING: Missing block: B:27:0x0067, code:
            r8 = r6.callHsmService("isVirusApk", r7);
     */
    /* JADX WARNING: Missing block: B:28:0x0069, code:
            r9 = move-exception;
     */
    /* JADX WARNING: Missing block: B:29:0x006a, code:
            r11 = new java.lang.StringBuilder();
            r11.append("callHsmService fail: ");
            r11.append(r9.getMessage());
            android.util.Slog.e("TrustSpaceManagerService", r11.toString());
     */
    private boolean isMaliciousApp(java.lang.String r15) {
        /*
        r14 = this;
        r0 = 0;
        if (r15 != 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r1 = r14.mVirusScanResult;
        monitor-enter(r1);
        r2 = r14.mVirusScanResult;	 Catch:{ all -> 0x00d6 }
        r2 = r2.containsKey(r15);	 Catch:{ all -> 0x00d6 }
        r3 = 1;
        r4 = 305; // 0x131 float:4.27E-43 double:1.507E-321;
        r5 = 303; // 0x12f float:4.25E-43 double:1.497E-321;
        if (r2 == 0) goto L_0x003f;
    L_0x0014:
        r2 = r14.mVirusScanResult;	 Catch:{ all -> 0x00d6 }
        r2 = r2.get(r15);	 Catch:{ all -> 0x00d6 }
        r2 = (java.lang.Integer) r2;	 Catch:{ all -> 0x00d6 }
        r2 = r2.intValue();	 Catch:{ all -> 0x00d6 }
        if (r2 == r5) goto L_0x0027;
    L_0x0022:
        if (r2 != r4) goto L_0x0025;
    L_0x0024:
        goto L_0x0027;
    L_0x0025:
        monitor-exit(r1);	 Catch:{ all -> 0x00d6 }
        return r0;
    L_0x0027:
        r0 = "TrustSpaceManagerService";
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x00d6 }
        r4.<init>();	 Catch:{ all -> 0x00d6 }
        r5 = "find Malicious App:";
        r4.append(r5);	 Catch:{ all -> 0x00d6 }
        r4.append(r15);	 Catch:{ all -> 0x00d6 }
        r4 = r4.toString();	 Catch:{ all -> 0x00d6 }
        android.util.Slog.i(r0, r4);	 Catch:{ all -> 0x00d6 }
        monitor-exit(r1);	 Catch:{ all -> 0x00d6 }
        return r3;
    L_0x003f:
        monitor-exit(r1);	 Catch:{ all -> 0x00d6 }
        r1 = android.os.SystemClock.uptimeMillis();
        r6 = com.huawei.hsm.permission.StubController.getHoldService();
        if (r6 != 0) goto L_0x0056;
    L_0x004a:
        r3 = HW_DEBUG;
        if (r3 == 0) goto L_0x0055;
    L_0x004e:
        r3 = "TrustSpaceManagerService";
        r4 = "isMaliciousApp, service is null!";
        android.util.Slog.e(r3, r4);
    L_0x0055:
        return r0;
    L_0x0056:
        r7 = new android.os.Bundle;
        r7.<init>();
        r8 = "packageName";
        r7.putString(r8, r15);
        r8 = 0;
        r9 = "isVirusApk";
        r9 = r6.callHsmService(r9, r7);	 Catch:{ Exception -> 0x0069 }
        r8 = r9;
        goto L_0x0084;
    L_0x0069:
        r9 = move-exception;
        r10 = "TrustSpaceManagerService";
        r11 = new java.lang.StringBuilder;
        r11.<init>();
        r12 = "callHsmService fail: ";
        r11.append(r12);
        r12 = r9.getMessage();
        r11.append(r12);
        r11 = r11.toString();
        android.util.Slog.e(r10, r11);
    L_0x0084:
        r9 = android.os.SystemClock.uptimeMillis();
        r9 = r9 - r1;
        r11 = HW_DEBUG;
        if (r11 == 0) goto L_0x00a3;
    L_0x008d:
        r11 = "TrustSpaceManagerService";
        r12 = new java.lang.StringBuilder;
        r12.<init>();
        r13 = "isMaliciousApp cost: ";
        r12.append(r13);
        r12.append(r9);
        r12 = r12.toString();
        android.util.Slog.d(r11, r12);
    L_0x00a3:
        if (r8 != 0) goto L_0x00ad;
    L_0x00a5:
        r3 = "TrustSpaceManagerService";
        r4 = "isVirusApk, res is null";
        android.util.Slog.i(r3, r4);
        return r0;
    L_0x00ad:
        r11 = "result_code";
        r12 = -1;
        r11 = r8.getInt(r11, r12);
        if (r11 == r12) goto L_0x00b9;
    L_0x00b6:
        r14.addVirusScanResult(r15, r11);
    L_0x00b9:
        if (r11 == r5) goto L_0x00bf;
    L_0x00bb:
        if (r11 != r4) goto L_0x00be;
    L_0x00bd:
        goto L_0x00bf;
    L_0x00be:
        return r0;
    L_0x00bf:
        r0 = "TrustSpaceManagerService";
        r4 = new java.lang.StringBuilder;
        r4.<init>();
        r5 = "find Malicious App:";
        r4.append(r5);
        r4.append(r15);
        r4 = r4.toString();
        android.util.Slog.i(r0, r4);
        return r3;
    L_0x00d6:
        r0 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x00d6 }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.trustspace.TrustSpaceManagerService.isMaliciousApp(java.lang.String):boolean");
    }

    private boolean isSystemPackageInstalled(java.lang.String packageName, int flag) {
        android.content.pm.ApplicationInfo appInfo = null;
        try {
            appInfo = android.app.AppGlobals.getPackageManager().getApplicationInfo(packageName, flag, 0);
        } catch (android.os.RemoteException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Can't find package:");
            stringBuilder.append(packageName);
            android.util.Log.d("TrustSpaceManagerService", stringBuilder.toString());
        }
        if (appInfo == null || !appInfo.isSystemApp()) {
            return false;
        }
        return true;
    }

    private boolean isSupportTrustSpaceInner() {
        if (isSystemPackageInstalled("com.huawei.appmarket", 0)) {
            return true;
        }
        return false;
    }

    private void enableTrustSpaceApp(boolean enablePackage, boolean enableLauncher, int userId) {
        android.content.pm.IPackageManager pm = android.app.AppGlobals.getPackageManager();
        android.content.ComponentName cName = new android.content.ComponentName("com.huawei.trustspace", "com.huawei.trustspace.mainscreen.LoadActivity");
        int i = 2;
        int newPackageState = enablePackage ? 0 : 2;
        if (enableLauncher) {
            i = 0;
        }
        int newLauncherState = i;
        try {
            pm.setApplicationEnabledSetting("com.huawei.trustspace", newPackageState, 0, userId, null);
            if (enablePackage) {
                pm.setComponentEnabledSetting(cName, newLauncherState, 1, userId);
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("enableTrustSpaceApp fail: ");
            stringBuilder.append(e.getMessage());
            android.util.Slog.w("TrustSpaceManagerService", stringBuilder.toString());
        }
    }

    private void loadSystemPackages() {
        android.util.ArraySet<java.lang.Integer> tempUidSet = new android.util.ArraySet();
        android.util.ArraySet<java.lang.String> tempPkgSet = new android.util.ArraySet();
        java.util.List<android.content.pm.ApplicationInfo> allApp = null;
        try {
            allApp = android.app.AppGlobals.getPackageManager().getInstalledApplications(8192, 0).getList();
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("TrustSpaceManagerService", "Get Installed Applications fail");
        }
        if (allApp != null) {
            for (android.content.pm.ApplicationInfo app : allApp) {
                if (app.isSystemApp() && (app.hwFlags & 33554432) == 0) {
                    tempUidSet.add(java.lang.Integer.valueOf(app.uid));
                    tempPkgSet.add(app.packageName);
                }
            }
            this.mSystemUids.clear();
            this.mSystemUids.addAll(tempUidSet);
            this.mSystemApps.clear();
            this.mSystemApps.addAll(tempPkgSet);
        }
    }

    private int getClonedProfileId() {
        if (!IS_SUPPORT_CLONE_APP) {
            return -1000;
        }
        try {
            for (android.content.pm.UserInfo info : ((android.os.IUserManager) android.os.ServiceManager.getService("user")).getProfiles(0, false)) {
                if (info.isClonedProfile()) {
                    return info.id;
                }
            }
            android.util.Slog.d("TrustSpaceManagerService", "Cloned Profile is not exist");
        } catch (android.os.RemoteException e) {
            android.util.Slog.w("TrustSpaceManagerService", "Failed to getProfiles");
        }
        return -1000;
    }

    private boolean isClonedProfile(int userId) {
        boolean z = false;
        if (!IS_SUPPORT_CLONE_APP) {
            return false;
        }
        try {
            android.content.pm.UserInfo userInfo = ((android.os.IUserManager) android.os.ServiceManager.getService("user")).getUserInfo(userId);
            if (userInfo != null && userInfo.isClonedProfile()) {
                z = true;
            }
            return z;
        } catch (android.os.RemoteException e) {
            android.util.Slog.w("TrustSpaceManagerService", "Failed to getUserInfo");
            return false;
        }
    }

    private void updateClonedProfileUserId(int userId) {
        if (IS_SUPPORT_CLONE_APP && userId != -1000) {
            this.mClonedProfileUserId = userId;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Cloned profile user");
            stringBuilder.append(userId);
            android.util.Slog.i("TrustSpaceManagerService", stringBuilder.toString());
        }
    }

    private boolean checkClonedProfile(int userId) {
        boolean z = false;
        if (!IS_SUPPORT_CLONE_APP || userId == -1000) {
            return false;
        }
        if (userId == this.mClonedProfileUserId) {
            z = true;
        }
        return z;
    }

    private void initTrustSpace() {
        if (!this.mSystemReady) {
            android.util.Slog.i("TrustSpaceManagerService", "TrustSpaceManagerService init begin");
            if (isSystemPackageInstalled("com.huawei.trustspace", 0)) {
                this.mSupportTrustSpace = isSupportTrustSpaceInner();
                if (this.mSupportTrustSpace) {
                    synchronized (this) {
                        this.mSettings.readPackages();
                    }
                    loadSystemPackages();
                    this.mMyPackageMonitor.register(this.mContext, null, android.os.UserHandle.ALL, false);
                    this.mSettingsObserver.registerContentObserver();
                    updateClonedProfileUserId(getClonedProfileId());
                    this.mEnableTrustSpace = isTrustSpaceEnable();
                }
                android.content.IntentFilter broadcastFilter = new android.content.IntentFilter();
                broadcastFilter.addAction("android.intent.action.USER_ADDED");
                this.mContext.registerReceiver(new com.android.server.security.trustspace.TrustSpaceManagerService.MyBroadcastReceiver(), broadcastFilter);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Enable TrustSpace App: ");
                stringBuilder.append(this.mSupportTrustSpace);
                android.util.Slog.i("TrustSpaceManagerService", stringBuilder.toString());
                if (this.mSupportTrustSpace) {
                    enableTrustSpaceApp(true, this.mEnableTrustSpace, 0);
                } else {
                    disableTrustSpaceForAllUsers();
                }
                this.mSystemReady = true;
                android.util.Slog.i("TrustSpaceManagerService", "TrustSpaceManagerService init end");
                return;
            }
            android.util.Slog.e("TrustSpaceManagerService", "TrustSpace application is not exist");
        }
    }

    private void disableTrustSpaceForAllUsers() {
        try {
            for (android.content.pm.UserInfo user : ((android.os.IUserManager) android.os.ServiceManager.getService("user")).getUsers(false)) {
                enableTrustSpaceApp(false, false, user.id);
            }
        } catch (android.os.RemoteException e) {
            android.util.Slog.d("TrustSpaceManagerService", "disableTrustSpaceForAllUsers, failed to getUserInfo");
        }
    }

    private boolean isValidUser(int type, int userId) {
        int i = 0;
        boolean isValidUser = userId == 0;
        if (type == 1) {
            if (userId == -1) {
                i = 1;
            }
            isValidUser |= i;
        }
        return checkClonedProfile(userId) | isValidUser;
    }

    private boolean isSpecialCaller(java.lang.String packageName, int uid) {
        if (packageName != null) {
            return this.mSystemApps.contains(packageName);
        }
        if (uid >= 10000) {
            if (!this.mSystemUids.contains(java.lang.Integer.valueOf(uid))) {
                return false;
            }
        }
        return true;
    }

    private boolean isSelfCall(java.lang.String calleePackage, java.lang.String callingPackage) {
        return calleePackage != null && calleePackage.equals(callingPackage);
    }

    private boolean isSpecialCallee(java.lang.String packageName) {
        return this.mSystemApps.contains(packageName);
    }

    private boolean isSpecialPackage(java.lang.String callingPackage, int callerUid, java.lang.String calleePackage) {
        boolean isCallerIntentProtected;
        boolean isCalleeIntentProtected;
        boolean isSpecialCaller = isSpecialCaller(callingPackage, callerUid);
        boolean isSpecialCallee = isSpecialCallee(calleePackage);
        synchronized (this) {
            isCallerIntentProtected = this.mSettings.isIntentProtectedApp(callingPackage);
            isCalleeIntentProtected = this.mSettings.isIntentProtectedApp(calleePackage);
        }
        return (isSpecialCaller && !isCallerIntentProtected) || (isSpecialCallee && !isCalleeIntentProtected);
    }

    private boolean shouldNotify(int type, java.lang.String target) {
        if ((type == 0 || type == 2 || type == 3) && !isMaliciousApp(target)) {
            return true;
        }
        return false;
    }

    /* JADX WARNING: Missing block: B:29:0x0059, code:
            if (r7 != 0) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:30:0x005b, code:
            if (r6 != 0) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:31:0x005d, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:33:0x0060, code:
            if (HW_DEBUG == false) goto L_0x00b0;
     */
    /* JADX WARNING: Missing block: B:34:0x0062, code:
            r2 = new java.lang.StringBuilder();
            r2.append("check Intent, type: ");
            r2.append(r15);
            r2.append(" calleePackage: ");
            r2.append(r10);
            r2.append(" calleelevel=");
            r2.append(r7);
            r2.append(" callerPid:");
            r2.append(r12);
            r2.append(" callerUid:");
            r2.append(r11);
            r2.append(" callerPackage:");
            r2.append(r13);
            r2.append(" callerLevel=");
            r2.append(r6);
            r2.append(" userId:");
            r2.append(r14);
            android.util.Slog.d("TrustSpaceManagerService", r2.toString());
     */
    /* JADX WARNING: Missing block: B:35:0x00b0, code:
            r0 = false;
            r2 = false;
     */
    /* JADX WARNING: Missing block: B:36:0x00b3, code:
            if (r7 != 1) goto L_0x00c3;
     */
    /* JADX WARNING: Missing block: B:37:0x00b5, code:
            if (r6 != 0) goto L_0x00c2;
     */
    /* JADX WARNING: Missing block: B:38:0x00b7, code:
            if (r17 == false) goto L_0x00ba;
     */
    /* JADX WARNING: Missing block: B:41:0x00be, code:
            if (isMaliciousApp(r13) == false) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:42:0x00c0, code:
            r0 = true;
     */
    /* JADX WARNING: Missing block: B:43:0x00c2, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:44:0x00c3, code:
            if (r6 != 1) goto L_0x00d3;
     */
    /* JADX WARNING: Missing block: B:45:0x00c5, code:
            if (r7 != 0) goto L_0x00d2;
     */
    /* JADX WARNING: Missing block: B:46:0x00c7, code:
            if (r16 == false) goto L_0x00ca;
     */
    /* JADX WARNING: Missing block: B:49:0x00ce, code:
            if (isMaliciousApp(r10) == false) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:50:0x00d0, code:
            r0 = true;
     */
    /* JADX WARNING: Missing block: B:51:0x00d2, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:53:0x00d4, code:
            if (r7 != 2) goto L_0x00e5;
     */
    /* JADX WARNING: Missing block: B:54:0x00d6, code:
            if (r6 != 0) goto L_0x00e4;
     */
    /* JADX WARNING: Missing block: B:55:0x00d8, code:
            if (r17 == false) goto L_0x00db;
     */
    /* JADX WARNING: Missing block: B:57:0x00db, code:
            r0 = true;
     */
    /* JADX WARNING: Missing block: B:58:0x00e0, code:
            if (shouldNotify(r9, r13) == false) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:59:0x00e2, code:
            r2 = true;
     */
    /* JADX WARNING: Missing block: B:60:0x00e4, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:61:0x00e5, code:
            if (r6 != 2) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:63:0x00eb, code:
            if (isMaliciousApp(r10) != false) goto L_0x00ee;
     */
    /* JADX WARNING: Missing block: B:64:0x00ed, code:
            return false;
     */
    /* JADX WARNING: Missing block: B:65:0x00ee, code:
            r0 = true;
     */
    /* JADX WARNING: Missing block: B:66:0x00ef, code:
            r18 = r0;
            r0 = r2;
     */
    /* JADX WARNING: Missing block: B:67:0x00f6, code:
            if (isMaliciousApp(r13) != false) goto L_0x0100;
     */
    /* JADX WARNING: Missing block: B:69:0x00fc, code:
            if (isMaliciousApp(r10) == false) goto L_0x00ff;
     */
    /* JADX WARNING: Missing block: B:72:0x0100, code:
            r1 = true;
     */
    /* JADX WARNING: Missing block: B:73:0x0101, code:
            r5 = r1;
     */
    /* JADX WARNING: Missing block: B:74:0x0102, code:
            if (r5 == false) goto L_0x0119;
     */
    /* JADX WARNING: Missing block: B:75:0x0104, code:
            if (r9 == 1) goto L_0x0119;
     */
    /* JADX WARNING: Missing block: B:76:0x0106, code:
            r20 = r5;
            r21 = r6;
            r22 = r7;
            notifyIntentPrevented(r15, r10, r7, r13, r6, 1);
     */
    /* JADX WARNING: Missing block: B:77:0x0119, code:
            r20 = r5;
            r21 = r6;
            r22 = r7;
     */
    /* JADX WARNING: Missing block: B:78:0x011f, code:
            if (r0 == false) goto L_0x012d;
     */
    /* JADX WARNING: Missing block: B:79:0x0121, code:
            notifyIntentPrevented(r15, r10, r22, r13, r21, false);
     */
    /* JADX WARNING: Missing block: B:80:0x012d, code:
            if (r18 == false) goto L_0x018c;
     */
    /* JADX WARNING: Missing block: B:81:0x012f, code:
            r2 = new java.lang.StringBuilder();
            r2.append("prevent Intent, type: ");
            r2.append(r15);
            r2.append(" calleePackage: ");
            r2.append(r10);
            r2.append(" calleelevel=");
            r2.append(r22);
            r2.append(" callerPid:");
            r2.append(r12);
            r2.append(" callerUid:");
            r2.append(r11);
            r2.append(" callerPackage:");
            r2.append(r13);
            r2.append(" callerLevel=");
            r2.append(r21);
            r2.append(" isMalicious=");
            r2.append(r20);
            r2.append(" userId:");
            r2.append(r14);
            android.util.Slog.i("TrustSpaceManagerService", r2.toString());
     */
    /* JADX WARNING: Missing block: B:82:0x018c, code:
            r5 = r20;
            r4 = r21;
            r3 = r22;
     */
    /* JADX WARNING: Missing block: B:83:0x0192, code:
            return r18;
     */
    private boolean checkIntent(int r24, java.lang.String r25, int r26, int r27, java.lang.String r28, int r29) {
        /*
        r23 = this;
        r8 = r23;
        r9 = r24;
        r10 = r25;
        r11 = r26;
        r12 = r27;
        r13 = r28;
        r14 = r29;
        r0 = r23.isUseTrustSpace();
        r1 = 0;
        if (r0 == 0) goto L_0x01f2;
    L_0x0015:
        r0 = r8.isValidUser(r9, r14);
        if (r0 == 0) goto L_0x01f2;
    L_0x001b:
        r0 = r8.isSelfCall(r10, r13);
        if (r0 != 0) goto L_0x01f2;
    L_0x0021:
        r0 = r8.isSpecialPackage(r13, r11, r10);
        if (r0 == 0) goto L_0x0029;
    L_0x0027:
        goto L_0x01f2;
    L_0x0029:
        r15 = com.android.server.security.trustspace.TrustSpaceSettings.componentTypeToString(r24);
        if (r10 == 0) goto L_0x01b2;
    L_0x002f:
        if (r13 != 0) goto L_0x0033;
    L_0x0031:
        goto L_0x01b2;
    L_0x0033:
        r2 = 0;
        r3 = 0;
        r4 = 0;
        r5 = 0;
        monitor-enter(r23);
        r0 = r8.mSettings;	 Catch:{ all -> 0x01af }
        r0 = r0.isTrustApp(r10);	 Catch:{ all -> 0x01af }
        r16 = r0;
        r0 = r8.mSettings;	 Catch:{ all -> 0x01ab }
        r0 = r0.isTrustApp(r13);	 Catch:{ all -> 0x01ab }
        r17 = r0;
        r0 = r8.mSettings;	 Catch:{ all -> 0x01a5 }
        r0 = r0.getProtectionLevel(r10);	 Catch:{ all -> 0x01a5 }
        r7 = r0 & 255;
        r0 = r8.mSettings;	 Catch:{ all -> 0x019d }
        r0 = r0.getProtectionLevel(r13);	 Catch:{ all -> 0x019d }
        r6 = r0 & 255;
        monitor-exit(r23);	 Catch:{ all -> 0x0193 }
        if (r7 != 0) goto L_0x005e;
    L_0x005b:
        if (r6 != 0) goto L_0x005e;
    L_0x005d:
        return r1;
    L_0x005e:
        r0 = HW_DEBUG;
        if (r0 == 0) goto L_0x00b0;
    L_0x0062:
        r0 = "TrustSpaceManagerService";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "check Intent, type: ";
        r2.append(r3);
        r2.append(r15);
        r3 = " calleePackage: ";
        r2.append(r3);
        r2.append(r10);
        r3 = " calleelevel=";
        r2.append(r3);
        r2.append(r7);
        r3 = " callerPid:";
        r2.append(r3);
        r2.append(r12);
        r3 = " callerUid:";
        r2.append(r3);
        r2.append(r11);
        r3 = " callerPackage:";
        r2.append(r3);
        r2.append(r13);
        r3 = " callerLevel=";
        r2.append(r3);
        r2.append(r6);
        r3 = " userId:";
        r2.append(r3);
        r2.append(r14);
        r2 = r2.toString();
        android.util.Slog.d(r0, r2);
    L_0x00b0:
        r0 = 0;
        r2 = 0;
        r3 = 1;
        if (r7 != r3) goto L_0x00c3;
    L_0x00b5:
        if (r6 != 0) goto L_0x00c2;
    L_0x00b7:
        if (r17 == 0) goto L_0x00ba;
    L_0x00b9:
        goto L_0x00c2;
    L_0x00ba:
        r4 = r8.isMaliciousApp(r13);
        if (r4 == 0) goto L_0x00ef;
    L_0x00c0:
        r0 = 1;
        goto L_0x00ef;
    L_0x00c2:
        return r1;
    L_0x00c3:
        if (r6 != r3) goto L_0x00d3;
    L_0x00c5:
        if (r7 != 0) goto L_0x00d2;
    L_0x00c7:
        if (r16 == 0) goto L_0x00ca;
    L_0x00c9:
        goto L_0x00d2;
    L_0x00ca:
        r4 = r8.isMaliciousApp(r10);
        if (r4 == 0) goto L_0x00ef;
    L_0x00d0:
        r0 = 1;
        goto L_0x00ef;
    L_0x00d2:
        return r1;
    L_0x00d3:
        r4 = 2;
        if (r7 != r4) goto L_0x00e5;
    L_0x00d6:
        if (r6 != 0) goto L_0x00e4;
    L_0x00d8:
        if (r17 == 0) goto L_0x00db;
    L_0x00da:
        goto L_0x00e4;
    L_0x00db:
        r0 = 1;
        r4 = r8.shouldNotify(r9, r13);
        if (r4 == 0) goto L_0x00ef;
    L_0x00e2:
        r2 = 1;
        goto L_0x00ef;
    L_0x00e4:
        return r1;
    L_0x00e5:
        if (r6 != r4) goto L_0x00ef;
    L_0x00e7:
        r4 = r8.isMaliciousApp(r10);
        if (r4 != 0) goto L_0x00ee;
    L_0x00ed:
        return r1;
    L_0x00ee:
        r0 = 1;
    L_0x00ef:
        r18 = r0;
        r0 = r2;
        r2 = r8.isMaliciousApp(r13);
        if (r2 != 0) goto L_0x0100;
    L_0x00f8:
        r2 = r8.isMaliciousApp(r10);
        if (r2 == 0) goto L_0x00ff;
    L_0x00fe:
        goto L_0x0100;
    L_0x00ff:
        goto L_0x0101;
    L_0x0100:
        r1 = r3;
    L_0x0101:
        r5 = r1;
        if (r5 == 0) goto L_0x0119;
    L_0x0104:
        if (r9 == r3) goto L_0x0119;
    L_0x0106:
        r19 = 1;
        r1 = r8;
        r2 = r15;
        r3 = r10;
        r4 = r7;
        r20 = r5;
        r5 = r13;
        r21 = r6;
        r22 = r7;
        r7 = r19;
        r1.notifyIntentPrevented(r2, r3, r4, r5, r6, r7);
        goto L_0x012d;
    L_0x0119:
        r20 = r5;
        r21 = r6;
        r22 = r7;
        if (r0 == 0) goto L_0x012d;
    L_0x0121:
        r7 = 0;
        r1 = r8;
        r2 = r15;
        r3 = r10;
        r4 = r22;
        r5 = r13;
        r6 = r21;
        r1.notifyIntentPrevented(r2, r3, r4, r5, r6, r7);
    L_0x012d:
        if (r18 == 0) goto L_0x018c;
    L_0x012f:
        r1 = "TrustSpaceManagerService";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "prevent Intent, type: ";
        r2.append(r3);
        r2.append(r15);
        r3 = " calleePackage: ";
        r2.append(r3);
        r2.append(r10);
        r3 = " calleelevel=";
        r2.append(r3);
        r3 = r22;
        r2.append(r3);
        r4 = " callerPid:";
        r2.append(r4);
        r2.append(r12);
        r4 = " callerUid:";
        r2.append(r4);
        r2.append(r11);
        r4 = " callerPackage:";
        r2.append(r4);
        r2.append(r13);
        r4 = " callerLevel=";
        r2.append(r4);
        r4 = r21;
        r2.append(r4);
        r5 = " isMalicious=";
        r2.append(r5);
        r5 = r20;
        r2.append(r5);
        r6 = " userId:";
        r2.append(r6);
        r2.append(r14);
        r2 = r2.toString();
        android.util.Slog.i(r1, r2);
        goto L_0x0192;
    L_0x018c:
        r5 = r20;
        r4 = r21;
        r3 = r22;
    L_0x0192:
        return r18;
    L_0x0193:
        r0 = move-exception;
        r4 = r6;
        r3 = r7;
        r5 = r4;
        r2 = r16;
        r4 = r3;
        r3 = r17;
        goto L_0x01b0;
    L_0x019d:
        r0 = move-exception;
        r3 = r7;
        r4 = r3;
        r2 = r16;
        r3 = r17;
        goto L_0x01b0;
    L_0x01a5:
        r0 = move-exception;
        r2 = r16;
        r3 = r17;
        goto L_0x01b0;
    L_0x01ab:
        r0 = move-exception;
        r2 = r16;
        goto L_0x01b0;
    L_0x01af:
        r0 = move-exception;
    L_0x01b0:
        monitor-exit(r23);	 Catch:{ all -> 0x01af }
        throw r0;
    L_0x01b2:
        r0 = "TrustSpaceManagerService";
        r2 = new java.lang.StringBuilder;
        r2.<init>();
        r3 = "unknown Intent, type: ";
        r2.append(r3);
        r2.append(r15);
        r3 = " calleePackage: ";
        r2.append(r3);
        r2.append(r10);
        r3 = " callerPid:";
        r2.append(r3);
        r2.append(r12);
        r3 = " callerUid:";
        r2.append(r3);
        r2.append(r11);
        r3 = " callerPackage:";
        r2.append(r3);
        r2.append(r13);
        r3 = " userId:";
        r2.append(r3);
        r2.append(r14);
        r2 = r2.toString();
        android.util.Slog.w(r0, r2);
        return r1;
    L_0x01f2:
        return r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.trustspace.TrustSpaceManagerService.checkIntent(int, java.lang.String, int, int, java.lang.String, int):boolean");
    }

    private void notifyIntentPrevented(java.lang.String typeString, java.lang.String calleePackage, int calleeLevel, java.lang.String callerPackage, int callerLevel, boolean isMalicious) {
        final java.lang.String str = typeString;
        final java.lang.String str2 = calleePackage;
        final java.lang.String str3 = callerPackage;
        final int i = calleeLevel;
        final int i2 = callerLevel;
        final boolean z = isMalicious;
        com.android.server.UiThread.getHandler().post(new java.lang.Runnable() {
            public void run() {
                android.content.Intent intent = new android.content.Intent("huawei.intent.action.TRUSTSPACE_INTENT_PREVENTED");
                intent.putExtra("component", str);
                intent.putExtra("callee", str2);
                intent.putExtra("caller", str3);
                intent.putExtra("calleeLevel", i);
                intent.putExtra("callerLevel", i2);
                intent.putExtra("isMalicious", z);
                intent.setPackage("com.huawei.trustspace");
                com.android.server.security.trustspace.TrustSpaceManagerService.this.mContext.startService(intent);
                android.util.Slog.d("TrustSpaceManagerService", "Notify intent prevented.");
            }
        });
    }

    private boolean isIntentProtectedAppInner(java.lang.String packageName) {
        if (calledFromValidUser()) {
            if (packageName != null) {
                boolean isIntentProtectedApp;
                synchronized (this) {
                    isIntentProtectedApp = this.mSettings.isIntentProtectedApp(packageName);
                }
                return isIntentProtectedApp;
            }
        }
        return false;
    }

    public boolean addIntentProtectedApps(java.util.List<java.lang.String> packages, int flags) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (!calledFromValidUser()) {
            return false;
        }
        synchronized (this) {
            for (java.lang.String packageName : packages) {
                this.mSettings.addIntentProtectedApp(packageName, flags);
                if (HW_DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("add ");
                    stringBuilder.append(packageName);
                    stringBuilder.append(" to intent protected list, flags=");
                    stringBuilder.append(flags);
                    android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                }
            }
            this.mSettings.writePackages();
        }
        return true;
    }

    public boolean removeIntentProtectedApp(java.lang.String packageName) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (calledFromValidUser()) {
            if (packageName != null) {
                synchronized (this) {
                    this.mSettings.removeIntentProtectedApp(packageName);
                    this.mSettings.writePackages();
                    if (HW_DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("remove ");
                        stringBuilder.append(packageName);
                        stringBuilder.append(" from intent protected list");
                        android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                    }
                }
                return true;
            }
        }
        return false;
    }

    public java.util.List<java.lang.String> getIntentProtectedApps(int flags) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (!calledFromValidUser()) {
            return new java.util.ArrayList(0);
        }
        java.util.List intentProtectedApps;
        synchronized (this) {
            intentProtectedApps = this.mSettings.getIntentProtectedApps(flags);
        }
        return intentProtectedApps;
    }

    public boolean removeIntentProtectedApps(java.util.List<java.lang.String> packages, int flags) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (!calledFromValidUser()) {
            return false;
        }
        synchronized (this) {
            this.mSettings.removeIntentProtectedApps(packages, flags);
            this.mSettings.writePackages();
            if (HW_DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("remove apps in intent protected list, flag=");
                stringBuilder.append(flags);
                android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
            }
        }
        return true;
    }

    public boolean updateTrustApps(java.util.List<java.lang.String> packages, int flag) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (calledFromValidUser()) {
            if (packages != null) {
                synchronized (this) {
                    this.mSettings.updateTrustApps(packages, flag);
                    this.mSettings.writePackages();
                    if (HW_DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("update trust apps, flag=");
                        stringBuilder.append(flag);
                        android.util.Slog.d("TrustSpaceManagerService", stringBuilder.toString());
                    }
                }
                return true;
            }
        }
        return false;
    }

    public boolean isIntentProtectedApp(java.lang.String packageName) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (calledFromValidUser()) {
            if (packageName != null) {
                boolean isIntentProtectedApp;
                synchronized (this) {
                    isIntentProtectedApp = this.mSettings.isIntentProtectedApp(packageName);
                }
                return isIntentProtectedApp;
            }
        }
        return false;
    }

    public int getProtectionLevel(java.lang.String packageName) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (calledFromValidUser()) {
            if (packageName != null) {
                int protectionLevel;
                synchronized (this) {
                    protectionLevel = this.mSettings.getProtectionLevel(packageName);
                }
                return protectionLevel;
            }
        }
        return 0;
    }

    public boolean isSupportTrustSpace() {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        if (calledFromValidUser()) {
            return this.mSupportTrustSpace;
        }
        return false;
    }

    public boolean isHwTrustSpace(int userId) {
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.MANAGE_TRUSTSPACE", null);
        boolean z = false;
        if (!calledFromValidUser()) {
            return false;
        }
        long ident = android.os.Binder.clearCallingIdentity();
        try {
            android.content.pm.UserInfo userInfo = ((android.os.IUserManager) android.os.ServiceManager.getService("user")).getUserInfo(userId);
            if (userInfo != null && userInfo.isHwTrustSpace()) {
                z = true;
            }
            android.os.Binder.restoreCallingIdentity(ident);
            return z;
        } catch (android.os.RemoteException e) {
            android.util.Slog.d("TrustSpaceManagerService", "failed to getUserInfo");
            android.os.Binder.restoreCallingIdentity(ident);
            return false;
        } catch (java.lang.Throwable th) {
            android.os.Binder.restoreCallingIdentity(ident);
            throw th;
        }
    }
}
