package com.android.server.security.tsmagent.openapi.impl;

public class TSMAgentImpl implements com.android.server.security.tsmagent.openapi.ITSMOperator {
    private static final java.lang.String DIC_NAME = "apk.signature";
    private static volatile com.android.server.security.tsmagent.openapi.impl.TSMAgentImpl sInstance;
    private final java.util.ArrayList<java.lang.String> mAuthorizedCallers = new java.util.ArrayList();
    private final android.content.Context mContext;

    private TSMAgentImpl(android.content.Context context) {
        this.mContext = context;
    }

    public static com.android.server.security.tsmagent.openapi.impl.TSMAgentImpl getInstance(android.content.Context context) {
        if (sInstance == null) {
            synchronized (com.android.server.security.tsmagent.openapi.impl.TSMAgentImpl.class) {
                if (sInstance == null) {
                    sInstance = new com.android.server.security.tsmagent.openapi.impl.TSMAgentImpl(context);
                }
            }
        }
        return sInstance;
    }

    public int createSSD(java.lang.String packageName, java.lang.String spID, java.lang.String ssdAid, java.lang.String sign, java.lang.String timeStamp) {
        int retVal = handleOperations(packageName, spID, ssdAid, sign, timeStamp, "createSSD");
        org.json.JSONObject obj = new org.json.JSONObject();
        try {
            obj.put("PKG", packageName);
            obj.put("create ssd ret", retVal);
        } catch (org.json.JSONException e) {
            e.printStackTrace();
        }
        android.util.Flog.bdReport(this.mContext, 550, obj.toString());
        return retVal;
    }

    public int deleteSSD(java.lang.String packageName, java.lang.String spID, java.lang.String ssdAid, java.lang.String sign, java.lang.String timeStamp) {
        int retVal = handleOperations(packageName, spID, ssdAid, sign, timeStamp, "deleteSSD");
        org.json.JSONObject obj = new org.json.JSONObject();
        try {
            obj.put("PKG", packageName);
            obj.put("delete ssd ret", retVal);
        } catch (org.json.JSONException e) {
            e.printStackTrace();
        }
        android.util.Flog.bdReport(this.mContext, 551, obj.toString());
        return retVal;
    }

    public java.lang.String getCplc(java.lang.String packageName) {
        if (sechulePreCheck(packageName) != 0) {
            return null;
        }
        java.lang.String queryCplc;
        synchronized (this) {
            queryCplc = com.android.server.security.tsmagent.logic.ese.ESEInfoManager.getInstance(this.mContext).queryCplc();
        }
        return queryCplc;
    }

    public int initEse(java.lang.String packageName, java.lang.String spID, java.lang.String sign, java.lang.String timeStamp) {
        int preCheckResult = sechulePreCheck(packageName);
        if (preCheckResult != 0) {
            return preCheckResult;
        }
        int resultCode;
        synchronized (this) {
            resultCode = new com.android.server.security.tsmagent.logic.card.tsm.InitEseTsmOperator(this.mContext, spID, sign, timeStamp).excute();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("initEse  result : ");
            stringBuilder.append(resultCode);
            com.android.server.security.tsmagent.utils.HwLog.d(stringBuilder.toString());
            org.json.JSONObject obj = new org.json.JSONObject();
            try {
                obj.put("PKG", packageName);
                obj.put("sync ssd ret", resultCode);
            } catch (org.json.JSONException e) {
                e.printStackTrace();
            }
            android.util.Flog.bdReport(this.mContext, 552, obj.toString());
        }
        return resultCode;
    }

    private int handleOperations(java.lang.String packageName, java.lang.String spID, java.lang.String ssdAid, java.lang.String sign, java.lang.String timeStamp, java.lang.String operatorType) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("handleOperations: ");
        stringBuilder.append(operatorType);
        com.android.server.security.tsmagent.utils.HwLog.d(stringBuilder.toString());
        if (checkParams(packageName, spID, ssdAid, sign, timeStamp)) {
            int preCheckResult = sechulePreCheck(packageName);
            if (preCheckResult != 0) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("sechulePreCheck failed, error code: ");
                stringBuilder2.append(preCheckResult);
                com.android.server.security.tsmagent.utils.HwLog.w(stringBuilder2.toString());
                return preCheckResult;
            }
            int handleOperatorResult;
            synchronized (this) {
                handleOperatorResult = handleOperatorResult(new com.android.server.security.tsmagent.logic.card.tsm.CreateOrDeleteOpenSSDTsmOperator(this.mContext, ssdAid, spID, sign, timeStamp, operatorType).excute());
            }
            return handleOperatorResult;
        }
        com.android.server.security.tsmagent.utils.HwLog.w("checkParams failed");
        return 1;
    }

    private boolean checkParams(java.lang.String packageName, java.lang.String spID, java.lang.String ssdAid, java.lang.String sign, java.lang.String timeStamp) {
        if (!(com.android.server.security.tsmagent.utils.StringUtil.isTrimedEmpty(packageName) || com.android.server.security.tsmagent.utils.StringUtil.isTrimedEmpty(spID) || com.android.server.security.tsmagent.utils.StringUtil.isTrimedEmpty(ssdAid) || com.android.server.security.tsmagent.utils.StringUtil.isTrimedEmpty(sign))) {
            if (!com.android.server.security.tsmagent.utils.StringUtil.isTrimedEmpty(timeStamp)) {
                return true;
            }
        }
        return false;
    }

    public int sechulePreCheck(java.lang.String pkgName) {
        if (!checkSupportFeature()) {
            com.android.server.security.tsmagent.utils.HwLog.w("checkSupportFeature failed");
            return -1;
        } else if (!checkNetwork()) {
            com.android.server.security.tsmagent.utils.HwLog.w("checkNetwork no network");
            return 3;
        } else if (checkCallerSignature(pkgName)) {
            return 0;
        } else {
            return 2;
        }
    }

    private boolean checkSupportFeature() {
        com.android.server.security.tsmagent.utils.HwLog.d("checkSupportFeature");
        return "CN".equalsIgnoreCase(android.os.SystemProperties.get("ro.product.locale.region", ""));
    }

    public boolean checkNetwork() {
        com.android.server.security.tsmagent.utils.HwLog.d("checkNetwork");
        return com.android.server.security.tsmagent.utils.NetworkUtil.isNetworkConnected(this.mContext);
    }

    /* JADX WARNING: Removed duplicated region for block: B:35:0x00b7 A:{ExcHandler: java.security.AccessControlException (e java.security.AccessControlException), Splitter: B:14:0x0042} */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00b7 A:{ExcHandler: java.security.AccessControlException (e java.security.AccessControlException), Splitter: B:14:0x0042} */
    /* JADX WARNING: Missing block: B:36:0x00b8, code:
            r5 = new java.lang.StringBuilder();
            r5.append("HwNFCOpenApiImpl checkCaller failed. pkg : ");
            r5.append(r12);
            com.android.server.security.tsmagent.utils.HwLog.w(r5.toString());
     */
    /* JADX WARNING: Missing block: B:37:0x00cc, code:
            return false;
     */
    public boolean checkCallerSignature(java.lang.String r12) {
        /*
        r11 = this;
        r0 = "checkCallerSignature";
        com.android.server.security.tsmagent.utils.HwLog.d(r0);
        r0 = r11.mAuthorizedCallers;
        r0 = r0.contains(r12);
        r1 = 1;
        if (r0 == 0) goto L_0x0014;
    L_0x000e:
        r0 = "operateSSD checkCaller success end";
        com.android.server.security.tsmagent.utils.HwLog.d(r0);
        return r1;
    L_0x0014:
        r0 = new com.android.server.security.tsmagent.server.wallet.request.QueryDicsRequset;
        r0.<init>();
        r0.itemName = r12;
        r2 = "apk.signature";
        r0.dicName = r2;
        r2 = new com.android.server.security.tsmagent.server.card.impl.CardServer;
        r3 = r11.mContext;
        r2.<init>(r3);
        r2 = r2.queryDics(r0);
        r3 = 0;
        if (r2 == 0) goto L_0x00cd;
    L_0x002d:
        r4 = r2.returnCode;
        if (r4 == 0) goto L_0x0033;
    L_0x0031:
        goto L_0x00cd;
    L_0x0033:
        r4 = r2.dicItems;
        r4 = r4.size();
        if (r4 > 0) goto L_0x0041;
    L_0x003b:
        r1 = "operateSSD checkCaller failed. dicItems size <= 0.";
        com.android.server.security.tsmagent.utils.HwLog.w(r1);
        return r3;
    L_0x0041:
        r4 = 0;
        r5 = r11.mContext;	 Catch:{ AccessControlException -> 0x00b7, AccessControlException -> 0x00b7, AccessControlException -> 0x00b7 }
        r5 = com.android.server.security.tsmagent.utils.PackageSignatureUtil.getInstalledAppHashList(r5, r12);	 Catch:{ AccessControlException -> 0x00b7, AccessControlException -> 0x00b7, AccessControlException -> 0x00b7 }
        r4 = r5;
        if (r4 == 0) goto L_0x00a2;
    L_0x004c:
        r5 = r4.size();
        if (r5 <= 0) goto L_0x00a2;
    L_0x0052:
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = r4.iterator();
    L_0x005b:
        r7 = r6.hasNext();
        if (r7 == 0) goto L_0x006b;
    L_0x0061:
        r7 = r6.next();
        r7 = (java.lang.String) r7;
        r5.append(r7);
        goto L_0x005b;
    L_0x006b:
        r6 = r5.toString();
        r7 = 0;
        r8 = r2.dicItems;
        r8 = r8.size();
    L_0x0076:
        if (r7 >= r8) goto L_0x00a2;
    L_0x0078:
        r9 = r2.dicItems;
        r9 = r9.get(r7);
        r9 = (com.android.server.security.tsmagent.server.wallet.response.DicItem) r9;
        r10 = r9.getParent();
        r10 = r12.equals(r10);
        if (r10 == 0) goto L_0x009f;
    L_0x008a:
        r10 = r9.getValue();
        r10 = r6.equals(r10);
        if (r10 == 0) goto L_0x009f;
    L_0x0094:
        r3 = r11.mAuthorizedCallers;
        r3.add(r12);
        r3 = "operateSSD checkCaller success end";
        com.android.server.security.tsmagent.utils.HwLog.d(r3);
        return r1;
    L_0x009f:
        r7 = r7 + 1;
        goto L_0x0076;
    L_0x00a2:
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r5 = "checkCaller failed. The caller pkg is not allowed. pkg = ";
        r1.append(r5);
        r1.append(r12);
        r1 = r1.toString();
        com.android.server.security.tsmagent.utils.HwLog.w(r1);
        return r3;
    L_0x00b7:
        r1 = move-exception;
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "HwNFCOpenApiImpl checkCaller failed. pkg : ";
        r5.append(r6);
        r5.append(r12);
        r5 = r5.toString();
        com.android.server.security.tsmagent.utils.HwLog.w(r5);
        return r3;
    L_0x00cd:
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r4 = "operateSSD checkCaller failed. query server failed. retCode = ";
        r1.append(r4);
        if (r2 != 0) goto L_0x00dc;
    L_0x00d9:
        r4 = "response is null";
        goto L_0x00e2;
    L_0x00dc:
        r4 = r2.returnCode;
        r4 = java.lang.Integer.valueOf(r4);
    L_0x00e2:
        r1.append(r4);
        r1 = r1.toString();
        com.android.server.security.tsmagent.utils.HwLog.w(r1);
        return r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.tsmagent.openapi.impl.TSMAgentImpl.checkCallerSignature(java.lang.String):boolean");
    }

    public int handleOperatorResult(int result) {
        int returnCode;
        java.lang.StringBuilder stringBuilder;
        if (result != -99) {
            switch (result) {
                case -2:
                    returnCode = 4;
                    break;
                case -1:
                    returnCode = 3;
                    break;
                case 0:
                    returnCode = 0;
                    break;
                default:
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("HwNFCOpenApiImpl operate ssd failed. tsm error. result : ");
                    stringBuilder.append(result);
                    com.android.server.security.tsmagent.utils.HwLog.w(stringBuilder.toString());
                    returnCode = 5;
                    break;
            }
        }
        returnCode = -99;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("handleOperatorResult : ");
        stringBuilder.append(result);
        com.android.server.security.tsmagent.utils.HwLog.d(stringBuilder.toString());
        return returnCode;
    }
}
