package com.android.server.security.tsmagent.utils;

public class PackageSignatureUtil {
    public static java.security.cert.Certificate[] getInstalledAPPCerts(android.content.Context context, java.lang.String packageName) throws java.security.cert.CertificateException, java.security.NoSuchAlgorithmException, java.security.AccessControlException {
        if (packageName == null || packageName.length() == 0) {
            throw new java.security.AccessControlException("Package Name not defined");
        }
        try {
            android.content.pm.PackageInfo foundPkgInfo = context.getPackageManager().getPackageInfo(packageName, 64);
            if (foundPkgInfo != null) {
                java.util.ArrayList<java.security.cert.Certificate> appCerts = new java.util.ArrayList();
                for (android.content.pm.Signature signature : foundPkgInfo.signatures) {
                    appCerts.add(decodeCertificate(signature.toByteArray()));
                }
                return (java.security.cert.Certificate[]) appCerts.toArray(new java.security.cert.Certificate[appCerts.size()]);
            }
            throw new java.security.AccessControlException("Package does not exist");
        } catch (android.content.pm.PackageManager.NameNotFoundException e) {
            throw new java.security.AccessControlException("Package does not exist");
        }
    }

    public static byte[] getAppCertHash(java.security.cert.Certificate appCert) throws java.security.cert.CertificateEncodingException {
        java.security.MessageDigest md = null;
        int i = 0;
        while (i < 10) {
            try {
                md = java.security.MessageDigest.getInstance("SHA");
                break;
            } catch (java.security.NoSuchAlgorithmException e) {
                com.android.server.security.tsmagent.utils.HwLog.e("getAppCertHash NoSuchAlgorithmException");
                i++;
            }
        }
        if (md != null) {
            byte[] hashArray = md.digest(appCert.getEncoded());
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Application Cert Hash Value: ");
            stringBuilder.append(byteArrayToHex(hashArray));
            com.android.server.security.tsmagent.utils.HwLog.i(stringBuilder.toString());
            return md.digest(appCert.getEncoded());
        }
        throw new java.security.AccessControlException("Hash can not be computed");
    }

    public static java.util.List<java.lang.String> getInstalledAppHashList(android.content.Context context, java.lang.String targetPackageName) throws java.security.AccessControlException, java.security.cert.CertificateException, java.security.NoSuchAlgorithmException {
        java.util.List<java.lang.String> hashesList = null;
        java.security.cert.Certificate[] certificates = getInstalledAPPCerts(context, targetPackageName);
        if (certificates != null && certificates.length > 0) {
            com.android.server.security.tsmagent.utils.HwLog.d("travel:accessControl fetch certificates array of caller successful ");
            hashesList = new java.util.ArrayList();
            for (java.security.cert.Certificate certificate : certificates) {
                hashesList.add(byteArrayToHex(getAppCertHash(certificate)));
            }
        }
        return hashesList;
    }

    public static java.security.cert.Certificate decodeCertificate(byte[] certData) throws java.security.cert.CertificateException {
        return (java.security.cert.X509Certificate) java.security.cert.CertificateFactory.getInstance("X.509").generateCertificate(new java.io.ByteArrayInputStream(certData));
    }

    public static java.lang.String byteArrayToHex(byte[] data) {
        if (data == null) {
            return null;
        }
        int len = data.length;
        java.lang.StringBuffer sb = new java.lang.StringBuffer();
        for (int i = 0; i < len; i++) {
            if ((data[i] & 255) < 16) {
                sb.append("0");
            }
            sb.append(java.lang.Integer.toHexString(data[i] & 255));
        }
        return sb.toString().toUpperCase(java.util.Locale.getDefault());
    }
}
