package com.android.server.security.tsmagent.utils;

public class WalletSSLSocketFactory extends javax.net.ssl.SSLSocketFactory {
    private static final java.lang.String CLIENT_AGREEMENT = "TLS";
    private static java.lang.String[] safeEnableCiphers = null;
    private javax.net.ssl.SSLContext sslContext = null;

    public WalletSSLSocketFactory(javax.net.ssl.X509TrustManager trustManager) {
        try {
            this.sslContext = javax.net.ssl.SSLContext.getInstance("TLS");
            this.sslContext.init(null, new javax.net.ssl.X509TrustManager[]{trustManager}, new java.security.SecureRandom());
        } catch (java.security.NoSuchAlgorithmException e) {
            com.android.server.security.tsmagent.utils.HwLog.e("SSLContext init exception");
        } catch (java.security.KeyManagementException e2) {
            com.android.server.security.tsmagent.utils.HwLog.e("SSLContext init exception");
        }
    }

    public java.net.Socket createSocket(java.net.Socket socket, java.lang.String host, int port, boolean autoClose) throws java.io.IOException {
        java.net.Socket mySocket = this.sslContext.getSocketFactory().createSocket(socket, host, port, autoClose);
        if (mySocket == null || !(mySocket instanceof javax.net.ssl.SSLSocket)) {
            return mySocket;
        }
        javax.net.ssl.SSLSocket mySSLSocket = (javax.net.ssl.SSLSocket) mySocket;
        setEnableSafeCipherSuites(mySSLSocket);
        return mySSLSocket;
    }

    public static void setEnableSafeCipherSuites(javax.net.ssl.SSLSocket sslsock) {
        java.lang.String[] enabledCiphers = sslsock.getEnabledCipherSuites();
        java.util.List<java.lang.String> enabledCiphersList = new java.util.ArrayList();
        java.lang.String upperCaseStr = "";
        for (java.lang.String cipherString : enabledCiphers) {
            upperCaseStr = cipherString.toUpperCase(java.util.Locale.ENGLISH);
            if (!(upperCaseStr.contains("RC4") || upperCaseStr.contains("DES") || upperCaseStr.contains("MD5") || upperCaseStr.contains("ANON") || upperCaseStr.contains("NULL"))) {
                if (!upperCaseStr.contains("TLS_EMPTY_RENEGOTIATION_INFO_SCSV")) {
                    enabledCiphersList.add(cipherString);
                }
            }
        }
        safeEnableCiphers = (java.lang.String[]) enabledCiphersList.toArray(new java.lang.String[enabledCiphersList.size()]);
        sslsock.setEnabledCipherSuites(safeEnableCiphers);
    }

    public java.lang.String[] getDefaultCipherSuites() {
        if (safeEnableCiphers != null) {
            return (java.lang.String[]) safeEnableCiphers.clone();
        }
        return new java.lang.String[0];
    }

    public java.lang.String[] getSupportedCipherSuites() {
        return new java.lang.String[0];
    }

    public java.net.Socket createSocket(java.lang.String arg0, int arg1) throws java.io.IOException {
        java.net.Socket mySocket = this.sslContext.getSocketFactory().createSocket(arg0, arg1);
        if (mySocket == null || !(mySocket instanceof javax.net.ssl.SSLSocket)) {
            return mySocket;
        }
        javax.net.ssl.SSLSocket mySSLSocket = (javax.net.ssl.SSLSocket) mySocket;
        setEnableSafeCipherSuites(mySSLSocket);
        return mySSLSocket;
    }

    public java.net.Socket createSocket(java.net.InetAddress arg0, int arg1) throws java.io.IOException {
        java.net.Socket mySocket = this.sslContext.getSocketFactory().createSocket(arg0, arg1);
        if (mySocket == null || !(mySocket instanceof javax.net.ssl.SSLSocket)) {
            return mySocket;
        }
        javax.net.ssl.SSLSocket mySSLSocket = (javax.net.ssl.SSLSocket) mySocket;
        setEnableSafeCipherSuites(mySSLSocket);
        return mySSLSocket;
    }

    public java.net.Socket createSocket(java.lang.String arg0, int arg1, java.net.InetAddress arg2, int arg3) throws java.io.IOException {
        java.net.Socket mySocket = this.sslContext.getSocketFactory().createSocket(arg0, arg1, arg2, arg3);
        if (mySocket == null || !(mySocket instanceof javax.net.ssl.SSLSocket)) {
            return mySocket;
        }
        javax.net.ssl.SSLSocket mySSLSocket = (javax.net.ssl.SSLSocket) mySocket;
        setEnableSafeCipherSuites(mySSLSocket);
        return mySSLSocket;
    }

    public java.net.Socket createSocket(java.net.InetAddress arg0, int arg1, java.net.InetAddress arg2, int arg3) throws java.io.IOException {
        java.net.Socket mySocket = this.sslContext.getSocketFactory().createSocket(arg0, arg1, arg2, arg3);
        if (mySocket == null || !(mySocket instanceof javax.net.ssl.SSLSocket)) {
            return mySocket;
        }
        javax.net.ssl.SSLSocket mySSLSocket = (javax.net.ssl.SSLSocket) mySocket;
        setEnableSafeCipherSuites(mySSLSocket);
        return mySSLSocket;
    }
}
