package com.android.server.statusbar;

public class HwStatusBarManagerService extends com.android.server.statusbar.StatusBarManagerService {
    private static final boolean DEBUG = false;
    private static final java.lang.String TAG = "HwStatusBarManagerService";
    volatile com.android.internal.statusbar.IStatusBar mBar;
    private android.content.Context mContext;
    private com.android.server.statusbar.HwStatusBarManagerService.HwNotificationDelegate mHwNotificationDelegate;
    java.lang.Object mLock = new java.lang.Object();
    private boolean mStatusBarExpanded;

    public interface HwNotificationDelegate {
        void onNotificationResidentClear(java.lang.String str, java.lang.String str2, int i, int i2);
    }

    private void enforceStatusBar() {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
    }

    public HwStatusBarManagerService(android.content.Context context, com.android.server.wm.WindowManagerService windowManager) {
        super(context, windowManager);
        this.mContext = context;
    }

    public void setHwNotificationDelegate(com.android.server.statusbar.HwStatusBarManagerService.HwNotificationDelegate delegate) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("setHwNotificationCallbacks delegate = ");
        stringBuilder.append(delegate);
        android.util.Slog.d("HwStatusBarManagerService", stringBuilder.toString());
        this.mHwNotificationDelegate = delegate;
    }

    public boolean onTransact(int code, android.os.Parcel data, android.os.Parcel reply, int flags) throws android.os.RemoteException {
        if (code == 101) {
            data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
            transactToStatusBar(101, "resentapp", "resentapp", data.readInt());
            reply.writeNoException();
            return true;
        } else if (code != 121) {
            switch (code) {
                case 105:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    java.lang.String packName = data.readString();
                    java.lang.String tag = data.readString();
                    int id = data.readInt();
                    int usrid = data.readInt();
                    if (this.mHwNotificationDelegate != null) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("onNotificationResidentClear packName = ");
                        stringBuilder.append(packName);
                        stringBuilder.append(" usrid:");
                        stringBuilder.append(usrid);
                        android.util.Slog.d("HwStatusBarManagerService", stringBuilder.toString());
                        this.mHwNotificationDelegate.onNotificationResidentClear(packName, tag, id, usrid);
                    }
                    reply.writeNoException();
                    return true;
                case 106:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    transactToStatusBar(106, "SystemUIColor", data.readInt(), data.readInt(), data.readInt(), data.readInt());
                    reply.writeNoException();
                    return true;
                case 107:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    toggleSplitScreenByLineGesture(107, "toggleSplitScreenByLineGesture", data.readInt(), data.readInt());
                    reply.writeNoException();
                    return true;
                case 108:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    transactRecentCall(code, "toggleRecentApps");
                    reply.writeNoException();
                    return true;
                case 109:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    transactRecentCall(code, "preloadRecentApps");
                    reply.writeNoException();
                    return true;
                case 110:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    transactRecentCall(code, "cancelPreloadRecentApps");
                    reply.writeNoException();
                    return true;
                case 111:
                    data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
                    transactToStatusBar(111, "unlockScreenPinningTest", null, 0);
                    reply.writeNoException();
                    android.util.Slog.d("HwStatusBarManagerService", "Transact unlockScreenPinningTest to status bar");
                    return true;
                default:
                    return super.onTransact(code, data, reply, flags);
            }
        } else {
            data.enforceInterface("com.android.internal.statusbar.IStatusBarService");
            notchTransactToStatusBarStatus(121, "notchTransactToStatusBarStatus", data.readInt(), data.readInt(), data.readInt(), data.readInt(), data.readInt(), data.readInt());
            reply.writeNoException();
            return true;
        }
    }

    private void transactToStatusBar(int code, java.lang.String transactName, java.lang.String paramName, int paramValue) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
        synchronized (this.mLock) {
            this.mBar = getStatusBar();
            if (this.mBar != null) {
                android.os.Parcel data = android.os.Parcel.obtain();
                android.os.Parcel reply = android.os.Parcel.obtain();
                try {
                    android.os.IBinder statusBarBinder = this.mBar.asBinder();
                    if (statusBarBinder != null) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Transact:");
                        stringBuilder.append(transactName);
                        stringBuilder.append(" to status bar");
                        android.util.Slog.d("HwStatusBarManagerService", stringBuilder.toString());
                        data.writeInterfaceToken("com.android.internal.statusbar.IStatusBar");
                        if (paramName != null) {
                            data.writeInt(paramValue);
                        }
                        statusBarBinder.transact(code, data, reply, 0);
                    }
                    reply.recycle();
                } catch (android.os.RemoteException localRemoteException) {
                    try {
                        localRemoteException.printStackTrace();
                        reply.recycle();
                    } catch (Throwable th) {
                        reply.recycle();
                        data.recycle();
                    }
                }
                data.recycle();
            }
        }
    }

    private void transactToStatusBar(int code, java.lang.String transactName, int isEmuiStyle, int statusbarColor, int navigationBarColor, int isEmuiLightStyle) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
        synchronized (this.mLock) {
            this.mBar = getStatusBar();
            if (this.mBar != null) {
                android.os.Parcel data = android.os.Parcel.obtain();
                android.os.Parcel reply = android.os.Parcel.obtain();
                try {
                    android.os.IBinder statusBarBinder = this.mBar.asBinder();
                    if (statusBarBinder != null) {
                        data.writeInterfaceToken("com.android.internal.statusbar.IStatusBar");
                        data.writeInt(isEmuiStyle);
                        data.writeInt(statusbarColor);
                        data.writeInt(navigationBarColor);
                        data.writeInt(isEmuiLightStyle);
                        statusBarBinder.transact(code, data, reply, 0);
                    }
                    reply.recycle();
                } catch (android.os.RemoteException localRemoteException) {
                    try {
                        localRemoteException.printStackTrace();
                        reply.recycle();
                    } catch (Throwable th) {
                        reply.recycle();
                        data.recycle();
                    }
                }
                data.recycle();
            }
        }
    }

    public void expandNotificationsPanel() {
        super.expandNotificationsPanel();
        this.mStatusBarExpanded = true;
    }

    public void collapsePanels() {
        super.collapsePanels();
        this.mStatusBarExpanded = false;
    }

    public boolean statusBarExpanded() {
        return this.mStatusBarExpanded;
    }

    public void onPanelHidden() throws android.os.RemoteException {
        super.onPanelHidden();
        reportToAware(90015);
    }

    public void onPanelRevealed(boolean clearNotificationEffects, int numItems) {
        super.onPanelRevealed(clearNotificationEffects, numItems);
        reportToAware(20015);
    }

    private void reportToAware(int event) {
        android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
        if (resManager == null) {
            android.util.Slog.w("HwStatusBarManagerService", "iAware is not started");
            return;
        }
        int resid = android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_STATUS_BAR);
        if (resManager.isResourceNeeded(resid)) {
            android.os.Bundle bundle = new android.os.Bundle();
            bundle.putInt("eventid", event);
            android.rms.iaware.CollectData data = new android.rms.iaware.CollectData(resid, java.lang.System.currentTimeMillis(), bundle);
            long id = android.os.Binder.clearCallingIdentity();
            resManager.reportData(data);
            android.os.Binder.restoreCallingIdentity(id);
        }
    }

    public void toggleSplitScreenByLineGesture(int code, java.lang.String transactName, int param1, int param2) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
        synchronized (this.mLock) {
            this.mBar = getStatusBar();
            if (this.mBar != null) {
                android.os.Parcel data = android.os.Parcel.obtain();
                android.os.Parcel reply = android.os.Parcel.obtain();
                try {
                    android.os.IBinder statusBarBinder = this.mBar.asBinder();
                    if (statusBarBinder != null) {
                        data.writeInterfaceToken("com.android.internal.statusbar.IStatusBar");
                        data.writeInt(param1);
                        data.writeInt(param2);
                        statusBarBinder.transact(code, data, reply, 0);
                    }
                    reply.recycle();
                } catch (android.os.RemoteException localRemoteException) {
                    try {
                        localRemoteException.printStackTrace();
                        reply.recycle();
                    } catch (Throwable th) {
                        reply.recycle();
                        data.recycle();
                    }
                }
                data.recycle();
            }
        }
    }

    private void transactRecentCall(int code, java.lang.String transactName) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
        synchronized (this.mLock) {
            this.mBar = getStatusBar();
            if (this.mBar != null) {
                android.os.Parcel data = android.os.Parcel.obtain();
                android.os.Parcel reply = android.os.Parcel.obtain();
                try {
                    android.os.IBinder statusBarBinder = this.mBar.asBinder();
                    if (statusBarBinder != null) {
                        data.writeInterfaceToken("com.android.internal.statusbar.IStatusBar");
                        statusBarBinder.transact(code, data, reply, 0);
                    }
                    reply.recycle();
                } catch (android.os.RemoteException localRemoteException) {
                    try {
                        localRemoteException.printStackTrace();
                        reply.recycle();
                    } catch (Throwable th) {
                        reply.recycle();
                        data.recycle();
                    }
                }
                data.recycle();
            }
        }
    }

    private void notchTransactToStatusBarStatus(int code, java.lang.String transactName, int isEmuiStyle, int statusbarColor, int navigationBarColor, int isEmuiLightStyle, int statusbarStateFlag, int barVisibility) {
        this.mContext.enforceCallingOrSelfPermission("android.permission.STATUS_BAR", "StatusBarManagerService");
        synchronized (this.mLock) {
            this.mBar = getStatusBar();
            if (this.mBar != null) {
                android.os.Parcel data = android.os.Parcel.obtain();
                android.os.Parcel reply = android.os.Parcel.obtain();
                try {
                    android.os.IBinder statusBarBinder = this.mBar.asBinder();
                    if (statusBarBinder != null) {
                        data.writeInterfaceToken("com.android.internal.statusbar.IStatusBar");
                        data.writeInt(isEmuiStyle);
                        data.writeInt(statusbarColor);
                        data.writeInt(navigationBarColor);
                        data.writeInt(isEmuiLightStyle);
                        data.writeInt(statusbarStateFlag);
                        data.writeInt(barVisibility);
                        statusBarBinder.transact(code, data, reply, 0);
                    }
                    reply.recycle();
                } catch (android.os.RemoteException e) {
                    try {
                        android.util.Slog.d("HwStatusBarManagerService", "RemoteException happen in the method notchTransactToStatusBarStatus!");
                        reply.recycle();
                    } catch (Throwable th) {
                        reply.recycle();
                        data.recycle();
                    }
                }
                data.recycle();
            }
        }
    }
}
