package com.android.server.usb;

public class HwUsbDeviceManager extends com.android.server.usb.UsbDeviceManager {
    private static final java.lang.String ACTION_USBLIQUID = "huawei.intent.action.USB_LIQUID";
    private static final java.lang.String CLASS_NAME_USBLIQUID = "com.huawei.hwdetectrepair.smartnotify.eventlistener.USBLiquidReceiver";
    private static boolean DEBUG = false;
    private static final java.lang.String FACTORY_VERSION = "factory";
    private static final java.lang.String MSG_USBLIQUID_TYPE = "MSG_USBLIQUID_TYPE";
    private static final java.lang.String PACKAGE_NAME_USBLIQUID = "com.huawei.hwdetectrepair";
    private static final java.lang.String PERSIST_CMCC_USB_LIMIT = "persist.sys.cmcc_usb_limit";
    private static final java.lang.String RUN_MODE_PROPERTY = "ro.runmode";
    private static final java.lang.String SYS_CMCC_USB_LIMIT = "cmcc_usb_limit";
    private static final java.lang.String TAG = com.android.server.usb.HwUsbDeviceManager.class.getSimpleName();
    private static final java.lang.String USB_STATE_PROPERTY = "sys.usb.state";
    private static final java.lang.String WATER_WARNING_RINGTONE = "WaterWarning.ogg";
    private android.media.AudioAttributes mAudioAttributes;
    private android.content.Context mContext;
    private final android.os.Handler mHwUsbDeviceManagerHandler;
    private final android.os.HandlerThread mHwUsbDeviceManagerThread;
    private boolean mIsShowingDialog = false;
    private android.media.Ringtone mRingRingtone;
    private final android.content.BroadcastReceiver mSimStatusCompletedReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (com.android.server.usb.HwUsbDeviceManager.DEBUG) {
                android.util.Slog.d(com.android.server.usb.HwUsbDeviceManager.TAG, "sim status completed");
            }
            com.android.server.usb.HwUsbDeviceManager.this.sendHandlerEmptyMessage(102);
        }
    };
    private android.net.Uri mUri;
    private android.app.AlertDialog mWarningDialog = null;

    static {
        boolean z;
        if (!android.util.Log.HWINFO) {
            if (!android.util.Log.HWModuleLog || !android.util.Log.isLoggable(TAG, 4)) {
                z = false;
                DEBUG = z;
            }
        }
        z = true;
        DEBUG = z;
    }

    public HwUsbDeviceManager(android.content.Context context, com.android.server.usb.UsbAlsaManager alsaManager, com.android.server.usb.UsbSettingsManager settingsManager) {
        super(context, alsaManager, settingsManager);
        setCMCCUsbLimit();
        setUsbConfig();
        registerSimStatusCompletedReceiver();
        this.mContext = context;
        this.mHwUsbDeviceManagerThread = new com.android.server.ServiceThread(TAG, -4, false);
        this.mHwUsbDeviceManagerThread.start();
        this.mHwUsbDeviceManagerHandler = new android.os.Handler(this.mHwUsbDeviceManagerThread.getLooper());
        this.mAudioAttributes = new android.media.AudioAttributes.Builder().setUsage(13).setContentType(4).build();
    }

    private java.lang.String getCmccUsbLimit() {
        return android.os.SystemProperties.get("persist.sys.cmcc_usb_limit", "0");
    }

    private java.lang.String getDebuggleMode() {
        return android.os.SystemProperties.get("ro.debuggable", "0");
    }

    private void setCMCCUsbLimit() {
        java.lang.String ro_debuggable = getDebuggleMode();
        java.lang.String usb_limit = getCmccUsbLimit();
        if (DEBUG) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setCMCCUsbLimit ro_debuggable ");
            stringBuilder.append(ro_debuggable);
            stringBuilder.append(" usb_limit ");
            stringBuilder.append(usb_limit);
            android.util.Slog.i(str, stringBuilder.toString());
        }
        if ("1".equals(ro_debuggable) && "1".equals(usb_limit)) {
            android.os.SystemProperties.set("persist.sys.cmcc_usb_limit", "0");
            if (DEBUG) {
                android.util.Slog.i(TAG, "UsbDeviceManager new init in debug mode set  to 0 !");
            }
        }
    }

    private void setUsbConfig() {
        java.lang.String cur_usb_config = android.os.SystemProperties.get("persist.sys.usb.config", "adb");
        java.lang.String usb_limit = getCmccUsbLimit();
        if (DEBUG) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setUsbConfig cur_usb_config ");
            stringBuilder.append(cur_usb_config);
            stringBuilder.append(" usb_limit ");
            stringBuilder.append(usb_limit);
            android.util.Slog.i(str, stringBuilder.toString());
        }
        if ("1".equals(usb_limit) && !containsFunctionOuter(cur_usb_config, "manufacture")) {
            boolean result = setUsbConfigEx("mass_storage");
            if (DEBUG) {
                java.lang.String str2 = TAG;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("UsbDeviceManager new init setusbconfig result: ");
                stringBuilder2.append(result);
                android.util.Slog.i(str2, stringBuilder2.toString());
            }
        }
    }

    protected void registerSimStatusCompletedReceiver() {
        if (DEBUG) {
            android.util.Slog.d(TAG, "registerSimStatusCompletedReceiver");
        }
        if (getContext() != null) {
            getContext().registerReceiver(this.mSimStatusCompletedReceiver, new android.content.IntentFilter("android.intent.action.SIM_STATE_CHANGED"));
        }
    }

    protected void dueSimStatusCompletedMsg() {
        java.lang.String usb_limit = getCmccUsbLimit();
        if (DEBUG) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("simcardstate at receive sim_status_change usb_limit = ");
            stringBuilder.append(usb_limit);
            android.util.Slog.i(str, stringBuilder.toString());
        }
        if (!"0".equals(usb_limit)) {
            int simcardstate = 0;
            try {
                if (getContext() != null) {
                    simcardstate = ((android.telephony.TelephonyManager) getContext().getSystemService("phone")).getSimState();
                }
                if (DEBUG) {
                    java.lang.String str2 = TAG;
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("simcardstate at boot completed is ");
                    stringBuilder2.append(simcardstate);
                    android.util.Slog.i(str2, stringBuilder2.toString());
                }
                if (!(simcardstate == 0 || simcardstate == 1 || simcardstate == 8 || simcardstate == 6)) {
                    android.util.Slog.i(TAG, "persist.sys.cmcc_usb_limit to 0 ");
                    android.os.SystemProperties.set("persist.sys.cmcc_usb_limit", "0");
                    setEnabledFunctionsEx("hisuite,mtp,mass_storage", true);
                    if (getContext() != null && getUsbHandlerConnected()) {
                        if (DEBUG) {
                            android.util.Slog.i(TAG, "Secure SYS_CMCC_USB_LIMIT 0 ");
                        }
                        android.provider.Settings.Secure.putInt(getContext().getContentResolver(), "cmcc_usb_limit", 0);
                    }
                }
            } catch (java.lang.Exception e) {
                android.util.Slog.i(TAG, "dueSimStatusCompletedMsg error", e);
            }
        }
    }

    protected boolean interceptSetEnabledFunctions(java.lang.String functions) {
        boolean isManufacturePort = false;
        java.lang.String usb_limit = getCmccUsbLimit();
        if (DEBUG) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("interceptSetEnabledFunctions  functions:");
            stringBuilder.append(functions);
            android.util.Slog.i(str, stringBuilder.toString());
        }
        if (functions != null) {
            isManufacturePort = containsFunctionOuter(functions, "manufacture");
        }
        if (android.os.SystemProperties.get("sys.usb.state", "").equals(functions) && isManufacturePort) {
            if (DEBUG) {
                java.lang.String str2 = TAG;
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("The current function: ");
                stringBuilder2.append(functions);
                stringBuilder2.append(" has been set, return!");
                android.util.Slog.i(str2, stringBuilder2.toString());
            }
            return true;
        } else if ("0".equals(usb_limit)) {
            return false;
        } else {
            int simcardstate = 0;
            try {
                if (getContext() != null) {
                    simcardstate = ((android.telephony.TelephonyManager) getContext().getSystemService("phone")).getSimState();
                }
                if (DEBUG) {
                    java.lang.String str3 = TAG;
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("interceptSetEnabledFunctions simcardstate = ");
                    stringBuilder3.append(simcardstate);
                    stringBuilder3.append(" IsManufacturePort:");
                    stringBuilder3.append(isManufacturePort);
                    android.util.Slog.i(str3, stringBuilder3.toString());
                }
                if (!(simcardstate == 0 || simcardstate == 1 || simcardstate == 8 || simcardstate == 6)) {
                    if (DEBUG) {
                        android.util.Slog.i(TAG, "persist.sys.cmcc_usb_limit set to 0 at setenable  ");
                    }
                    android.os.SystemProperties.set("persist.sys.cmcc_usb_limit", "0");
                    usb_limit = "0";
                }
            } catch (java.lang.Exception e) {
                android.util.Slog.i(TAG, "interceptSetEnabledFunctions error", e);
            }
            if (!"1".equals(usb_limit) || isManufacturePort) {
                return false;
            }
            if (DEBUG) {
                android.util.Slog.i(TAG, "cmcc usb_limit return !");
            }
            return true;
        }
    }

    protected boolean isCmccUsbLimit() {
        if ("1".equals(android.os.SystemProperties.get("persist.sys.cmcc_usb_limit", "0"))) {
            return true;
        }
        return false;
    }

    protected java.lang.String removeAdbFunction(java.lang.String functions, java.lang.String function) {
        if (containsFunctionOuter(functions, "manufacture")) {
            return functions;
        }
        return super.removeAdbFunction(functions, function);
    }

    protected boolean isAdbDisabled() {
        if (!android.hdm.HwDeviceManager.disallowOp(11)) {
            return false;
        }
        android.provider.Settings.Global.putInt(this.mContentResolver, "adb_enabled", 0);
        return true;
    }

    protected void sendUSBLiquidBroadcast(android.content.Context context, java.lang.String msg) {
        android.content.Intent intent = new android.content.Intent("huawei.intent.action.USB_LIQUID");
        intent.setClassName("com.huawei.hwdetectrepair", "com.huawei.hwdetectrepair.smartnotify.eventlistener.USBLiquidReceiver");
        intent.putExtra("MSG_USBLIQUID_TYPE", msg);
        context.sendBroadcastAsUser(intent, android.os.UserHandle.ALL, "android.permission.MANAGE_USB");
    }

    protected void usbWaterInNotification(boolean enable) {
        android.util.Slog.i(TAG, "usbWaterInNotification");
        if (!this.mIsShowingDialog) {
            this.mIsShowingDialog = true;
            if (enable) {
                playRing();
            } else {
                stopRing();
            }
            android.os.Message msg = android.os.Message.obtain(this.mHwUsbDeviceManagerHandler, new java.lang.Runnable() {
                public void run() {
                    com.android.server.usb.HwUsbDeviceManager.this.createWarningDialog();
                }
            });
            msg.setAsynchronous(true);
            this.mHwUsbDeviceManagerHandler.sendMessage(msg);
        }
    }

    protected void playRing() {
        this.mHwUsbDeviceManagerHandler.post(new java.lang.Runnable() {
            public void run() {
                com.android.server.usb.HwUsbDeviceManager.this.mUri = com.android.server.usb.HwUsbDeviceManager.queryRingMusicUri(com.android.server.usb.HwUsbDeviceManager.this.mContext, "WaterWarning.ogg");
                com.android.server.usb.HwUsbDeviceManager.this.mRingRingtone = com.android.server.usb.HwUsbDeviceManager.this.playRing(com.android.server.usb.HwUsbDeviceManager.this.mUri);
            }
        });
    }

    protected void stopRing() {
        this.mHwUsbDeviceManagerHandler.post(new java.lang.Runnable() {
            public void run() {
                com.android.server.usb.HwUsbDeviceManager.this.stopRing(com.android.server.usb.HwUsbDeviceManager.this.mRingRingtone);
            }
        });
    }

    private android.media.Ringtone playRing(android.net.Uri uri) {
        android.media.Ringtone ringtone = android.media.RingtoneManager.getRingtone(this.mContext, uri);
        if (ringtone != null) {
            ringtone.setAudioAttributes(this.mAudioAttributes);
            ringtone.play();
        }
        return ringtone;
    }

    private void stopRing(android.media.Ringtone ringtone) {
        if (ringtone != null) {
            ringtone.stop();
        }
    }

    private static android.net.Uri queryRingMusicUri(android.content.Context context, java.lang.String fileName) {
        return queryRingMusicUri(context.getContentResolver(), fileName);
    }

    /* JADX WARNING: Missing block: B:13:0x0047, code:
            if (r9 != null) goto L_0x0049;
     */
    private static android.net.Uri queryRingMusicUri(android.content.ContentResolver r10, java.lang.String r11) {
        /*
        r0 = 0;
        if (r11 != 0) goto L_0x0004;
    L_0x0003:
        return r0;
    L_0x0004:
        r7 = android.provider.MediaStore.Audio.Media.INTERNAL_CONTENT_URI;
        r1 = "_id";
        r3 = new java.lang.String[]{r1};
        r1 = new java.lang.StringBuilder;
        r2 = "_data like '%";
        r1.<init>(r2);
        r8 = r1;
        r8.append(r11);
        r1 = "'";
        r8.append(r1);
        r9 = r0;
        r4 = r8.toString();	 Catch:{ Exception -> 0x004f }
        r5 = 0;
        r6 = 0;
        r1 = r10;
        r2 = r7;
        r1 = r1.query(r2, r3, r4, r5, r6);	 Catch:{ Exception -> 0x004f }
        r9 = r1;
        if (r9 == 0) goto L_0x0047;
    L_0x002c:
        r1 = r9.moveToFirst();	 Catch:{ Exception -> 0x004f }
        if (r1 == 0) goto L_0x0047;
    L_0x0032:
        r1 = "_id";
        r1 = r9.getColumnIndex(r1);	 Catch:{ Exception -> 0x004f }
        r1 = r9.getInt(r1);	 Catch:{ Exception -> 0x004f }
        r4 = (long) r1;	 Catch:{ Exception -> 0x004f }
        r2 = android.content.ContentUris.withAppendedId(r7, r4);	 Catch:{ Exception -> 0x004f }
        if (r9 == 0) goto L_0x0046;
    L_0x0043:
        r9.close();
    L_0x0046:
        return r2;
    L_0x0047:
        if (r9 == 0) goto L_0x0069;
    L_0x0049:
        r9.close();
        goto L_0x0069;
    L_0x004d:
        r0 = move-exception;
        goto L_0x006a;
    L_0x004f:
        r1 = move-exception;
        r2 = TAG;	 Catch:{ all -> 0x004d }
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x004d }
        r4.<init>();	 Catch:{ all -> 0x004d }
        r5 = "queryRingMusicUri query database exception: ";
        r4.append(r5);	 Catch:{ all -> 0x004d }
        r4.append(r1);	 Catch:{ all -> 0x004d }
        r4 = r4.toString();	 Catch:{ all -> 0x004d }
        android.util.Slog.e(r2, r4);	 Catch:{ all -> 0x004d }
        if (r9 == 0) goto L_0x0069;
    L_0x0068:
        goto L_0x0049;
    L_0x0069:
        return r0;
    L_0x006a:
        if (r9 == 0) goto L_0x006f;
    L_0x006c:
        r9.close();
    L_0x006f:
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.usb.HwUsbDeviceManager.queryRingMusicUri(android.content.ContentResolver, java.lang.String):android.net.Uri");
    }

    private void createWarningDialog() {
        this.mWarningDialog = new android.app.AlertDialog.Builder(this.mContext, 33947691).setTitle(33685900).setMessage(33685901).setIcon(17301543).setPositiveButton(33685902, new android.content.DialogInterface.OnClickListener() {
            public void onClick(android.content.DialogInterface dialog, int which) {
                android.util.Slog.i(com.android.server.usb.HwUsbDeviceManager.TAG, "dialog click, dismiss and stopRing");
                dialog.dismiss();
                com.android.server.usb.HwUsbDeviceManager.this.stopRing();
                com.android.server.usb.HwUsbDeviceManager.this.mIsShowingDialog = false;
            }
        }).create();
        this.mWarningDialog.getWindow().setType(2009);
        this.mWarningDialog.show();
        this.mWarningDialog.setCancelable(false);
        android.util.Slog.i(TAG, "createWarningDialog");
    }

    public void setHdbEnabledEx(boolean enable) {
        huawei.android.hardware.usb.HwUsbManagerEx.getInstance().setHdbEnabled(enable);
    }

    public void dump(java.io.FileDescriptor fd, com.android.internal.util.IndentingPrintWriter writer, java.lang.String[] args) {
        huawei.android.hardware.usb.HwUsbManagerEx.getInstance().dump(fd, args);
    }
}
