package com.android.server.wallpaper;

public class HwWallpaperManagerService extends com.android.server.wallpaper.WallpaperManagerService {
    public static final boolean DEBUG = false;
    private static final java.lang.String PERMISSION = "com.huawei.wallpaperservcie.permission.SET_WALLPAPER_OFFSET";
    private static final java.lang.String ROG_KILL_APP_END_ACTION = "com.huawei.systemmamanger.action.KILL_ROGAPP_END";
    static final java.lang.String TAG = "HwWallpaperService";
    public static final java.lang.String WALLPAPER_MANAGER_SERVICE_READY_ACTION = "android.intent.action.WALLPAPER_MANAGER_SERVICE_READY";
    protected int disHeight;
    protected int disWidth;

    public static class Lifecycle extends com.android.server.SystemService {
        private com.android.server.wallpaper.HwWallpaperManagerService mService;

        public Lifecycle(android.content.Context context) {
            super(context);
        }

        public void onStart() {
            this.mService = new com.android.server.wallpaper.HwWallpaperManagerService(getContext());
            publishBinderService("wallpaper", this.mService);
        }

        public void onBootPhase(int phase) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("HwWallpaperManagerService.java#Lifecycle#systemRunning() phase:");
            stringBuilder.append(phase);
            android.util.Slog.d("HwWallpaperService", stringBuilder.toString());
            if (phase == 550) {
                this.mService.systemRunning();
            } else if (phase == 600) {
                this.mService.switchUser(0, null);
            } else if (phase == 1000) {
                this.mService.wallpaperManagerServiceReady();
            }
        }

        public void onUnlockUser(int userHandle) {
            this.mService.onUnlockUser(userHandle);
        }
    }

    public HwWallpaperManagerService(android.content.Context context) {
        super(context);
        android.util.DisplayMetrics dm = new android.util.DisplayMetrics();
        ((android.view.WindowManager) getContext().getSystemService("window")).getDefaultDisplay().getMetrics(dm);
        this.disWidth = dm.widthPixels;
        this.disHeight = dm.heightPixels;
    }

    public void wallpaperManagerServiceReady() {
        createBlurWallpaper(false);
        this.mContext.sendBroadcastAsUser(new android.content.Intent("android.intent.action.WALLPAPER_MANAGER_SERVICE_READY"), new android.os.UserHandle(this.mCurrentUserId));
        android.util.Slog.i("HwWallpaperService", "HwWallpaperManagerService.java#wallpaperManagerServiceReady() sendBroadcast[WALLPAPER_MANAGER_SERVICE_READY_ACTION]");
    }

    public void systemRunning() {
        super.systemReady();
        com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(0);
        synchronized (getLock()) {
            notifyBlurCallbacksLocked(wallpaper);
        }
        android.content.IntentFilter userFilter = new android.content.IntentFilter();
        userFilter.addAction("com.huawei.systemmamanger.action.KILL_ROGAPP_END");
        getContext().registerReceiver(new android.content.BroadcastReceiver() {
            public void onReceive(android.content.Context context, android.content.Intent intent) {
                if ("com.huawei.systemmamanger.action.KILL_ROGAPP_END".equals(intent.getAction())) {
                    com.android.server.wallpaper.HwWallpaperManagerService.this.restartLiveWallpaperService();
                }
            }
        }, userFilter);
    }

    public void handleWallpaperObserverEvent(final com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper) {
        new java.lang.Thread("BlurWallpaperThread") {
            public void run() {
                android.util.Slog.d("HwWallpaperService", "onEvent createBlurBitmap Blur wallpaper Begin");
                long timeBegin = java.lang.System.currentTimeMillis();
                com.android.server.wallpaper.HwWallpaperManagerService.this.createBlurWallpaper(true);
                long takenTime = java.lang.System.currentTimeMillis() - timeBegin;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onEvent createBlurBitmap Blur takenTime = ");
                stringBuilder.append(takenTime);
                android.util.Slog.d("HwWallpaperService", stringBuilder.toString());
                synchronized (com.android.server.wallpaper.HwWallpaperManagerService.this.getLock()) {
                    com.android.server.wallpaper.HwWallpaperManagerService.this.notifyBlurCallbacksLocked(wallpaper);
                }
            }
        }.start();
    }

    public void createBlurWallpaper(boolean force) {
        synchronized (getLock()) {
            android.graphics.Bitmap wallpaper;
            android.graphics.Bitmap wallpaper2;
            if (!force) {
                try {
                    if (new java.io.File(android.os.Environment.getUserSystemDirectory(getWallpaperUserId()), "blurwallpaper").exists()) {
                        return;
                    }
                } catch (java.lang.OutOfMemoryError e) {
                    android.util.Slog.w("HwWallpaperService", "No memory load current wallpaper", e);
                } catch (Throwable th) {
                }
            }
            java.lang.String bitmapStyle = "";
            android.app.WallpaperInfo info = getWallpaperInfo(getWallpaperUserId());
            java.lang.String bitmapStyle2;
            if (info == null) {
                wallpaper = getCurrentWallpaperLocked(getContext());
                bitmapStyle2 = "static";
            } else {
                android.graphics.drawable.Drawable dr = android.common.HwFrameworkFactory.getHwWallpaperInfoStub(info).loadThumbnailWithoutTheme(getContext().getPackageManager());
                if (dr == null) {
                    wallpaper2 = null;
                } else if (dr instanceof android.graphics.drawable.BitmapDrawable) {
                    wallpaper2 = ((android.graphics.drawable.BitmapDrawable) dr).getBitmap();
                } else {
                    try {
                        wallpaper = android.graphics.Bitmap.createBitmap(dr.getIntrinsicWidth(), dr.getIntrinsicHeight(), dr.getOpacity() != -1 ? android.graphics.Bitmap.Config.ARGB_8888 : android.graphics.Bitmap.Config.RGB_565);
                        android.graphics.Canvas c = new android.graphics.Canvas(wallpaper);
                        dr.setBounds(0, 0, dr.getIntrinsicWidth(), dr.getIntrinsicHeight());
                        dr.draw(c);
                    } catch (java.lang.RuntimeException e2) {
                        android.util.Slog.e("HwWallpaperService", "create blurwallpaper draw has some errors");
                        wallpaper2 = null;
                    }
                    bitmapStyle2 = "live";
                }
                wallpaper = wallpaper2;
                bitmapStyle2 = "live";
            }
            if (wallpaper == null || wallpaper.isRecycled()) {
                android.util.Slog.d("HwWallpaperService", "wallpaper is null or has been recycled");
                wallpaper = getDefaultWallpaperLocked(getContext());
            }
            if (wallpaper != null) {
                android.graphics.Bitmap bitmap;
                int h = this.disHeight;
                int w = this.disWidth;
                if (!android.view.ViewConfiguration.get(getContext()).hasPermanentMenuKey()) {
                    h += getContext().getResources().getDimensionPixelSize(17105186);
                }
                if (wallpaper.getHeight() == h && wallpaper.getWidth() == 2 * w) {
                    int[] inPixels = new int[(this.disWidth * h)];
                    android.graphics.Bitmap bitmap2 = android.graphics.Bitmap.createBitmap(this.disWidth, h, android.graphics.Bitmap.Config.ARGB_8888);
                    wallpaper.getPixels(inPixels, 0, this.disWidth, 0, 0, this.disWidth, h);
                    bitmap2.setPixels(inPixels, 0, this.disWidth, 0, 0, this.disWidth, h);
                    bitmap = bitmap2;
                    if (!(bitmap == wallpaper || wallpaper.isRecycled())) {
                        wallpaper.recycle();
                        wallpaper = bitmap;
                        if (info != null) {
                            removeThumbnailCache(info);
                        }
                    }
                }
                bitmap = wallpaper;
                if (!(wallpaper.getHeight() == h / 4 && wallpaper.getWidth() == w / 4)) {
                    wallpaper = android.graphics.Bitmap.createScaledBitmap(bitmap, this.disWidth / 4, h / 4, true);
                    if (!(wallpaper == null || wallpaper == bitmap || bitmap.isRecycled())) {
                        bitmap.recycle();
                        if (info != null) {
                            removeThumbnailCache(info);
                        }
                    }
                }
            }
            if (wallpaper != null) {
                wallpaper2 = com.android.server.BlurUtils.stackBlur(wallpaper, 80);
                if (wallpaper2 != null) {
                    wallpaper.recycle();
                    if (huawei.android.hwpicaveragenoises.HwPicAverageNoises.isAverageNoiseSupported()) {
                        saveBlurWallpaperBitmapLocked(wallpaper2);
                    } else {
                        android.graphics.Bitmap blurImg = com.android.server.BlurUtils.addBlackBoard(wallpaper2, 1275068416);
                        if (blurImg != null) {
                            wallpaper2.recycle();
                            saveBlurWallpaperBitmapLocked(blurImg);
                        }
                    }
                }
            }
        }
    }

    /* JADX WARNING: Missing block: B:29:0x0056, code:
            return null;
     */
    public android.os.ParcelFileDescriptor getBlurWallpaper(android.app.IWallpaperManagerCallback r8) {
        /*
        r7 = this;
        r0 = r7.getLock();
        monitor-enter(r0);
        r1 = r7.getWallpaperUserId();	 Catch:{ all -> 0x0057 }
        r2 = r7.getWallpaperMap();	 Catch:{ all -> 0x0057 }
        r2 = r2.get(r1);	 Catch:{ all -> 0x0057 }
        r2 = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) r2;	 Catch:{ all -> 0x0057 }
        r3 = 0;
        if (r2 == 0) goto L_0x0055;
    L_0x0016:
        r4 = r2.getCallbacks();	 Catch:{ all -> 0x0057 }
        if (r4 != 0) goto L_0x001d;
    L_0x001c:
        goto L_0x0055;
    L_0x001d:
        if (r8 == 0) goto L_0x0030;
    L_0x001f:
        r4 = r2.getCallbacks();	 Catch:{ all -> 0x0057 }
        r4 = r4.isContainIBinder(r8);	 Catch:{ all -> 0x0057 }
        if (r4 != 0) goto L_0x0030;
    L_0x0029:
        r4 = r2.getCallbacks();	 Catch:{ all -> 0x0057 }
        r4.register(r8);	 Catch:{ all -> 0x0057 }
    L_0x0030:
        r4 = android.os.Environment.getUserSystemDirectory(r1);	 Catch:{ FileNotFoundException -> 0x004b }
        r5 = new java.io.File;	 Catch:{ FileNotFoundException -> 0x004b }
        r6 = "blurwallpaper";
        r5.<init>(r4, r6);	 Catch:{ FileNotFoundException -> 0x004b }
        r6 = r5.exists();	 Catch:{ FileNotFoundException -> 0x004b }
        if (r6 != 0) goto L_0x0043;
    L_0x0041:
        monitor-exit(r0);	 Catch:{ all -> 0x0057 }
        return r3;
    L_0x0043:
        r6 = 268435456; // 0x10000000 float:2.5243549E-29 double:1.32624737E-315;
        r6 = android.os.ParcelFileDescriptor.open(r5, r6);	 Catch:{ FileNotFoundException -> 0x004b }
        monitor-exit(r0);	 Catch:{ all -> 0x0057 }
        return r6;
    L_0x004b:
        r4 = move-exception;
        r5 = "HwWallpaperService";
        r6 = "Error getting wallpaper";
        android.util.Slog.w(r5, r6, r4);	 Catch:{ all -> 0x0057 }
        monitor-exit(r0);	 Catch:{ all -> 0x0057 }
        return r3;
    L_0x0055:
        monitor-exit(r0);	 Catch:{ all -> 0x0057 }
        return r3;
    L_0x0057:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x0057 }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.wallpaper.HwWallpaperManagerService.getBlurWallpaper(android.app.IWallpaperManagerCallback):android.os.ParcelFileDescriptor");
    }

    public int getWallpaperUserId() {
        int callingUid = android.os.Binder.getCallingUid();
        if (callingUid == 1000) {
            return getCurrentUserId();
        }
        return android.os.UserHandle.getUserId(callingUid);
    }

    private android.graphics.Bitmap getCurrentWallpaperLocked(android.content.Context context) {
        android.os.ParcelFileDescriptor fd = getWallpaper(new android.os.Bundle());
        if (fd != null) {
            try {
                android.graphics.Bitmap bm = scaleWallpaperBitmapToScreenSize(android.graphics.BitmapFactory.decodeFileDescriptor(fd.getFileDescriptor(), null, new android.graphics.BitmapFactory.Options()));
                try {
                    fd.close();
                } catch (java.io.IOException e) {
                }
                return bm;
            } catch (java.lang.OutOfMemoryError e2) {
                android.util.Slog.w("HwWallpaperService", "Can't decode file", e2);
                try {
                    fd.close();
                } catch (java.io.IOException e3) {
                }
            } catch (Throwable th) {
                try {
                    fd.close();
                } catch (java.io.IOException e4) {
                }
            }
        }
        return null;
    }

    private android.graphics.Bitmap getDefaultWallpaperLocked(android.content.Context context) {
        java.io.InputStream is = android.hwtheme.HwThemeManager.getDefaultWallpaperIS(context, getCurrentUserId());
        if (is != null) {
            try {
                android.graphics.Bitmap bm = scaleWallpaperBitmapToScreenSize(android.graphics.BitmapFactory.decodeStream(is, null, new android.graphics.BitmapFactory.Options()));
                try {
                    is.close();
                } catch (java.io.IOException e) {
                }
                return bm;
            } catch (java.lang.OutOfMemoryError e2) {
                android.util.Slog.w("HwWallpaperService", "Can't decode stream", e2);
                try {
                    is.close();
                } catch (java.io.IOException e3) {
                }
            } catch (Throwable th) {
                try {
                    is.close();
                } catch (java.io.IOException e4) {
                }
            }
        }
        return null;
    }

    private void notifyBlurCallbacksLocked(com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper) {
        android.os.RemoteCallbackList<android.app.IWallpaperManagerCallback> callbacks = wallpaper.getCallbacks();
        synchronized (callbacks) {
            int n = callbacks.beginBroadcast();
            for (int i = 0; i < n; i++) {
                try {
                    ((android.app.IWallpaperManagerCallback) callbacks.getBroadcastItem(i)).onBlurWallpaperChanged();
                } catch (android.os.RemoteException e) {
                }
            }
            callbacks.finishBroadcast();
        }
    }

    public android.os.ParcelFileDescriptor getWallpaper(android.os.Bundle outParams) {
        synchronized (getLock()) {
            int wallpaperUserId = getWallpaperUserId();
            com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(wallpaperUserId);
            if (outParams != null) {
                try {
                    outParams.putInt("width", wallpaper.getWidth());
                    outParams.putInt("height", wallpaper.getHeight());
                } catch (java.io.FileNotFoundException e) {
                    android.util.Slog.w("HwWallpaperService", "Error getting wallpaper", e);
                    return null;
                }
            }
            java.io.File f = new java.io.File(android.os.Environment.getUserSystemDirectory(wallpaperUserId), "wallpaper");
            if (f.exists()) {
                android.os.ParcelFileDescriptor open = android.os.ParcelFileDescriptor.open(f, 268435456);
                return open;
            }
            return null;
        }
    }

    private void saveBlurWallpaperBitmapLocked(android.graphics.Bitmap blurImg) {
        android.util.Slog.d("HwWallpaperService", "saveBlurWallpaperBitmapLocked begin");
        long timeBegin = java.lang.System.currentTimeMillis();
        android.os.ParcelFileDescriptor fd;
        java.io.FileOutputStream fos;
        try {
            java.io.File dir = android.os.Environment.getUserSystemDirectory(getWallpaperUserId());
            if (!dir.exists() && dir.mkdir()) {
                android.os.FileUtils.setPermissions(dir.getPath(), 505, -1, -1);
            }
            java.io.File file = new java.io.File(dir, "blurwallpaper");
            fd = android.os.ParcelFileDescriptor.open(file, 939524096);
            if (android.os.SELinux.restorecon(file)) {
                fos = null;
                fos = new android.os.ParcelFileDescriptor.AutoCloseOutputStream(fd);
                blurImg.compress(android.graphics.Bitmap.CompressFormat.PNG, 90, fos);
                try {
                    fos.close();
                } catch (java.io.IOException e) {
                }
                if (fd != null) {
                    try {
                        fd.close();
                    } catch (java.io.IOException e2) {
                    }
                }
                long takenTime = java.lang.System.currentTimeMillis() - timeBegin;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("saveBlurWallpaperBitmapLocked takenTime = ");
                stringBuilder.append(takenTime);
                android.util.Slog.d("HwWallpaperService", stringBuilder.toString());
            }
            if (fd != null) {
                try {
                    fd.close();
                } catch (java.io.IOException e3) {
                }
            }
        } catch (java.io.FileNotFoundException e4) {
            android.util.Slog.w("HwWallpaperService", "Error setting wallpaper", e4);
        } catch (Throwable th) {
            if (fos != null) {
                try {
                    fos.close();
                } catch (java.io.IOException e5) {
                }
            }
            if (fd != null) {
                try {
                    fd.close();
                } catch (java.io.IOException e6) {
                }
            }
        }
    }

    private android.graphics.Bitmap generateBitmap(android.content.Context context, android.graphics.Bitmap bm, int width, int height, android.app.WallpaperInfo info) {
        java.lang.OutOfMemoryError e;
        java.lang.Throwable th;
        android.content.Context context2 = context;
        android.graphics.Bitmap bm2 = bm;
        int i = width;
        int i2 = height;
        android.app.WallpaperInfo wallpaperInfo = info;
        synchronized (getLock()) {
            if (context2 != null) {
                if (bm2 != null) {
                    try {
                        android.view.WindowManager wm = (android.view.WindowManager) context2.getSystemService("window");
                        android.util.DisplayMetrics metrics = new android.util.DisplayMetrics();
                        wm.getDefaultDisplay().getMetrics(metrics);
                        bm2.setDensity(metrics.noncompatDensityDpi);
                        if (i > 0 && i2 > 0) {
                            if (bm.getWidth() != i || bm.getHeight() != i2) {
                                try {
                                    android.graphics.Bitmap newBimap = android.graphics.Bitmap.createBitmap(i, i2, android.graphics.Bitmap.Config.ARGB_8888);
                                    if (newBimap == null) {
                                        android.util.Slog.w("HwWallpaperService", "Can't generate bitmap, newBimap = null");
                                        return bm2;
                                    }
                                    newBimap.setDensity(metrics.noncompatDensityDpi);
                                    android.graphics.Canvas c = new android.graphics.Canvas(newBimap);
                                    android.graphics.Rect targetRect = new android.graphics.Rect();
                                    targetRect.right = bm.getWidth();
                                    targetRect.bottom = bm.getHeight();
                                    int deltaw = i - targetRect.right;
                                    int deltah = i2 - targetRect.bottom;
                                    if (deltaw > 0 || deltah > 0) {
                                        float tempWidth = ((float) i) / ((float) targetRect.right);
                                        float tempHeight = ((float) i2) / ((float) targetRect.bottom);
                                        float scale = tempWidth > tempHeight ? tempWidth : tempHeight;
                                        targetRect.right = (int) (((float) targetRect.right) * scale);
                                        targetRect.bottom = (int) (((float) targetRect.bottom) * scale);
                                        deltaw = i - targetRect.right;
                                        deltah = i2 - targetRect.bottom;
                                    }
                                    targetRect.offset(deltaw / 2, deltah / 2);
                                    android.graphics.Paint paint = new android.graphics.Paint();
                                    paint.setFilterBitmap(true);
                                    paint.setXfermode(new android.graphics.PorterDuffXfermode(android.graphics.PorterDuff.Mode.SRC));
                                    c.drawBitmap(bm2, null, targetRect, paint);
                                    bm.recycle();
                                    bm2 = null;
                                    if (wallpaperInfo != null) {
                                        try {
                                            removeThumbnailCache(wallpaperInfo);
                                        } catch (java.lang.OutOfMemoryError e2) {
                                            e = e2;
                                        }
                                    }
                                    return newBimap;
                                } catch (java.lang.OutOfMemoryError e3) {
                                    e = e3;
                                    android.util.Slog.w("HwWallpaperService", "Can't generate bitmap:", e);
                                    return bm2;
                                } catch (Throwable th2) {
                                    th = th2;
                                    throw th;
                                }
                            }
                        }
                        return bm2;
                    } catch (Throwable th3) {
                        th = th3;
                        throw th;
                    }
                }
            }
            return null;
        }
    }

    private void removeThumbnailCache(android.app.WallpaperInfo info) {
        if (info != null) {
            info.removeThumbnailCache(getContext().getPackageManager());
        }
    }

    protected boolean getHwWallpaperWidth(com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper, boolean success) {
        if (success) {
            return false;
        }
        android.view.Display d = ((android.view.WindowManager) getContext().getSystemService("window")).getDefaultDisplay();
        android.graphics.Point pSize = new android.graphics.Point();
        d.getSize(pSize);
        wallpaper.setWidth(android.os.SystemProperties.getInt("ro.config.hwwallpaperwidth", 2 * pSize.x));
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("loadSettings, mWidth:");
        stringBuilder.append(wallpaper.getWidth());
        stringBuilder.append(", mHeight:");
        stringBuilder.append(wallpaper.getHeight());
        stringBuilder.append(", display size:");
        stringBuilder.append(pSize);
        android.util.Slog.i("HwWallpaperService", stringBuilder.toString());
        return true;
    }

    private void saveWallpaperOffsets(int[] offsets) {
        if (offsets != null) {
            int i;
            java.lang.StringBuilder sb = new java.lang.StringBuilder();
            for (i = 0; i < offsets.length; i++) {
                sb.append(offsets[i]);
                if (i < offsets.length - 1) {
                    sb.append(",");
                }
            }
            i = getWallpaperUserId();
            android.provider.Settings.System.putStringForUser(getContext().getContentResolver(), "curr_wallpaper_offsets", sb.toString(), i);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("saveWallpaperOffsets(");
            stringBuilder.append(i);
            stringBuilder.append("):");
            stringBuilder.append(sb);
            android.util.Slog.i("HwWallpaperService", stringBuilder.toString());
        }
    }

    protected void updateWallpaperOffsets(com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper) {
        com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaperData = wallpaper;
        android.graphics.Bitmap bm = getCurrentWallpaperLocked(getContext());
        int x_port;
        int y_port;
        if (bm != null) {
            android.util.DisplayMetrics metrics = new android.util.DisplayMetrics();
            android.view.Display display = ((android.view.WindowManager) getContext().getSystemService("window")).getDefaultDisplay();
            display.getMetrics(metrics);
            bm.setDensity(metrics.noncompatDensityDpi);
            android.graphics.Point size = new android.graphics.Point();
            display.getRealSize(size);
            int min = size.x < size.y ? size.x : size.y;
            int max = size.x > size.y ? size.x : size.y;
            int width = bm.getWidth();
            int height = bm.getHeight();
            int i = 0;
            if ((height != max && width != max) || (width != 2 * min && width != max)) {
                x_port = 0;
                int x_port2 = new java.lang.StringBuilder();
                y_port = 1;
                x_port2.append("Irregular bitmap: width=");
                x_port2.append(width);
                x_port2.append(", height=");
                x_port2.append(height);
                android.util.Slog.w("HwWallpaperService", x_port2.toString());
                while (true) {
                    x_port2 = i;
                    if (x_port2 >= wallpaperData.currOffsets.length) {
                        break;
                    }
                    wallpaperData.currOffsets[x_port2] = -1;
                    i = x_port2 + 1;
                }
            } else {
                x_port = 0;
                y_port = 1;
                if (wallpaperData.nextOffsets[0] == -1) {
                    wallpaperData.currOffsets[0] = -1;
                } else if (wallpaperData.nextOffsets[0] < -1) {
                    wallpaperData.currOffsets[0] = 0;
                } else if (wallpaperData.nextOffsets[0] <= width - min) {
                    wallpaperData.currOffsets[0] = wallpaperData.nextOffsets[0];
                } else if (wallpaperData.nextOffsets[0] > width - min) {
                    wallpaperData.currOffsets[0] = width - min;
                }
                wallpaperData.currOffsets[1] = 0;
                wallpaperData.currOffsets[2] = 0;
                if (wallpaperData.nextOffsets[3] == -1) {
                    wallpaperData.currOffsets[3] = -1;
                } else if (wallpaperData.nextOffsets[3] < -1) {
                    wallpaperData.currOffsets[3] = 0;
                } else if (wallpaperData.nextOffsets[3] <= height - min) {
                    wallpaperData.currOffsets[3] = wallpaperData.nextOffsets[3];
                } else if (wallpaperData.nextOffsets[3] > height - min) {
                    wallpaperData.currOffsets[3] = height - min;
                }
            }
            saveWallpaperOffsets(wallpaperData.currOffsets);
            if (!bm.isRecycled()) {
                bm.recycle();
                return;
            }
            return;
        }
        x_port = 0;
        y_port = 1;
    }

    public int[] getCurrOffsets() throws android.os.RemoteException {
        int[] offsets;
        synchronized (getLock()) {
            offsets = new int[]{-1, -1, -1, -1};
            int userId = getWallpaperUserId();
            com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(userId);
            java.lang.String wallpaperOffsets = android.provider.Settings.System.getStringForUser(getContext().getContentResolver(), "curr_wallpaper_offsets", userId);
            if (wallpaperOffsets != null) {
                java.lang.String[] str = wallpaperOffsets.split(",");
                if (str.length == wallpaper.currOffsets.length) {
                    for (int i = 0; i < wallpaper.currOffsets.length; i++) {
                        wallpaper.currOffsets[i] = java.lang.Integer.parseInt(str[i]);
                    }
                }
            }
            java.lang.System.arraycopy(wallpaper.currOffsets, 0, offsets, 0, wallpaper.currOffsets.length);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getCurrOffsets(");
            stringBuilder.append(userId);
            stringBuilder.append("):");
            stringBuilder.append(offsets[0]);
            stringBuilder.append(",");
            stringBuilder.append(offsets[1]);
            stringBuilder.append(",");
            stringBuilder.append(offsets[2]);
            stringBuilder.append(",");
            stringBuilder.append(offsets[3]);
            android.util.Slog.i("HwWallpaperService", stringBuilder.toString());
        }
        return offsets;
    }

    public void setCurrOffsets(int[] offsets) throws android.os.RemoteException {
        getContext().enforceCallingOrSelfPermission("com.huawei.wallpaperservcie.permission.SET_WALLPAPER_OFFSET", null);
        synchronized (getLock()) {
            com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(getWallpaperUserId());
            if (!(offsets == null || wallpaper == null || offsets.length != wallpaper.currOffsets.length)) {
                java.lang.System.arraycopy(offsets, 0, wallpaper.currOffsets, 0, wallpaper.currOffsets.length);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setCurrOffsets:");
                stringBuilder.append(offsets[0]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[1]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[2]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[3]);
                android.util.Slog.i("HwWallpaperService", stringBuilder.toString());
            }
        }
    }

    public void setNextOffsets(int[] offsets) throws android.os.RemoteException {
        synchronized (getLock()) {
            com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(android.os.UserHandle.getCallingUserId());
            if (!(offsets == null || wallpaper == null || offsets.length != wallpaper.nextOffsets.length)) {
                java.lang.System.arraycopy(offsets, 0, wallpaper.nextOffsets, 0, wallpaper.nextOffsets.length);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("setNextOffsets:");
                stringBuilder.append(offsets[0]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[1]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[2]);
                stringBuilder.append(",");
                stringBuilder.append(offsets[3]);
                android.util.Slog.i("HwWallpaperService", stringBuilder.toString());
            }
        }
    }

    public android.graphics.Bitmap scaleWallpaperBitmapToScreenSize(android.graphics.Bitmap bitmap) {
        if (bitmap == null) {
            return null;
        }
        android.graphics.Bitmap bmp;
        android.graphics.Matrix m = new android.graphics.Matrix();
        android.graphics.Point size = new android.graphics.Point();
        int longSideLength = 0;
        int shortSideLength = 0;
        int bitmap_height = bitmap.getHeight();
        int bitmap_width = bitmap.getWidth();
        int bitmapLongSideLength = bitmap_height > bitmap_width ? bitmap_height : bitmap_width;
        int bitmapShortSideLength = bitmap_height > bitmap_width ? bitmap_width : bitmap_height;
        try {
            android.view.IWindowManager.Stub.asInterface(android.os.ServiceManager.checkService("window")).getBaseDisplaySize(0, size);
            longSideLength = size.x > size.y ? size.x : size.y;
            shortSideLength = size.x > size.y ? size.y : size.x;
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("HwWallpaperService", "IWindowManager null");
        }
        int shortSideLength2 = shortSideLength;
        if (!(longSideLength == 0 || shortSideLength2 == 0 || bitmapLongSideLength == longSideLength)) {
            if (bitmapLongSideLength != 2 * shortSideLength2 || bitmapShortSideLength != longSideLength) {
                if ((((float) bitmapLongSideLength) / ((float) shortSideLength2)) / (((float) bitmapShortSideLength) / ((float) longSideLength)) == 2.0f) {
                    longSideLength = shortSideLength2 * 2;
                }
                int longSideLength2 = longSideLength;
                float scale = ((float) longSideLength2) / ((float) bitmapLongSideLength);
                m.setScale(scale, scale);
                bmp = android.graphics.Bitmap.createBitmap(bitmap, 0, 0, bitmap_width, bitmap_height, m, 1);
                return bmp;
            }
        }
        int i = longSideLength;
        bmp = bitmap;
        return bmp;
    }

    private void restartLiveWallpaperService() {
        com.android.server.wallpaper.WallpaperManagerService.WallpaperData wallpaper = (com.android.server.wallpaper.WallpaperManagerService.WallpaperData) getWallpaperMap().get(getWallpaperUserId());
        if (wallpaper != null && wallpaper.wallpaperComponent != null) {
            android.util.Slog.d("HwWallpaperService", "restartLiveWallpaperService ");
            bindWallpaperComponentLocked(wallpaper.wallpaperComponent, true, false, wallpaper, null);
        }
    }

    public void reportWallpaper(android.content.ComponentName componentName) {
        if (componentName != null) {
            android.rms.HwSysResManager resManager = android.rms.HwSysResManager.getInstance();
            if (resManager != null && resManager.isResourceNeeded(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC))) {
                android.os.Bundle bundleArgs = new android.os.Bundle();
                bundleArgs.putString("pkgname", componentName.getPackageName());
                bundleArgs.putInt("relationType", 17);
                android.rms.iaware.CollectData data = new android.rms.iaware.CollectData(android.rms.iaware.AwareConstant.ResourceType.getReousrceId(android.rms.iaware.AwareConstant.ResourceType.RESOURCE_APPASSOC), java.lang.System.currentTimeMillis(), bundleArgs);
                long id = android.os.Binder.clearCallingIdentity();
                resManager.reportData(data);
                android.os.Binder.restoreCallingIdentity(id);
            }
        }
    }
}
