package com.android.server.wm;

public class HwWindowStateAnimator extends com.android.server.wm.WindowStateAnimator {
    private static final int SCENE_POS_EXIT = -1;
    private static final int SCENE_POS_START = 1;
    private static final java.lang.String TAG = "HwWindowStateAnimator";
    private static final int TYPE_LEFT = 1;
    private static final int TYPE_NORMAL = 0;
    private static final int TYPE_RIGHT = 2;
    private android.view.Display mDefaultDisplay;
    private android.view.DisplayInfo mDefaultDisplayInfo = new android.view.DisplayInfo();
    private com.huawei.displayengine.DisplayEngineManager mDisplayEngineManager;
    int mHeight;
    private boolean mIsDefaultDisplay = true;
    final boolean mIsLazy;
    boolean mLazyIsLeft;
    boolean mLazyIsRight;
    float mLazyScale;
    int mPreOpenLazyMode;
    int mWidth;
    private final android.view.WindowManager mWindowManager;

    public HwWindowStateAnimator(com.android.server.wm.WindowState win) {
        super(win);
        this.mIsLazy = win.toString().contains("hwSingleMode_window");
        int displayId = this.mWin.getDisplayId();
        if (!(displayId == -1 || displayId == 0)) {
            this.mIsDefaultDisplay = false;
        }
        this.mPreOpenLazyMode = this.mService.getLazyMode();
        if (!this.mIsDefaultDisplay) {
            this.mPreOpenLazyMode = 0;
        }
        this.mLazyScale = 1.0f;
        this.mLazyIsExiting = false;
        this.mLazyIsEntering = false;
        this.mWindowManager = (android.view.WindowManager) this.mContext.getSystemService("window");
        this.mDisplayEngineManager = new com.huawei.displayengine.DisplayEngineManager();
    }

    private void updatedisplayinfo() {
        this.mDefaultDisplay = this.mWindowManager.getDefaultDisplay();
        this.mDefaultDisplay.getDisplayInfo(this.mDefaultDisplayInfo);
        boolean isPortrait = this.mDefaultDisplayInfo.logicalHeight > this.mDefaultDisplayInfo.logicalWidth;
        this.mWidth = isPortrait ? this.mDefaultDisplayInfo.logicalWidth : this.mDefaultDisplayInfo.logicalHeight;
        this.mHeight = isPortrait ? this.mDefaultDisplayInfo.logicalHeight : this.mDefaultDisplayInfo.logicalWidth;
    }

    public int adjustAnimLayerIfCoverclosed(int type, int animLayer) {
        if (type != 2000 || animLayer >= 400000 || (com.android.server.HwServiceFactory.isCoverClosed() ^ 1)) {
            return animLayer;
        }
        return 400000;
    }

    void computeShownFrameRightLocked() {
        computeShownFrameLocked(2);
    }

    void computeShownFrameLeftLocked() {
        computeShownFrameLocked(1);
    }

    void computeShownFrameLocked(int type) {
        int i = type;
        if (i == 1 || i == 2) {
            updatedisplayinfo();
        }
        com.android.server.wm.ScreenRotationAnimation screenRotationAnimation = this.mAnimator.getScreenRotationAnimationLocked(this.mWin.getDisplayId());
        boolean screenAnimation = screenRotationAnimation != null && screenRotationAnimation.isAnimating();
        float ratio = 1.0f;
        float pendingX = 0.0f;
        float pendingY = 0.0f;
        if (i == 1) {
            ratio = this.mLazyScale;
            pendingY = ((float) this.mHeight) * (1.0f - this.mLazyScale);
        } else if (i == 2) {
            ratio = this.mLazyScale;
            pendingX = ((float) this.mWidth) * (1.0f - this.mLazyScale);
            pendingY = ((float) this.mHeight) * (1.0f - this.mLazyScale);
        }
        if (screenAnimation) {
            android.graphics.Rect frame = this.mWin.mFrame;
            float[] tmpFloats = this.mService.mTmpFloats;
            android.graphics.Matrix tmpMatrix = this.mWin.mTmpMatrix;
            if (screenRotationAnimation.isRotating()) {
                float w = (float) frame.width();
                float h = (float) frame.height();
                if (w < 1.0f || h < 1.0f) {
                    tmpMatrix.reset();
                } else {
                    tmpMatrix.setScale(1.0f + (2.0f / w), 1.0f + (2.0f / h), w / 2.0f, h / 2.0f);
                }
            } else {
                tmpMatrix.reset();
            }
            tmpMatrix.postScale(this.mWin.mGlobalScale, this.mWin.mGlobalScale);
            tmpMatrix.postTranslate((float) this.mWin.mAttrs.surfaceInsets.left, (float) this.mWin.mAttrs.surfaceInsets.top);
            this.mHaveMatrix = true;
            tmpMatrix.getValues(tmpFloats);
            this.mDsDx = tmpFloats[0] * ratio;
            this.mDtDx = tmpFloats[3] * ratio;
            this.mDtDy = tmpFloats[1] * ratio;
            this.mDsDy = tmpFloats[4] * ratio;
            float x = (tmpFloats[2] * ratio) + pendingX;
            this.mShownPosition.set((int) x, (int) ((tmpFloats[5] * ratio) + pendingY));
            this.mShownAlpha = this.mAlpha;
            if (this.mService.mLimitedAlphaCompositing && android.graphics.PixelFormat.formatHasAlpha(this.mWin.mAttrs.format)) {
                if (this.mWin.isIdentityMatrix(this.mDsDx, this.mDtDx, this.mDtDy, this.mDsDy)) {
                }
            }
            if (screenAnimation) {
                this.mShownAlpha *= screenRotationAnimation.getEnterTransformation().getAlpha();
            }
        } else if ((!this.mIsWallpaper || !this.mService.mRoot.mWallpaperActionPending) && !this.mWin.isDragResizeChanged()) {
            this.mShownPosition.set((int) ((((float) this.mWin.mFrame.left) * ratio) + pendingX), (int) ((((float) this.mWin.mFrame.top) * ratio) + pendingY));
            this.mShownAlpha = this.mAlpha;
            this.mHaveMatrix = false;
            this.mDsDx = this.mWin.mGlobalScale * ratio;
            this.mDtDx = 0.0f;
            this.mDtDy = 0.0f;
            this.mDsDy = this.mWin.mGlobalScale * ratio;
        }
    }

    void computeShownFrameLocked() {
        hwPrepareSurfaceLocked();
    }

    boolean isChildWindowAnimating() {
        return false;
    }

    void computeShownFrameNormalLocked() {
        computeShownFrameLocked(0);
    }

    public void hwPrepareSurfaceLocked() {
        int openLazyMode = this.mService.getLazyMode();
        if (!this.mIsDefaultDisplay) {
            openLazyMode = 0;
        }
        int requestedOrientation = -1;
        if (this.mWin.mAppToken != null) {
            requestedOrientation = this.mWin.mAppToken.mOrientation;
        }
        if (this.mIsLazy) {
            computeShownFrameNormalLocked();
            if (this.mWin.toString().contains("hwSingleMode_windowbg")) {
                this.mAnimLayer = 10000 + this.mAnimator.offsetLayer;
            }
            if (this.mWin.toString().contains("hwSingleMode_windowbg_hint")) {
                this.mAnimLayer = 810000;
            }
        } else if (isOrientationLandscape(requestedOrientation)) {
            computeShownFrameNormalLocked();
            this.mPreOpenLazyMode = 0;
        } else {
            computeShownFrameLockedByLazyMode(openLazyMode);
        }
        if (this.mWin.mAttrs.type == 2000 && this.mPreOpenLazyMode != 0 && openLazyMode != 0 && (this.mLazyIsLeft || this.mLazyIsRight)) {
            this.mDsDy += 2.0f / ((float) this.mWin.mFrame.height());
        }
        if (isMultiWindowInSingleHandMode()) {
            this.mWin.getDisplayContent().mDividerControllerLocked.adjustBoundsForSingleHand();
        }
        traceLogForLazyMode(openLazyMode);
        if (android.util.HwPCUtils.isPcCastModeInServer() && !this.mIsDefaultDisplay && android.util.HwPCUtils.isValidExtDisplayId(this.mWin.getDisplayId())) {
            computeShownPCFrameLocked();
        }
    }

    private boolean floatEqualCompare(float f) {
        return ((double) java.lang.Math.abs(this.mLazyScale - f)) < 1.0E-6d;
    }

    private boolean isOrientationLandscape(int requestedOrientation) {
        if (!(requestedOrientation == 0 || requestedOrientation == 6 || requestedOrientation == 8)) {
            if (requestedOrientation != 11) {
                return false;
            }
        }
        return true;
    }

    private void computeShownFrameLockedByLazyMode(int openLazyMode) {
        if (openLazyMode == 0 && this.mPreOpenLazyMode == 1) {
            this.mPreOpenLazyMode = 0;
            this.mLazyIsExiting = true;
            this.mLazyIsEntering = false;
            this.mAnimator.offsetLayer = 0;
            this.mLazyScale = 0.8f;
            computeShownFrameLeftLocked();
        } else if (openLazyMode == 0 && this.mPreOpenLazyMode == 2) {
            this.mPreOpenLazyMode = 0;
            this.mLazyIsExiting = true;
            this.mLazyIsEntering = false;
            this.mLazyScale = 0.8f;
            this.mAnimator.offsetLayer = 0;
            computeShownFrameRightLocked();
        } else if (openLazyMode == 0 && this.mLazyIsExiting && this.mPreOpenLazyMode == 0) {
            if (this.mLazyIsLeft) {
                setLeftLazyScale();
            } else if (this.mLazyIsRight) {
                setRightLazyScale();
            } else {
                this.mLazyScale = 1.0f;
                this.mLazyIsExiting = false;
                this.mLazyIsEntering = false;
                this.mLazyIsRight = false;
                this.mLazyIsLeft = false;
                this.mPreOpenLazyMode = 0;
                computeShownFrameNormalLocked();
            }
        } else if (openLazyMode == 1) {
            handleLeftScale();
        } else if (openLazyMode == 2) {
            handleRightScale();
        } else {
            computeShownFrameNormalLocked();
        }
    }

    private void setLeftLazyScale() {
        if (floatEqualCompare(0.8f)) {
            this.mLazyScale = 0.85f;
            computeShownFrameLeftLocked();
        } else if (floatEqualCompare(0.85f)) {
            this.mLazyScale = 0.9f;
            computeShownFrameLeftLocked();
        } else if (floatEqualCompare(0.9f)) {
            this.mLazyScale = 0.95f;
            computeShownFrameLeftLocked();
        } else if (floatEqualCompare(0.95f)) {
            this.mLazyScale = 1.0f;
            this.mLazyIsExiting = false;
            this.mLazyIsLeft = false;
            computeShownFrameNormalLocked();
        }
    }

    private void setRightLazyScale() {
        if (floatEqualCompare(0.8f)) {
            this.mLazyScale = 0.85f;
            computeShownFrameRightLocked();
        } else if (floatEqualCompare(0.85f)) {
            this.mLazyScale = 0.9f;
            computeShownFrameRightLocked();
        } else if (floatEqualCompare(0.9f)) {
            this.mLazyScale = 0.95f;
            computeShownFrameRightLocked();
        } else if (floatEqualCompare(0.95f)) {
            this.mLazyScale = 1.0f;
            this.mLazyIsExiting = false;
            this.mLazyIsRight = false;
            computeShownFrameNormalLocked();
        }
    }

    private void handleLeftScale() {
        if (this.mPreOpenLazyMode == 0) {
            this.mPreOpenLazyMode = 1;
            this.mLazyIsEntering = true;
            this.mLazyIsExiting = false;
            this.mLazyScale = 0.95f;
            computeShownFrameLeftLocked();
        } else if (this.mPreOpenLazyMode == 1 && this.mLazyIsEntering) {
            if (floatEqualCompare(0.95f)) {
                this.mLazyScale = 0.9f;
            } else if (floatEqualCompare(0.9f)) {
                this.mLazyScale = 0.85f;
            } else if (floatEqualCompare(0.85f)) {
                this.mLazyScale = 0.8f;
            } else if (floatEqualCompare(0.8f)) {
                this.mLazyScale = 0.75f;
                this.mLazyIsEntering = false;
                this.mLazyIsLeft = true;
            }
            computeShownFrameLeftLocked();
        } else {
            this.mLazyScale = 0.75f;
            this.mLazyIsLeft = true;
            this.mAnimator.offsetLayer = 800000;
            computeShownFrameLeftLocked();
        }
    }

    private void handleRightScale() {
        if (this.mPreOpenLazyMode == 0) {
            this.mPreOpenLazyMode = 2;
            this.mLazyIsEntering = true;
            this.mLazyIsExiting = false;
            this.mLazyScale = 0.95f;
            computeShownFrameRightLocked();
        } else if (this.mPreOpenLazyMode == 2 && this.mLazyIsEntering) {
            if (floatEqualCompare(0.95f)) {
                this.mLazyScale = 0.9f;
            } else if (floatEqualCompare(0.9f)) {
                this.mLazyScale = 0.85f;
            } else if (floatEqualCompare(0.85f)) {
                this.mLazyScale = 0.8f;
            } else if (floatEqualCompare(0.8f)) {
                this.mLazyScale = 0.75f;
                this.mLazyIsEntering = false;
                this.mLazyIsRight = true;
            }
            computeShownFrameRightLocked();
        } else {
            this.mLazyScale = 0.75f;
            this.mLazyIsRight = true;
            this.mAnimator.offsetLayer = 800000;
            computeShownFrameRightLocked();
        }
    }

    private boolean isMultiWindowInSingleHandMode() {
        return (this.mWin.mAttrs.type == 2034 && this.mLazyIsEntering && floatEqualCompare(0.8f)) || (this.mLazyIsExiting && floatEqualCompare(0.95f));
    }

    private void traceLogForLazyMode(int openLazyMode) {
    }

    private void computeShownPCFrameLocked() {
        if (this.mService != null) {
            if (this.mService.mHwWMSEx != null) {
                float pcScreenScale = this.mService.mHwWMSEx.getPCScreenScale();
                this.mWin.getPendingTransaction().setMatrix(this.mWin.getSurfaceControl(), pcScreenScale, 0.0f, 0.0f, pcScreenScale);
                return;
            }
        }
        android.util.HwPCUtils.log("HwWindowStateAnimator", "fail to computeShownPCFrameLocked, service is down");
    }

    public float[] getPCDisplayModeSurfacePos(android.graphics.Rect tmpSize) {
        com.android.server.wm.WindowState w = this.mWin;
        float posLeft = (float) tmpSize.left;
        float posTop = (float) tmpSize.top;
        if (android.util.HwPCUtils.isPcCastModeInServer() && android.util.HwPCUtils.isValidExtDisplayId(w.getDisplayId())) {
            int mode = this.mService.getPCScreenDisplayMode();
            if (mode != 0) {
                float pcDisplayScale = mode == 1 ? 0.95f : 0.9f;
                android.graphics.Rect surfaceInsets = this.mWin.mAttrs.surfaceInsets;
                android.graphics.Point outPoint = new android.graphics.Point();
                this.mService.getBaseDisplaySize(w.getDisplayId(), outPoint);
                float scale = (1.0f - pcDisplayScale) / 2.0f;
                if (this.mDsDx == 1.0f && this.mDsDy == 1.0f) {
                    posTop = (((float) outPoint.y) * scale) + (posTop * pcDisplayScale);
                    posLeft = (((float) outPoint.x) * scale) + (posLeft * pcDisplayScale);
                } else if (surfaceInsets.left > 0 && surfaceInsets.top > 0) {
                    float tmpScale = 1.0f - pcDisplayScale;
                    posLeft += ((float) surfaceInsets.left) * tmpScale;
                    posTop += ((float) surfaceInsets.top) * tmpScale;
                }
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getPCDisplayModeSurfacePos name:");
                stringBuilder.append(w.mLastTitle);
                stringBuilder.append(" posLeft:");
                stringBuilder.append(posLeft);
                stringBuilder.append(" posTop:");
                stringBuilder.append(posTop);
                android.util.HwPCUtils.log("HwWindowStateAnimator", stringBuilder.toString());
            }
        }
        return new float[]{posLeft, posTop};
    }

    private boolean ignoreParentClipRect(android.view.WindowManager.LayoutParams lp) {
        return (lp.privateFlags & 1073741824) != 0;
    }

    com.android.server.wm.WindowSurfaceController createSurfaceLocked(int windowType, int ownerUid) {
        com.android.server.wm.WindowSurfaceController surfaceController = super.createSurfaceLocked(windowType, ownerUid);
        sendMessageToDESceneHandler(1);
        return surfaceController;
    }

    void destroySurfaceLocked() {
        sendMessageToDESceneHandler(-1);
        super.destroySurfaceLocked();
    }

    private void sendMessageToDESceneHandler(int pos) {
        com.android.server.wm.WindowState ws = this.mWin;
        android.view.WindowManager.LayoutParams attrs = ws.mAttrs;
        com.android.server.wm.WindowManagerService service = ws.mService;
        java.lang.String SurName = attrs.getTitle().toString();
        com.android.server.wm.DisplayContent displayContent = service.getDefaultDisplayContentLocked();
        int initScreenWidth = displayContent.mInitialDisplayWidth;
        int initScreenHeight = displayContent.mInitialDisplayHeight;
        android.os.Bundle data = new android.os.Bundle();
        data.putInt("Position", pos);
        data.putString("SurfaceName", SurName);
        data.putInt("FrameLeft", ws.mFrame.left);
        data.putInt("FrameRight", ws.mFrame.right);
        data.putInt("FrameTop", ws.mFrame.top);
        data.putInt("FrameBottom", ws.mFrame.bottom);
        data.putInt("SourceWidth", ws.mRequestedWidth);
        data.putInt("SourceHeight", ws.mRequestedHeight);
        data.putInt("DisplayWidth", initScreenWidth);
        data.putInt("DisplayHeight", initScreenHeight);
        data.putInt("Layer", ws.mLayer);
        data.putInt("AnimLayer", this.mAnimLayer);
        data.putInt("BaseLayer", ws.mBaseLayer);
        data.putInt("SubLayer", ws.mSubLayer);
        data.putInt("LastLayer", this.mLastLayer);
        data.putInt("SurfaceFormat", this.mSurfaceFormat);
        data.putString("AttachWinName", null);
        this.mDisplayEngineManager.sendMessage(2, data);
    }

    private int checkWindowType(com.android.server.wm.WindowState win) {
        if (24 == win.mAppOp) {
            return 1;
        }
        if (2005 == win.getAttrs().type) {
            return 2;
        }
        return -1;
    }

    public boolean isEvilWindow(com.android.server.wm.WindowState win) {
        if (win == null) {
            return false;
        }
        return com.android.server.mtm.iaware.appmng.appfreeze.AwareAppFreezeMng.getInstance().isEvilWindow(win.mSession.mPid, java.lang.System.identityHashCode(win), checkWindowType(win));
    }
}
