package com.android.server.wm;

public class IntelliServiceManager {
    private static final boolean DEBUG = android.util.Log.HWLog;
    private static final int DELAY_TIME = 800;
    private static final int INTELLI_ALGO_FACE_ORIENTION = 2;
    public static final int INTELLI_FACE_ORIENTION_TIMEMOUT = -2;
    private static final java.lang.String RO_SWITCH = "ro.config.face_detect";
    private static final java.lang.String RO_SWITCH_ROTATION = "ro.config.face_smart_rotation";
    private static final java.lang.String SERVICE_ACTION = "com.huawei.intelliServer.intelliServer";
    private static final java.lang.String SERVICE_CLASS = "com.huawei.intelliServer.intelliServer.IntelliService";
    private static final java.lang.String SERVICE_PACKAGE = "com.huawei.intelliServer.intelliServer";
    private static final java.lang.String SETTING_SWITCH = "smart_rotation_key";
    public static final java.lang.String TAG = "IntelliServiceManager";
    private static int mDisplayRotation;
    private static com.android.server.wm.IntelliServiceManager mInstance = null;
    private static int mSensorRotation;
    private com.android.server.wm.IntelliServiceManager.FaceRotationCallback mCallback;
    private android.content.ServiceConnection mConnection = new android.content.ServiceConnection() {
        public void onServiceConnected(android.content.ComponentName componentName, android.os.IBinder iBinder) {
            com.android.server.wm.IntelliServiceManager.this.mRemote = com.huawei.IntelliServer.intellilib.IIntelliService.Stub.asInterface(iBinder);
            com.android.server.wm.IntelliServiceManager.this.registerListener("serviceconnect");
            com.android.server.wm.IntelliServiceManager.this.mContext.getMainThreadHandler().removeCallbacks(com.android.server.wm.IntelliServiceManager.this.mFinishRunnble);
            com.android.server.wm.IntelliServiceManager.this.mContext.getMainThreadHandler().postDelayed(com.android.server.wm.IntelliServiceManager.this.mFinishRunnble, 800);
        }

        public void onServiceDisconnected(android.content.ComponentName componentName) {
            android.util.Log.d("IntelliServiceManager", "onServiceDisconnected");
            com.android.server.wm.IntelliServiceManager.this.mRemote = null;
            com.android.server.wm.IntelliServiceManager.this.mIsKeepPortrait = false;
            com.android.server.wm.IntelliServiceManager.this.mIsRunning = false;
            com.android.server.wm.IntelliServiceManager.this.mCallback = null;
        }
    };
    private android.content.Context mContext;
    private int mFaceRotaion = -2;
    java.lang.Runnable mFinishRunnble = new java.lang.Runnable() {
        public void run() {
            android.util.Slog.w("IntelliServiceManager", "detect face timeout");
            com.android.server.wm.IntelliServiceManager.this.stopIntelliService(-2);
        }
    };
    private com.huawei.IntelliServer.intellilib.IIntelliListener mIntelliEventListener = new com.huawei.IntelliServer.intellilib.IIntelliListener.Stub() {
        public void onEvent(com.huawei.IntelliServer.intellilib.IntelliAlgoResult intelliAlgoResult) throws android.os.RemoteException {
            if (com.android.server.wm.IntelliServiceManager.this.mCallback == null) {
                return;
            }
            if (intelliAlgoResult == null) {
                android.util.Slog.e("IntelliServiceManager", "intelliAlgoResult is null");
                com.android.server.wm.IntelliServiceManager.this.stopIntelliService(-2);
            } else if (intelliAlgoResult.getRotation() != -1) {
                if (com.android.server.wm.IntelliServiceManager.DEBUG) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("intelliAlgoResult rotation: ");
                    stringBuilder.append(intelliAlgoResult.getRotation());
                    android.util.Slog.i("IntelliServiceManager", stringBuilder.toString());
                }
                com.android.server.wm.IntelliServiceManager.this.stopIntelliService(intelliAlgoResult.getRotation());
            }
        }

        public void onErr(int i) throws android.os.RemoteException {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("face Rotation onErr ");
            stringBuilder.append(i);
            android.util.Slog.e("IntelliServiceManager", stringBuilder.toString());
        }
    };
    private boolean mIsKeepPortrait = false;
    private boolean mIsRunning = false;
    private com.huawei.IntelliServer.intellilib.IIntelliService mRemote;
    private android.content.Intent mServiceIntent;
    private long startTime;

    public interface FaceRotationCallback {
        void onEvent(int i);
    }

    private IntelliServiceManager(android.content.Context context) {
        this.mContext = context;
        this.mServiceIntent = new android.content.Intent("com.huawei.intelliServer.intelliServer");
        this.mServiceIntent.setClassName("com.huawei.intelliServer.intelliServer", "com.huawei.intelliServer.intelliServer.IntelliService");
    }

    public static com.android.server.wm.IntelliServiceManager getInstance(android.content.Context context) {
        if (mInstance == null) {
            synchronized (com.android.server.wm.IntelliServiceManager.class) {
                if (mInstance == null) {
                    mInstance = new com.android.server.wm.IntelliServiceManager(context);
                }
            }
        }
        return mInstance;
    }

    public static boolean isRotationConsistentFR() {
        boolean z = true;
        if (mDisplayRotation == -1 || mSensorRotation == -1) {
            return true;
        }
        if (mDisplayRotation != mSensorRotation) {
            z = false;
        }
        return z;
    }

    public static void setSensorRotation(int sensorRotation) {
        mSensorRotation = sensorRotation;
    }

    public static void setDisplayRotation(int displayRotation) {
        mDisplayRotation = displayRotation;
    }

    private void stopIntelliService(final int faceRotation) {
        this.mFaceRotaion = faceRotation;
        this.mIsKeepPortrait = false;
        new java.lang.Thread(new java.lang.Runnable() {
            public void run() {
                if (com.android.server.wm.IntelliServiceManager.this.mCallback != null) {
                    com.android.server.wm.IntelliServiceManager.this.mCallback.onEvent(faceRotation);
                }
                com.android.server.wm.IntelliServiceManager.this.mContext.getMainThreadHandler().removeCallbacks(com.android.server.wm.IntelliServiceManager.this.mFinishRunnble);
                com.android.server.wm.IntelliServiceManager.this.mIsRunning = false;
                com.android.server.wm.IntelliServiceManager.this.mCallback = null;
                if (com.android.server.wm.IntelliServiceManager.this.mRemote != null) {
                    try {
                        com.android.server.wm.IntelliServiceManager.this.mRemote.unregistListener(2, com.android.server.wm.IntelliServiceManager.this.mIntelliEventListener);
                    } catch (android.os.RemoteException e) {
                        android.util.Slog.e("IntelliServiceManager", "unregisiterListener fail");
                    }
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("close camera, detect cost ");
                    stringBuilder.append(java.lang.Long.toString(com.android.server.wm.IntelliServiceManager.this.startTime - java.lang.System.currentTimeMillis()));
                    android.util.Slog.i("IntelliServiceManager", stringBuilder.toString());
                }
            }
        }).start();
    }

    public int getFaceRotaion() {
        return this.mFaceRotaion;
    }

    public boolean isKeepPortrait() {
        return this.mIsKeepPortrait;
    }

    public void setKeepPortrait(boolean IsKeepPortrait) {
        this.mIsKeepPortrait = IsKeepPortrait;
        if (DEBUG) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("set IsKeepPortrait = ");
            stringBuilder.append(this.mIsKeepPortrait);
            android.util.Slog.d("IntelliServiceManager", stringBuilder.toString());
        }
    }

    private void registerListener(java.lang.String reason) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("registerListener for:");
        stringBuilder.append(reason);
        stringBuilder.append("cost ");
        stringBuilder.append(java.lang.Long.toString(this.startTime - java.lang.System.currentTimeMillis()));
        android.util.Slog.i("IntelliServiceManager", stringBuilder.toString());
        new java.lang.Thread(new java.lang.Runnable() {
            public void run() {
                try {
                    if (com.android.server.wm.IntelliServiceManager.this.mRemote != null) {
                        com.android.server.wm.IntelliServiceManager.this.mRemote.registListener(2, com.android.server.wm.IntelliServiceManager.this.mIntelliEventListener);
                    }
                } catch (android.os.RemoteException e) {
                    android.util.Slog.e("IntelliServiceManager", "regisiterListener fail ");
                }
            }
        }).start();
    }

    private void bindIntelliService() {
        new java.lang.Thread(new java.lang.Runnable() {
            public void run() {
                android.util.Slog.d("IntelliServiceManager", "bindIntelliService");
                com.android.server.wm.IntelliServiceManager.this.mContext.bindServiceAsUser(com.android.server.wm.IntelliServiceManager.this.mServiceIntent, com.android.server.wm.IntelliServiceManager.this.mConnection, 1, android.os.UserHandle.CURRENT);
            }
        }).start();
    }

    public void unbindIntelliService() {
        if (this.mRemote != null) {
            new java.lang.Thread(new java.lang.Runnable() {
                public void run() {
                    android.util.Slog.d("IntelliServiceManager", "unbindIntelliService");
                    com.android.server.wm.IntelliServiceManager.this.mContext.unbindService(com.android.server.wm.IntelliServiceManager.this.mConnection);
                    com.android.server.wm.IntelliServiceManager.this.mRemote = null;
                }
            }).start();
        }
    }

    public void startIntelliService(com.android.server.wm.IntelliServiceManager.FaceRotationCallback faceRotationCallback) {
        if (faceRotationCallback == null) {
            android.util.Slog.w("IntelliServiceManager", "face rotation call back is null");
            return;
        }
        if (!this.mIsRunning) {
            this.mIsRunning = true;
            this.startTime = java.lang.System.currentTimeMillis();
            if (this.mRemote == null) {
                bindIntelliService();
            } else {
                registerListener("startservice");
            }
        } else if (DEBUG) {
            android.util.Slog.d("IntelliServiceManager", "IntelliService is already running");
        }
        this.mContext.getMainThreadHandler().removeCallbacks(this.mFinishRunnble);
        this.mContext.getMainThreadHandler().postDelayed(this.mFinishRunnble, 800);
        this.mCallback = faceRotationCallback;
    }

    public static boolean isIntelliServiceEnabled(android.content.Context context, int orientation, int userId) {
        if (!(com.android.internal.view.RotationPolicy.isRotationLocked(context) || android.os.SystemProperties.getInt("ro.config.face_detect", 0) == 0)) {
            if (android.os.SystemProperties.getBoolean("ro.config.face_smart_rotation", true)) {
                java.lang.StringBuilder stringBuilder;
                if (android.provider.Settings.Secure.getIntForUser(context.getContentResolver(), "smart_rotation_key", 0, userId) != 1) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("setting switch is off for user ");
                    stringBuilder.append(userId);
                    android.util.Slog.d("IntelliServiceManager", stringBuilder.toString());
                    return false;
                }
                if (!(orientation == 0 || orientation == 1 || orientation == 5 || orientation == 6)) {
                    if (orientation != 8) {
                        if (!isRotationConsistentFR()) {
                            return true;
                        }
                        android.util.Slog.d("IntelliServiceManager", "sensor rotation consistent with display");
                        return false;
                    }
                }
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("skip process orientation ");
                stringBuilder.append(orientation);
                android.util.Slog.d("IntelliServiceManager", stringBuilder.toString());
                return false;
            }
        }
        return false;
    }
}
