package com.android.server.wm;

final class SingleHandWindow {
    private static final boolean DEBUG = false;
    private static final java.lang.String HINT_INFO_TAG = "hint_info";
    private static final float INITIAL_SCALE = 0.75f;
    private static final float MAX_SCALE = 1.0f;
    private static final float MIN_SCALE = 0.3f;
    private static final java.lang.String SINGLE_HAND_MODE_GUIDE_SHOWN = "single_hand_mode_guide_shown";
    private static final java.lang.String SINGLE_HAND_MODE_HINT_SHOWN = "single_hand_mode_hint_shown";
    private static final java.lang.String TAG = "SingleHandWindow";
    private static final float WINDOW_ALPHA = 1.0f;
    private static final java.lang.String WINDOW_BG_TAG = "other_area";
    private static final java.lang.String YES = "yes";
    private android.view.View.OnClickListener mActionClickListener = new android.view.View.OnClickListener() {
        public void onClick(android.view.View v) {
            com.android.server.wm.SingleHandWindow.this.showHint(true);
            android.provider.Settings.Global.putString(com.android.server.wm.SingleHandWindow.this.mContext.getContentResolver(), "single_hand_mode_guide_shown", "yes");
        }
    };
    private boolean mAttachedToWindow = false;
    private android.content.res.Configuration mConfiguration = new android.content.res.Configuration();
    private final android.content.Context mContext;
    private final android.view.Display mDefaultDisplay;
    private android.view.DisplayInfo mDefaultDisplayInfo = new android.view.DisplayInfo();
    private final android.hardware.display.DisplayManager.DisplayListener mDisplayListener = new android.hardware.display.DisplayManager.DisplayListener() {
        public void onDisplayAdded(int displayId) {
        }

        public void onDisplayChanged(int displayId) {
            if (displayId != com.android.server.wm.SingleHandWindow.this.mDefaultDisplay.getDisplayId()) {
                return;
            }
            if (!com.android.server.wm.SingleHandWindow.this.updateDefaultDisplayInfo()) {
                com.android.server.wm.SingleHandWindow.this.dismiss();
            } else if (com.android.server.wm.SingleHandWindow.this.mIsNeedRelayout) {
                com.android.server.wm.SingleHandWindow.this.relayout();
            }
        }

        public void onDisplayRemoved(int displayId) {
            if (displayId == com.android.server.wm.SingleHandWindow.this.mDefaultDisplay.getDisplayId()) {
                com.android.server.wm.SingleHandWindow.this.dismiss();
            }
        }
    };
    private final android.hardware.display.DisplayManager mDisplayManager;
    private android.os.Handler mHandler;
    private int mHeight;
    private float mHeightScale;
    private android.widget.ImageView mImageView;
    private android.content.BroadcastReceiver mIntentReceiver = new android.content.BroadcastReceiver() {
        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (intent != null) {
                if (intent.getAction() != null) {
                    java.lang.String action = intent.getAction();
                    if ("android.intent.action.LOCALE_CHANGED".equals(action)) {
                        com.android.server.wm.SingleHandWindow.this.updateLocale();
                    }
                    if ("android.intent.action.CONFIGURATION_CHANGED".equals(action)) {
                        com.android.server.wm.SingleHandWindow.this.updateConfiguration();
                    }
                }
            }
        }
    };
    private boolean mIsNeedRelayout = false;
    private android.view.ViewGroup.LayoutParams mLayoutParams;
    private final boolean mLeft;
    private final java.lang.String mName;
    private final android.view.View.OnTouchListener mOnTouchListener = new android.view.View.OnTouchListener() {
        public boolean onTouch(android.view.View view, android.view.MotionEvent event) {
            boolean inRegion = com.android.server.wm.SingleHandWindow.this.singlehandRegionContainsPoint((int) event.getRawX(), (int) event.getRawY());
            int actionMasked = event.getActionMasked();
            if (actionMasked != 3) {
                switch (actionMasked) {
                    case 0:
                        com.android.server.wm.SingleHandWindow.this.mPointDownOuter = inRegion ^ 1;
                        break;
                    case 1:
                        android.widget.ImageView imageView = (android.widget.ImageView) com.android.server.wm.SingleHandWindow.this.mWindowContent.findViewById(34603162);
                        if (imageView == null || imageView.getVisibility() != 0) {
                            com.android.server.wm.SingleHandWindow.this.showHint(false);
                            android.provider.Settings.Global.putString(com.android.server.wm.SingleHandWindow.this.mContext.getContentResolver(), "single_hand_mode_hint_shown", "yes");
                        } else if (!inRegion && com.android.server.wm.SingleHandWindow.this.mPointDownOuter) {
                            android.provider.Settings.Global.putString(com.android.server.wm.SingleHandWindow.this.mContext.getContentResolver(), "single_hand_mode", "");
                        }
                        com.android.server.wm.SingleHandWindow.this.mPointDownOuter = false;
                        break;
                    default:
                        break;
                }
            }
            com.android.server.wm.SingleHandWindow.this.mPointDownOuter = false;
            return true;
        }
    };
    private boolean mPointDownOuter = false;
    private android.view.DisplayInfo mPreDisplayInfo = new android.view.DisplayInfo();
    private android.widget.RelativeLayout mRelateViewbottom;
    private android.widget.RelativeLayout mRelateViewtop;
    private final com.android.server.wm.WindowManagerService mService;
    private int mWidth;
    private float mWidthScale;
    private android.view.View mWindowContent;
    private final android.view.WindowManager mWindowManager;
    private android.view.WindowManager.LayoutParams mWindowParams;
    private boolean mWindowVisible;
    private android.widget.TextView overlay_display_window = null;
    private android.widget.TextView overlay_guide_window = null;
    private android.widget.TextView singlehandmode_slide_hint_text_1 = null;
    private android.widget.TextView singlehandmode_slide_hint_text_2 = null;

    public SingleHandWindow(android.content.Context context, boolean left, java.lang.String name, int width, int height, com.android.server.wm.WindowManagerService service) {
        this.mContext = context;
        this.mName = name;
        this.mWidth = width;
        this.mHeight = height;
        this.mLeft = left;
        this.mHandler = new android.os.Handler();
        this.mWindowManager = (android.view.WindowManager) context.getSystemService("window");
        this.mDisplayManager = (android.hardware.display.DisplayManager) context.getSystemService("display");
        this.mService = service;
        this.mDefaultDisplay = this.mWindowManager.getDefaultDisplay();
        this.mDefaultDisplayInfo = this.mService.getDefaultDisplayContentLocked().getDisplayInfo();
        this.mConfiguration = this.mContext.getResources().getConfiguration();
        this.mPreDisplayInfo.copyFrom(this.mDefaultDisplayInfo);
        if (this.mName.contains("blurpaper")) {
            createWindow();
        }
    }

    public void show() {
        if (!this.mWindowVisible) {
            if (!this.mName.contains("blurpaper")) {
                this.mService.freezeOrThawRotation(0);
                this.mService.setLazyMode(this.mLeft ? 1 : 2);
            }
            this.mDisplayManager.registerDisplayListener(this.mDisplayListener, null);
            if (updateDefaultDisplayInfo()) {
                if (this.mName.equals("blurpapertop")) {
                    this.mWindowParams.x = 0;
                    this.mWindowParams.y = 0;
                    this.mWindowParams.width = this.mWidth;
                    this.mWindowParams.height = this.mHeight;
                    this.mWindowContent.setOnTouchListener(this.mOnTouchListener);
                    this.mWindowManager.addView(this.mWindowContent, this.mWindowParams);
                }
                this.mWindowVisible = true;
            } else {
                this.mDisplayManager.unregisterDisplayListener(this.mDisplayListener);
            }
        }
    }

    public void dismiss() {
        if (this.mAttachedToWindow) {
            this.mAttachedToWindow = false;
            this.mContext.unregisterReceiver(this.mIntentReceiver);
        }
        if (this.mWindowVisible) {
            if (updateDefaultDisplayInfo()) {
                this.mDisplayManager.unregisterDisplayListener(this.mDisplayListener);
            }
            if (this.mName.contains("blurpaper")) {
                this.mWindowManager.removeView(this.mWindowContent);
            } else {
                this.mHandler.postDelayed(new java.lang.Runnable() {
                    public void run() {
                        com.android.server.wm.SingleHandWindow.this.mService.freezeOrThawRotation(-1);
                    }
                }, 100);
                this.mService.setLazyMode(0);
            }
            this.mWindowVisible = false;
        }
    }

    public void relayout() {
        if (this.mWindowVisible && this.mName.contains("blurpaper")) {
            this.mWindowManager.removeView(this.mWindowContent);
            this.mWindowVisible = false;
            createWindow();
            updateWindowParams();
            this.mWindowContent.setOnTouchListener(this.mOnTouchListener);
            this.mWindowManager.addView(this.mWindowContent, this.mWindowParams);
            this.mWindowVisible = true;
        }
    }

    private android.graphics.Bitmap cropwallpaper(boolean isTop) {
        if (com.android.server.wm.SingleHandAdapter.scaleWallpaper == null) {
            android.util.Slog.e("SingleHandWindow", "scaleWallpaper null.");
            return null;
        }
        android.graphics.Bitmap crop;
        int w = com.android.server.wm.SingleHandAdapter.scaleWallpaper.getWidth();
        int h = com.android.server.wm.SingleHandAdapter.scaleWallpaper.getHeight();
        if (isTop) {
            crop = android.graphics.Bitmap.createBitmap(com.android.server.wm.SingleHandAdapter.scaleWallpaper, 0, 0, w, (int) (((float) h) * 0.25f));
        } else if (this.mLeft) {
            crop = android.graphics.Bitmap.createBitmap(com.android.server.wm.SingleHandAdapter.scaleWallpaper, (int) (((float) w) * 0.75f), (int) (((float) h) * 0.25f), (int) (((float) w) - (((float) w) * 0.75f)), (int) (((float) h) * 0.75f));
        } else {
            crop = android.graphics.Bitmap.createBitmap(com.android.server.wm.SingleHandAdapter.scaleWallpaper, 0, (int) (((float) h) * 0.25f), (int) (((float) w) - (((float) w) * 0.75f)), (int) (((float) h) * 0.75f));
            return crop;
        }
        return crop;
    }

    void updateLocale() {
        android.util.Slog.d("SingleHandWindow", "updateLocale .");
        if (this.overlay_display_window != null) {
            this.overlay_display_window.setText(this.mContext.getResources().getString(33685745));
        }
        if (this.overlay_guide_window != null) {
            this.overlay_guide_window.setText(this.mContext.getResources().getString(33686171));
            this.overlay_guide_window.setBackgroundDrawable(this.mContext.getResources().getDrawable(33751974));
        }
        if (this.singlehandmode_slide_hint_text_1 != null) {
            this.singlehandmode_slide_hint_text_1.setText(this.mContext.getResources().getString(33686172, new java.lang.Object[]{java.lang.Integer.valueOf(1)}));
        }
        if (this.singlehandmode_slide_hint_text_2 != null) {
            this.singlehandmode_slide_hint_text_2.setText(this.mContext.getResources().getString(33686173, new java.lang.Object[]{java.lang.Integer.valueOf(2)}));
        }
    }

    void updateConfiguration() {
        android.content.res.Configuration newConfiguration = this.mContext.getResources().getConfiguration();
        int diff = this.mConfiguration.diff(newConfiguration);
        this.mConfiguration = newConfiguration;
        if ((diff & 128) != 0) {
            android.provider.Settings.Global.putString(this.mContext.getContentResolver(), "single_hand_mode", "");
        }
    }

    private boolean updateDefaultDisplayInfo() {
        this.mIsNeedRelayout = false;
        if (!this.mDefaultDisplay.getDisplayInfo(this.mDefaultDisplayInfo)) {
            android.util.Slog.w("SingleHandWindow", "Cannot show overlay display because there is no default display upon which to show it.");
            return false;
        } else if (this.mPreDisplayInfo == null) {
            return false;
        } else {
            if (!this.mPreDisplayInfo.equals(this.mDefaultDisplayInfo)) {
                this.mWidthScale = ((float) this.mDefaultDisplayInfo.logicalWidth) / ((float) this.mPreDisplayInfo.logicalWidth);
                this.mHeightScale = ((float) this.mDefaultDisplayInfo.logicalHeight) / ((float) this.mPreDisplayInfo.logicalHeight);
                if (!(this.mDefaultDisplayInfo.logicalWidth == this.mPreDisplayInfo.logicalWidth && this.mDefaultDisplayInfo.logicalHeight == this.mPreDisplayInfo.logicalHeight && this.mDefaultDisplayInfo.logicalDensityDpi == this.mPreDisplayInfo.logicalDensityDpi)) {
                    this.mIsNeedRelayout = true;
                }
                this.mPreDisplayInfo.copyFrom(this.mDefaultDisplayInfo);
            }
            return true;
        }
    }

    public void updateLayoutParams() {
        this.mLayoutParams = this.mRelateViewtop.getLayoutParams();
        this.mLayoutParams.height = this.mDefaultDisplayInfo.logicalHeight / 4;
        this.mRelateViewtop.setLayoutParams(this.mLayoutParams);
        this.mLayoutParams = this.mRelateViewbottom.getLayoutParams();
        this.mLayoutParams.height = (this.mDefaultDisplayInfo.logicalHeight * 3) / 4;
        this.mLayoutParams.width = this.mDefaultDisplayInfo.logicalWidth / 4;
        if (this.mLeft) {
            ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(11);
        } else {
            ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(9);
        }
        ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(12);
        this.mRelateViewbottom.setLayoutParams(this.mLayoutParams);
    }

    private void createWindow() {
        android.view.ViewGroup.MarginLayoutParams marginParams;
        this.mWindowContent = android.view.LayoutInflater.from(this.mContext).inflate(34013238, null);
        boolean hintShown = isSingleHandModeHintShown("single_hand_mode_hint_shown");
        if (!this.mAttachedToWindow) {
            this.mAttachedToWindow = true;
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("android.intent.action.LOCALE_CHANGED");
            filter.addAction("android.intent.action.CONFIGURATION_CHANGED");
            this.mContext.registerReceiver(this.mIntentReceiver, filter, null, this.mHandler);
        }
        if (this.mName.contains("blurpaper")) {
            synchronized (com.android.server.wm.SingleHandAdapter.mLock) {
                this.mWindowContent.setBackgroundColor(0);
                this.mRelateViewtop = (android.widget.RelativeLayout) this.mWindowContent.findViewById(34603160);
                this.mLayoutParams = this.mRelateViewtop.getLayoutParams();
                this.mLayoutParams.height = this.mDefaultDisplayInfo.logicalHeight / 4;
                this.mRelateViewtop.setLayoutParams(this.mLayoutParams);
                this.mRelateViewtop.setBackground(new android.graphics.drawable.BitmapDrawable(this.mRelateViewtop.getResources(), cropwallpaper(true)));
                this.mRelateViewbottom = (android.widget.RelativeLayout) this.mWindowContent.findViewById(34603161);
                this.mLayoutParams = this.mRelateViewbottom.getLayoutParams();
                this.mLayoutParams.height = (this.mDefaultDisplayInfo.logicalHeight * 3) / 4;
                this.mLayoutParams.width = this.mDefaultDisplayInfo.logicalWidth / 4;
                if (this.mLeft) {
                    ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(11);
                } else {
                    ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(9);
                }
                ((android.widget.RelativeLayout.LayoutParams) this.mLayoutParams).addRule(12);
                this.mRelateViewbottom.setLayoutParams(this.mLayoutParams);
                this.mRelateViewbottom.setBackground(new android.graphics.drawable.BitmapDrawable(this.mRelateViewbottom.getResources(), cropwallpaper(false)));
            }
        }
        this.mWindowParams = new android.view.WindowManager.LayoutParams(2026);
        android.view.WindowManager.LayoutParams layoutParams = this.mWindowParams;
        layoutParams.flags |= 16778024;
        layoutParams = this.mWindowParams;
        layoutParams.privateFlags |= 2;
        this.mWindowParams.alpha = 1.0f;
        this.mWindowParams.gravity = 51;
        this.mWindowParams.format = -3;
        if (this.mName.contains("blurpaper")) {
            showHint(hintShown ^ 1);
            this.mWidthScale = 1.0f;
            this.mHeightScale = 1.0f;
        }
        android.widget.RelativeLayout layout = (android.widget.RelativeLayout) this.mWindowContent.findViewById(34603068);
        int top = this.mContext.getApplicationContext().getResources().getDimensionPixelSize(17105318);
        android.view.ViewGroup.LayoutParams LayoutParam = layout.getLayoutParams();
        if (LayoutParam instanceof android.view.ViewGroup.MarginLayoutParams) {
            marginParams = (android.view.ViewGroup.MarginLayoutParams) LayoutParam;
        } else {
            marginParams = new android.view.ViewGroup.MarginLayoutParams(LayoutParam);
        }
        marginParams.setMargins(0, top, -2, -2);
        layout.setLayoutParams(marginParams);
        updateLocale();
    }

    private void updateWindowParams() {
        this.mWindowParams.x = 0;
        this.mWindowParams.y = 0;
        this.mWindowParams.width = this.mDefaultDisplayInfo.logicalWidth;
        this.mWindowParams.height = this.mDefaultDisplayInfo.logicalHeight;
        this.mWidth = (int) (((float) this.mWidth) * this.mWidthScale);
        this.mHeight = (int) (((float) this.mHeight) * this.mHeightScale);
    }

    boolean isSingleHandModeHintShown(java.lang.String tag) {
        java.lang.String value = android.provider.Settings.Global.getString(this.mContext.getContentResolver(), tag);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("tag ");
        stringBuilder.append(tag);
        stringBuilder.append("value ");
        stringBuilder.append(value);
        android.util.Slog.d("SingleHandWindow", stringBuilder.toString());
        if (value != null) {
            if (value.equals("yes")) {
                return true;
            }
        }
        return false;
    }

    private void show(android.view.View v, boolean visible) {
        if (v == null) {
            return;
        }
        if (visible) {
            v.setVisibility(0);
        } else {
            v.setVisibility(4);
        }
    }

    private void showHint(boolean visible) {
        android.widget.LinearLayout.LayoutParams params;
        this.mImageView = (android.widget.ImageView) this.mWindowContent.findViewById(34603162);
        ((android.widget.FrameLayout) this.mWindowContent.findViewById(34603163)).setOnClickListener(new android.view.View.OnClickListener() {
            public void onClick(android.view.View v) {
                com.android.server.wm.SingleHandWindow.this.mImageView.performClick();
            }
        });
        if (!(visible || this.mImageView == null)) {
            this.mImageView.setOnClickListener(this.mActionClickListener);
        }
        show(this.mImageView, visible ^ 1);
        if (visible) {
            this.mWindowContent.setBackgroundColor(-1728053248);
        } else {
            this.mWindowContent.setBackgroundColor(0);
        }
        this.overlay_display_window = (android.widget.TextView) this.mWindowContent.findViewById(34603164);
        this.overlay_guide_window = (android.widget.TextView) this.mWindowContent.findViewById(34603235);
        if (isSingleHandModeHintShown("single_hand_mode_guide_shown")) {
            show(this.overlay_guide_window, false);
        } else {
            show(this.overlay_guide_window, visible ^ 1);
        }
        show(this.overlay_display_window, visible ^ 1);
        this.singlehandmode_slide_hint_text_1 = (android.widget.TextView) this.mWindowContent.findViewById(34603257);
        show(this.singlehandmode_slide_hint_text_1, visible);
        this.singlehandmode_slide_hint_text_2 = (android.widget.TextView) this.mWindowContent.findViewById(34603258);
        show(this.singlehandmode_slide_hint_text_2, visible);
        android.widget.LinearLayout viewSlideHint = (android.widget.LinearLayout) this.mWindowContent.findViewById(34603166);
        if (viewSlideHint != null) {
            if (visible) {
                viewSlideHint.setVisibility(0);
            } else {
                viewSlideHint.setVisibility(4);
            }
        }
        android.widget.ImageView imageView = (android.widget.ImageView) this.mWindowContent.findViewById(34603259);
        if (imageView != null) {
            params = (android.widget.LinearLayout.LayoutParams) imageView.getLayoutParams();
            params.width = (this.mDefaultDisplayInfo.logicalWidth * 4) / 9;
            params.height = params.width;
            imageView.setLayoutParams(params);
        }
        show(imageView, visible);
        imageView = (android.widget.ImageView) this.mWindowContent.findViewById(34603260);
        if (imageView != null) {
            params = (android.widget.LinearLayout.LayoutParams) imageView.getLayoutParams();
            params.width = (this.mDefaultDisplayInfo.logicalWidth * 4) / 9;
            params.height = params.width;
            imageView.setLayoutParams(params);
        }
        show(imageView, visible);
        setWindowTitle(visible);
        if (this.mWindowVisible) {
            this.mWindowManager.updateViewLayout(this.mWindowContent, this.mWindowParams);
        }
    }

    private void setWindowTitle(boolean visible) {
        if (visible) {
            this.mWindowParams.setTitle("hwSingleMode_windowbg_hint");
        } else if (this.mLeft) {
            this.mWindowParams.setTitle("hwSingleMode_windowbg_left");
        } else {
            this.mWindowParams.setTitle("hwSingleMode_windowbg_right");
        }
    }

    boolean singlehandRegionContainsPoint(int x, int y) {
        int top = (int) (((float) this.mDefaultDisplayInfo.logicalHeight) * 1048576000);
        int bottom = this.mDefaultDisplayInfo.logicalHeight;
        int left;
        int right;
        if (this.mLeft) {
            left = 0;
            right = (int) (((float) this.mDefaultDisplayInfo.logicalWidth) * 1061158912);
        } else {
            left = (int) (((float) this.mDefaultDisplayInfo.logicalWidth) * 0.25f);
            right = this.mDefaultDisplayInfo.logicalWidth;
        }
        if (y < top || y >= bottom || x < left || x >= right) {
            return false;
        }
        return true;
    }

    public void onBlurWallpaperChanged() {
        this.mRelateViewtop = (android.widget.RelativeLayout) this.mWindowContent.findViewById(34603160);
        this.mRelateViewtop.setBackground(new android.graphics.drawable.BitmapDrawable(this.mRelateViewtop.getResources(), cropwallpaper(true)));
        this.mRelateViewbottom = (android.widget.RelativeLayout) this.mWindowContent.findViewById(34603161);
        this.mRelateViewbottom.setBackground(new android.graphics.drawable.BitmapDrawable(this.mRelateViewbottom.getResources(), cropwallpaper(null)));
    }
}
