package com.android.server.zrhung;

public final class ZRHungService extends com.android.server.SystemService implements com.android.server.zrhung.IZRHungService {
    private static final int MSG_ZRHUNG_INIT = 1;
    private static final int MSG_ZRHUNG_SOCKET_EVENT_RECEIVE = 2;
    private static final int MSG_ZRHUNG_USER_EVENT_DELAY = 3;
    private static final java.lang.String TAG = "ZRHungService";
    private static final int ZRHUNG_ANR_INTERVAL = 6000;
    private static final int ZRHUNG_USER_EVENT_TIMEOUT = 10000;
    private static com.android.server.zrhung.IZRHungService mService = null;
    private final java.util.HashMap<java.lang.String, com.android.server.zrhung.ZRHungService.AppEyeANRData> mANRMap = new java.util.HashMap();
    private final android.content.Context mContext;
    private java.lang.String[] mDirectRecoverPackageList = null;
    private volatile int mForegroundAppPid;
    private volatile int mForegroundAppUid;
    private final android.os.Handler mHandler;
    private android.os.Handler.Callback mHandlerCallback = new android.os.Handler.Callback() {
        public boolean handleMessage(android.os.Message msg) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("handleMessage :");
            stringBuilder.append(msg.what);
            android.util.Slog.d("ZRHungService", stringBuilder.toString());
            switch (msg.what) {
                case 1:
                    com.android.server.zrhung.ZRHungService.this.handleInitService();
                    return true;
                case 2:
                    com.android.server.zrhung.ZRHungService.this.handleAppFreezeEvent((com.android.server.zrhung.appeye.AppEyeMessage) msg.obj);
                    return true;
                case 3:
                    java.lang.String packageName = ((com.android.server.zrhung.appeye.AppEyeMessage) msg.obj).getAppPkgName();
                    android.zrhung.ZrHungData data = new android.zrhung.ZrHungData();
                    data.putString("packageName", packageName);
                    com.android.server.zrhung.ZRHungService.this.handleUserEvent(data, true);
                    return true;
                default:
                    return false;
            }
        }
    };
    private boolean mIsDirectRecoveryConfiged = false;
    private boolean mIsDirectRecoveryEnabled = false;
    private android.app.IProcessObserver mProcessObserver = new android.app.IProcessObserver.Stub() {
        public void onForegroundActivitiesChanged(int pid, int uid, boolean foregroundActivities) {
            if (foregroundActivities) {
                com.android.server.zrhung.ZRHungService.this.mForegroundAppPid = pid;
                com.android.server.zrhung.ZRHungService.this.mForegroundAppUid = uid;
            }
        }

        public void onProcessDied(int pid, int uid) {
        }
    };
    private com.android.server.zrhung.appeye.AppEyeSocketThread mSocketThread = null;

    static final class AppEyeANRData {
        public static final int ANR_DIALOG_REMOVED = 1;
        public static final int ANR_DIALOG_SHOWING = 0;
        private int mANRDialogStatus = 1;
        private long mANRTime = 0;
        private java.lang.String mANRType = null;

        AppEyeANRData(java.lang.String aNRType, long currentTime) {
            this.mANRType = aNRType;
            this.mANRTime = currentTime;
        }
    }

    public ZRHungService(android.content.Context context) {
        super(context);
        setInstance(this);
        this.mContext = context;
        android.os.HandlerThread handlerThread = new android.os.HandlerThread("ZRHungService");
        handlerThread.start();
        this.mHandler = new android.os.Handler(handlerThread.getLooper(), this.mHandlerCallback);
        android.util.Slog.d("ZRHungService", "ZRHungService on create!");
    }

    public static synchronized com.android.server.zrhung.IZRHungService getInstance() {
        com.android.server.zrhung.IZRHungService iZRHungService;
        synchronized (com.android.server.zrhung.ZRHungService.class) {
            iZRHungService = mService;
        }
        return iZRHungService;
    }

    private static void setInstance(com.android.server.zrhung.IZRHungService service) {
        mService = service;
    }

    public void onStart() {
        android.util.Slog.d("ZRHungService", "onStart!");
    }

    public void onBootPhase(int phase) {
        android.util.Slog.d("ZRHungService", "onBootPhase!");
        if (phase == 1000 && this.mHandler != null) {
            this.mHandler.sendEmptyMessage(1);
        }
    }

    private void registerProcessObserver() {
        try {
            android.app.ActivityManagerNative.getDefault().registerProcessObserver(this.mProcessObserver);
        } catch (android.os.RemoteException e) {
            android.util.Slog.e("ZRHungService", "ZRHungService register ProcessObserver fail");
        }
    }

    public boolean sendEvent(android.zrhung.ZrHungData args) {
        if (args == null) {
            return false;
        }
        java.lang.String eventType = args.getString("eventtype");
        int i = -1;
        int hashCode = eventType.hashCode();
        if (hashCode != -74099055) {
            if (hashCode != 1777228417) {
                if (hashCode != 1914956048) {
                    if (hashCode == 1985941039) {
                        if (eventType.equals("settime")) {
                            i = 2;
                        }
                    }
                } else if (eventType.equals("showanrdialog")) {
                    i = 3;
                }
            } else if (eventType.equals("recoverresult")) {
                i = true;
            }
        } else if (eventType.equals("socketrecover")) {
            i = false;
        }
        switch (i) {
            case 0:
                com.android.server.zrhung.appeye.AppEyeMessage object = (com.android.server.zrhung.appeye.AppEyeMessage) args.get("appeyemessage");
                if (object != null) {
                    android.os.Message message = this.mHandler.obtainMessage();
                    message.what = 2;
                    message.obj = object;
                    message.sendToTarget();
                    android.util.Slog.i("ZRHungService", "Receive a socket message from zrhung");
                    return true;
                }
                android.util.Slog.i("ZRHungService", "NULL message");
                return false;
            case 1:
                if (handleUserEvent(args, false)) {
                    return true;
                }
                android.util.Slog.w("ZRHungService", "sendEvent  recoverresult error!");
                return false;
            case 2:
                setAppEyeANRDataLocked(args);
                return true;
            case 3:
                if (canShowANRDialogs(args)) {
                    return true;
                }
                return false;
            default:
                return false;
        }
    }

    private void handleInitService() {
        if (this.mSocketThread == null) {
            this.mSocketThread = new com.android.server.zrhung.appeye.AppEyeSocketThread();
            this.mSocketThread.start();
            android.util.Slog.d("ZRHungService", "handleInitService!");
            registerProcessObserver();
            return;
        }
        android.util.Slog.d("ZRHungService", "socketThread already start!");
    }

    private void handleAppFreezeEvent(com.android.server.zrhung.appeye.AppEyeMessage message) {
        if (message == null) {
            android.util.Slog.e("ZRHungService", "null message or mPath received from Server");
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("received message:");
        stringBuilder.append(message.toString());
        android.util.Slog.d("ZRHungService", stringBuilder.toString());
        java.lang.String command = message.getCommand();
        java.lang.Object obj = -1;
        int hashCode = command.hashCode();
        if (hashCode != -1547232625) {
            if (hashCode != -1164891468) {
                if (hashCode == 1702423020) {
                    if (command.equals("killMultiTarget")) {
                        obj = 2;
                    }
                }
            } else if (command.equals("notifyUser")) {
                obj = null;
            }
        } else if (command.equals("killTarget")) {
            obj = 1;
        }
        switch (obj) {
            case null:
                notifyRecoverEventToUser(message);
                break;
            case 1:
                killApplicationProcess(message.getAppPid());
                break;
            case 2:
                java.util.Iterator it = message.getAppPidList().iterator();
                while (it.hasNext()) {
                    killApplicationProcess(((java.lang.Integer) it.next()).intValue());
                }
                break;
            default:
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("invalid command: ");
                stringBuilder2.append(command);
                android.util.Slog.e("ZRHungService", stringBuilder2.toString());
                break;
        }
    }

    private void notifyRecoverEventToUser(com.android.server.zrhung.appeye.AppEyeMessage message) {
        int pid = message.getAppPid();
        int uid = message.getAppUid();
        java.lang.String processName = message.getAppProcessName();
        java.lang.String packageName = message.getAppPkgName();
        if (!(processName == null || packageName == null)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("notifyRecoverEventToUser -- pid:");
            stringBuilder.append(pid);
            stringBuilder.append(" uid:");
            stringBuilder.append(uid);
            stringBuilder.append(" processName:");
            stringBuilder.append(processName);
            stringBuilder.append(" packageName:");
            stringBuilder.append(packageName);
            android.util.Slog.d("ZRHungService", stringBuilder.toString());
            if (pid != this.mForegroundAppPid) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("notifyRecoverEventToUser return due to no match foreground app mForegroundAppPid:");
                stringBuilder.append(this.mForegroundAppPid);
                stringBuilder.append(" mForegroundAppUid:");
                stringBuilder.append(this.mForegroundAppUid);
                stringBuilder.append(" mTargetAppPid:");
                stringBuilder.append(pid);
                stringBuilder.append(" mTargetAppUid:");
                stringBuilder.append(uid);
                android.util.Slog.d("ZRHungService", stringBuilder.toString());
                return;
            }
            this.mHandler.removeMessages(3);
            com.huawei.android.app.HwActivityManager.handleShowAppEyeAnrUi(pid, uid, processName, packageName);
            android.os.Message msg = this.mHandler.obtainMessage();
            msg.what = 3;
            msg.obj = message;
            this.mHandler.sendMessageDelayed(msg, 10000);
        }
    }

    private boolean handleUserEvent(android.zrhung.ZrHungData args, boolean isTimeout) {
        if (args == null) {
            android.util.Slog.e("ZRHungService", "null args received!");
            return false;
        } else if (handleDirectRecoverPackages(args.getString("packageName"), args.getInt("pid"))) {
            return true;
        } else {
            if (isTimeout) {
                args.putString("result", "Timeout");
            } else if (!this.mHandler.hasMessages(3) || args.getString("result") == null) {
                return false;
            } else {
                this.mHandler.removeMessages(3);
            }
            if (!sendAppFreezeEvent((short) 278, args, null, "user handled recover")) {
                android.util.Slog.e("ZRHungService", "send App Freeze recover result error!");
            }
            return true;
        }
    }

    private boolean sendAppFreezeEvent(short wpId, android.zrhung.ZrHungData args, java.lang.String cmdBuf, java.lang.String buffer) {
        java.lang.StringBuilder stringBuilder;
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        if (args != null) {
            try {
                java.lang.String recoverresult = args.getString("result");
                if (recoverresult != null) {
                    sb.append("result = ");
                    sb.append(recoverresult);
                    sb.append(10);
                }
                int uid = args.getInt("uid");
                if (uid > 0) {
                    sb.append("uid = ");
                    sb.append(java.lang.Integer.toString(uid));
                    sb.append(10);
                }
                int pid = args.getInt("pid");
                if (pid > 0) {
                    sb.append("pid = ");
                    sb.append(java.lang.Integer.toString(pid));
                    sb.append(10);
                }
                java.lang.String pkgName = args.getString("packageName");
                if (pkgName != null) {
                    sb.append("packageName = ");
                    sb.append(pkgName);
                    sb.append(10);
                }
                java.lang.String procName = args.getString("processName");
                if (procName != null) {
                    sb.append("processName = ");
                    sb.append(procName);
                    sb.append(10);
                }
            } catch (java.lang.Exception ex) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("exception info ex:");
                stringBuilder.append(ex);
                android.util.Slog.e("ZRHungService", stringBuilder.toString());
                return false;
            }
        }
        if (buffer != null) {
            sb.append(buffer);
        }
        java.lang.Exception ex2 = android.util.ZRHung.sendHungEvent(wpId, cmdBuf, sb.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" sendAppFreezeEvent message:");
        stringBuilder.append(sb.toString());
        android.util.Slog.d("ZRHungService", stringBuilder.toString());
        if (ex2 == null) {
            android.util.Slog.e("ZRHungService", " sendAppFreezeEvent failed!");
        }
        return true;
    }

    /* JADX WARNING: Missing block: B:27:0x006a, code:
            return r0;
     */
    private boolean canShowANRDialogs(android.zrhung.ZrHungData r9) {
        /*
        r8 = this;
        r0 = 1;
        r1 = r8.mANRMap;
        monitor-enter(r1);
        if (r9 == 0) goto L_0x0069;
    L_0x0006:
        r2 = "packageName";
        r2 = r9.getString(r2);	 Catch:{ all -> 0x0067 }
        r3 = "result";
        r3 = r9.getString(r3);	 Catch:{ all -> 0x0067 }
        r4 = "pid";
        r4 = r9.getInt(r4);	 Catch:{ all -> 0x0067 }
        r5 = r8.handleDirectRecoverPackages(r2, r4);	 Catch:{ all -> 0x0067 }
        r6 = 0;
        if (r5 == 0) goto L_0x0021;
    L_0x001f:
        monitor-exit(r1);	 Catch:{ all -> 0x0067 }
        return r6;
    L_0x0021:
        if (r2 == 0) goto L_0x0069;
    L_0x0023:
        if (r3 == 0) goto L_0x0069;
    L_0x0025:
        r5 = "original";
        r5 = r3.equals(r5);	 Catch:{ all -> 0x0067 }
        if (r5 == 0) goto L_0x0044;
    L_0x002d:
        r5 = r8.canShowOriginalANRDialogsLocked(r2);	 Catch:{ all -> 0x0067 }
        if (r5 != 0) goto L_0x003c;
    L_0x0033:
        r5 = "ZRHungService";
        r7 = " forbid ORIGNAL ANR Dialogs";
        android.util.Slog.d(r5, r7);	 Catch:{ all -> 0x0067 }
        r0 = 0;
        goto L_0x005a;
    L_0x003c:
        r5 = "ZRHungService";
        r7 = " show ORIGNAL ANR Dialogs";
        android.util.Slog.d(r5, r7);	 Catch:{ all -> 0x0067 }
        goto L_0x005a;
    L_0x0044:
        r5 = r8.canShowAppEyeANRDialogsLocked(r2);	 Catch:{ all -> 0x0067 }
        if (r5 != 0) goto L_0x0053;
    L_0x004a:
        r5 = "ZRHungService";
        r7 = " forbid APPEYE ANR Dialogs";
        android.util.Slog.d(r5, r7);	 Catch:{ all -> 0x0067 }
        r0 = 0;
        goto L_0x005a;
    L_0x0053:
        r5 = "ZRHungService";
        r7 = " show APPEYE ANR Dialogs";
        android.util.Slog.d(r5, r7);	 Catch:{ all -> 0x0067 }
    L_0x005a:
        if (r0 == 0) goto L_0x0069;
    L_0x005c:
        r5 = r8.isTargetAnrProcessStillAlive(r4);	 Catch:{ all -> 0x0067 }
        r0 = r5;
        if (r0 == 0) goto L_0x0069;
    L_0x0063:
        r8.resetAppEyeANRDataLocked(r2, r3, r6);	 Catch:{ all -> 0x0067 }
        goto L_0x0069;
    L_0x0067:
        r2 = move-exception;
        goto L_0x006b;
    L_0x0069:
        monitor-exit(r1);	 Catch:{ all -> 0x0067 }
        return r0;
    L_0x006b:
        monitor-exit(r1);	 Catch:{ all -> 0x0067 }
        throw r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.zrhung.ZRHungService.canShowANRDialogs(android.zrhung.ZrHungData):boolean");
    }

    private boolean canShowOriginalANRDialogsLocked(java.lang.String packageName) {
        long currentTime = android.os.SystemClock.uptimeMillis();
        if (packageName == null) {
            return true;
        }
        com.android.server.zrhung.ZRHungService.AppEyeANRData lastANRData = (com.android.server.zrhung.ZRHungService.AppEyeANRData) this.mANRMap.get(packageName);
        if (lastANRData == null || !lastANRData.mANRType.equals("appeye")) {
            return true;
        }
        return updateShowAnrDialogFlagIfNeeded(lastANRData, currentTime, "OriginalANRDialog");
    }

    private boolean canShowAppEyeANRDialogsLocked(java.lang.String packageName) {
        long currentTime = android.os.SystemClock.uptimeMillis();
        if (packageName == null) {
            return true;
        }
        com.android.server.zrhung.ZRHungService.AppEyeANRData lastANRData = (com.android.server.zrhung.ZRHungService.AppEyeANRData) this.mANRMap.get(packageName);
        if (lastANRData != null) {
            return updateShowAnrDialogFlagIfNeeded(lastANRData, currentTime, "AppEyeANRDialog");
        }
        return true;
    }

    private boolean updateShowAnrDialogFlagIfNeeded(com.android.server.zrhung.ZRHungService.AppEyeANRData lastANRData, long curTime, java.lang.String dialogType) {
        boolean isShowDialog = true;
        java.lang.String lastANRType = lastANRData.mANRType;
        int dialogStatus = lastANRData.mANRDialogStatus;
        long lastAnrTime = lastANRData.mANRTime;
        java.lang.StringBuilder sb = new java.lang.StringBuilder(" forbid Show ");
        sb.append(dialogType);
        if (dialogStatus == 1 && curTime - lastAnrTime < 6000) {
            sb.append(", last anr dialog removed less than 6s");
            isShowDialog = false;
        }
        if (dialogStatus == 0 && curTime - lastAnrTime < 10000) {
            sb.append(", exist showing or pending dialog");
            isShowDialog = false;
        }
        if (!isShowDialog) {
            android.util.Slog.d("ZRHungService", sb.toString());
        }
        return isShowDialog;
    }

    private void resetAppEyeANRDataLocked(java.lang.String packageName, java.lang.String aNRType, int dialogStatus) {
        long currentTime = android.os.SystemClock.uptimeMillis();
        com.android.server.zrhung.ZRHungService.AppEyeANRData lastANRData = (com.android.server.zrhung.ZRHungService.AppEyeANRData) this.mANRMap.get(packageName);
        if (lastANRData != null) {
            lastANRData.mANRTime = currentTime;
            lastANRData.mANRType = aNRType;
            lastANRData.mANRDialogStatus = dialogStatus;
            return;
        }
        this.mANRMap.put(packageName, new com.android.server.zrhung.ZRHungService.AppEyeANRData(aNRType, currentTime));
    }

    private void setAppEyeANRDataLocked(android.zrhung.ZrHungData args) {
        synchronized (this.mANRMap) {
            java.lang.String packageName = args.getString("packageName");
            if (packageName != null) {
                com.android.server.zrhung.ZRHungService.AppEyeANRData lastANRData = (com.android.server.zrhung.ZRHungService.AppEyeANRData) this.mANRMap.get(packageName);
                if (lastANRData != null) {
                    lastANRData.mANRTime = android.os.SystemClock.uptimeMillis();
                    lastANRData.mANRDialogStatus = 1;
                }
            }
        }
    }

    private void killApplicationProcess(int pid) {
        if (pid > 0) {
            java.lang.StringBuilder stringBuilder;
            if (android.zrhung.appeye.AppEyeBinderBlock.isNativeProcess(pid) != 0) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(" process is native process or not exist, pid:");
                stringBuilder.append(pid);
                android.util.Slog.e("ZRHungService", stringBuilder.toString());
                return;
            }
            try {
                android.os.Process.killProcess(pid);
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("kill process pid:");
                stringBuilder.append(pid);
                android.util.Slog.e("ZRHungService", stringBuilder.toString());
            } catch (java.lang.Exception e) {
                android.util.Slog.e("ZRHungService", "kill process error");
            }
        }
    }

    private boolean handleDirectRecoverPackages(java.lang.String packageName, int pid) {
        if (packageName == null) {
            return false;
        }
        if (!this.mIsDirectRecoveryConfiged) {
            initRecoverPackageList();
        }
        if (this.mIsDirectRecoveryEnabled) {
            if (this.mDirectRecoverPackageList != null) {
                java.lang.String[] strArr = this.mDirectRecoverPackageList;
                int length = strArr.length;
                int i = 0;
                while (i < length) {
                    if (!packageName.equals(strArr[i]) || pid <= 0) {
                        i++;
                    } else {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("kill process pid:");
                        stringBuilder.append(pid);
                        stringBuilder.append(" packageName:");
                        stringBuilder.append(packageName);
                        stringBuilder.append(" reason:directRecover");
                        android.util.Slog.e("ZRHungService", stringBuilder.toString());
                        android.os.Process.killProcess(pid);
                        android.zrhung.ZrHungData data = new android.zrhung.ZrHungData();
                        data.putString("packageName", packageName);
                        data.putString("result", "Direct Kill");
                        sendAppFreezeEvent((short) 278, data, null, "direct recover");
                        return true;
                    }
                }
                return false;
            }
        }
        return false;
    }

    private void initRecoverPackageList() {
        android.util.ZRHung.HungConfig cfg = android.util.ZRHung.getHungConfig((short) 278);
        if (cfg != null) {
            if (cfg.status == 0) {
                this.mDirectRecoverPackageList = cfg.value.split(",");
                if (this.mDirectRecoverPackageList == null) {
                    android.util.Slog.e("ZRHungService", "initRecoverPackageList failed, due to null list!");
                    this.mIsDirectRecoveryConfiged = true;
                    return;
                } else if (this.mDirectRecoverPackageList.length < 2) {
                    android.util.Slog.e("ZRHungService", "initRecoverPackageList failed, due to err config!");
                    this.mIsDirectRecoveryConfiged = true;
                    return;
                } else {
                    this.mIsDirectRecoveryConfiged = true;
                    this.mIsDirectRecoveryEnabled = this.mDirectRecoverPackageList[0].trim().equals("1");
                    return;
                }
            }
        }
        android.util.Slog.e("ZRHungService", "initRecoverPackageList failed!");
    }

    private boolean isTargetAnrProcessStillAlive(int pid) {
        java.lang.String procName = android.zrhung.appeye.AppEyeBinderBlock.readProcName(java.lang.Integer.toString(pid));
        if (procName != null) {
            if (!"unknown".equals(procName)) {
                return true;
            }
        }
        android.util.Slog.e("ZRHungService", "target anr process has been removed, do not show dialog!");
        return false;
    }
}
