package com.android.systemui.shared.recents.model;

class BackgroundTaskLoader implements java.lang.Runnable {
    static boolean DEBUG = false;
    static java.lang.String TAG = "BackgroundTaskLoader";
    private boolean mCancelled;
    private android.content.Context mContext;
    private final com.android.systemui.shared.recents.model.IconLoader mIconLoader;
    private final com.android.systemui.shared.recents.model.TaskResourceLoadQueue mLoadQueue;
    private final android.os.HandlerThread mLoadThread;
    private final android.os.Handler mLoadThreadHandler;
    private final android.os.Handler mMainThreadHandler = new android.os.Handler();
    private final com.android.systemui.shared.recents.model.BackgroundTaskLoader.OnIdleChangedListener mOnIdleChangedListener;
    private boolean mStarted;
    private boolean mWaitingOnLoadQueue;

    interface OnIdleChangedListener {
        void onIdleChanged(boolean z);
    }

    public BackgroundTaskLoader(com.android.systemui.shared.recents.model.TaskResourceLoadQueue loadQueue, com.android.systemui.shared.recents.model.IconLoader iconLoader, com.android.systemui.shared.recents.model.BackgroundTaskLoader.OnIdleChangedListener onIdleChangedListener) {
        this.mLoadQueue = loadQueue;
        this.mIconLoader = iconLoader;
        this.mOnIdleChangedListener = onIdleChangedListener;
        this.mLoadThread = new android.os.HandlerThread("Recents-TaskResourceLoader", 10);
        this.mLoadThread.start();
        this.mLoadThreadHandler = new android.os.Handler(this.mLoadThread.getLooper());
    }

    void start(android.content.Context context) {
        this.mContext = context;
        this.mCancelled = false;
        if (this.mStarted) {
            synchronized (this.mLoadThread) {
                this.mLoadThread.notifyAll();
            }
            return;
        }
        this.mStarted = true;
        this.mLoadThreadHandler.post(this);
    }

    void stop() {
        this.mCancelled = true;
        if (this.mWaitingOnLoadQueue) {
            this.mContext = null;
        }
    }

    public void run() {
        while (true) {
            if (this.mCancelled) {
                this.mContext = null;
                synchronized (this.mLoadThread) {
                    try {
                        this.mLoadThread.wait();
                    } catch (java.lang.InterruptedException e) {
                        android.util.Log.e("TaskResourceLoadQueue", "InterruptedException", e);
                    }
                }
            } else {
                processLoadQueueItem();
                if (!this.mCancelled && this.mLoadQueue.isEmpty()) {
                    synchronized (this.mLoadQueue) {
                        try {
                            this.mWaitingOnLoadQueue = true;
                            this.mMainThreadHandler.post(new com.android.systemui.shared.recents.model.-$$Lambda$BackgroundTaskLoader$gaMb8n3irXHj3SpODGi50cngupE(this));
                            this.mLoadQueue.wait();
                            this.mMainThreadHandler.post(new com.android.systemui.shared.recents.model.-$$Lambda$BackgroundTaskLoader$XRsMGIp0x8MAJ36UKSTd3DJ9dTg(this));
                            this.mWaitingOnLoadQueue = false;
                        } catch (java.lang.InterruptedException e2) {
                            java.lang.String str = TAG;
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("run,InterruptedException: ");
                            stringBuilder.append(e2.getMessage());
                            android.util.Log.e(str, stringBuilder.toString());
                        }
                    }
                }
            }
        }
    }

    private void processLoadQueueItem() {
        com.android.systemui.shared.recents.model.Task t = this.mLoadQueue.nextTask();
        if (t != null) {
            android.graphics.drawable.Drawable icon = this.mIconLoader.getIcon(t);
            if (DEBUG) {
                java.lang.String str = TAG;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Loading thumbnail: ");
                stringBuilder.append(t.key);
                android.util.Log.d(str, stringBuilder.toString());
            }
            com.android.systemui.shared.recents.model.ThumbnailData thumbnailData = com.android.systemui.shared.system.ActivityManagerWrapper.getInstance().getTaskThumbnail(t.key.id, true);
            if (!this.mCancelled) {
                this.mMainThreadHandler.post(new com.android.systemui.shared.recents.model.-$$Lambda$BackgroundTaskLoader$mJeiv3P4w5EJwXqKPoDi48s7tFI(t, thumbnailData, icon));
            }
        }
    }
}
