package com.android.systemui.shared.recents.model;

class FilteredTaskList {
    private com.android.systemui.shared.recents.model.TaskFilter mFilter;
    private final android.util.ArrayMap<com.android.systemui.shared.recents.model.Task.TaskKey, java.lang.Integer> mFilteredTaskIndices = new android.util.ArrayMap();
    private final java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mFilteredTasks = new java.util.ArrayList();
    private final java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mTasks = new java.util.ArrayList();

    FilteredTaskList() {
    }

    boolean setFilter(com.android.systemui.shared.recents.model.TaskFilter filter) {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> prevFilteredTasks = new java.util.ArrayList(this.mFilteredTasks);
        this.mFilter = filter;
        updateFilteredTasks();
        synchronized (this.mFilteredTasks) {
            if (prevFilteredTasks.equals(this.mFilteredTasks)) {
                return false;
            }
            return true;
        }
    }

    void add(com.android.systemui.shared.recents.model.Task t) {
        this.mTasks.add(t);
        updateFilteredTasks();
    }

    void set(java.util.List<com.android.systemui.shared.recents.model.Task> tasks) {
        this.mTasks.clear();
        this.mTasks.addAll(tasks);
        updateFilteredTasks();
    }

    boolean remove(com.android.systemui.shared.recents.model.Task t) {
        synchronized (this.mFilteredTasks) {
            if (this.mFilteredTasks.contains(t)) {
                boolean removed = this.mTasks.remove(t);
                updateFilteredTasks();
                return removed;
            }
            return false;
        }
    }

    int indexOf(com.android.systemui.shared.recents.model.Task t) {
        if (t == null || !this.mFilteredTaskIndices.containsKey(t.key)) {
            return -1;
        }
        return ((java.lang.Integer) this.mFilteredTaskIndices.get(t.key)).intValue();
    }

    int size() {
        int size;
        synchronized (this.mFilteredTasks) {
            size = this.mFilteredTasks.size();
        }
        return size;
    }

    boolean contains(com.android.systemui.shared.recents.model.Task t) {
        return this.mFilteredTaskIndices.containsKey(t.key);
    }

    private void updateFilteredTasks() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mFilteredTasksTemp = new java.util.ArrayList();
        if (this.mFilter != null) {
            android.util.SparseArray<com.android.systemui.shared.recents.model.Task> taskIdMap = new android.util.SparseArray();
            int taskCount = this.mTasks.size();
            int i = 0;
            for (int i2 = 0; i2 < taskCount; i2++) {
                com.android.systemui.shared.recents.model.Task t = (com.android.systemui.shared.recents.model.Task) this.mTasks.get(i2);
                taskIdMap.put(t.key.id, t);
            }
            while (i < taskCount) {
                com.android.systemui.shared.recents.model.Task t2 = (com.android.systemui.shared.recents.model.Task) this.mTasks.get(i);
                if (this.mFilter.acceptTask(taskIdMap, t2, i)) {
                    mFilteredTasksTemp.add(t2);
                }
                i++;
            }
        } else {
            mFilteredTasksTemp.addAll(this.mTasks);
        }
        synchronized (this.mFilteredTasks) {
            this.mFilteredTasks.clear();
            this.mFilteredTasks.addAll(mFilteredTasksTemp);
        }
        updateFilteredTaskIndices();
    }

    private void updateFilteredTaskIndices() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mFilteredTasksTemp = new java.util.ArrayList();
        synchronized (this.mFilteredTasks) {
            mFilteredTasksTemp.addAll(this.mFilteredTasks);
        }
        int taskCount = mFilteredTasksTemp.size();
        this.mFilteredTaskIndices.clear();
        for (int i = 0; i < taskCount; i++) {
            this.mFilteredTaskIndices.put(((com.android.systemui.shared.recents.model.Task) mFilteredTasksTemp.get(i)).key, java.lang.Integer.valueOf(i));
        }
    }

    java.util.ArrayList<com.android.systemui.shared.recents.model.Task> getTasks() {
        java.util.ArrayList arrayList;
        synchronized (this.mFilteredTasks) {
            arrayList = this.mFilteredTasks;
        }
        return arrayList;
    }
}
