package com.android.systemui.shared.recents.model;

public class HighResThumbnailLoader implements com.android.systemui.shared.recents.model.Task.TaskCallbacks {
    private final com.android.systemui.shared.system.ActivityManagerWrapper mActivityManager;
    private boolean mFlingingFast;
    private final boolean mIsLowRamDevice;
    @com.android.internal.annotations.GuardedBy("mLoadQueue")
    private final java.util.ArrayDeque<com.android.systemui.shared.recents.model.Task> mLoadQueue = new java.util.ArrayDeque();
    private final java.lang.Thread mLoadThread;
    private final java.lang.Runnable mLoader = new java.lang.Runnable() {
        public void run() {
            android.os.Process.setThreadPriority(11);
            while (true) {
                com.android.systemui.shared.recents.model.Task next = null;
                synchronized (com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadQueue) {
                    if (com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoading) {
                        if (!com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadQueue.isEmpty()) {
                            next = (com.android.systemui.shared.recents.model.Task) com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadQueue.poll();
                            if (next != null) {
                                com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadingTasks.add(next);
                            }
                        }
                    }
                    try {
                        com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoaderIdling = true;
                        com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadQueue.wait();
                        com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoaderIdling = false;
                    } catch (java.lang.InterruptedException e) {
                    }
                }
                if (next != null) {
                    loadTask(next);
                }
            }
            while (true) {
            }
        }

        private void loadTask(com.android.systemui.shared.recents.model.Task t) {
            com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mMainThreadHandler.post(new com.android.systemui.shared.recents.model.-$$Lambda$HighResThumbnailLoader$1$s-1KK0EnA0WJuK_oehEz11H5MbU(this, t, com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mActivityManager.getTaskThumbnail(t.key.id, false)));
        }

        public static /* synthetic */ void lambda$loadTask$0(com.android.systemui.shared.recents.model.HighResThumbnailLoader.AnonymousClass1 anonymousClass1, com.android.systemui.shared.recents.model.Task t, com.android.systemui.shared.recents.model.ThumbnailData thumbnail) {
            synchronized (com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadQueue) {
                com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mLoadingTasks.remove(t);
            }
            if (com.android.systemui.shared.recents.model.HighResThumbnailLoader.this.mVisibleTasks.contains(t)) {
                t.notifyTaskDataLoaded(thumbnail, t.icon);
            }
        }
    };
    @com.android.internal.annotations.GuardedBy("mLoadQueue")
    private boolean mLoaderIdling;
    private boolean mLoading;
    @com.android.internal.annotations.GuardedBy("mLoadQueue")
    private final android.util.ArraySet<com.android.systemui.shared.recents.model.Task> mLoadingTasks = new android.util.ArraySet();
    private final android.os.Handler mMainThreadHandler;
    private boolean mTaskLoadQueueIdle;
    private boolean mVisible;
    private final java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mVisibleTasks = new java.util.ArrayList();

    public HighResThumbnailLoader(com.android.systemui.shared.system.ActivityManagerWrapper activityManager, android.os.Looper looper, boolean isLowRamDevice) {
        this.mActivityManager = activityManager;
        this.mMainThreadHandler = new android.os.Handler(looper);
        this.mLoadThread = new java.lang.Thread(this.mLoader, "Recents-HighResThumbnailLoader");
        this.mLoadThread.start();
        this.mIsLowRamDevice = isLowRamDevice;
    }

    public void setVisible(boolean visible) {
        if (!this.mIsLowRamDevice) {
            this.mVisible = visible;
            updateLoading();
        }
    }

    public void setFlingingFast(boolean flingingFast) {
        if (this.mFlingingFast != flingingFast) {
            if (!this.mIsLowRamDevice) {
                this.mFlingingFast = flingingFast;
                updateLoading();
            }
        }
    }

    public void setTaskLoadQueueIdle(boolean idle) {
        if (!this.mIsLowRamDevice) {
            this.mTaskLoadQueueIdle = idle;
            updateLoading();
        }
    }

    @com.android.internal.annotations.VisibleForTesting
    boolean isLoading() {
        return this.mLoading;
    }

    private void updateLoading() {
        boolean z = this.mVisible && !this.mFlingingFast && this.mTaskLoadQueueIdle;
        setLoading(z);
    }

    private void setLoading(boolean loading) {
        if (loading != this.mLoading) {
            synchronized (this.mLoadQueue) {
                this.mLoading = loading;
                if (loading) {
                    startLoading();
                } else {
                    stopLoading();
                }
            }
        }
    }

    @com.android.internal.annotations.GuardedBy("mLoadQueue")
    private void startLoading() {
        for (int i = this.mVisibleTasks.size() - 1; i >= 0; i--) {
            com.android.systemui.shared.recents.model.Task t = (com.android.systemui.shared.recents.model.Task) this.mVisibleTasks.get(i);
            if (!((t.thumbnail != null && !t.thumbnail.reducedResolution) || this.mLoadQueue.contains(t) || this.mLoadingTasks.contains(t))) {
                this.mLoadQueue.add(t);
            }
        }
        this.mLoadQueue.notifyAll();
    }

    @com.android.internal.annotations.GuardedBy("mLoadQueue")
    private void stopLoading() {
        this.mLoadQueue.clear();
        this.mLoadQueue.notifyAll();
    }

    public void onTaskVisible(com.android.systemui.shared.recents.model.Task t) {
        t.addCallback(this);
        this.mVisibleTasks.add(t);
        if ((t.thumbnail == null || t.thumbnail.reducedResolution) && this.mLoading) {
            synchronized (this.mLoadQueue) {
                this.mLoadQueue.add(t);
                this.mLoadQueue.notifyAll();
            }
        }
    }

    public void onTaskInvisible(com.android.systemui.shared.recents.model.Task t) {
        t.removeCallback(this);
        this.mVisibleTasks.remove(t);
        synchronized (this.mLoadQueue) {
            this.mLoadQueue.remove(t);
        }
    }

    @com.android.internal.annotations.VisibleForTesting
    void waitForLoaderIdle() {
        while (true) {
            synchronized (this.mLoadQueue) {
                if (this.mLoadQueue.isEmpty() && this.mLoaderIdling) {
                    return;
                }
            }
            android.os.SystemClock.sleep(100);
        }
        while (true) {
        }
    }

    public void onTaskDataLoaded(com.android.systemui.shared.recents.model.Task task, com.android.systemui.shared.recents.model.ThumbnailData thumbnailData) {
        if (thumbnailData != null && !thumbnailData.reducedResolution) {
            synchronized (this.mLoadQueue) {
                this.mLoadQueue.remove(task);
            }
        }
    }

    public void onTaskDataUnloaded() {
    }

    public void onTaskWindowingModeChanged() {
    }
}
