package com.android.systemui.shared.recents.model;

public abstract class IconLoader {
    public static final int BADGED_TYPE_CLONE = 1;
    public static final int BADGED_TYPE_NONE = 0;
    public static final int BADGED_TYPE_TRUSTSPACE = 2;
    private static final java.lang.String TAG = "IconLoader";
    protected final android.util.LruCache<android.content.ComponentName, android.content.pm.ActivityInfo> mActivityInfoCache;
    protected final android.content.Context mContext;
    protected final android.util.IconDrawableFactory mDrawableFactory;
    protected final com.android.systemui.shared.recents.model.TaskKeyLruCache<android.graphics.drawable.Drawable> mIconCache;

    public static class DefaultIconLoader extends com.android.systemui.shared.recents.model.IconLoader {
        private final android.graphics.drawable.BitmapDrawable mDefaultIcon;

        public DefaultIconLoader(android.content.Context context, com.android.systemui.shared.recents.model.TaskKeyLruCache<android.graphics.drawable.Drawable> iconCache, android.util.LruCache<android.content.ComponentName, android.content.pm.ActivityInfo> activityInfoCache) {
            super(context, iconCache, activityInfoCache);
            android.graphics.Bitmap icon = android.graphics.Bitmap.createBitmap(1, 1, android.graphics.Bitmap.Config.ALPHA_8);
            icon.eraseColor(0);
            this.mDefaultIcon = new android.graphics.drawable.BitmapDrawable(context.getResources(), icon);
        }

        public android.graphics.drawable.Drawable getDefaultIcon(int userId) {
            return this.mDefaultIcon;
        }

        protected android.graphics.drawable.Drawable createBadgedDrawable(android.graphics.drawable.Drawable icon, int userId, android.app.ActivityManager.TaskDescription desc) {
            return createBadgedDrawable(icon, userId, 0);
        }

        protected android.graphics.drawable.Drawable getBadgedActivityIcon(android.content.pm.ActivityInfo info, int userId, android.app.ActivityManager.TaskDescription desc) {
            return getBadgedActivityIcon(info, userId, 0);
        }

        protected android.graphics.drawable.Drawable getBadgedActivityIcon(android.content.pm.ActivityInfo info, int userId, int badgedIconType) {
            return getBadgedIcon(this.mDrawableFactory.getBadgedIcon(info, info.applicationInfo, userId), userId, badgedIconType);
        }
    }

    protected abstract android.graphics.drawable.Drawable createBadgedDrawable(android.graphics.drawable.Drawable drawable, int i, android.app.ActivityManager.TaskDescription taskDescription);

    protected abstract android.graphics.drawable.Drawable getBadgedActivityIcon(android.content.pm.ActivityInfo activityInfo, int i, android.app.ActivityManager.TaskDescription taskDescription);

    public abstract android.graphics.drawable.Drawable getDefaultIcon(int i);

    public IconLoader(android.content.Context context, com.android.systemui.shared.recents.model.TaskKeyLruCache<android.graphics.drawable.Drawable> iconCache, android.util.LruCache<android.content.ComponentName, android.content.pm.ActivityInfo> activityInfoCache) {
        this.mContext = context;
        this.mIconCache = iconCache;
        this.mActivityInfoCache = activityInfoCache;
        this.mDrawableFactory = android.util.IconDrawableFactory.newInstance(context);
    }

    public android.content.pm.ActivityInfo getAndUpdateActivityInfo(com.android.systemui.shared.recents.model.Task.TaskKey taskKey) {
        android.content.ComponentName cn = taskKey.getComponent();
        android.content.pm.ActivityInfo activityInfo = (android.content.pm.ActivityInfo) this.mActivityInfoCache.get(cn);
        if (activityInfo == null) {
            activityInfo = com.android.systemui.shared.system.PackageManagerWrapper.getInstance().getActivityInfo(cn, taskKey.userId);
            if (cn != null) {
                if (activityInfo != null) {
                    this.mActivityInfoCache.put(cn, activityInfo);
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Unexpected null component name or activity info: ");
            stringBuilder.append(cn);
            stringBuilder.append(", ");
            stringBuilder.append(activityInfo);
            android.util.Log.e("IconLoader", stringBuilder.toString());
            return null;
        }
        return activityInfo;
    }

    public android.graphics.drawable.Drawable getIcon(com.android.systemui.shared.recents.model.Task t) {
        android.graphics.drawable.Drawable cachedIcon = (android.graphics.drawable.Drawable) this.mIconCache.get(t.key);
        if (cachedIcon != null) {
            return cachedIcon;
        }
        cachedIcon = createNewIconForTask(t.key, t.taskDescription, true);
        this.mIconCache.put(t.key, cachedIcon);
        return cachedIcon;
    }

    public android.graphics.drawable.Drawable getAndInvalidateIfModified(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityManager.TaskDescription td, boolean loadIfNotCached) {
        android.graphics.drawable.Drawable icon = (android.graphics.drawable.Drawable) this.mIconCache.getAndInvalidateIfModified(taskKey);
        if (icon != null) {
            return icon;
        }
        if (loadIfNotCached) {
            icon = createNewIconForTask(taskKey, td, false);
            if (icon != null) {
                this.mIconCache.put(taskKey, icon);
                return icon;
            }
        }
        return null;
    }

    private android.graphics.drawable.Drawable createNewIconForTask(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityManager.TaskDescription desc, boolean returnDefault) {
        int userId = taskKey.userId;
        int badgedIconType = getBadgedIconType(taskKey.baseIntent.getHwFlags(), taskKey.getComponent().getPackageName());
        android.graphics.Bitmap tdIcon = desc.getInMemoryIcon();
        if (tdIcon != null) {
            return createDrawableFromBitmap(tdIcon, userId, badgedIconType);
        }
        if (desc.getIconResource() != 0) {
            try {
                return createBadgedDrawable(this.mContext.getDrawable(desc.getIconResource()), userId, badgedIconType);
            } catch (android.content.res.Resources.NotFoundException e) {
                android.util.Log.e("IconLoader", "Could not find icon drawable from resource", e);
            }
        }
        tdIcon = android.app.ActivityManager.TaskDescription.loadTaskDescriptionIcon(desc.getIconFilename(), userId);
        if (tdIcon != null) {
            return createDrawableFromBitmap(tdIcon, userId, badgedIconType);
        }
        android.content.pm.ActivityInfo activityInfo = getAndUpdateActivityInfo(taskKey);
        if (activityInfo != null) {
            android.graphics.drawable.Drawable icon = getBadgedActivityIcon(activityInfo, userId, badgedIconType);
            if (icon != null) {
                return icon;
            }
        }
        return returnDefault ? getDefaultIcon(userId) : null;
    }

    protected android.graphics.drawable.Drawable createDrawableFromBitmap(android.graphics.Bitmap icon, int userId, android.app.ActivityManager.TaskDescription desc) {
        return createBadgedDrawable(new android.graphics.drawable.BitmapDrawable(this.mContext.getResources(), icon), userId, desc);
    }

    protected android.graphics.drawable.Drawable createBadgedDrawable(android.graphics.drawable.Drawable icon, int userId, int badgedIconType) {
        if (userId != android.os.UserHandle.myUserId()) {
            return this.mContext.getPackageManager().getUserBadgedIcon(icon, new android.os.UserHandle(userId));
        }
        return icon;
    }

    protected android.graphics.drawable.Drawable createDrawableFromBitmap(android.graphics.Bitmap icon, int userId, int badgedIconType) {
        return createBadgedDrawable(new android.graphics.drawable.BitmapDrawable(this.mContext.getResources(), icon), userId, badgedIconType);
    }

    protected android.graphics.drawable.Drawable getBadgedActivityIcon(android.content.pm.ActivityInfo info, int userId, int badgedIconType) {
        return getBadgedIcon(this.mDrawableFactory.getBadgedIcon(info, info.applicationInfo, userId), userId, badgedIconType);
    }

    protected android.graphics.drawable.Drawable getBadgedIcon(android.graphics.drawable.Drawable icon, int userId, int badgedIconType) {
        if (userId != android.os.UserHandle.myUserId()) {
            return this.mContext.getPackageManager().getUserBadgedIcon(icon, new android.os.UserHandle(userId));
        }
        if (badgedIconType == 1) {
            return this.mContext.getPackageManager().getUserBadgedIcon(icon, new android.os.UserHandle(2147383647));
        }
        if (badgedIconType == 2) {
            return getTrustSpaceBadgedDrawable(this.mContext.getResources(), icon);
        }
        return icon;
    }

    public static android.graphics.drawable.Drawable getTrustSpaceBadgedDrawable(android.content.res.Resources res, android.graphics.drawable.Drawable drawable) {
        int badgedWidth = drawable.getIntrinsicWidth();
        int badgedHeight = drawable.getIntrinsicHeight();
        try {
            android.graphics.drawable.Drawable badgeDrawable = res.getDrawable(com.android.systemui.shared.R.drawable.ic_trustspace_badge, null);
            android.graphics.Bitmap bitmap = android.graphics.Bitmap.createBitmap(badgedWidth, badgedHeight, android.graphics.Bitmap.Config.ARGB_8888);
            android.graphics.Canvas canvas = new android.graphics.Canvas(bitmap);
            drawable.setBounds(0, 0, badgedWidth, badgedHeight);
            drawable.draw(canvas);
            badgeDrawable.setBounds(0, 0, badgedWidth, badgedHeight);
            badgeDrawable.draw(canvas);
            return new android.graphics.drawable.BitmapDrawable(bitmap);
        } catch (android.content.res.Resources.NotFoundException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Could not find badgeDrawable from resource");
            stringBuilder.append(e.getMessage());
            android.util.Log.e("IconLoader", stringBuilder.toString());
            return drawable;
        }
    }

    public static int getBadgedIconType(int hwFlags, java.lang.String packageName) {
        int i = 0;
        if ((hwFlags & 1) != 0) {
            return 1;
        }
        if (android.trustspace.TrustSpaceManager.getDefault().isIntentProtectedApp(packageName)) {
            i = 2;
        }
        return i;
    }
}
