package com.android.systemui.shared.recents.model;

public class RecentsTaskLoadPlan {
    private static final boolean IS_EMUI_LITE = android.os.SystemProperties.getBoolean("ro.build.hw_emui_lite.enable", false);
    private static final boolean IS_NOVA_PERFORMANCE = android.os.SystemProperties.getBoolean("ro.config.hw_nova_performance", false);
    private static final int MAX_RECENT_TASK_EMUI = 20;
    private static final int MAX_RECENT_TASK_EMUI_LITE = 15;
    public static final java.lang.String TAG = "RecentsTaskLoadPlan";
    private final android.content.Context mContext;
    private final android.app.KeyguardManager mKeyguardManager;
    private java.util.List<android.app.ActivityManager.RecentTaskInfo> mRawTasks;
    private com.android.systemui.shared.recents.model.TaskStack mStack;
    private final android.util.SparseBooleanArray mTmpLockedUsers = new android.util.SparseBooleanArray();

    public static class Options {
        public boolean loadIcons = true;
        public boolean loadThumbnails = false;
        public int numVisibleTaskThumbnails = 0;
        public int numVisibleTasks = 0;
        public boolean onlyLoadForCache = false;
        public boolean onlyLoadPausedActivities = false;
        public int runningTaskId = -1;
    }

    public static class PreloadOptions {
        public boolean loadTitles = true;
    }

    public static int getMaxRecentTasks() {
        if (isEmuiLite()) {
            return 15;
        }
        return 20;
    }

    public RecentsTaskLoadPlan(android.content.Context context) {
        this.mContext = context;
        this.mKeyguardManager = (android.app.KeyguardManager) context.getSystemService("keyguard");
    }

    public void preloadPlan(com.android.systemui.shared.recents.model.RecentsTaskLoadPlan.PreloadOptions opts, com.android.systemui.shared.recents.model.RecentsTaskLoader loader, int runningTaskId, int currentUserId) {
        int i;
        int taskCount;
        com.android.systemui.shared.recents.model.RecentsTaskLoadPlan.PreloadOptions preloadOptions = opts;
        com.android.systemui.shared.recents.model.RecentsTaskLoader recentsTaskLoader = loader;
        java.util.Map<java.lang.String, java.lang.Boolean> map = com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.refreshToCache(this.mContext);
        com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.refreshPlayingMusicUidSet();
        android.content.res.Resources res = this.mContext.getResources();
        java.util.List allTasks = new java.util.ArrayList();
        if (this.mRawTasks == null) {
            this.mRawTasks = com.android.systemui.shared.system.ActivityManagerWrapper.getInstance().getRecentTasks(getMaxRecentTasks(), currentUserId);
            java.util.Collections.reverse(this.mRawTasks);
        } else {
            i = currentUserId;
        }
        int taskCount2 = this.mRawTasks.size();
        int i2 = 0;
        while (i2 < taskCount2) {
            android.content.res.Resources res2;
            int i3;
            android.app.ActivityManager.RecentTaskInfo t = (android.app.ActivityManager.RecentTaskInfo) this.mRawTasks.get(i2);
            int windowingMode = t.configuration.windowConfiguration.getWindowingMode();
            com.android.systemui.shared.recents.model.Task.TaskKey taskKey = new com.android.systemui.shared.recents.model.Task.TaskKey(t.persistentId, windowingMode, t.baseIntent, t.userId, t.lastActiveTime);
            boolean isFreeformTask = windowingMode == 5;
            boolean isStackTask = !isFreeformTask;
            boolean isLaunchTarget = taskKey.id == runningTaskId;
            android.content.pm.ActivityInfo info = recentsTaskLoader.getAndUpdateActivityInfo(taskKey);
            if (info == null) {
                res2 = res;
                taskCount = taskCount2;
                i3 = i2;
            } else {
                java.lang.String andUpdateActivityTitle;
                boolean z;
                android.graphics.drawable.Drawable andUpdateActivityIcon;
                if (preloadOptions.loadTitles) {
                    andUpdateActivityTitle = recentsTaskLoader.getAndUpdateActivityTitle(taskKey, t.taskDescription);
                } else {
                    andUpdateActivityTitle = "";
                }
                java.lang.String title = andUpdateActivityTitle;
                if (preloadOptions.loadTitles) {
                    andUpdateActivityTitle = recentsTaskLoader.getAndUpdateContentDescription(taskKey, t.taskDescription);
                } else {
                    andUpdateActivityTitle = "";
                }
                java.lang.String titleDescription = andUpdateActivityTitle;
                if (isStackTask) {
                    z = false;
                    andUpdateActivityIcon = recentsTaskLoader.getAndUpdateActivityIcon(taskKey, t.taskDescription, false);
                } else {
                    z = false;
                    andUpdateActivityIcon = null;
                }
                android.graphics.drawable.Drawable icon = andUpdateActivityIcon;
                com.android.systemui.shared.recents.model.ThumbnailData thumbnail = recentsTaskLoader.getAndUpdateThumbnail(taskKey, z, z);
                int activityColor = recentsTaskLoader.getActivityPrimaryColor(t.taskDescription);
                res2 = res;
                res = recentsTaskLoader.getActivityBackgroundColor(t.taskDescription);
                boolean isSystemApp = (info == null || (info.applicationInfo.flags & 1) == 0) ? false : true;
                taskCount = taskCount2;
                if (this.mTmpLockedUsers.indexOfKey(t.userId) < 0) {
                    this.mTmpLockedUsers.put(t.userId, this.mKeyguardManager.isDeviceLocked(t.userId));
                } else {
                    int i4 = windowingMode;
                }
                boolean isLocked = this.mTmpLockedUsers.get(t.userId);
                java.lang.String packageName = info != null ? info.packageName : "";
                i3 = i2;
                com.android.systemui.shared.recents.model.Task task = new com.android.systemui.shared.recents.model.Task(taskKey, icon, thumbnail, title, titleDescription, activityColor, res, isLaunchTarget, isStackTask, isSystemApp, t.supportsSplitScreenMultiWindow, t.taskDescription, t.resizeMode, t.topActivity, isLocked);
                task.setPakcageName(packageName);
                if (!shouldSkipLoadTask(map, t, task)) {
                    allTasks.add(task);
                }
            }
            i2 = i3 + 1;
            res = res2;
            taskCount2 = taskCount;
            preloadOptions = opts;
            recentsTaskLoader = loader;
            i = currentUserId;
        }
        taskCount = taskCount2;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("to show tasks size is ");
        stringBuilder.append(allTasks.size());
        android.util.Log.i("RecentsTaskLoadPlan", stringBuilder.toString());
        this.mStack = new com.android.systemui.shared.recents.model.TaskStack();
        this.mStack.setTasks(allTasks, false);
    }

    public void executePlan(com.android.systemui.shared.recents.model.RecentsTaskLoadPlan.Options opts, com.android.systemui.shared.recents.model.RecentsTaskLoader loader) {
        android.content.res.Resources res = this.mContext.getResources();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = this.mStack.getTasks();
        int taskCount = tasks.size();
        int i = 0;
        while (i < taskCount) {
            com.android.systemui.shared.recents.model.Task task = (com.android.systemui.shared.recents.model.Task) tasks.get(i);
            com.android.systemui.shared.recents.model.Task.TaskKey taskKey = task.key;
            boolean isRunningTask = task.key.id == opts.runningTaskId;
            boolean isVisibleTask = i >= taskCount - opts.numVisibleTasks;
            boolean isVisibleThumbnail = i >= taskCount - opts.numVisibleTaskThumbnails;
            if (!opts.onlyLoadPausedActivities || !isRunningTask) {
                if (opts.loadIcons && ((isRunningTask || isVisibleTask) && task.icon == null)) {
                    task.icon = loader.getAndUpdateActivityIcon(taskKey, task.taskDescription, true);
                }
                if (opts.loadThumbnails && isVisibleThumbnail) {
                    task.thumbnail = loader.getAndUpdateThumbnail(taskKey, true, true);
                }
            }
            i++;
        }
    }

    public com.android.systemui.shared.recents.model.TaskStack getTaskStack() {
        return this.mStack;
    }

    public boolean hasTasks() {
        boolean z = false;
        if (this.mStack == null) {
            return false;
        }
        if (this.mStack.getTaskCount() > 0) {
            z = true;
        }
        return z;
    }

    private boolean shouldSkipLoadTask(java.util.Map<java.lang.String, java.lang.Boolean> lockMap, android.app.ActivityManager.RecentTaskInfo recentInfo, com.android.systemui.shared.recents.model.Task task) {
        if (!com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.willRemovedTask(recentInfo)) {
            return false;
        }
        java.lang.StringBuilder stringBuilder;
        if (lockMap.get(task.packageName) == null ? false : ((java.lang.Boolean) lockMap.get(task.packageName)).booleanValue()) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(task.packageName);
            stringBuilder.append("is locked, so need load it");
            android.util.Log.d("RecentsTaskLoadPlan", stringBuilder.toString());
            return false;
        } else if (com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.getPlayingMusicUid(this.mContext, task)) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(task.packageName);
            stringBuilder2.append("is music, so need load it");
            android.util.Log.d("RecentsTaskLoadPlan", stringBuilder2.toString());
            return false;
        } else {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("in removing, will remove task: ");
            stringBuilder.append(task.packageName);
            android.util.Log.i("RecentsTaskLoadPlan", stringBuilder.toString());
            return true;
        }
    }

    public static boolean isEmuiLite() {
        if (!IS_EMUI_LITE) {
            if (!IS_NOVA_PERFORMANCE) {
                return false;
            }
        }
        return true;
    }
}
