package com.android.systemui.shared.recents.model;

public class RecentsTaskLoader {
    private static final boolean DEBUG = false;
    public static final int SVELTE_DISABLE_CACHE = 2;
    public static final int SVELTE_DISABLE_LOADING = 3;
    public static final int SVELTE_LIMIT_CACHE = 1;
    public static final int SVELTE_NONE = 0;
    private static final java.lang.String TAG = "RecentsTaskLoader";
    private final android.util.LruCache<android.content.ComponentName, android.content.pm.ActivityInfo> mActivityInfoCache;
    private final com.android.systemui.shared.recents.model.TaskKeyLruCache<java.lang.String> mActivityLabelCache;
    private com.android.systemui.shared.recents.model.TaskKeyLruCache.EvictionCallback mClearActivityInfoOnEviction = new com.android.systemui.shared.recents.model.TaskKeyLruCache.EvictionCallback() {
        public void onEntryEvicted(com.android.systemui.shared.recents.model.Task.TaskKey key) {
            if (key != null) {
                com.android.systemui.shared.recents.model.RecentsTaskLoader.this.mActivityInfoCache.remove(key.getComponent());
            }
        }
    };
    private final com.android.systemui.shared.recents.model.TaskKeyLruCache<java.lang.String> mContentDescriptionCache;
    private int mDefaultTaskBarBackgroundColor;
    private int mDefaultTaskViewBackgroundColor;
    private final com.android.systemui.shared.recents.model.HighResThumbnailLoader mHighResThumbnailLoader;
    private final com.android.systemui.shared.recents.model.TaskKeyLruCache<android.graphics.drawable.Drawable> mIconCache;
    private final com.android.systemui.shared.recents.model.IconLoader mIconLoader;
    private final com.android.systemui.shared.recents.model.TaskResourceLoadQueue mLoadQueue;
    private final com.android.systemui.shared.recents.model.BackgroundTaskLoader mLoader;
    private final int mMaxIconCacheSize;
    private final int mMaxThumbnailCacheSize;
    private int mNumVisibleTasksLoaded;
    private int mSvelteLevel;
    @com.android.internal.annotations.GuardedBy("this")
    private final com.android.systemui.shared.recents.model.TaskKeyStrongCache<com.android.systemui.shared.recents.model.ThumbnailData> mTempCache = new com.android.systemui.shared.recents.model.TaskKeyStrongCache();
    @com.android.internal.annotations.GuardedBy("this")
    private final com.android.systemui.shared.recents.model.TaskKeyStrongCache<com.android.systemui.shared.recents.model.ThumbnailData> mThumbnailCache = new com.android.systemui.shared.recents.model.TaskKeyStrongCache();

    public RecentsTaskLoader(android.content.Context context, int maxThumbnailCacheSize, int maxIconCacheSize, int svelteLevel) {
        this.mMaxThumbnailCacheSize = maxThumbnailCacheSize;
        this.mMaxIconCacheSize = maxIconCacheSize;
        this.mSvelteLevel = svelteLevel;
        int numRecentTasks = android.app.ActivityManager.getMaxRecentTasksStatic();
        this.mHighResThumbnailLoader = new com.android.systemui.shared.recents.model.HighResThumbnailLoader(com.android.systemui.shared.system.ActivityManagerWrapper.getInstance(), android.os.Looper.getMainLooper(), android.app.ActivityManager.isLowRamDeviceStatic());
        this.mLoadQueue = new com.android.systemui.shared.recents.model.TaskResourceLoadQueue();
        this.mIconCache = new com.android.systemui.shared.recents.model.TaskKeyLruCache(this.mMaxIconCacheSize, this.mClearActivityInfoOnEviction);
        this.mActivityLabelCache = new com.android.systemui.shared.recents.model.TaskKeyLruCache(numRecentTasks, this.mClearActivityInfoOnEviction);
        this.mContentDescriptionCache = new com.android.systemui.shared.recents.model.TaskKeyLruCache(numRecentTasks, this.mClearActivityInfoOnEviction);
        this.mActivityInfoCache = new android.util.LruCache(numRecentTasks);
        this.mIconLoader = createNewIconLoader(context, this.mIconCache, this.mActivityInfoCache);
        com.android.systemui.shared.recents.model.TaskResourceLoadQueue taskResourceLoadQueue = this.mLoadQueue;
        com.android.systemui.shared.recents.model.IconLoader iconLoader = this.mIconLoader;
        com.android.systemui.shared.recents.model.HighResThumbnailLoader highResThumbnailLoader = this.mHighResThumbnailLoader;
        java.util.Objects.requireNonNull(highResThumbnailLoader);
        this.mLoader = new com.android.systemui.shared.recents.model.BackgroundTaskLoader(taskResourceLoadQueue, iconLoader, new com.android.systemui.shared.recents.model.-$$Lambda$vKccogRiJjM5FBa4zs196J3w_Fs(highResThumbnailLoader));
    }

    protected com.android.systemui.shared.recents.model.IconLoader createNewIconLoader(android.content.Context context, com.android.systemui.shared.recents.model.TaskKeyLruCache<android.graphics.drawable.Drawable> iconCache, android.util.LruCache<android.content.ComponentName, android.content.pm.ActivityInfo> activityInfoCache) {
        return new com.android.systemui.shared.recents.model.IconLoader.DefaultIconLoader(context, iconCache, activityInfoCache);
    }

    public void setDefaultColors(int defaultTaskBarBackgroundColor, int defaultTaskViewBackgroundColor) {
        this.mDefaultTaskBarBackgroundColor = defaultTaskBarBackgroundColor;
        this.mDefaultTaskViewBackgroundColor = defaultTaskViewBackgroundColor;
    }

    public int getIconCacheSize() {
        return this.mMaxIconCacheSize;
    }

    public int getThumbnailCacheSize() {
        return this.mMaxThumbnailCacheSize;
    }

    public com.android.systemui.shared.recents.model.HighResThumbnailLoader getHighResThumbnailLoader() {
        return this.mHighResThumbnailLoader;
    }

    public synchronized void preloadTasks(com.android.systemui.shared.recents.model.RecentsTaskLoadPlan plan, int runningTaskId) {
        preloadTasks(plan, runningTaskId, com.android.systemui.shared.system.ActivityManagerWrapper.getInstance().getCurrentUserId());
    }

    public synchronized void preloadTasks(com.android.systemui.shared.recents.model.RecentsTaskLoadPlan plan, int runningTaskId, int currentUserId) {
        try {
            android.os.Trace.beginSection("preloadPlan");
            plan.preloadPlan(new com.android.systemui.shared.recents.model.RecentsTaskLoadPlan.PreloadOptions(), this, runningTaskId, currentUserId);
            android.os.Trace.endSection();
        } catch (Throwable th) {
            android.os.Trace.endSection();
        }
    }

    public synchronized void loadTasks(com.android.systemui.shared.recents.model.RecentsTaskLoadPlan plan, com.android.systemui.shared.recents.model.RecentsTaskLoadPlan.Options opts) {
        if (opts != null) {
            if (opts.onlyLoadForCache && opts.loadThumbnails) {
                this.mTempCache.copyEntries(this.mThumbnailCache);
                this.mThumbnailCache.evictAll();
            }
            plan.executePlan(opts, this);
            this.mTempCache.evictAll();
            if (!opts.onlyLoadForCache) {
                this.mNumVisibleTasksLoaded = opts.numVisibleTasks;
            }
        } else {
            throw new java.lang.RuntimeException("Requires load options");
        }
    }

    public void loadTaskData(com.android.systemui.shared.recents.model.Task t) {
        android.graphics.drawable.Drawable icon = (android.graphics.drawable.Drawable) this.mIconCache.getAndInvalidateIfModified(t.key);
        icon = icon != null ? icon : this.mIconLoader.getDefaultIcon(t.key.userId);
        this.mLoadQueue.addTask(t);
        t.notifyTaskDataLoaded(t.thumbnail, icon);
    }

    public void unloadTaskData(com.android.systemui.shared.recents.model.Task t) {
        this.mLoadQueue.removeTask(t);
        t.notifyTaskDataUnloaded(this.mIconLoader.getDefaultIcon(t.key.userId));
    }

    public void deleteTaskData(com.android.systemui.shared.recents.model.Task t, boolean notifyTaskDataUnloaded) {
        this.mLoadQueue.removeTask(t);
        this.mIconCache.remove(t.key);
        this.mActivityLabelCache.remove(t.key);
        this.mContentDescriptionCache.remove(t.key);
        this.mThumbnailCache.remove(t.key);
        this.mTempCache.remove(t.key);
        t.recycle();
        if (notifyTaskDataUnloaded) {
            t.notifyTaskDataUnloaded(this.mIconLoader.getDefaultIcon(t.key.userId));
        }
    }

    public synchronized void onTrimMemory(int level) {
        if (level != 5) {
            if (level != 10) {
                if (level != 15) {
                    if (level == 20) {
                        stopLoader();
                        this.mIconCache.trimToSize(java.lang.Math.max(this.mNumVisibleTasksLoaded, this.mMaxIconCacheSize / 2));
                    } else if (level != 40) {
                        if (level != 60) {
                            if (level != 80) {
                            }
                        }
                    }
                }
                this.mIconCache.evictAll();
                this.mActivityInfoCache.evictAll();
                this.mActivityLabelCache.evictAll();
                this.mContentDescriptionCache.evictAll();
                this.mThumbnailCache.evictAll();
            }
            this.mIconCache.trimToSize(java.lang.Math.max(1, this.mMaxIconCacheSize / 4));
            this.mActivityInfoCache.trimToSize(java.lang.Math.max(1, android.app.ActivityManager.getMaxRecentTasksStatic() / 4));
        }
        this.mIconCache.trimToSize(java.lang.Math.max(1, this.mMaxIconCacheSize / 2));
        this.mActivityInfoCache.trimToSize(java.lang.Math.max(1, android.app.ActivityManager.getMaxRecentTasksStatic() / 2));
    }

    public void onPackageChanged(java.lang.String packageName) {
        for (android.content.ComponentName cn : this.mActivityInfoCache.snapshot().keySet()) {
            if (cn.getPackageName().equals(packageName)) {
                this.mActivityInfoCache.remove(cn);
            }
        }
    }

    java.lang.String getAndUpdateActivityTitle(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityManager.TaskDescription td) {
        if (td != null && td.getLabel() != null) {
            return td.getLabel();
        }
        java.lang.String label = (java.lang.String) this.mActivityLabelCache.getAndInvalidateIfModified(taskKey);
        if (label != null) {
            return label;
        }
        android.content.pm.ActivityInfo activityInfo = getAndUpdateActivityInfo(taskKey);
        if (activityInfo == null) {
            return "";
        }
        label = com.android.systemui.shared.system.ActivityManagerWrapper.getInstance().getBadgedActivityLabel(activityInfo, taskKey.userId);
        this.mActivityLabelCache.put(taskKey, label);
        return label;
    }

    java.lang.String getAndUpdateContentDescription(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityManager.TaskDescription td) {
        java.lang.String label = (java.lang.String) this.mContentDescriptionCache.getAndInvalidateIfModified(taskKey);
        if (label != null) {
            return label;
        }
        android.content.pm.ActivityInfo activityInfo = getAndUpdateActivityInfo(taskKey);
        if (activityInfo == null) {
            return "";
        }
        label = com.android.systemui.shared.system.ActivityManagerWrapper.getInstance().getBadgedContentDescription(activityInfo, taskKey.userId, td);
        if (td == null) {
            this.mContentDescriptionCache.put(taskKey, label);
        }
        return label;
    }

    android.graphics.drawable.Drawable getAndUpdateActivityIcon(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityManager.TaskDescription td, boolean loadIfNotCached) {
        return this.mIconLoader.getAndInvalidateIfModified(taskKey, td, loadIfNotCached);
    }

    /* JADX WARNING: Missing block: B:21:0x003d, code:
            return r1;
     */
    synchronized com.android.systemui.shared.recents.model.ThumbnailData getAndUpdateThumbnail(com.android.systemui.shared.recents.model.Task.TaskKey r5, boolean r6, boolean r7) {
        /*
        r4 = this;
        monitor-enter(r4);
        r0 = r4.mThumbnailCache;	 Catch:{ all -> 0x0041 }
        r0 = r0.getAndInvalidateIfModified(r5);	 Catch:{ all -> 0x0041 }
        r0 = (com.android.systemui.shared.recents.model.ThumbnailData) r0;	 Catch:{ all -> 0x0041 }
        if (r0 == 0) goto L_0x000d;
    L_0x000b:
        monitor-exit(r4);
        return r0;
    L_0x000d:
        r1 = r4.mTempCache;	 Catch:{ all -> 0x0041 }
        r1 = r1.getAndInvalidateIfModified(r5);	 Catch:{ all -> 0x0041 }
        r1 = (com.android.systemui.shared.recents.model.ThumbnailData) r1;	 Catch:{ all -> 0x0041 }
        r0 = r1;
        if (r0 == 0) goto L_0x001f;
    L_0x0018:
        r1 = r4.mThumbnailCache;	 Catch:{ all -> 0x0041 }
        r1.put(r5, r0);	 Catch:{ all -> 0x0041 }
        monitor-exit(r4);
        return r0;
    L_0x001f:
        if (r6 == 0) goto L_0x003e;
    L_0x0021:
        r1 = r4.mSvelteLevel;	 Catch:{ all -> 0x0041 }
        r2 = 3;
        if (r1 >= r2) goto L_0x003e;
    L_0x0026:
        r1 = com.android.systemui.shared.system.ActivityManagerWrapper.getInstance();	 Catch:{ all -> 0x0041 }
        r2 = r5.id;	 Catch:{ all -> 0x0041 }
        r3 = 1;
        r1 = r1.getTaskThumbnail(r2, r3);	 Catch:{ all -> 0x0041 }
        r2 = r1.thumbnail;	 Catch:{ all -> 0x0041 }
        if (r2 == 0) goto L_0x003e;
    L_0x0035:
        if (r7 == 0) goto L_0x003c;
    L_0x0037:
        r2 = r4.mThumbnailCache;	 Catch:{ all -> 0x0041 }
        r2.put(r5, r1);	 Catch:{ all -> 0x0041 }
    L_0x003c:
        monitor-exit(r4);
        return r1;
    L_0x003e:
        r1 = 0;
        monitor-exit(r4);
        return r1;
    L_0x0041:
        r5 = move-exception;
        monitor-exit(r4);
        throw r5;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.systemui.shared.recents.model.RecentsTaskLoader.getAndUpdateThumbnail(com.android.systemui.shared.recents.model.Task$TaskKey, boolean, boolean):com.android.systemui.shared.recents.model.ThumbnailData");
    }

    int getActivityPrimaryColor(android.app.ActivityManager.TaskDescription td) {
        if (td == null || td.getPrimaryColor() == 0) {
            return this.mDefaultTaskBarBackgroundColor;
        }
        return td.getPrimaryColor();
    }

    int getActivityBackgroundColor(android.app.ActivityManager.TaskDescription td) {
        if (td == null || td.getBackgroundColor() == 0) {
            return this.mDefaultTaskViewBackgroundColor;
        }
        return td.getBackgroundColor();
    }

    android.content.pm.ActivityInfo getAndUpdateActivityInfo(com.android.systemui.shared.recents.model.Task.TaskKey taskKey) {
        return this.mIconLoader.getAndUpdateActivityInfo(taskKey);
    }

    public void startLoader(android.content.Context ctx) {
        this.mLoader.start(ctx);
    }

    private void stopLoader() {
        this.mLoader.stop();
        this.mLoadQueue.clearTasks();
    }

    public synchronized void dump(java.lang.String prefix, java.io.PrintWriter writer) {
        java.lang.String innerPrefix = new java.lang.StringBuilder();
        innerPrefix.append(prefix);
        innerPrefix.append("  ");
        innerPrefix = innerPrefix.toString();
        writer.print(prefix);
        writer.println("RecentsTaskLoader");
        writer.print(prefix);
        writer.println("Icon Cache");
        this.mIconCache.dump(innerPrefix, writer);
        writer.print(prefix);
        writer.println("Thumbnail Cache");
        this.mThumbnailCache.dump(innerPrefix, writer);
        writer.print(prefix);
        writer.println("Temp Thumbnail Cache");
        this.mTempCache.dump(innerPrefix, writer);
    }
}
