package com.android.systemui.shared.recents.model;

public class Task {
    public static final java.lang.String TAG = "Task";
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public int colorBackground;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public int colorPrimary;
    public android.graphics.drawable.Drawable icon;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isDockable;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isHwTaskLocked;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isLaunchTarget;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isLocked;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isStackTask;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean isSystemApp;
    @android.view.ViewDebug.ExportedProperty(deepExport = true, prefix = "key_")
    public com.android.systemui.shared.recents.model.Task.TaskKey key;
    private java.util.ArrayList<com.android.systemui.shared.recents.model.Task.TaskCallbacks> mCallbacks = new java.util.ArrayList();
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public java.lang.String packageName;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public int resizeMode;
    public android.app.ActivityManager.TaskDescription taskDescription;
    public int temporarySortIndexInStack;
    public com.android.systemui.shared.recents.model.ThumbnailData thumbnail;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public java.lang.String title;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public java.lang.String titleDescription;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public android.content.ComponentName topActivity;
    @android.view.ViewDebug.ExportedProperty(category = "recents")
    public boolean useLightOnPrimaryColor;

    public interface TaskCallbacks {
        void onTaskDataLoaded(com.android.systemui.shared.recents.model.Task task, com.android.systemui.shared.recents.model.ThumbnailData thumbnailData);

        void onTaskDataUnloaded();

        void onTaskWindowingModeChanged();
    }

    public static class TaskKey {
        @android.view.ViewDebug.ExportedProperty(category = "recents")
        public final android.content.Intent baseIntent;
        @android.view.ViewDebug.ExportedProperty(category = "recents")
        public final int id;
        @android.view.ViewDebug.ExportedProperty(category = "recents")
        public long lastActiveTime;
        private int mHashCode;
        @android.view.ViewDebug.ExportedProperty(category = "recents")
        public final int userId;
        @android.view.ViewDebug.ExportedProperty(category = "recents")
        public int windowingMode;

        public TaskKey(int id, int windowingMode, android.content.Intent intent, int userId, long lastActiveTime) {
            this.id = id;
            this.windowingMode = windowingMode;
            this.baseIntent = intent;
            this.userId = userId;
            this.lastActiveTime = lastActiveTime;
            updateHashCode();
        }

        public void setWindowingMode(int windowingMode) {
            this.windowingMode = windowingMode;
            updateHashCode();
        }

        public android.content.ComponentName getComponent() {
            return this.baseIntent.getComponent();
        }

        public java.lang.String getPackageName() {
            if (this.baseIntent.getComponent() != null) {
                return this.baseIntent.getComponent().getPackageName();
            }
            return this.baseIntent.getPackage();
        }

        public boolean equals(java.lang.Object o) {
            boolean z = false;
            if (!(o instanceof com.android.systemui.shared.recents.model.Task.TaskKey)) {
                return false;
            }
            com.android.systemui.shared.recents.model.Task.TaskKey otherKey = (com.android.systemui.shared.recents.model.Task.TaskKey) o;
            if (this.id == otherKey.id && this.windowingMode == otherKey.windowingMode && this.userId == otherKey.userId) {
                z = true;
            }
            return z;
        }

        public int hashCode() {
            return this.mHashCode;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("id=");
            stringBuilder.append(this.id);
            stringBuilder.append(" windowingMode=");
            stringBuilder.append(this.windowingMode);
            stringBuilder.append(" user=");
            stringBuilder.append(this.userId);
            stringBuilder.append(" lastActiveTime=");
            stringBuilder.append(this.lastActiveTime);
            return stringBuilder.toString();
        }

        private void updateHashCode() {
            this.mHashCode = java.util.Objects.hash(new java.lang.Object[]{java.lang.Integer.valueOf(this.id), java.lang.Integer.valueOf(this.windowingMode), java.lang.Integer.valueOf(this.userId)});
        }
    }

    public Task(com.android.systemui.shared.recents.model.Task.TaskKey key, android.graphics.drawable.Drawable icon, com.android.systemui.shared.recents.model.ThumbnailData thumbnail, java.lang.String title, java.lang.String titleDescription, int colorPrimary, int colorBackground, boolean isLaunchTarget, boolean isStackTask, boolean isSystemApp, boolean isDockable, android.app.ActivityManager.TaskDescription taskDescription, int resizeMode, android.content.ComponentName topActivity, boolean isLocked) {
        this.key = key;
        this.icon = icon;
        this.thumbnail = thumbnail;
        this.title = title;
        this.titleDescription = titleDescription;
        this.colorPrimary = colorPrimary;
        this.colorBackground = colorBackground;
        this.useLightOnPrimaryColor = com.android.systemui.shared.recents.utilities.Utilities.computeContrastBetweenColors(this.colorPrimary, -1) > 3.0f;
        this.taskDescription = taskDescription;
        this.isLaunchTarget = isLaunchTarget;
        this.isStackTask = isStackTask;
        this.isSystemApp = isSystemApp;
        this.isDockable = isDockable;
        this.resizeMode = resizeMode;
        this.topActivity = topActivity;
        this.isLocked = isLocked;
    }

    public void setPakcageName(java.lang.String packageName) {
        this.packageName = packageName;
        this.isHwTaskLocked = com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.isHwTaskLocked(packageName, false);
    }

    public void copyFrom(com.android.systemui.shared.recents.model.Task o) {
        this.key = o.key;
        this.icon = o.icon;
        this.thumbnail = o.thumbnail;
        this.title = o.title;
        this.titleDescription = o.titleDescription;
        this.colorPrimary = o.colorPrimary;
        this.colorBackground = o.colorBackground;
        this.useLightOnPrimaryColor = o.useLightOnPrimaryColor;
        this.taskDescription = o.taskDescription;
        this.isLaunchTarget = o.isLaunchTarget;
        this.isStackTask = o.isStackTask;
        this.isSystemApp = o.isSystemApp;
        this.isDockable = o.isDockable;
        this.resizeMode = o.resizeMode;
        this.isLocked = o.isLocked;
        this.topActivity = o.topActivity;
        this.packageName = o.packageName;
        this.isHwTaskLocked = o.isHwTaskLocked;
    }

    public void addCallback(com.android.systemui.shared.recents.model.Task.TaskCallbacks cb) {
        if (!this.mCallbacks.contains(cb)) {
            this.mCallbacks.add(cb);
        }
    }

    public void removeCallback(com.android.systemui.shared.recents.model.Task.TaskCallbacks cb) {
        this.mCallbacks.remove(cb);
    }

    public void setWindowingMode(int windowingMode) {
        this.key.setWindowingMode(windowingMode);
        int callbackCount = this.mCallbacks.size();
        for (int i = 0; i < callbackCount; i++) {
            ((com.android.systemui.shared.recents.model.Task.TaskCallbacks) this.mCallbacks.get(i)).onTaskWindowingModeChanged();
        }
    }

    public void notifyTaskDataLoaded(com.android.systemui.shared.recents.model.ThumbnailData thumbnailData, android.graphics.drawable.Drawable applicationIcon) {
        this.icon = applicationIcon;
        this.thumbnail = thumbnailData;
        int callbackCount = this.mCallbacks.size();
        for (int i = 0; i < callbackCount; i++) {
            ((com.android.systemui.shared.recents.model.Task.TaskCallbacks) this.mCallbacks.get(i)).onTaskDataLoaded(this, thumbnailData);
        }
    }

    public void notifyTaskDataUnloaded(android.graphics.drawable.Drawable defaultApplicationIcon) {
        this.icon = defaultApplicationIcon;
        this.thumbnail = null;
        for (int i = this.mCallbacks.size() - 1; i >= 0; i--) {
            ((com.android.systemui.shared.recents.model.Task.TaskCallbacks) this.mCallbacks.get(i)).onTaskDataUnloaded();
        }
    }

    public android.content.ComponentName getTopComponent() {
        if (this.topActivity != null) {
            return this.topActivity;
        }
        return this.key.baseIntent.getComponent();
    }

    public boolean equals(java.lang.Object o) {
        return this.key.equals(((com.android.systemui.shared.recents.model.Task) o).key);
    }

    public java.lang.String toString() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("[");
        stringBuilder.append(this.key.toString());
        stringBuilder.append("] ");
        stringBuilder.append(this.title);
        return stringBuilder.toString();
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter writer) {
        writer.print(prefix);
        writer.print(this.key);
        if (!this.isDockable) {
            writer.print(" dockable=N");
        }
        if (this.isLaunchTarget) {
            writer.print(" launchTarget=Y");
        }
        if (this.isLocked) {
            writer.print(" locked=Y");
        }
        writer.print(" ");
        writer.print(this.title);
        writer.println();
    }

    public void recycle() {
        if (this.thumbnail != null) {
            android.graphics.Bitmap b = this.thumbnail.thumbnail;
            if (!(b == null || b.isRecycled())) {
                b.recycle();
                this.thumbnail = null;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Task recycle ");
                stringBuilder.append(this.key);
                android.util.Log.i("Task", stringBuilder.toString());
            }
        }
    }
}
