package com.android.systemui.shared.recents.model;

public abstract class TaskKeyCache<V> {
    protected static final java.lang.String TAG = "TaskKeyCache";
    protected final android.util.SparseArray<com.android.systemui.shared.recents.model.Task.TaskKey> mKeys = new android.util.SparseArray();

    protected abstract void evictAllCache();

    protected abstract V getCacheEntry(int i);

    protected abstract void putCacheEntry(int i, V v);

    protected abstract void removeCacheEntry(int i);

    final V get(com.android.systemui.shared.recents.model.Task.TaskKey key) {
        return getCacheEntry(key.id);
    }

    final V getAndInvalidateIfModified(com.android.systemui.shared.recents.model.Task.TaskKey key) {
        com.android.systemui.shared.recents.model.Task.TaskKey lastKey;
        synchronized (this.mKeys) {
            lastKey = (com.android.systemui.shared.recents.model.Task.TaskKey) this.mKeys.get(key.id);
        }
        if (lastKey == null || (lastKey.windowingMode == key.windowingMode && lastKey.lastActiveTime == key.lastActiveTime)) {
            return getCacheEntry(key.id);
        }
        remove(key);
        return null;
    }

    final void put(com.android.systemui.shared.recents.model.Task.TaskKey key, V value) {
        if (key == null) {
            android.util.Log.e("TaskKeyCache", "Unexpected key == null");
            return;
        }
        synchronized (this.mKeys) {
            this.mKeys.put(key.id, key);
        }
        putCacheEntry(key.id, value);
    }

    final void remove(com.android.systemui.shared.recents.model.Task.TaskKey key) {
        removeCacheEntry(key.id);
        synchronized (this.mKeys) {
            this.mKeys.remove(key.id);
        }
    }

    final void evictAll() {
        evictAllCache();
        synchronized (this.mKeys) {
            this.mKeys.clear();
        }
    }
}
