package com.android.systemui.shared.recents.model;

public class TaskKeyLruCache<V> extends com.android.systemui.shared.recents.model.TaskKeyCache<V> {
    private final android.util.LruCache<java.lang.Integer, V> mCache;
    private final com.android.systemui.shared.recents.model.TaskKeyLruCache.EvictionCallback mEvictionCallback;

    public interface EvictionCallback {
        void onEntryEvicted(com.android.systemui.shared.recents.model.Task.TaskKey taskKey);
    }

    public TaskKeyLruCache(int cacheSize) {
        this(cacheSize, null);
    }

    public TaskKeyLruCache(int cacheSize, com.android.systemui.shared.recents.model.TaskKeyLruCache.EvictionCallback evictionCallback) {
        this.mEvictionCallback = evictionCallback;
        this.mCache = new android.util.LruCache<java.lang.Integer, V>(cacheSize) {
            protected void entryRemoved(boolean evicted, java.lang.Integer taskId, V v, V v2) {
                if (com.android.systemui.shared.recents.model.TaskKeyLruCache.this.mEvictionCallback != null) {
                    com.android.systemui.shared.recents.model.TaskKeyLruCache.this.mEvictionCallback.onEntryEvicted(com.android.systemui.shared.recents.model.TaskKeyLruCache.this.getTaskKeyById(taskId.intValue()));
                }
                synchronized (com.android.systemui.shared.recents.model.TaskKeyLruCache.this.mKeys) {
                    com.android.systemui.shared.recents.model.TaskKeyLruCache.this.mKeys.remove(taskId.intValue());
                }
            }
        };
    }

    final void trimToSize(int cacheSize) {
        this.mCache.trimToSize(cacheSize);
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter writer) {
        java.lang.String innerPrefix = new java.lang.StringBuilder();
        innerPrefix.append(prefix);
        innerPrefix.append("  ");
        innerPrefix = innerPrefix.toString();
        writer.print(prefix);
        writer.print("TaskKeyCache");
        writer.print(" numEntries=");
        writer.print(this.mKeys.size());
        writer.println();
        int keyCount = this.mKeys.size();
        for (int i = 0; i < keyCount; i++) {
            writer.print(innerPrefix);
            writer.println(this.mKeys.get(this.mKeys.keyAt(i)));
        }
    }

    final com.android.systemui.shared.recents.model.Task.TaskKey getTaskKeyById(int id) {
        com.android.systemui.shared.recents.model.Task.TaskKey taskKey;
        synchronized (this.mKeys) {
            taskKey = (com.android.systemui.shared.recents.model.Task.TaskKey) this.mKeys.get(id);
        }
        return taskKey;
    }

    protected V getCacheEntry(int id) {
        return this.mCache.get(java.lang.Integer.valueOf(id));
    }

    protected void putCacheEntry(int id, V value) {
        this.mCache.put(java.lang.Integer.valueOf(id), value);
    }

    protected void removeCacheEntry(int id) {
        this.mCache.remove(java.lang.Integer.valueOf(id));
    }

    protected void evictAllCache() {
        this.mCache.evictAll();
    }
}
