package com.android.systemui.shared.recents.model;

public class TaskStack {
    private static final java.lang.String TAG = "TaskStack";
    private com.android.systemui.shared.recents.model.TaskStack.TaskStackCallbacks mCb;
    private final java.util.ArrayList<com.android.systemui.shared.recents.model.Task> mRawTaskList = new java.util.ArrayList();
    private final com.android.systemui.shared.recents.model.FilteredTaskList mStackTaskList = new com.android.systemui.shared.recents.model.FilteredTaskList();

    public interface TaskStackCallbacks {
        void onStackTaskAdded(com.android.systemui.shared.recents.model.TaskStack taskStack, com.android.systemui.shared.recents.model.Task task);

        void onStackTaskRemoved(com.android.systemui.shared.recents.model.TaskStack taskStack, com.android.systemui.shared.recents.model.Task task, com.android.systemui.shared.recents.model.Task task2, com.android.systemui.shared.recents.utilities.AnimationProps animationProps, boolean z, boolean z2);

        void onStackTasksRemoved(com.android.systemui.shared.recents.model.TaskStack taskStack);

        void onStackTasksUpdated(com.android.systemui.shared.recents.model.TaskStack taskStack);
    }

    public TaskStack() {
        this.mStackTaskList.setFilter(com.android.systemui.shared.recents.model.-$$Lambda$TaskStack$gkuBLLtJ6FV7PDAxT-_KECDzTOI.INSTANCE);
    }

    public void setCallbacks(com.android.systemui.shared.recents.model.TaskStack.TaskStackCallbacks cb) {
        this.mCb = cb;
    }

    public void removeTask(com.android.systemui.shared.recents.model.Task t, com.android.systemui.shared.recents.utilities.AnimationProps animation, boolean fromDockGesture) {
        removeTask(t, animation, fromDockGesture, true);
    }

    public void removeTask(com.android.systemui.shared.recents.model.Task t, com.android.systemui.shared.recents.utilities.AnimationProps animation, boolean fromDockGesture, boolean dismissRecentsIfAllRemoved) {
        if (this.mStackTaskList.contains(t)) {
            this.mStackTaskList.remove(t);
            com.android.systemui.shared.recents.model.Task newFrontMostTask = getFrontMostTask();
            if (this.mCb != null) {
                this.mCb.onStackTaskRemoved(this, t, newFrontMostTask, animation, fromDockGesture, dismissRecentsIfAllRemoved);
            }
        }
        this.mRawTaskList.remove(t);
    }

    public void removeAllTasks(boolean notifyStackChanges) {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = this.mStackTaskList.getTasks();
        for (int i = tasks.size() - 1; i >= 0; i--) {
            com.android.systemui.shared.recents.model.Task t = (com.android.systemui.shared.recents.model.Task) tasks.get(i);
            this.mStackTaskList.remove(t);
            this.mRawTaskList.remove(t);
        }
        if (this.mCb != null && notifyStackChanges) {
            this.mCb.onStackTasksRemoved(this);
        }
    }

    public void setTasks(com.android.systemui.shared.recents.model.TaskStack stack, boolean notifyStackChanges) {
        setTasks(stack.mRawTaskList, notifyStackChanges);
    }

    public void setTasks(java.util.List<com.android.systemui.shared.recents.model.Task> tasks, boolean notifyStackChanges) {
        int i;
        com.android.systemui.shared.recents.model.Task task;
        int i2;
        android.util.ArrayMap<com.android.systemui.shared.recents.model.Task.TaskKey, com.android.systemui.shared.recents.model.Task> currentTasksMap = createTaskKeyMapFromList(this.mRawTaskList);
        android.util.ArrayMap<com.android.systemui.shared.recents.model.Task.TaskKey, com.android.systemui.shared.recents.model.Task> newTasksMap = createTaskKeyMapFromList(tasks);
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> addedTasks = new java.util.ArrayList();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> removedTasks = new java.util.ArrayList();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> allTasks = new java.util.ArrayList();
        boolean notifyStackChanges2 = this.mCb == null ? false : notifyStackChanges;
        for (i = this.mRawTaskList.size() - 1; i >= 0; i--) {
            task = (com.android.systemui.shared.recents.model.Task) this.mRawTaskList.get(i);
            if (task == null) {
                android.util.Log.e("TaskStack", "setTasks,task is null here");
            } else if (!newTasksMap.containsKey(task.key) && notifyStackChanges2) {
                removedTasks.add(task);
            }
        }
        int taskCount = tasks.size();
        int i3 = 0;
        for (i2 = 0; i2 < taskCount; i2++) {
            com.android.systemui.shared.recents.model.Task newTask = (com.android.systemui.shared.recents.model.Task) tasks.get(i2);
            task = (com.android.systemui.shared.recents.model.Task) currentTasksMap.get(newTask.key);
            if (task == null && notifyStackChanges2) {
                addedTasks.add(newTask);
            } else if (task != null) {
                task.copyFrom(newTask);
                newTask = task;
            }
            allTasks.add(newTask);
        }
        java.util.List<com.android.systemui.shared.recents.model.Task> list = tasks;
        for (i2 = allTasks.size() - 1; i2 >= 0; i2--) {
            ((com.android.systemui.shared.recents.model.Task) allTasks.get(i2)).temporarySortIndexInStack = i2;
        }
        this.mStackTaskList.set(allTasks);
        this.mRawTaskList.clear();
        this.mRawTaskList.addAll(allTasks);
        int removedTaskCount = removedTasks.size();
        com.android.systemui.shared.recents.model.Task newFrontMostTask = getFrontMostTask();
        i2 = 0;
        while (true) {
            int i4 = i2;
            if (i4 >= removedTaskCount) {
                break;
            }
            int i5 = i4;
            int removedTaskCount2 = removedTaskCount;
            this.mCb.onStackTaskRemoved(this, (com.android.systemui.shared.recents.model.Task) removedTasks.get(i4), newFrontMostTask, com.android.systemui.shared.recents.utilities.AnimationProps.IMMEDIATE, false, true);
            i2 = i5 + 1;
            list = tasks;
            removedTaskCount = removedTaskCount2;
        }
        i2 = addedTasks.size();
        while (true) {
            i = i3;
            if (i >= i2) {
                break;
            }
            this.mCb.onStackTaskAdded(this, (com.android.systemui.shared.recents.model.Task) addedTasks.get(i));
            i3 = i + 1;
        }
        if (notifyStackChanges2) {
            this.mCb.onStackTasksUpdated(this);
        }
    }

    public com.android.systemui.shared.recents.model.Task getFrontMostTask() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> stackTasks = this.mStackTaskList.getTasks();
        if (stackTasks.isEmpty()) {
            return null;
        }
        return (com.android.systemui.shared.recents.model.Task) stackTasks.get(stackTasks.size() - 1);
    }

    public java.util.ArrayList<com.android.systemui.shared.recents.model.Task.TaskKey> getTaskKeys() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task.TaskKey> taskKeys = new java.util.ArrayList();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = computeAllTasksList();
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            taskKeys.add(((com.android.systemui.shared.recents.model.Task) tasks.get(i)).key);
        }
        return taskKeys;
    }

    public java.util.ArrayList<com.android.systemui.shared.recents.model.Task> getTasks() {
        return this.mStackTaskList.getTasks();
    }

    public java.util.ArrayList<com.android.systemui.shared.recents.model.Task> computeAllTasksList() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = new java.util.ArrayList();
        tasks.addAll(this.mStackTaskList.getTasks());
        return tasks;
    }

    public int getTaskCount() {
        return this.mStackTaskList.size();
    }

    public com.android.systemui.shared.recents.model.Task getLaunchTarget() {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = this.mStackTaskList.getTasks();
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            com.android.systemui.shared.recents.model.Task task = (com.android.systemui.shared.recents.model.Task) tasks.get(i);
            if (task != null && task.isLaunchTarget) {
                return task;
            }
        }
        return null;
    }

    public boolean isNextLaunchTargetPip(long lastPipTime) {
        com.android.systemui.shared.recents.model.Task launchTarget = getLaunchTarget();
        com.android.systemui.shared.recents.model.Task nextLaunchTarget = getNextLaunchTargetRaw();
        boolean z = false;
        if (nextLaunchTarget == null || lastPipTime <= 0) {
            return launchTarget != null && lastPipTime > 0 && getTaskCount() == 1;
        } else {
            if (lastPipTime > nextLaunchTarget.key.lastActiveTime) {
                z = true;
            }
            return z;
        }
    }

    public com.android.systemui.shared.recents.model.Task getNextLaunchTarget() {
        com.android.systemui.shared.recents.model.Task nextLaunchTarget = getNextLaunchTargetRaw();
        if (nextLaunchTarget != null) {
            return nextLaunchTarget;
        }
        return (com.android.systemui.shared.recents.model.Task) getTasks().get(getTaskCount() - 1);
    }

    private com.android.systemui.shared.recents.model.Task getNextLaunchTargetRaw() {
        if (getTaskCount() == 0) {
            return null;
        }
        int launchTaskIndex = indexOfTask(getLaunchTarget());
        if (launchTaskIndex == -1 || launchTaskIndex <= 0) {
            return null;
        }
        return (com.android.systemui.shared.recents.model.Task) getTasks().get(launchTaskIndex - 1);
    }

    public int indexOfTask(com.android.systemui.shared.recents.model.Task t) {
        return this.mStackTaskList.indexOf(t);
    }

    public com.android.systemui.shared.recents.model.Task findTaskWithId(int taskId) {
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = computeAllTasksList();
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            com.android.systemui.shared.recents.model.Task task = (com.android.systemui.shared.recents.model.Task) tasks.get(i);
            if (task != null && task.key != null && task.key.id == taskId) {
                return task;
            }
        }
        return null;
    }

    public android.util.ArraySet<android.content.ComponentName> computeComponentsRemoved(java.lang.String packageName, int userId) {
        android.util.ArraySet<android.content.ComponentName> existingComponents = new android.util.ArraySet();
        android.util.ArraySet<android.content.ComponentName> removedComponents = new android.util.ArraySet();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task.TaskKey> taskKeys = getTaskKeys();
        int taskKeyCount = taskKeys.size();
        for (int i = 0; i < taskKeyCount; i++) {
            com.android.systemui.shared.recents.model.Task.TaskKey t = (com.android.systemui.shared.recents.model.Task.TaskKey) taskKeys.get(i);
            if (t.userId == userId) {
                android.content.ComponentName cn = t.getComponent();
                if (cn.getPackageName().equals(packageName)) {
                    if (!existingComponents.contains(cn)) {
                        if (com.android.systemui.shared.system.PackageManagerWrapper.getInstance().getActivityInfo(cn, userId) != null) {
                            existingComponents.add(cn);
                        } else {
                            removedComponents.add(cn);
                        }
                    }
                }
            }
        }
        return removedComponents;
    }

    public java.lang.String toString() {
        java.lang.String str = new java.lang.StringBuilder();
        str.append("Stack Tasks (");
        str.append(this.mStackTaskList.size());
        str.append("):\n");
        str = str.toString();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = this.mStackTaskList.getTasks();
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(str);
            stringBuilder.append("    ");
            stringBuilder.append(((com.android.systemui.shared.recents.model.Task) tasks.get(i)).toString());
            stringBuilder.append("\n");
            str = stringBuilder.toString();
        }
        return str;
    }

    private android.util.ArrayMap<com.android.systemui.shared.recents.model.Task.TaskKey, com.android.systemui.shared.recents.model.Task> createTaskKeyMapFromList(java.util.List<com.android.systemui.shared.recents.model.Task> tasks) {
        android.util.ArrayMap<com.android.systemui.shared.recents.model.Task.TaskKey, com.android.systemui.shared.recents.model.Task> map = new android.util.ArrayMap(tasks.size());
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            com.android.systemui.shared.recents.model.Task task = (com.android.systemui.shared.recents.model.Task) tasks.get(i);
            map.put(task.key, task);
        }
        return map;
    }

    public void dump(java.lang.String prefix, java.io.PrintWriter writer) {
        java.lang.String innerPrefix = new java.lang.StringBuilder();
        innerPrefix.append(prefix);
        innerPrefix.append("  ");
        innerPrefix = innerPrefix.toString();
        writer.print(prefix);
        writer.print("TaskStack");
        writer.print(" numStackTasks=");
        writer.print(this.mStackTaskList.size());
        writer.println();
        java.util.ArrayList<com.android.systemui.shared.recents.model.Task> tasks = this.mStackTaskList.getTasks();
        int taskCount = tasks.size();
        for (int i = 0; i < taskCount; i++) {
            ((com.android.systemui.shared.recents.model.Task) tasks.get(i)).dump(innerPrefix, writer);
        }
    }
}
