package com.android.systemui.shared.recents.utilities;

public class AnimationProps {
    public static final int ALL = 0;
    public static final int ALPHA = 4;
    public static final int BOUNDS = 6;
    public static final int DIM_ALPHA = 7;
    public static final com.android.systemui.shared.recents.utilities.AnimationProps IMMEDIATE = new com.android.systemui.shared.recents.utilities.AnimationProps(0, LINEAR_INTERPOLATOR);
    private static final android.view.animation.Interpolator LINEAR_INTERPOLATOR = new android.view.animation.LinearInterpolator();
    public static final int SCALE = 5;
    public static final int TRANSLATION_X = 1;
    public static final int TRANSLATION_Y = 2;
    public static final int TRANSLATION_Z = 3;
    private android.animation.Animator.AnimatorListener mListener;
    private android.util.SparseLongArray mPropDuration;
    private android.util.SparseArray<android.view.animation.Interpolator> mPropInterpolators;
    private android.util.SparseLongArray mPropStartDelay;

    @java.lang.annotation.Retention(java.lang.annotation.RetentionPolicy.SOURCE)
    public @interface PropType {
    }

    public AnimationProps(int duration, android.view.animation.Interpolator interpolator) {
        this(0, duration, interpolator, null);
    }

    public AnimationProps(int duration, android.view.animation.Interpolator interpolator, android.animation.Animator.AnimatorListener listener) {
        this(0, duration, interpolator, listener);
    }

    public AnimationProps(int startDelay, int duration, android.view.animation.Interpolator interpolator) {
        this(startDelay, duration, interpolator, null);
    }

    public AnimationProps(int startDelay, int duration, android.view.animation.Interpolator interpolator, android.animation.Animator.AnimatorListener listener) {
        setStartDelay(0, startDelay);
        setDuration(0, duration);
        setInterpolator(0, interpolator);
        setListener(listener);
    }

    public android.animation.AnimatorSet createAnimator(java.util.List<android.animation.Animator> animators) {
        android.animation.AnimatorSet anim = new android.animation.AnimatorSet();
        if (this.mListener != null) {
            anim.addListener(this.mListener);
        }
        anim.playTogether(animators);
        return anim;
    }

    public <T extends android.animation.ValueAnimator> T apply(int propertyType, T animator) {
        animator.setStartDelay(getStartDelay(propertyType));
        animator.setDuration(getDuration(propertyType));
        animator.setInterpolator(getInterpolator(propertyType));
        return animator;
    }

    public com.android.systemui.shared.recents.utilities.AnimationProps setStartDelay(int propertyType, int startDelay) {
        if (this.mPropStartDelay == null) {
            this.mPropStartDelay = new android.util.SparseLongArray();
        }
        this.mPropStartDelay.append(propertyType, (long) startDelay);
        return this;
    }

    public long getStartDelay(int propertyType) {
        if (this.mPropStartDelay == null) {
            return 0;
        }
        long startDelay = this.mPropStartDelay.get(propertyType, -1);
        if (startDelay != -1) {
            return startDelay;
        }
        return this.mPropStartDelay.get(0, 0);
    }

    public com.android.systemui.shared.recents.utilities.AnimationProps setDuration(int propertyType, int duration) {
        if (this.mPropDuration == null) {
            this.mPropDuration = new android.util.SparseLongArray();
        }
        this.mPropDuration.append(propertyType, (long) duration);
        return this;
    }

    public long getDuration(int propertyType) {
        if (this.mPropDuration == null) {
            return 0;
        }
        long duration = this.mPropDuration.get(propertyType, -1);
        if (duration != -1) {
            return duration;
        }
        return this.mPropDuration.get(0, 0);
    }

    public com.android.systemui.shared.recents.utilities.AnimationProps setInterpolator(int propertyType, android.view.animation.Interpolator interpolator) {
        if (this.mPropInterpolators == null) {
            this.mPropInterpolators = new android.util.SparseArray();
        }
        this.mPropInterpolators.append(propertyType, interpolator);
        return this;
    }

    public android.view.animation.Interpolator getInterpolator(int propertyType) {
        if (this.mPropInterpolators == null) {
            return LINEAR_INTERPOLATOR;
        }
        android.view.animation.Interpolator interp = (android.view.animation.Interpolator) this.mPropInterpolators.get(propertyType);
        if (interp != null) {
            return interp;
        }
        return (android.view.animation.Interpolator) this.mPropInterpolators.get(0, LINEAR_INTERPOLATOR);
    }

    public com.android.systemui.shared.recents.utilities.AnimationProps setListener(android.animation.Animator.AnimatorListener listener) {
        this.mListener = listener;
        return this;
    }

    public android.animation.Animator.AnimatorListener getListener() {
        return this.mListener;
    }

    public boolean isImmediate() {
        int count = this.mPropDuration.size();
        for (int i = 0; i < count; i++) {
            if (this.mPropDuration.valueAt(i) > 0) {
                return false;
            }
        }
        return true;
    }
}
