package com.android.systemui.shared.recents.utilities;

public class Utilities {
    public static final android.util.Property<android.graphics.drawable.Drawable, java.lang.Integer> DRAWABLE_ALPHA = new android.util.IntProperty<android.graphics.drawable.Drawable>("drawableAlpha") {
        public void setValue(android.graphics.drawable.Drawable object, int alpha) {
            object.setAlpha(alpha);
        }

        public java.lang.Integer get(android.graphics.drawable.Drawable object) {
            return java.lang.Integer.valueOf(object.getAlpha());
        }
    };
    public static final android.util.Property<android.graphics.drawable.Drawable, android.graphics.Rect> DRAWABLE_RECT = new android.util.Property<android.graphics.drawable.Drawable, android.graphics.Rect>(android.graphics.Rect.class, "drawableBounds") {
        public void set(android.graphics.drawable.Drawable object, android.graphics.Rect bounds) {
            object.setBounds(bounds);
        }

        public android.graphics.Rect get(android.graphics.drawable.Drawable object) {
            return object.getBounds();
        }
    };
    public static final com.android.systemui.shared.recents.utilities.RectFEvaluator RECTF_EVALUATOR = new com.android.systemui.shared.recents.utilities.RectFEvaluator();
    public static final android.animation.RectEvaluator RECT_EVALUATOR = new android.animation.RectEvaluator(new android.graphics.Rect());

    public static <T extends android.view.View> T findParent(android.view.View v, java.lang.Class<T> parentClass) {
        for (android.view.ViewParent parent = v.getParent(); parent != null; parent = parent.getParent()) {
            if (parentClass.isAssignableFrom(parent.getClass())) {
                return (android.view.View) parent;
            }
        }
        return null;
    }

    public static <T> android.util.ArraySet<T> objectToSet(T obj, android.util.ArraySet<T> setOut) {
        setOut.clear();
        if (obj != null) {
            setOut.add(obj);
        }
        return setOut;
    }

    public static <T> android.util.ArraySet<T> arrayToSet(T[] array, android.util.ArraySet<T> setOut) {
        setOut.clear();
        if (array != null) {
            java.util.Collections.addAll(setOut, array);
        }
        return setOut;
    }

    public static float clamp(float value, float min, float max) {
        return max(min, min(max, value));
    }

    public static int clamp(int value, int min, int max) {
        return max(min, min(max, value));
    }

    public static float clamp01(float value) {
        return max(0.0f, min(1.0f, value));
    }

    private static int max(int a, int b) {
        return a > b ? a : b;
    }

    private static int min(int a, int b) {
        return a < b ? a : b;
    }

    private static float max(float a, float b) {
        return a > b ? a : b;
    }

    private static float min(float a, float b) {
        return a < b ? a : b;
    }

    public static float mapRange(float value, float min, float max) {
        return ((max - min) * value) + min;
    }

    public static float unmapRange(float value, float min, float max) {
        return (value - min) / (max - min);
    }

    public static void scaleRectAboutCenter(android.graphics.RectF r, float scale) {
        if (scale != 1.0f) {
            float cx = r.centerX();
            float cy = r.centerY();
            r.offset(-cx, -cy);
            r.left *= scale;
            r.top *= scale;
            r.right *= scale;
            r.bottom *= scale;
            r.offset(cx, cy);
        }
    }

    public static float computeContrastBetweenColors(int bg, int fg) {
        float fgR;
        float fgB;
        float bgR = ((float) android.graphics.Color.red(bg)) / 255.0f;
        float bgG = ((float) android.graphics.Color.green(bg)) / 255.0f;
        float bgB = ((float) android.graphics.Color.blue(bg)) / 255.0f;
        float bgL = ((0.2126f * (bgR < 0.03928f ? bgR / 12.92f : (float) java.lang.Math.pow((double) ((bgR + 0.055f) / 1.055f), 2.4000000953674316d))) + (0.7152f * (bgG < 0.03928f ? bgG / 12.92f : (float) java.lang.Math.pow((double) ((bgG + 0.055f) / 1.055f), 2.4000000953674316d)))) + (0.0722f * (bgB < 0.03928f ? bgB / 12.92f : (float) java.lang.Math.pow((double) ((bgB + 0.055f) / 1.055f), 2.4000000953674316d)));
        float fgR2 = ((float) android.graphics.Color.red(fg)) / 255.0f;
        float fgG = ((float) android.graphics.Color.green(fg)) / 255.0f;
        float fgB2 = ((float) android.graphics.Color.blue(fg)) / 255.0f;
        if (fgR2 < 0.03928f) {
            fgR = fgR2 / 12.92f;
            fgB = fgB2;
        } else {
            fgB = fgB2;
            fgR = (float) java.lang.Math.pow((double) ((fgR2 + 0.055f) / 1.055f), 2.4000000953674316d);
        }
        return java.lang.Math.abs(((((0.2126f * fgR) + (0.7152f * (fgG < 0.03928f ? fgG / 12.92f : (float) java.lang.Math.pow((double) ((fgG + 0.055f) / 1.055f), 2.4000000953674316d)))) + (0.0722f * (fgB < 0.03928f ? fgB / 12.92f : (float) java.lang.Math.pow((double) ((fgB + 0.055f) / 1.055f), 2.4000000953674316d)))) + 0.05f) / (0.05f + bgL));
    }

    public static int getColorWithOverlay(int baseColor, int overlayColor, float overlayAlpha) {
        return android.graphics.Color.rgb((int) ((((float) android.graphics.Color.red(baseColor)) * overlayAlpha) + ((1.0f - overlayAlpha) * ((float) android.graphics.Color.red(overlayColor)))), (int) ((((float) android.graphics.Color.green(baseColor)) * overlayAlpha) + ((1.0f - overlayAlpha) * ((float) android.graphics.Color.green(overlayColor)))), (int) ((((float) android.graphics.Color.blue(baseColor)) * overlayAlpha) + ((1.0f - overlayAlpha) * ((float) android.graphics.Color.blue(overlayColor)))));
    }

    public static void cancelAnimationWithoutCallbacks(android.animation.Animator animator) {
        if (animator != null && animator.isStarted()) {
            removeAnimationListenersRecursive(animator);
            animator.cancel();
        }
    }

    public static void removeAnimationListenersRecursive(android.animation.Animator animator) {
        if (animator instanceof android.animation.AnimatorSet) {
            java.util.ArrayList<android.animation.Animator> animators = ((android.animation.AnimatorSet) animator).getChildAnimations();
            for (int i = animators.size() - 1; i >= 0; i--) {
                removeAnimationListenersRecursive((android.animation.Animator) animators.get(i));
            }
        }
        animator.removeAllListeners();
    }

    public static void setViewFrameFromTranslation(android.view.View v) {
        android.graphics.RectF taskViewRect = new android.graphics.RectF((float) v.getLeft(), (float) v.getTop(), (float) v.getRight(), (float) v.getBottom());
        taskViewRect.offset(v.getTranslationX(), v.getTranslationY());
        v.setTranslationX(0.0f);
        v.setTranslationY(0.0f);
        v.setLeftTopRightBottom((int) taskViewRect.left, (int) taskViewRect.top, (int) taskViewRect.right, (int) taskViewRect.bottom);
    }

    public static android.view.ViewStub findViewStubById(android.view.View v, int stubId) {
        return (android.view.ViewStub) v.findViewById(stubId);
    }

    public static android.view.ViewStub findViewStubById(android.app.Activity a, int stubId) {
        return (android.view.ViewStub) a.findViewById(stubId);
    }

    public static float dpToPx(android.content.res.Resources res, float dp) {
        return android.util.TypedValue.applyDimension(1, dp, res.getDisplayMetrics());
    }

    public static void addTraceEvent(java.lang.String event) {
        android.os.Trace.traceBegin(8, event);
        android.os.Trace.traceEnd(8);
    }

    public static boolean isDescendentAccessibilityFocused(android.view.View v) {
        if (v.isAccessibilityFocused()) {
            return true;
        }
        if (v instanceof android.view.ViewGroup) {
            android.view.ViewGroup vg = (android.view.ViewGroup) v;
            int childCount = vg.getChildCount();
            for (int i = 0; i < childCount; i++) {
                if (isDescendentAccessibilityFocused(vg.getChildAt(i))) {
                    return true;
                }
            }
        }
        return false;
    }

    public static android.content.res.Configuration getAppConfiguration(android.content.Context context) {
        return context.getApplicationContext().getResources().getConfiguration();
    }

    public static long getNextFrameNumber(android.view.Surface s) {
        if (s == null || !s.isValid()) {
            return -1;
        }
        return s.getNextFrameNumber();
    }

    public static android.view.Surface getSurface(android.view.View v) {
        android.view.ViewRootImpl viewRoot = v.getViewRootImpl();
        if (viewRoot == null) {
            return null;
        }
        return viewRoot.mSurface;
    }

    public static java.lang.String dumpRect(android.graphics.Rect r) {
        if (r == null) {
            return "N:0,0-0,0";
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(r.left);
        stringBuilder.append(",");
        stringBuilder.append(r.top);
        stringBuilder.append("-");
        stringBuilder.append(r.right);
        stringBuilder.append(",");
        stringBuilder.append(r.bottom);
        return stringBuilder.toString();
    }

    public static void postAtFrontOfQueueAsynchronously(android.os.Handler h, java.lang.Runnable r) {
        h.sendMessageAtFrontOfQueue(h.obtainMessage().setCallback(r));
    }
}
