package com.android.systemui.shared.recents.view;

public class AnimateableViewBounds extends android.view.ViewOutlineProvider {
    private static final float MAX_ALPHA = 0.8f;
    private static final float MIN_ALPHA = 0.1f;
    protected float mAlpha = 1.0f;
    protected android.graphics.Rect mClipBounds = new android.graphics.Rect();
    protected android.graphics.Rect mClipRect = new android.graphics.Rect();
    protected int mCornerRadius;
    protected android.graphics.Rect mLastClipBounds = new android.graphics.Rect();
    protected android.view.View mSourceView;

    public AnimateableViewBounds(android.view.View source, int cornerRadius) {
        this.mSourceView = source;
        this.mCornerRadius = cornerRadius;
    }

    public void reset() {
        this.mClipRect.set(0, 0, 0, 0);
        updateClipBounds();
    }

    public void getOutline(android.view.View view, android.graphics.Outline outline) {
        outline.setAlpha(com.android.systemui.shared.recents.utilities.Utilities.mapRange(this.mAlpha, 0.1f, 0.8f));
        if (this.mCornerRadius > 0) {
            outline.setRoundRect(this.mClipRect.left, this.mClipRect.top, this.mSourceView.getWidth() - this.mClipRect.right, this.mSourceView.getHeight() - this.mClipRect.bottom, (float) this.mCornerRadius);
            return;
        }
        outline.setRect(this.mClipRect.left, this.mClipRect.top, this.mSourceView.getWidth() - this.mClipRect.right, this.mSourceView.getHeight() - this.mClipRect.bottom);
    }

    public void setAlpha(float alpha) {
        if (java.lang.Float.compare(alpha, this.mAlpha) != 0) {
            this.mAlpha = alpha;
            this.mSourceView.invalidateOutline();
        }
    }

    public float getAlpha() {
        return this.mAlpha;
    }

    public void setClipTop(int top) {
        this.mClipRect.top = top;
        updateClipBounds();
    }

    public int getClipTop() {
        return this.mClipRect.top;
    }

    public void setClipBottom(int bottom) {
        this.mClipRect.bottom = bottom;
        updateClipBounds();
    }

    public int getClipBottom() {
        return this.mClipRect.bottom;
    }

    public android.graphics.Rect getClipBounds() {
        return this.mClipBounds;
    }

    protected void updateClipBounds() {
        this.mClipBounds.set(max(0, this.mClipRect.left), max(0, this.mClipRect.top), this.mSourceView.getWidth() - max(0, this.mClipRect.right), this.mSourceView.getHeight() - max(0, this.mClipRect.bottom));
        if (!this.mLastClipBounds.equals(this.mClipBounds)) {
            this.mSourceView.setClipBounds(this.mClipBounds);
            this.mSourceView.invalidateOutline();
            this.mLastClipBounds.set(this.mClipBounds);
        }
    }

    private int max(int a, int b) {
        return a > b ? a : b;
    }
}
