package com.android.systemui.shared.recents.view;

public class RecentsTransition {
    public static android.app.ActivityOptions createAspectScaleAnimation(android.content.Context context, android.os.Handler handler, boolean scaleUp, com.android.systemui.shared.recents.view.AppTransitionAnimationSpecsFuture animationSpecsFuture, final java.lang.Runnable animationStartCallback) {
        return android.app.ActivityOptions.makeMultiThumbFutureAspectScaleAnimation(context, handler, animationSpecsFuture != null ? animationSpecsFuture.getFuture() : null, new android.app.ActivityOptions.OnAnimationStartedListener() {
            private boolean mHandled;

            public void onAnimationStarted() {
                if (!this.mHandled) {
                    this.mHandled = true;
                    if (animationStartCallback != null) {
                        animationStartCallback.run();
                    }
                }
            }
        }, scaleUp);
    }

    public static android.os.IRemoteCallback wrapStartedListener(final android.os.Handler handler, final java.lang.Runnable animationStartCallback) {
        if (animationStartCallback == null) {
            return null;
        }
        return new android.os.IRemoteCallback.Stub() {
            public void sendResult(android.os.Bundle data) throws android.os.RemoteException {
                handler.post(animationStartCallback);
            }
        };
    }

    public static android.graphics.Bitmap drawViewIntoHardwareBitmap(int width, int height, final android.view.View view, final float scale, final int eraseColor) {
        return createHardwareBitmap(width, height, new java.util.function.Consumer<android.graphics.Canvas>() {
            public void accept(android.graphics.Canvas c) {
                c.scale(scale, scale);
                if (eraseColor != 0) {
                    c.drawColor(eraseColor);
                }
                if (view != null) {
                    view.draw(c);
                }
            }
        });
    }

    public static android.graphics.Bitmap createHardwareBitmap(int width, int height, java.util.function.Consumer<android.graphics.Canvas> consumer) {
        android.view.RenderNode node = android.view.RenderNode.create("RecentsTransition", null);
        node.setLeftTopRightBottom(0, 0, width, height);
        node.setClipToBounds(false);
        android.view.DisplayListCanvas c = node.start(width, height);
        consumer.accept(c);
        node.end(c);
        return android.view.ThreadedRenderer.createHardwareBitmap(node, width, height);
    }
}
