package com.android.systemui.shared.system;

public class ActivityManagerWrapper {
    public static final java.lang.String CLOSE_SYSTEM_WINDOWS_REASON_RECENTS = "recentapps";
    private static final java.lang.String TAG = "ActivityManagerWrapper";
    private static final com.android.systemui.shared.system.ActivityManagerWrapper sInstance = new com.android.systemui.shared.system.ActivityManagerWrapper();
    private final com.android.systemui.shared.system.BackgroundExecutor mBackgroundExecutor = com.android.systemui.shared.system.BackgroundExecutor.get();
    private android.content.Context mContext;
    private final android.content.pm.PackageManager mPackageManager;
    private final com.android.systemui.shared.system.TaskStackChangeListeners mTaskStackChangeListeners = new com.android.systemui.shared.system.TaskStackChangeListeners(android.os.Looper.getMainLooper());

    private ActivityManagerWrapper() {
        android.content.Context context = android.app.AppGlobals.getInitialApplication();
        this.mContext = context;
        this.mPackageManager = context.getPackageManager();
    }

    public static com.android.systemui.shared.system.ActivityManagerWrapper getInstance() {
        return sInstance;
    }

    public int getCurrentUserId() {
        try {
            android.content.pm.UserInfo ui = android.app.ActivityManager.getService().getCurrentUser();
            return ui != null ? ui.id : 0;
        } catch (android.os.RemoteException e) {
            throw e.rethrowFromSystemServer();
        }
    }

    public android.app.ActivityManager.RunningTaskInfo getRunningTask() {
        return getRunningTask(3);
    }

    public android.app.ActivityManager.RunningTaskInfo getRunningTask(@android.app.WindowConfiguration.ActivityType int ignoreActivityType) {
        try {
            java.util.List<android.app.ActivityManager.RunningTaskInfo> tasks = android.app.ActivityManager.getService().getFilteredTasks(1, ignoreActivityType, 2);
            if (tasks.isEmpty()) {
                return null;
            }
            return (android.app.ActivityManager.RunningTaskInfo) tasks.get(0);
        } catch (android.os.RemoteException e) {
            return null;
        }
    }

    public java.util.List<android.app.ActivityManager.RecentTaskInfo> getRecentTasks(int numTasks, int userId) {
        try {
            return android.app.ActivityManager.getService().getRecentTasks(numTasks, 2, userId).getList();
        } catch (android.os.RemoteException e) {
            android.util.Log.e("ActivityManagerWrapper", "Failed to get recent tasks", e);
            return new java.util.ArrayList();
        }
    }

    public com.android.systemui.shared.recents.model.ThumbnailData getTaskThumbnail(int taskId, boolean reducedResolution) {
        android.app.ActivityManager.TaskSnapshot snapshot = null;
        try {
            snapshot = android.app.ActivityManager.getService().getTaskSnapshot(taskId, reducedResolution);
        } catch (android.os.RemoteException e) {
            android.util.Log.w("ActivityManagerWrapper", "Failed to retrieve task snapshot", e);
        }
        if (snapshot != null) {
            return new com.android.systemui.shared.recents.model.ThumbnailData(snapshot);
        }
        return new com.android.systemui.shared.recents.model.ThumbnailData();
    }

    public java.lang.String getBadgedActivityLabel(android.content.pm.ActivityInfo info, int userId) {
        return getBadgedLabel(info.loadLabel(this.mPackageManager).toString(), userId);
    }

    public java.lang.String getBadgedApplicationLabel(android.content.pm.ApplicationInfo appInfo, int userId) {
        return getBadgedLabel(appInfo.loadLabel(this.mPackageManager).toString(), userId);
    }

    public java.lang.String getBadgedContentDescription(android.content.pm.ActivityInfo info, int userId, android.app.ActivityManager.TaskDescription td) {
        java.lang.String activityLabel;
        if (td == null || td.getLabel() == null) {
            activityLabel = info.loadLabel(this.mPackageManager).toString();
        } else {
            activityLabel = td.getLabel();
        }
        java.lang.String applicationLabel = info.applicationInfo.loadLabel(this.mPackageManager).toString();
        java.lang.String badgedApplicationLabel = getBadgedLabel(applicationLabel, userId);
        if (applicationLabel.equals(activityLabel)) {
            return badgedApplicationLabel;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(badgedApplicationLabel);
        stringBuilder.append(" ");
        stringBuilder.append(activityLabel);
        return stringBuilder.toString();
    }

    private java.lang.String getBadgedLabel(java.lang.String label, int userId) {
        if (userId != android.os.UserHandle.myUserId()) {
            return this.mPackageManager.getUserBadgedLabel(label, new android.os.UserHandle(userId)).toString();
        }
        return label;
    }

    public void startRecentsActivity(android.content.Intent intent, final com.android.systemui.shared.system.AssistDataReceiver assistDataReceiver, final com.android.systemui.shared.system.RecentsAnimationListener animationHandler, final java.util.function.Consumer<java.lang.Boolean> resultCallback, android.os.Handler resultCallbackHandler) {
        java.lang.Exception e = null;
        if (assistDataReceiver != null) {
            try {
                e = new android.app.IAssistDataReceiver.Stub() {
                    public void onHandleAssistData(android.os.Bundle resultData) {
                        assistDataReceiver.onHandleAssistData(resultData);
                    }

                    public void onHandleAssistScreenshot(android.graphics.Bitmap screenshot) {
                        assistDataReceiver.onHandleAssistScreenshot(screenshot);
                    }
                };
            } catch (java.lang.Exception e2) {
                if (resultCallback != null) {
                    resultCallbackHandler.post(new java.lang.Runnable() {
                        public void run() {
                            resultCallback.accept(java.lang.Boolean.valueOf(false));
                        }
                    });
                    return;
                }
                return;
            }
        }
        android.view.IRecentsAnimationRunner runner = null;
        if (animationHandler != null) {
            runner = new android.view.IRecentsAnimationRunner.Stub() {
                public void onAnimationStart(android.view.IRecentsAnimationController controller, android.view.RemoteAnimationTarget[] apps, android.graphics.Rect homeContentInsets, android.graphics.Rect minimizedHomeBounds) {
                    animationHandler.onAnimationStart(new com.android.systemui.shared.system.RecentsAnimationControllerCompat(controller), com.android.systemui.shared.system.RemoteAnimationTargetCompat.wrap(apps), homeContentInsets, minimizedHomeBounds);
                }

                public void onAnimationCanceled() {
                    animationHandler.onAnimationCanceled();
                }
            };
        }
        android.app.ActivityManager.getService().startRecentsActivity(intent, e, runner);
        if (resultCallback != null) {
            resultCallbackHandler.post(new java.lang.Runnable() {
                public void run() {
                    resultCallback.accept(java.lang.Boolean.valueOf(true));
                }
            });
        }
    }

    public void cancelRecentsAnimation(boolean restoreHomeStackPosition) {
        try {
            android.app.ActivityManager.getService().cancelRecentsAnimation(restoreHomeStackPosition);
        } catch (android.os.RemoteException e) {
            android.util.Log.e("ActivityManagerWrapper", "Failed to cancel recents animation", e);
        }
    }

    public void startActivityFromRecentsAsync(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityOptions options, java.util.function.Consumer<java.lang.Boolean> resultCallback, android.os.Handler resultCallbackHandler) {
        startActivityFromRecentsAsync(taskKey, options, 0, 0, resultCallback, resultCallbackHandler);
    }

    public void startActivityFromRecentsAsync(com.android.systemui.shared.recents.model.Task.TaskKey taskKey, android.app.ActivityOptions options, int windowingMode, int activityType, java.util.function.Consumer<java.lang.Boolean> resultCallback, android.os.Handler resultCallbackHandler) {
        if (taskKey.windowingMode == 3) {
            if (options == null) {
                options = android.app.ActivityOptions.makeBasic();
            }
            options.setLaunchWindowingMode(4);
        } else if (!(windowingMode == 0 && activityType == 0)) {
            if (options == null) {
                options = android.app.ActivityOptions.makeBasic();
            }
            options.setLaunchWindowingMode(windowingMode);
            options.setLaunchActivityType(activityType);
        }
        final android.app.ActivityOptions finalOptions = options;
        final com.android.systemui.shared.recents.model.Task.TaskKey taskKey2 = taskKey;
        final java.util.function.Consumer<java.lang.Boolean> consumer = resultCallback;
        final android.os.Handler handler = resultCallbackHandler;
        this.mBackgroundExecutor.submit(new java.lang.Runnable() {
            public void run() {
                boolean result = false;
                try {
                    result = com.android.systemui.shared.system.ActivityManagerWrapper.this.startActivityFromRecents(taskKey2.id, finalOptions);
                } catch (java.lang.Exception e) {
                }
                final boolean finalResult = result;
                if (consumer != null) {
                    handler.post(new java.lang.Runnable() {
                        public void run() {
                            consumer.accept(java.lang.Boolean.valueOf(finalResult));
                        }
                    });
                }
            }
        });
    }

    public boolean startActivityFromRecents(int taskId, android.app.ActivityOptions options) {
        android.os.Bundle optsBundle;
        if (options == null) {
            optsBundle = null;
        } else {
            try {
                optsBundle = options.toBundle();
            } catch (java.lang.Exception e) {
                return false;
            }
        }
        android.app.ActivityManager.getService().startActivityFromRecents(taskId, optsBundle);
        return true;
    }

    public void registerTaskStackListener(com.android.systemui.shared.system.TaskStackChangeListener listener) {
        synchronized (this.mTaskStackChangeListeners) {
            this.mTaskStackChangeListeners.addListener(android.app.ActivityManager.getService(), listener);
        }
    }

    public void unregisterTaskStackListener(com.android.systemui.shared.system.TaskStackChangeListener listener) {
        synchronized (this.mTaskStackChangeListeners) {
            this.mTaskStackChangeListeners.removeListener(listener);
        }
    }

    public void closeSystemWindows(final java.lang.String reason) {
        this.mBackgroundExecutor.submit(new java.lang.Runnable() {
            public void run() {
                try {
                    android.app.ActivityManager.getService().closeSystemDialogs(reason);
                } catch (android.os.RemoteException e) {
                    android.util.Log.w("ActivityManagerWrapper", "Failed to close system windows", e);
                }
            }
        });
    }

    public void removeTask(final int taskId) {
        this.mBackgroundExecutor.submit(new java.lang.Runnable() {
            public void run() {
                try {
                    android.app.ActivityManager.getService().removeTask(taskId);
                } catch (android.os.RemoteException e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Failed to remove task=");
                    stringBuilder.append(taskId);
                    android.util.Log.w("ActivityManagerWrapper", stringBuilder.toString(), e);
                }
            }
        });
    }

    public void cancelWindowTransition(int taskId) {
        try {
            android.app.ActivityManager.getService().cancelTaskWindowTransition(taskId);
        } catch (android.os.RemoteException e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Failed to cancel window transition for task=");
            stringBuilder.append(taskId);
            android.util.Log.w("ActivityManagerWrapper", stringBuilder.toString(), e);
        }
    }

    public boolean isScreenPinningActive() {
        boolean z = false;
        try {
            if (android.app.ActivityManager.getService().getLockTaskModeState() == 2) {
                z = true;
            }
            return z;
        } catch (android.os.RemoteException e) {
            return false;
        }
    }

    public boolean isScreenPinningEnabled() {
        return android.provider.Settings.System.getInt(android.app.AppGlobals.getInitialApplication().getContentResolver(), "lock_to_app_enabled", 0) != 0;
    }

    public boolean isLockToAppActive() {
        boolean z = false;
        try {
            if (android.app.ActivityManager.getService().getLockTaskModeState() != 0) {
                z = true;
            }
            return z;
        } catch (android.os.RemoteException e) {
            return false;
        }
    }

    public boolean showVoiceSession(android.os.IBinder token, android.os.Bundle args, int flags) {
        com.android.internal.app.IVoiceInteractionManagerService service = com.android.internal.app.IVoiceInteractionManagerService.Stub.asInterface(android.os.ServiceManager.getService("voiceinteraction"));
        if (service == null) {
            return false;
        }
        try {
            return service.showSessionFromSession(token, args, flags);
        } catch (android.os.RemoteException e) {
            return false;
        }
    }

    public void removeHwTask(final com.android.systemui.shared.recents.model.Task task) {
        this.mBackgroundExecutor.submit(new java.lang.Runnable() {
            public void run() {
                com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.sendRemoveTaskToSystemManager(com.android.systemui.shared.system.ActivityManagerWrapper.this.mContext, task);
            }
        });
    }

    public void removeHwAllTask() {
        this.mBackgroundExecutor.submit(new java.lang.Runnable() {
            public void run() {
                com.android.systemui.shared.recents.hwutil.HwRecentsTaskUtils.sendRemoveAllTask(com.android.systemui.shared.system.ActivityManagerWrapper.this.mContext);
            }
        });
    }

    public com.android.systemui.shared.recents.model.ThumbnailData getTaskThumbnailEx(boolean refresh) {
        com.huawei.android.view.HwTaskSnapshotWrapper wrapper = com.huawei.android.view.HwWindowManager.getForegroundTaskSnapshotWrapper(refresh);
        android.app.ActivityManager.TaskSnapshot snapshot = null;
        if (wrapper != null) {
            snapshot = wrapper.getTaskSnapshot();
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("getTaskThumbnailEx HwWindowManager snapshot =");
        stringBuilder.append(snapshot);
        stringBuilder.append(",refresh=");
        stringBuilder.append(refresh);
        android.util.Log.w("ActivityManagerWrapper", stringBuilder.toString());
        if (snapshot != null) {
            return new com.android.systemui.shared.recents.model.ThumbnailData(snapshot);
        }
        return new com.android.systemui.shared.recents.model.ThumbnailData();
    }
}
