package com.android.systemui.shared.system;

public class InputConsumerController {
    private static final java.lang.String TAG = com.android.systemui.shared.system.InputConsumerController.class.getSimpleName();
    private com.android.systemui.shared.system.InputConsumerController.InputEventReceiver mInputEventReceiver;
    private com.android.systemui.shared.system.InputConsumerController.TouchListener mListener;
    private final java.lang.String mName;
    private com.android.systemui.shared.system.InputConsumerController.RegistrationListener mRegistrationListener;
    private final android.os.IBinder mToken = new android.os.Binder();
    private final android.view.IWindowManager mWindowManager;

    private final class InputEventReceiver extends android.view.BatchedInputEventReceiver {
        public InputEventReceiver(android.view.InputChannel inputChannel, android.os.Looper looper) {
            super(inputChannel, looper, android.view.Choreographer.getSfInstance());
        }

        public void onInputEvent(android.view.InputEvent event, int displayId) {
            boolean handled = true;
            try {
                if (com.android.systemui.shared.system.InputConsumerController.this.mListener != null && (event instanceof android.view.MotionEvent)) {
                    handled = com.android.systemui.shared.system.InputConsumerController.this.mListener.onTouchEvent((android.view.MotionEvent) event);
                }
                finishInputEvent(event, handled);
            } catch (Throwable th) {
                finishInputEvent(event, true);
            }
        }
    }

    public interface RegistrationListener {
        void onRegistrationChanged(boolean z);
    }

    public interface TouchListener {
        boolean onTouchEvent(android.view.MotionEvent motionEvent);
    }

    public InputConsumerController(android.view.IWindowManager windowManager, java.lang.String name) {
        this.mWindowManager = windowManager;
        this.mName = name;
    }

    public static com.android.systemui.shared.system.InputConsumerController getPipInputConsumer() {
        return new com.android.systemui.shared.system.InputConsumerController(android.view.WindowManagerGlobal.getWindowManagerService(), "pip_input_consumer");
    }

    public static com.android.systemui.shared.system.InputConsumerController getRecentsAnimationInputConsumer() {
        return new com.android.systemui.shared.system.InputConsumerController(android.view.WindowManagerGlobal.getWindowManagerService(), "recents_animation_input_consumer");
    }

    public void setTouchListener(com.android.systemui.shared.system.InputConsumerController.TouchListener listener) {
        this.mListener = listener;
    }

    public void setRegistrationListener(com.android.systemui.shared.system.InputConsumerController.RegistrationListener listener) {
        this.mRegistrationListener = listener;
        if (this.mRegistrationListener != null) {
            this.mRegistrationListener.onRegistrationChanged(this.mInputEventReceiver != null);
        }
    }

    public boolean isRegistered() {
        return this.mInputEventReceiver != null;
    }

    public void registerInputConsumer() {
        if (this.mInputEventReceiver == null) {
            android.view.InputChannel inputChannel = new android.view.InputChannel();
            try {
                this.mWindowManager.destroyInputConsumer(this.mName);
                this.mWindowManager.createInputConsumer(this.mToken, this.mName, inputChannel);
            } catch (android.os.RemoteException e) {
                android.util.Log.e(TAG, "Failed to create input consumer", e);
            }
            this.mInputEventReceiver = new com.android.systemui.shared.system.InputConsumerController.InputEventReceiver(inputChannel, android.os.Looper.myLooper());
            if (this.mRegistrationListener != null) {
                this.mRegistrationListener.onRegistrationChanged(true);
            }
        }
    }

    public void unregisterInputConsumer() {
        if (this.mInputEventReceiver != null) {
            try {
                this.mWindowManager.destroyInputConsumer(this.mName);
            } catch (android.os.RemoteException e) {
                android.util.Log.e(TAG, "Failed to destroy input consumer", e);
            }
            this.mInputEventReceiver.dispose();
            this.mInputEventReceiver = null;
            if (this.mRegistrationListener != null) {
                this.mRegistrationListener.onRegistrationChanged(false);
            }
        }
    }

    public void dump(java.io.PrintWriter pw, java.lang.String prefix) {
        java.lang.String innerPrefix = new java.lang.StringBuilder();
        innerPrefix.append(prefix);
        innerPrefix.append("  ");
        innerPrefix = innerPrefix.toString();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(prefix);
        stringBuilder.append(TAG);
        pw.println(stringBuilder.toString());
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(innerPrefix);
        stringBuilder.append("registered=");
        stringBuilder.append(this.mInputEventReceiver != null);
        pw.println(stringBuilder.toString());
    }
}
