package com.android.systemui.shared.system;

public class RecentsAnimationControllerCompat {
    private static final java.lang.String TAG = com.android.systemui.shared.system.RecentsAnimationControllerCompat.class.getSimpleName();
    private android.view.IRecentsAnimationController mAnimationController;

    public RecentsAnimationControllerCompat(android.view.IRecentsAnimationController animationController) {
        this.mAnimationController = animationController;
    }

    public com.android.systemui.shared.recents.model.ThumbnailData screenshotTask(int taskId) {
        try {
            android.app.ActivityManager.TaskSnapshot snapshot = this.mAnimationController.screenshotTask(taskId);
            return snapshot != null ? new com.android.systemui.shared.recents.model.ThumbnailData(snapshot) : new com.android.systemui.shared.recents.model.ThumbnailData();
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to screenshot task", e);
            return new com.android.systemui.shared.recents.model.ThumbnailData();
        }
    }

    public void setInputConsumerEnabled(boolean enabled) {
        try {
            this.mAnimationController.setInputConsumerEnabled(enabled);
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to set input consumer enabled state", e);
        }
    }

    public void setAnimationTargetsBehindSystemBars(boolean behindSystemBars) {
        try {
            this.mAnimationController.setAnimationTargetsBehindSystemBars(behindSystemBars);
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to set whether animation targets are behind system bars", e);
        }
    }

    public void setSplitScreenMinimized(boolean minimized) {
        try {
            this.mAnimationController.setSplitScreenMinimized(minimized);
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to set minimize dock", e);
        }
    }

    public void hideCurrentInputMethod() {
        try {
            this.mAnimationController.hideCurrentInputMethod();
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to set hide input method", e);
        }
    }

    public void finish(boolean toHome) {
        try {
            this.mAnimationController.finish(toHome);
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "Failed to finish recents animation", e);
        }
    }
}
