package com.android.systemui.shared.system;

public abstract class RotationWatcher {
    private static final java.lang.String TAG = "RotationWatcher";
    private final android.content.Context mContext;
    private boolean mIsWatching = false;
    private final android.view.IRotationWatcher mWatcher = new android.view.IRotationWatcher.Stub() {
        public void onRotationChanged(int rotation) {
            com.android.systemui.shared.system.RotationWatcher.this.onRotationChanged(rotation);
        }
    };

    protected abstract void onRotationChanged(int i);

    public RotationWatcher(android.content.Context context) {
        this.mContext = context;
    }

    public void enable() {
        if (!this.mIsWatching) {
            try {
                android.view.WindowManagerGlobal.getWindowManagerService().watchRotation(this.mWatcher, this.mContext.getDisplay().getDisplayId());
                this.mIsWatching = true;
            } catch (android.os.RemoteException e) {
                android.util.Log.w("RotationWatcher", "Failed to set rotation watcher", e);
            }
        }
    }

    public void disable() {
        if (this.mIsWatching) {
            try {
                android.view.WindowManagerGlobal.getWindowManagerService().removeRotationWatcher(this.mWatcher);
                this.mIsWatching = false;
            } catch (android.os.RemoteException e) {
                android.util.Log.w("RotationWatcher", "Failed to remove rotation watcher", e);
            }
        }
    }
}
