package com.android.systemui.shared.system;

public class WindowCallbacksCompat {
    private final android.view.View mView;
    private final android.view.WindowCallbacks mWindowCallbacks = new android.view.WindowCallbacks() {
        public void onWindowSizeIsChanging(android.graphics.Rect newBounds, boolean fullscreen, android.graphics.Rect systemInsets, android.graphics.Rect stableInsets) {
            com.android.systemui.shared.system.WindowCallbacksCompat.this.onWindowSizeIsChanging(newBounds, fullscreen, systemInsets, stableInsets);
        }

        public void onWindowDragResizeStart(android.graphics.Rect initialBounds, boolean fullscreen, android.graphics.Rect systemInsets, android.graphics.Rect stableInsets, int resizeMode) {
            com.android.systemui.shared.system.WindowCallbacksCompat.this.onWindowDragResizeStart(initialBounds, fullscreen, systemInsets, stableInsets, resizeMode);
        }

        public void onWindowDragResizeEnd() {
            com.android.systemui.shared.system.WindowCallbacksCompat.this.onWindowDragResizeEnd();
        }

        public boolean onContentDrawn(int offsetX, int offsetY, int sizeX, int sizeY) {
            return com.android.systemui.shared.system.WindowCallbacksCompat.this.onContentDrawn(offsetX, offsetY, sizeX, sizeY);
        }

        public void onRequestDraw(boolean reportNextDraw) {
            com.android.systemui.shared.system.WindowCallbacksCompat.this.onRequestDraw(reportNextDraw);
        }

        public void onPostDraw(android.view.DisplayListCanvas canvas) {
            com.android.systemui.shared.system.WindowCallbacksCompat.this.onPostDraw(canvas);
        }
    };

    public WindowCallbacksCompat(android.view.View view) {
        this.mView = view;
    }

    public void onWindowSizeIsChanging(android.graphics.Rect newBounds, boolean fullscreen, android.graphics.Rect systemInsets, android.graphics.Rect stableInsets) {
    }

    public void onWindowDragResizeStart(android.graphics.Rect initialBounds, boolean fullscreen, android.graphics.Rect systemInsets, android.graphics.Rect stableInsets, int resizeMode) {
    }

    public void onWindowDragResizeEnd() {
    }

    public boolean onContentDrawn(int offsetX, int offsetY, int sizeX, int sizeY) {
        return false;
    }

    public void onRequestDraw(boolean reportNextDraw) {
        if (reportNextDraw) {
            reportDrawFinish();
        }
    }

    public void onPostDraw(android.graphics.Canvas canvas) {
    }

    public void reportDrawFinish() {
        this.mView.getViewRootImpl().reportDrawFinish();
    }

    public boolean attach() {
        android.view.ViewRootImpl root = this.mView.getViewRootImpl();
        if (root == null) {
            return false;
        }
        root.addWindowCallbacks(this.mWindowCallbacks);
        root.requestInvalidateRootRenderNode();
        return true;
    }

    public void detach() {
        android.view.ViewRootImpl root = this.mView.getViewRootImpl();
        if (root != null) {
            root.removeWindowCallbacks(this.mWindowCallbacks);
        }
    }
}
