package com.google.gson;

final class DefaultDateTypeAdapter extends com.google.gson.TypeAdapter<java.util.Date> {
    private static final java.lang.String SIMPLE_NAME = "DefaultDateTypeAdapter";
    private final java.lang.Class<? extends java.util.Date> dateType;
    private final java.text.DateFormat enUsFormat;
    private final java.text.DateFormat localFormat;

    DefaultDateTypeAdapter(java.lang.Class<? extends java.util.Date> dateType) {
        this((java.lang.Class) dateType, java.text.DateFormat.getDateTimeInstance(2, 2, java.util.Locale.US), java.text.DateFormat.getDateTimeInstance(2, 2));
    }

    DefaultDateTypeAdapter(java.lang.Class<? extends java.util.Date> dateType, java.lang.String datePattern) {
        this((java.lang.Class) dateType, new java.text.SimpleDateFormat(datePattern, java.util.Locale.US), new java.text.SimpleDateFormat(datePattern));
    }

    DefaultDateTypeAdapter(java.lang.Class<? extends java.util.Date> dateType, int style) {
        this((java.lang.Class) dateType, java.text.DateFormat.getDateInstance(style, java.util.Locale.US), java.text.DateFormat.getDateInstance(style));
    }

    public DefaultDateTypeAdapter(int dateStyle, int timeStyle) {
        this(java.util.Date.class, java.text.DateFormat.getDateTimeInstance(dateStyle, timeStyle, java.util.Locale.US), java.text.DateFormat.getDateTimeInstance(dateStyle, timeStyle));
    }

    public DefaultDateTypeAdapter(java.lang.Class<? extends java.util.Date> dateType, int dateStyle, int timeStyle) {
        this((java.lang.Class) dateType, java.text.DateFormat.getDateTimeInstance(dateStyle, timeStyle, java.util.Locale.US), java.text.DateFormat.getDateTimeInstance(dateStyle, timeStyle));
    }

    DefaultDateTypeAdapter(java.lang.Class<? extends java.util.Date> dateType, java.text.DateFormat enUsFormat, java.text.DateFormat localFormat) {
        if (!(dateType == java.util.Date.class || dateType == java.sql.Date.class)) {
            if (dateType != java.sql.Timestamp.class) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Date type must be one of ");
                stringBuilder.append(java.util.Date.class);
                stringBuilder.append(", ");
                stringBuilder.append(java.sql.Timestamp.class);
                stringBuilder.append(", or ");
                stringBuilder.append(java.sql.Date.class);
                stringBuilder.append(" but was ");
                stringBuilder.append(dateType);
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        this.dateType = dateType;
        this.enUsFormat = enUsFormat;
        this.localFormat = localFormat;
    }

    public void write(com.google.gson.stream.JsonWriter out, java.util.Date value) throws java.io.IOException {
        if (value == null) {
            out.nullValue();
            return;
        }
        synchronized (this.localFormat) {
            out.value(this.enUsFormat.format(value));
        }
    }

    public java.util.Date read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
        if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
            in.nextNull();
            return null;
        }
        java.util.Date date = deserializeToDate(in.nextString());
        if (this.dateType == java.util.Date.class) {
            return date;
        }
        if (this.dateType == java.sql.Timestamp.class) {
            return new java.sql.Timestamp(date.getTime());
        }
        if (this.dateType == java.sql.Date.class) {
            return new java.sql.Date(date.getTime());
        }
        throw new java.lang.AssertionError();
    }

    private java.util.Date deserializeToDate(java.lang.String s) {
        java.util.Date parse;
        synchronized (this.localFormat) {
            try {
                parse = this.localFormat.parse(s);
            } catch (java.text.ParseException e) {
                try {
                    return this.enUsFormat.parse(s);
                } catch (java.text.ParseException e2) {
                    throw new com.google.gson.JsonSyntaxException(s, e2);
                } catch (java.text.ParseException e3) {
                    return com.google.gson.internal.bind.util.ISO8601Utils.parse(s, new java.text.ParsePosition(0));
                }
            }
        }
        return parse;
    }

    public java.lang.String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("DefaultDateTypeAdapter");
        sb.append('(');
        sb.append(this.localFormat.getClass().getSimpleName());
        sb.append(')');
        return sb.toString();
    }
}
