package com.google.gson;

public enum FieldNamingPolicy implements com.google.gson.FieldNamingStrategy {
    IDENTITY {
        public java.lang.String translateName(java.lang.reflect.Field f) {
            return f.getName();
        }
    },
    UPPER_CAMEL_CASE {
        public java.lang.String translateName(java.lang.reflect.Field f) {
            return com.google.gson.FieldNamingPolicy.upperCaseFirstLetter(f.getName());
        }
    },
    UPPER_CAMEL_CASE_WITH_SPACES {
        public java.lang.String translateName(java.lang.reflect.Field f) {
            return com.google.gson.FieldNamingPolicy.upperCaseFirstLetter(com.google.gson.FieldNamingPolicy.separateCamelCase(f.getName(), " "));
        }
    },
    LOWER_CASE_WITH_UNDERSCORES {
        public java.lang.String translateName(java.lang.reflect.Field f) {
            return com.google.gson.FieldNamingPolicy.separateCamelCase(f.getName(), "_").toLowerCase(java.util.Locale.ENGLISH);
        }
    },
    LOWER_CASE_WITH_DASHES {
        public java.lang.String translateName(java.lang.reflect.Field f) {
            return com.google.gson.FieldNamingPolicy.separateCamelCase(f.getName(), "-").toLowerCase(java.util.Locale.ENGLISH);
        }
    };

    static java.lang.String separateCamelCase(java.lang.String name, java.lang.String separator) {
        java.lang.StringBuilder translation = new java.lang.StringBuilder();
        int length = name.length();
        for (int i = 0; i < length; i++) {
            char character = name.charAt(i);
            if (java.lang.Character.isUpperCase(character) && translation.length() != 0) {
                translation.append(separator);
            }
            translation.append(character);
        }
        return translation.toString();
    }

    static java.lang.String upperCaseFirstLetter(java.lang.String name) {
        java.lang.StringBuilder fieldNameBuilder = new java.lang.StringBuilder();
        int index = 0;
        char firstCharacter = name.charAt(0);
        int length = name.length();
        while (index < length - 1) {
            if (java.lang.Character.isLetter(firstCharacter)) {
                break;
            }
            fieldNameBuilder.append(firstCharacter);
            index++;
            firstCharacter = name.charAt(index);
        }
        if (java.lang.Character.isUpperCase(firstCharacter)) {
            return name;
        }
        fieldNameBuilder.append(modifyString(java.lang.Character.toUpperCase(firstCharacter), name, index + 1));
        return fieldNameBuilder.toString();
    }

    private static java.lang.String modifyString(char firstCharacter, java.lang.String srcString, int indexOfSubstring) {
        if (indexOfSubstring >= srcString.length()) {
            return java.lang.String.valueOf(firstCharacter);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(firstCharacter);
        stringBuilder.append(srcString.substring(indexOfSubstring));
        return stringBuilder.toString();
    }
}
