package com.google.gson;

public final class Gson {
    static final boolean DEFAULT_COMPLEX_MAP_KEYS = false;
    static final boolean DEFAULT_ESCAPE_HTML = true;
    static final boolean DEFAULT_JSON_NON_EXECUTABLE = false;
    static final boolean DEFAULT_LENIENT = false;
    static final boolean DEFAULT_PRETTY_PRINT = false;
    static final boolean DEFAULT_SERIALIZE_NULLS = false;
    static final boolean DEFAULT_SPECIALIZE_FLOAT_VALUES = false;
    private static final java.lang.String JSON_NON_EXECUTABLE_PREFIX = ")]}'\n";
    private static final com.google.gson.reflect.TypeToken<?> NULL_KEY_SURROGATE = com.google.gson.reflect.TypeToken.get(java.lang.Object.class);
    private final java.lang.ThreadLocal<java.util.Map<com.google.gson.reflect.TypeToken<?>, com.google.gson.Gson.FutureTypeAdapter<?>>> calls;
    private final com.google.gson.internal.ConstructorConstructor constructorConstructor;
    private final com.google.gson.internal.Excluder excluder;
    private final java.util.List<com.google.gson.TypeAdapterFactory> factories;
    private final com.google.gson.FieldNamingStrategy fieldNamingStrategy;
    private final boolean generateNonExecutableJson;
    private final boolean htmlSafe;
    private final com.google.gson.internal.bind.JsonAdapterAnnotationTypeAdapterFactory jsonAdapterFactory;
    private final boolean lenient;
    private final boolean prettyPrinting;
    private final boolean serializeNulls;
    private final java.util.Map<com.google.gson.reflect.TypeToken<?>, com.google.gson.TypeAdapter<?>> typeTokenCache;

    static class FutureTypeAdapter<T> extends com.google.gson.TypeAdapter<T> {
        private com.google.gson.TypeAdapter<T> delegate;

        FutureTypeAdapter() {
        }

        public void setDelegate(com.google.gson.TypeAdapter<T> typeAdapter) {
            if (this.delegate == null) {
                this.delegate = typeAdapter;
                return;
            }
            throw new java.lang.AssertionError();
        }

        public T read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (this.delegate != null) {
                return this.delegate.read(in);
            }
            throw new java.lang.IllegalStateException();
        }

        public void write(com.google.gson.stream.JsonWriter out, T value) throws java.io.IOException {
            if (this.delegate != null) {
                this.delegate.write(out, value);
                return;
            }
            throw new java.lang.IllegalStateException();
        }
    }

    public Gson() {
        this(com.google.gson.internal.Excluder.DEFAULT, com.google.gson.FieldNamingPolicy.IDENTITY, java.util.Collections.emptyMap(), false, false, false, true, false, false, false, com.google.gson.LongSerializationPolicy.DEFAULT, java.util.Collections.emptyList());
    }

    Gson(com.google.gson.internal.Excluder excluder, com.google.gson.FieldNamingStrategy fieldNamingStrategy, java.util.Map<java.lang.reflect.Type, com.google.gson.InstanceCreator<?>> instanceCreators, boolean serializeNulls, boolean complexMapKeySerialization, boolean generateNonExecutableGson, boolean htmlSafe, boolean prettyPrinting, boolean lenient, boolean serializeSpecialFloatingPointValues, com.google.gson.LongSerializationPolicy longSerializationPolicy, java.util.List<com.google.gson.TypeAdapterFactory> typeAdapterFactories) {
        com.google.gson.internal.Excluder excluder2 = excluder;
        com.google.gson.FieldNamingStrategy fieldNamingStrategy2 = fieldNamingStrategy;
        boolean z = serializeSpecialFloatingPointValues;
        this.calls = new java.lang.ThreadLocal();
        this.typeTokenCache = new java.util.concurrent.ConcurrentHashMap();
        this.constructorConstructor = new com.google.gson.internal.ConstructorConstructor(instanceCreators);
        this.excluder = excluder2;
        this.fieldNamingStrategy = fieldNamingStrategy2;
        this.serializeNulls = serializeNulls;
        this.generateNonExecutableJson = generateNonExecutableGson;
        this.htmlSafe = htmlSafe;
        this.prettyPrinting = prettyPrinting;
        this.lenient = lenient;
        java.util.List<com.google.gson.TypeAdapterFactory> factories = new java.util.ArrayList();
        factories.add(com.google.gson.internal.bind.TypeAdapters.JSON_ELEMENT_FACTORY);
        factories.add(com.google.gson.internal.bind.ObjectTypeAdapter.FACTORY);
        factories.add(excluder2);
        factories.addAll(typeAdapterFactories);
        factories.add(com.google.gson.internal.bind.TypeAdapters.STRING_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.INTEGER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.BOOLEAN_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.BYTE_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.SHORT_FACTORY);
        com.google.gson.TypeAdapter<java.lang.Number> longAdapter = longAdapter(longSerializationPolicy);
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.lang.Long.TYPE, java.lang.Long.class, longAdapter));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.lang.Double.TYPE, java.lang.Double.class, doubleAdapter(z)));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.lang.Float.TYPE, java.lang.Float.class, floatAdapter(z)));
        factories.add(com.google.gson.internal.bind.TypeAdapters.NUMBER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.ATOMIC_INTEGER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.ATOMIC_BOOLEAN_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.util.concurrent.atomic.AtomicLong.class, atomicLongAdapter(longAdapter)));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.util.concurrent.atomic.AtomicLongArray.class, atomicLongArrayAdapter(longAdapter)));
        factories.add(com.google.gson.internal.bind.TypeAdapters.ATOMIC_INTEGER_ARRAY_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.CHARACTER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.STRING_BUILDER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.STRING_BUFFER_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.math.BigDecimal.class, com.google.gson.internal.bind.TypeAdapters.BIG_DECIMAL));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.math.BigInteger.class, com.google.gson.internal.bind.TypeAdapters.BIG_INTEGER));
        factories.add(com.google.gson.internal.bind.TypeAdapters.URL_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.URI_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.UUID_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.CURRENCY_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.LOCALE_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.INET_ADDRESS_FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.BIT_SET_FACTORY);
        factories.add(com.google.gson.internal.bind.DateTypeAdapter.FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.CALENDAR_FACTORY);
        factories.add(com.google.gson.internal.bind.TimeTypeAdapter.FACTORY);
        factories.add(com.google.gson.internal.bind.SqlDateTypeAdapter.FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.TIMESTAMP_FACTORY);
        factories.add(com.google.gson.internal.bind.ArrayTypeAdapter.FACTORY);
        factories.add(com.google.gson.internal.bind.TypeAdapters.CLASS_FACTORY);
        factories.add(new com.google.gson.internal.bind.CollectionTypeAdapterFactory(this.constructorConstructor));
        factories.add(new com.google.gson.internal.bind.MapTypeAdapterFactory(this.constructorConstructor, complexMapKeySerialization));
        this.jsonAdapterFactory = new com.google.gson.internal.bind.JsonAdapterAnnotationTypeAdapterFactory(this.constructorConstructor);
        factories.add(this.jsonAdapterFactory);
        factories.add(com.google.gson.internal.bind.TypeAdapters.ENUM_FACTORY);
        factories.add(new com.google.gson.internal.bind.ReflectiveTypeAdapterFactory(this.constructorConstructor, fieldNamingStrategy2, excluder2, this.jsonAdapterFactory));
        this.factories = java.util.Collections.unmodifiableList(factories);
    }

    public com.google.gson.internal.Excluder excluder() {
        return this.excluder;
    }

    public com.google.gson.FieldNamingStrategy fieldNamingStrategy() {
        return this.fieldNamingStrategy;
    }

    public boolean serializeNulls() {
        return this.serializeNulls;
    }

    public boolean htmlSafe() {
        return this.htmlSafe;
    }

    private com.google.gson.TypeAdapter<java.lang.Number> doubleAdapter(boolean serializeSpecialFloatingPointValues) {
        if (serializeSpecialFloatingPointValues) {
            return com.google.gson.internal.bind.TypeAdapters.DOUBLE;
        }
        return new com.google.gson.TypeAdapter<java.lang.Number>() {
            public java.lang.Double read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                    return java.lang.Double.valueOf(in.nextDouble());
                }
                in.nextNull();
                return null;
            }

            public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
                if (value == null) {
                    out.nullValue();
                    return;
                }
                com.google.gson.Gson.checkValidFloatingPoint(value.doubleValue());
                out.value(value);
            }
        };
    }

    private com.google.gson.TypeAdapter<java.lang.Number> floatAdapter(boolean serializeSpecialFloatingPointValues) {
        if (serializeSpecialFloatingPointValues) {
            return com.google.gson.internal.bind.TypeAdapters.FLOAT;
        }
        return new com.google.gson.TypeAdapter<java.lang.Number>() {
            public java.lang.Float read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                    return java.lang.Float.valueOf((float) in.nextDouble());
                }
                in.nextNull();
                return null;
            }

            public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
                if (value == null) {
                    out.nullValue();
                    return;
                }
                com.google.gson.Gson.checkValidFloatingPoint((double) value.floatValue());
                out.value(value);
            }
        };
    }

    static void checkValidFloatingPoint(double value) {
        if (java.lang.Double.isNaN(value) || java.lang.Double.isInfinite(value)) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(value);
            stringBuilder.append(" is not a valid double value as per JSON specification. To override this behavior, use GsonBuilder.serializeSpecialFloatingPointValues() method.");
            throw new java.lang.IllegalArgumentException(stringBuilder.toString());
        }
    }

    private static com.google.gson.TypeAdapter<java.lang.Number> longAdapter(com.google.gson.LongSerializationPolicy longSerializationPolicy) {
        if (longSerializationPolicy == com.google.gson.LongSerializationPolicy.DEFAULT) {
            return com.google.gson.internal.bind.TypeAdapters.LONG;
        }
        return new com.google.gson.TypeAdapter<java.lang.Number>() {
            public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                    return java.lang.Long.valueOf(in.nextLong());
                }
                in.nextNull();
                return null;
            }

            public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
                if (value == null) {
                    out.nullValue();
                } else {
                    out.value(value.toString());
                }
            }
        };
    }

    private static com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicLong> atomicLongAdapter(final com.google.gson.TypeAdapter<java.lang.Number> longAdapter) {
        return new com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicLong>() {
            public void write(com.google.gson.stream.JsonWriter out, java.util.concurrent.atomic.AtomicLong value) throws java.io.IOException {
                longAdapter.write(out, java.lang.Long.valueOf(value.get()));
            }

            public java.util.concurrent.atomic.AtomicLong read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                return new java.util.concurrent.atomic.AtomicLong(((java.lang.Number) longAdapter.read(in)).longValue());
            }
        }.nullSafe();
    }

    private static com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicLongArray> atomicLongArrayAdapter(final com.google.gson.TypeAdapter<java.lang.Number> longAdapter) {
        return new com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicLongArray>() {
            public void write(com.google.gson.stream.JsonWriter out, java.util.concurrent.atomic.AtomicLongArray value) throws java.io.IOException {
                out.beginArray();
                int length = value.length();
                for (int i = 0; i < length; i++) {
                    longAdapter.write(out, java.lang.Long.valueOf(value.get(i)));
                }
                out.endArray();
            }

            public java.util.concurrent.atomic.AtomicLongArray read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                java.util.List<java.lang.Long> list = new java.util.ArrayList();
                in.beginArray();
                while (in.hasNext()) {
                    list.add(java.lang.Long.valueOf(((java.lang.Number) longAdapter.read(in)).longValue()));
                }
                in.endArray();
                int length = list.size();
                java.util.concurrent.atomic.AtomicLongArray array = new java.util.concurrent.atomic.AtomicLongArray(length);
                for (int i = 0; i < length; i++) {
                    array.set(i, ((java.lang.Long) list.get(i)).longValue());
                }
                return array;
            }
        }.nullSafe();
    }

    public <T> com.google.gson.TypeAdapter<T> getAdapter(com.google.gson.reflect.TypeToken<T> type) {
        com.google.gson.TypeAdapter<?> cached = (com.google.gson.TypeAdapter) this.typeTokenCache.get(type == null ? NULL_KEY_SURROGATE : type);
        if (cached != null) {
            return cached;
        }
        java.util.Map<com.google.gson.reflect.TypeToken<?>, com.google.gson.Gson.FutureTypeAdapter<?>> threadCalls = (java.util.Map) this.calls.get();
        boolean requiresThreadLocalCleanup = false;
        if (threadCalls == null) {
            threadCalls = new java.util.HashMap();
            this.calls.set(threadCalls);
            requiresThreadLocalCleanup = true;
        }
        com.google.gson.Gson.FutureTypeAdapter<T> ongoingCall = (com.google.gson.Gson.FutureTypeAdapter) threadCalls.get(type);
        if (ongoingCall != null) {
            return ongoingCall;
        }
        try {
            com.google.gson.Gson.FutureTypeAdapter<T> call = new com.google.gson.Gson.FutureTypeAdapter();
            threadCalls.put(type, call);
            for (com.google.gson.TypeAdapterFactory factory : this.factories) {
                com.google.gson.TypeAdapter<T> candidate = factory.create(this, type);
                if (candidate != null) {
                    call.setDelegate(candidate);
                    this.typeTokenCache.put(type, candidate);
                    return candidate;
                }
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("GSON cannot handle ");
            stringBuilder.append(type);
            throw new java.lang.IllegalArgumentException(stringBuilder.toString());
        } finally {
            threadCalls.remove(type);
            if (requiresThreadLocalCleanup) {
                this.calls.remove();
            }
        }
    }

    public <T> com.google.gson.TypeAdapter<T> getDelegateAdapter(com.google.gson.TypeAdapterFactory skipPast, com.google.gson.reflect.TypeToken<T> type) {
        if (!this.factories.contains(skipPast)) {
            skipPast = this.jsonAdapterFactory;
        }
        boolean skipPastFound = false;
        for (com.google.gson.TypeAdapterFactory factory : this.factories) {
            if (skipPastFound) {
                com.google.gson.TypeAdapter<T> candidate = factory.create(this, type);
                if (candidate != null) {
                    return candidate;
                }
            } else if (factory == skipPast) {
                skipPastFound = true;
            }
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("GSON cannot serialize ");
        stringBuilder.append(type);
        throw new java.lang.IllegalArgumentException(stringBuilder.toString());
    }

    public <T> com.google.gson.TypeAdapter<T> getAdapter(java.lang.Class<T> type) {
        return getAdapter(com.google.gson.reflect.TypeToken.get((java.lang.Class) type));
    }

    public com.google.gson.JsonElement toJsonTree(java.lang.Object src) {
        if (src == null) {
            return com.google.gson.JsonNull.INSTANCE;
        }
        return toJsonTree(src, src.getClass());
    }

    public com.google.gson.JsonElement toJsonTree(java.lang.Object src, java.lang.reflect.Type typeOfSrc) {
        com.google.gson.stream.JsonWriter writer = new com.google.gson.internal.bind.JsonTreeWriter();
        toJson(src, typeOfSrc, writer);
        return writer.get();
    }

    public java.lang.String toJson(java.lang.Object src) {
        if (src == null) {
            return toJson(com.google.gson.JsonNull.INSTANCE);
        }
        return toJson(src, src.getClass());
    }

    public java.lang.String toJson(java.lang.Object src, java.lang.reflect.Type typeOfSrc) {
        java.lang.Appendable writer = new java.io.StringWriter();
        toJson(src, typeOfSrc, writer);
        return writer.toString();
    }

    public void toJson(java.lang.Object src, java.lang.Appendable writer) throws com.google.gson.JsonIOException {
        if (src != null) {
            toJson(src, src.getClass(), writer);
        } else {
            toJson(com.google.gson.JsonNull.INSTANCE, writer);
        }
    }

    public void toJson(java.lang.Object src, java.lang.reflect.Type typeOfSrc, java.lang.Appendable writer) throws com.google.gson.JsonIOException {
        try {
            toJson(src, typeOfSrc, newJsonWriter(com.google.gson.internal.Streams.writerForAppendable(writer)));
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        }
    }

    public void toJson(java.lang.Object src, java.lang.reflect.Type typeOfSrc, com.google.gson.stream.JsonWriter writer) throws com.google.gson.JsonIOException {
        com.google.gson.TypeAdapter<?> adapter = getAdapter(com.google.gson.reflect.TypeToken.get(typeOfSrc));
        boolean oldLenient = writer.isLenient();
        writer.setLenient(true);
        boolean oldHtmlSafe = writer.isHtmlSafe();
        writer.setHtmlSafe(this.htmlSafe);
        boolean oldSerializeNulls = writer.getSerializeNulls();
        writer.setSerializeNulls(this.serializeNulls);
        try {
            adapter.write(writer, src);
            writer.setLenient(oldLenient);
            writer.setHtmlSafe(oldHtmlSafe);
            writer.setSerializeNulls(oldSerializeNulls);
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        } catch (Throwable th) {
            writer.setLenient(oldLenient);
            writer.setHtmlSafe(oldHtmlSafe);
            writer.setSerializeNulls(oldSerializeNulls);
        }
    }

    public java.lang.String toJson(com.google.gson.JsonElement jsonElement) {
        java.lang.Appendable writer = new java.io.StringWriter();
        toJson(jsonElement, writer);
        return writer.toString();
    }

    public void toJson(com.google.gson.JsonElement jsonElement, java.lang.Appendable writer) throws com.google.gson.JsonIOException {
        try {
            toJson(jsonElement, newJsonWriter(com.google.gson.internal.Streams.writerForAppendable(writer)));
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        }
    }

    public com.google.gson.stream.JsonWriter newJsonWriter(java.io.Writer writer) throws java.io.IOException {
        if (this.generateNonExecutableJson) {
            writer.write(")]}'\n");
        }
        com.google.gson.stream.JsonWriter jsonWriter = new com.google.gson.stream.JsonWriter(writer);
        if (this.prettyPrinting) {
            jsonWriter.setIndent("  ");
        }
        jsonWriter.setSerializeNulls(this.serializeNulls);
        return jsonWriter;
    }

    public com.google.gson.stream.JsonReader newJsonReader(java.io.Reader reader) {
        com.google.gson.stream.JsonReader jsonReader = new com.google.gson.stream.JsonReader(reader);
        jsonReader.setLenient(this.lenient);
        return jsonReader;
    }

    public void toJson(com.google.gson.JsonElement jsonElement, com.google.gson.stream.JsonWriter writer) throws com.google.gson.JsonIOException {
        boolean oldLenient = writer.isLenient();
        writer.setLenient(true);
        boolean oldHtmlSafe = writer.isHtmlSafe();
        writer.setHtmlSafe(this.htmlSafe);
        boolean oldSerializeNulls = writer.getSerializeNulls();
        writer.setSerializeNulls(this.serializeNulls);
        try {
            com.google.gson.internal.Streams.write(jsonElement, writer);
            writer.setLenient(oldLenient);
            writer.setHtmlSafe(oldHtmlSafe);
            writer.setSerializeNulls(oldSerializeNulls);
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        } catch (Throwable th) {
            writer.setLenient(oldLenient);
            writer.setHtmlSafe(oldHtmlSafe);
            writer.setSerializeNulls(oldSerializeNulls);
        }
    }

    public <T> T fromJson(java.lang.String json, java.lang.Class<T> classOfT) throws com.google.gson.JsonSyntaxException {
        return com.google.gson.internal.Primitives.wrap(classOfT).cast(fromJson(json, (java.lang.reflect.Type) classOfT));
    }

    public <T> T fromJson(java.lang.String json, java.lang.reflect.Type typeOfT) throws com.google.gson.JsonSyntaxException {
        if (json == null) {
            return null;
        }
        return fromJson(new java.io.StringReader(json), typeOfT);
    }

    public <T> T fromJson(java.io.Reader json, java.lang.Class<T> classOfT) throws com.google.gson.JsonSyntaxException, com.google.gson.JsonIOException {
        com.google.gson.stream.JsonReader jsonReader = newJsonReader(json);
        java.lang.Object object = fromJson(jsonReader, (java.lang.reflect.Type) classOfT);
        assertFullConsumption(object, jsonReader);
        return com.google.gson.internal.Primitives.wrap(classOfT).cast(object);
    }

    public <T> T fromJson(java.io.Reader json, java.lang.reflect.Type typeOfT) throws com.google.gson.JsonIOException, com.google.gson.JsonSyntaxException {
        com.google.gson.stream.JsonReader jsonReader = newJsonReader(json);
        T object = fromJson(jsonReader, typeOfT);
        assertFullConsumption(object, jsonReader);
        return object;
    }

    private static void assertFullConsumption(java.lang.Object obj, com.google.gson.stream.JsonReader reader) {
        if (obj != null) {
            try {
                if (reader.peek() != com.google.gson.stream.JsonToken.END_DOCUMENT) {
                    throw new com.google.gson.JsonIOException("JSON document was not fully consumed.");
                }
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            } catch (java.lang.Throwable e2) {
                throw new com.google.gson.JsonIOException(e2);
            }
        }
    }

    public <T> T fromJson(com.google.gson.stream.JsonReader reader, java.lang.reflect.Type typeOfT) throws com.google.gson.JsonIOException, com.google.gson.JsonSyntaxException {
        boolean isEmpty = true;
        boolean oldLenient = reader.isLenient();
        reader.setLenient(true);
        try {
            reader.peek();
            isEmpty = false;
            T object = getAdapter(com.google.gson.reflect.TypeToken.get(typeOfT)).read(reader);
            reader.setLenient(oldLenient);
            return object;
        } catch (java.lang.Throwable e) {
            if (isEmpty) {
                reader.setLenient(oldLenient);
                return null;
            }
            throw new com.google.gson.JsonSyntaxException(e);
        } catch (java.lang.Throwable e2) {
            throw new com.google.gson.JsonSyntaxException(e2);
        } catch (java.lang.Throwable e22) {
            throw new com.google.gson.JsonSyntaxException(e22);
        } catch (Throwable th) {
            reader.setLenient(oldLenient);
        }
    }

    public <T> T fromJson(com.google.gson.JsonElement json, java.lang.Class<T> classOfT) throws com.google.gson.JsonSyntaxException {
        return com.google.gson.internal.Primitives.wrap(classOfT).cast(fromJson(json, (java.lang.reflect.Type) classOfT));
    }

    public <T> T fromJson(com.google.gson.JsonElement json, java.lang.reflect.Type typeOfT) throws com.google.gson.JsonSyntaxException {
        if (json == null) {
            return null;
        }
        return fromJson(new com.google.gson.internal.bind.JsonTreeReader(json), typeOfT);
    }

    public java.lang.String toString() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder("{serializeNulls:");
        stringBuilder.append(this.serializeNulls);
        stringBuilder.append(",factories:");
        stringBuilder.append(this.factories);
        stringBuilder.append(",instanceCreators:");
        stringBuilder.append(this.constructorConstructor);
        stringBuilder.append("}");
        return stringBuilder.toString();
    }
}
