package com.google.gson;

public final class GsonBuilder {
    private boolean complexMapKeySerialization = false;
    private java.lang.String datePattern;
    private int dateStyle = 2;
    private boolean escapeHtmlChars = true;
    private com.google.gson.internal.Excluder excluder = com.google.gson.internal.Excluder.DEFAULT;
    private final java.util.List<com.google.gson.TypeAdapterFactory> factories = new java.util.ArrayList();
    private com.google.gson.FieldNamingStrategy fieldNamingPolicy = com.google.gson.FieldNamingPolicy.IDENTITY;
    private boolean generateNonExecutableJson = false;
    private final java.util.List<com.google.gson.TypeAdapterFactory> hierarchyFactories = new java.util.ArrayList();
    private final java.util.Map<java.lang.reflect.Type, com.google.gson.InstanceCreator<?>> instanceCreators = new java.util.HashMap();
    private boolean lenient = false;
    private com.google.gson.LongSerializationPolicy longSerializationPolicy = com.google.gson.LongSerializationPolicy.DEFAULT;
    private boolean prettyPrinting = false;
    private boolean serializeNulls = false;
    private boolean serializeSpecialFloatingPointValues = false;
    private int timeStyle = 2;

    public com.google.gson.GsonBuilder setVersion(double ignoreVersionsAfter) {
        this.excluder = this.excluder.withVersion(ignoreVersionsAfter);
        return this;
    }

    public com.google.gson.GsonBuilder excludeFieldsWithModifiers(int... modifiers) {
        this.excluder = this.excluder.withModifiers(modifiers);
        return this;
    }

    public com.google.gson.GsonBuilder generateNonExecutableJson() {
        this.generateNonExecutableJson = true;
        return this;
    }

    public com.google.gson.GsonBuilder excludeFieldsWithoutExposeAnnotation() {
        this.excluder = this.excluder.excludeFieldsWithoutExposeAnnotation();
        return this;
    }

    public com.google.gson.GsonBuilder serializeNulls() {
        this.serializeNulls = true;
        return this;
    }

    public com.google.gson.GsonBuilder enableComplexMapKeySerialization() {
        this.complexMapKeySerialization = true;
        return this;
    }

    public com.google.gson.GsonBuilder disableInnerClassSerialization() {
        this.excluder = this.excluder.disableInnerClassSerialization();
        return this;
    }

    public com.google.gson.GsonBuilder setLongSerializationPolicy(com.google.gson.LongSerializationPolicy serializationPolicy) {
        this.longSerializationPolicy = serializationPolicy;
        return this;
    }

    public com.google.gson.GsonBuilder setFieldNamingPolicy(com.google.gson.FieldNamingPolicy namingConvention) {
        this.fieldNamingPolicy = namingConvention;
        return this;
    }

    public com.google.gson.GsonBuilder setFieldNamingStrategy(com.google.gson.FieldNamingStrategy fieldNamingStrategy) {
        this.fieldNamingPolicy = fieldNamingStrategy;
        return this;
    }

    public com.google.gson.GsonBuilder setExclusionStrategies(com.google.gson.ExclusionStrategy... strategies) {
        for (com.google.gson.ExclusionStrategy strategy : strategies) {
            this.excluder = this.excluder.withExclusionStrategy(strategy, true, true);
        }
        return this;
    }

    public com.google.gson.GsonBuilder addSerializationExclusionStrategy(com.google.gson.ExclusionStrategy strategy) {
        this.excluder = this.excluder.withExclusionStrategy(strategy, true, false);
        return this;
    }

    public com.google.gson.GsonBuilder addDeserializationExclusionStrategy(com.google.gson.ExclusionStrategy strategy) {
        this.excluder = this.excluder.withExclusionStrategy(strategy, false, true);
        return this;
    }

    public com.google.gson.GsonBuilder setPrettyPrinting() {
        this.prettyPrinting = true;
        return this;
    }

    public com.google.gson.GsonBuilder setLenient() {
        this.lenient = true;
        return this;
    }

    public com.google.gson.GsonBuilder disableHtmlEscaping() {
        this.escapeHtmlChars = false;
        return this;
    }

    public com.google.gson.GsonBuilder setDateFormat(java.lang.String pattern) {
        this.datePattern = pattern;
        return this;
    }

    public com.google.gson.GsonBuilder setDateFormat(int style) {
        this.dateStyle = style;
        this.datePattern = null;
        return this;
    }

    public com.google.gson.GsonBuilder setDateFormat(int dateStyle, int timeStyle) {
        this.dateStyle = dateStyle;
        this.timeStyle = timeStyle;
        this.datePattern = null;
        return this;
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x001b  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x003c  */
    public com.google.gson.GsonBuilder registerTypeAdapter(java.lang.reflect.Type r4, java.lang.Object r5) {
        /*
        r3 = this;
        r0 = r5 instanceof com.google.gson.JsonSerializer;
        if (r0 != 0) goto L_0x0013;
    L_0x0004:
        r0 = r5 instanceof com.google.gson.JsonDeserializer;
        if (r0 != 0) goto L_0x0013;
    L_0x0008:
        r0 = r5 instanceof com.google.gson.InstanceCreator;
        if (r0 != 0) goto L_0x0013;
    L_0x000c:
        r0 = r5 instanceof com.google.gson.TypeAdapter;
        if (r0 == 0) goto L_0x0011;
    L_0x0010:
        goto L_0x0013;
    L_0x0011:
        r0 = 0;
        goto L_0x0014;
    L_0x0013:
        r0 = 1;
    L_0x0014:
        com.google.gson.internal.C$Gson$Preconditions.checkArgument(r0);
        r0 = r5 instanceof com.google.gson.InstanceCreator;
        if (r0 == 0) goto L_0x0023;
    L_0x001b:
        r0 = r3.instanceCreators;
        r1 = r5;
        r1 = (com.google.gson.InstanceCreator) r1;
        r0.put(r4, r1);
    L_0x0023:
        r0 = r5 instanceof com.google.gson.JsonSerializer;
        if (r0 != 0) goto L_0x002b;
    L_0x0027:
        r0 = r5 instanceof com.google.gson.JsonDeserializer;
        if (r0 == 0) goto L_0x0038;
    L_0x002b:
        r0 = com.google.gson.reflect.TypeToken.get(r4);
        r1 = r3.factories;
        r2 = com.google.gson.internal.bind.TreeTypeAdapter.newFactoryWithMatchRawType(r0, r5);
        r1.add(r2);
    L_0x0038:
        r0 = r5 instanceof com.google.gson.TypeAdapter;
        if (r0 == 0) goto L_0x004c;
    L_0x003c:
        r0 = r3.factories;
        r1 = com.google.gson.reflect.TypeToken.get(r4);
        r2 = r5;
        r2 = (com.google.gson.TypeAdapter) r2;
        r1 = com.google.gson.internal.bind.TypeAdapters.newFactory(r1, r2);
        r0.add(r1);
    L_0x004c:
        return r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.gson.GsonBuilder.registerTypeAdapter(java.lang.reflect.Type, java.lang.Object):com.google.gson.GsonBuilder");
    }

    public com.google.gson.GsonBuilder registerTypeAdapterFactory(com.google.gson.TypeAdapterFactory factory) {
        this.factories.add(factory);
        return this;
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0028  */
    public com.google.gson.GsonBuilder registerTypeHierarchyAdapter(java.lang.Class<?> r3, java.lang.Object r4) {
        /*
        r2 = this;
        r0 = r4 instanceof com.google.gson.JsonSerializer;
        if (r0 != 0) goto L_0x000f;
    L_0x0004:
        r0 = r4 instanceof com.google.gson.JsonDeserializer;
        if (r0 != 0) goto L_0x000f;
    L_0x0008:
        r0 = r4 instanceof com.google.gson.TypeAdapter;
        if (r0 == 0) goto L_0x000d;
    L_0x000c:
        goto L_0x000f;
    L_0x000d:
        r0 = 0;
        goto L_0x0010;
    L_0x000f:
        r0 = 1;
    L_0x0010:
        com.google.gson.internal.C$Gson$Preconditions.checkArgument(r0);
        r0 = r4 instanceof com.google.gson.JsonDeserializer;
        if (r0 != 0) goto L_0x001b;
    L_0x0017:
        r0 = r4 instanceof com.google.gson.JsonSerializer;
        if (r0 == 0) goto L_0x0024;
    L_0x001b:
        r0 = r2.hierarchyFactories;
        r1 = com.google.gson.internal.bind.TreeTypeAdapter.newTypeHierarchyFactory(r3, r4);
        r0.add(r1);
    L_0x0024:
        r0 = r4 instanceof com.google.gson.TypeAdapter;
        if (r0 == 0) goto L_0x0034;
    L_0x0028:
        r0 = r2.factories;
        r1 = r4;
        r1 = (com.google.gson.TypeAdapter) r1;
        r1 = com.google.gson.internal.bind.TypeAdapters.newTypeHierarchyFactory(r3, r1);
        r0.add(r1);
    L_0x0034:
        return r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.gson.GsonBuilder.registerTypeHierarchyAdapter(java.lang.Class, java.lang.Object):com.google.gson.GsonBuilder");
    }

    public com.google.gson.GsonBuilder serializeSpecialFloatingPointValues() {
        this.serializeSpecialFloatingPointValues = true;
        return this;
    }

    public com.google.gson.Gson create() {
        java.util.List<com.google.gson.TypeAdapterFactory> factories = new java.util.ArrayList((this.factories.size() + this.hierarchyFactories.size()) + 3);
        factories.addAll(this.factories);
        java.util.Collections.reverse(factories);
        java.util.List<com.google.gson.TypeAdapterFactory> hierarchyFactories = new java.util.ArrayList(this.hierarchyFactories);
        java.util.Collections.reverse(hierarchyFactories);
        factories.addAll(hierarchyFactories);
        addTypeAdaptersForDate(this.datePattern, this.dateStyle, this.timeStyle, factories);
        return new com.google.gson.Gson(this.excluder, this.fieldNamingPolicy, this.instanceCreators, this.serializeNulls, this.complexMapKeySerialization, this.generateNonExecutableJson, this.escapeHtmlChars, this.prettyPrinting, this.lenient, this.serializeSpecialFloatingPointValues, this.longSerializationPolicy, factories);
    }

    private void addTypeAdaptersForDate(java.lang.String datePattern, int dateStyle, int timeStyle, java.util.List<com.google.gson.TypeAdapterFactory> factories) {
        com.google.gson.TypeAdapter dateTypeAdapter;
        com.google.gson.TypeAdapter timestampTypeAdapter;
        com.google.gson.TypeAdapter javaSqlDateTypeAdapter;
        if (datePattern != null && !"".equals(datePattern.trim())) {
            dateTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.util.Date.class, datePattern);
            timestampTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.sql.Timestamp.class, datePattern);
            javaSqlDateTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.sql.Date.class, datePattern);
        } else if (dateStyle != 2 && timeStyle != 2) {
            dateTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.util.Date.class, dateStyle, timeStyle);
            timestampTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.sql.Timestamp.class, dateStyle, timeStyle);
            javaSqlDateTypeAdapter = new com.google.gson.DefaultDateTypeAdapter(java.sql.Date.class, dateStyle, timeStyle);
        } else {
            return;
        }
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.util.Date.class, dateTypeAdapter));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.sql.Timestamp.class, timestampTypeAdapter));
        factories.add(com.google.gson.internal.bind.TypeAdapters.newFactory(java.sql.Date.class, javaSqlDateTypeAdapter));
    }
}
