package com.google.gson;

public final class JsonPrimitive extends com.google.gson.JsonElement {
    private static final java.lang.Class<?>[] PRIMITIVE_TYPES = new java.lang.Class[]{java.lang.Integer.TYPE, java.lang.Long.TYPE, java.lang.Short.TYPE, java.lang.Float.TYPE, java.lang.Double.TYPE, java.lang.Byte.TYPE, java.lang.Boolean.TYPE, java.lang.Character.TYPE, java.lang.Integer.class, java.lang.Long.class, java.lang.Short.class, java.lang.Float.class, java.lang.Double.class, java.lang.Byte.class, java.lang.Boolean.class, java.lang.Character.class};
    private java.lang.Object value;

    public JsonPrimitive(java.lang.Boolean bool) {
        setValue(bool);
    }

    public JsonPrimitive(java.lang.Number number) {
        setValue(number);
    }

    public JsonPrimitive(java.lang.String string) {
        setValue(string);
    }

    public JsonPrimitive(java.lang.Character c) {
        setValue(c);
    }

    JsonPrimitive(java.lang.Object primitive) {
        setValue(primitive);
    }

    public com.google.gson.JsonPrimitive deepCopy() {
        return this;
    }

    void setValue(java.lang.Object primitive) {
        if (primitive instanceof java.lang.Character) {
            this.value = java.lang.String.valueOf(((java.lang.Character) primitive).charValue());
            return;
        }
        boolean z;
        if (!(primitive instanceof java.lang.Number)) {
            if (!isPrimitiveOrString(primitive)) {
                z = false;
                com.google.gson.internal.C$Gson$Preconditions.checkArgument(z);
                this.value = primitive;
            }
        }
        z = true;
        com.google.gson.internal.C$Gson$Preconditions.checkArgument(z);
        this.value = primitive;
    }

    public boolean isBoolean() {
        return this.value instanceof java.lang.Boolean;
    }

    java.lang.Boolean getAsBooleanWrapper() {
        return (java.lang.Boolean) this.value;
    }

    public boolean getAsBoolean() {
        if (isBoolean()) {
            return getAsBooleanWrapper().booleanValue();
        }
        return java.lang.Boolean.parseBoolean(getAsString());
    }

    public boolean isNumber() {
        return this.value instanceof java.lang.Number;
    }

    public java.lang.Number getAsNumber() {
        return this.value instanceof java.lang.String ? new com.google.gson.internal.LazilyParsedNumber((java.lang.String) this.value) : (java.lang.Number) this.value;
    }

    public boolean isString() {
        return this.value instanceof java.lang.String;
    }

    public java.lang.String getAsString() {
        if (isNumber()) {
            return getAsNumber().toString();
        }
        if (isBoolean()) {
            return getAsBooleanWrapper().toString();
        }
        return (java.lang.String) this.value;
    }

    public double getAsDouble() {
        return isNumber() ? getAsNumber().doubleValue() : java.lang.Double.parseDouble(getAsString());
    }

    public java.math.BigDecimal getAsBigDecimal() {
        return this.value instanceof java.math.BigDecimal ? (java.math.BigDecimal) this.value : new java.math.BigDecimal(this.value.toString());
    }

    public java.math.BigInteger getAsBigInteger() {
        if (this.value instanceof java.math.BigInteger) {
            return (java.math.BigInteger) this.value;
        }
        return new java.math.BigInteger(this.value.toString());
    }

    public float getAsFloat() {
        return isNumber() ? getAsNumber().floatValue() : java.lang.Float.parseFloat(getAsString());
    }

    public long getAsLong() {
        return isNumber() ? getAsNumber().longValue() : java.lang.Long.parseLong(getAsString());
    }

    public short getAsShort() {
        return isNumber() ? getAsNumber().shortValue() : java.lang.Short.parseShort(getAsString());
    }

    public int getAsInt() {
        return isNumber() ? getAsNumber().intValue() : java.lang.Integer.parseInt(getAsString());
    }

    public byte getAsByte() {
        return isNumber() ? getAsNumber().byteValue() : java.lang.Byte.parseByte(getAsString());
    }

    public char getAsCharacter() {
        return getAsString().charAt(0);
    }

    private static boolean isPrimitiveOrString(java.lang.Object target) {
        if (target instanceof java.lang.String) {
            return true;
        }
        java.lang.Class<?> classOfPrimitive = target.getClass();
        for (java.lang.Class<?> standardPrimitive : PRIMITIVE_TYPES) {
            if (standardPrimitive.isAssignableFrom(classOfPrimitive)) {
                return true;
            }
        }
        return false;
    }

    public int hashCode() {
        if (this.value == null) {
            return 31;
        }
        long value;
        if (isIntegral(this)) {
            value = getAsNumber().longValue();
            return (int) ((value >>> 32) ^ value);
        } else if (!(this.value instanceof java.lang.Number)) {
            return this.value.hashCode();
        } else {
            value = java.lang.Double.doubleToLongBits(getAsNumber().doubleValue());
            return (int) ((value >>> 32) ^ value);
        }
    }

    public boolean equals(java.lang.Object obj) {
        boolean z = true;
        if (this == obj) {
            return true;
        }
        if (obj != null) {
            if (getClass() == obj.getClass()) {
                com.google.gson.JsonPrimitive other = (com.google.gson.JsonPrimitive) obj;
                if (this.value == null) {
                    if (other.value != null) {
                        z = false;
                    }
                    return z;
                } else if (isIntegral(this) && isIntegral(other)) {
                    if (getAsNumber().longValue() != other.getAsNumber().longValue()) {
                        z = false;
                    }
                    return z;
                } else if (!(this.value instanceof java.lang.Number) || !(other.value instanceof java.lang.Number)) {
                    return this.value.equals(other.value);
                } else {
                    double a = getAsNumber().doubleValue();
                    double b = other.getAsNumber().doubleValue();
                    if (a != b) {
                        if (!java.lang.Double.isNaN(a) || !java.lang.Double.isNaN(b)) {
                            z = false;
                        }
                    }
                    return z;
                }
            }
        }
        return false;
    }

    private static boolean isIntegral(com.google.gson.JsonPrimitive primitive) {
        boolean z = false;
        if (!(primitive.value instanceof java.lang.Number)) {
            return false;
        }
        java.lang.Number number = primitive.value;
        if (!((number instanceof java.math.BigInteger) || (number instanceof java.lang.Long) || (number instanceof java.lang.Integer) || (number instanceof java.lang.Short))) {
            if (!(number instanceof java.lang.Byte)) {
                return z;
            }
        }
        z = true;
        return z;
    }
}
