package com.google.gson;

public abstract class TypeAdapter<T> {
    public abstract T read(com.google.gson.stream.JsonReader jsonReader) throws java.io.IOException;

    public abstract void write(com.google.gson.stream.JsonWriter jsonWriter, T t) throws java.io.IOException;

    public final void toJson(java.io.Writer out, T value) throws java.io.IOException {
        write(new com.google.gson.stream.JsonWriter(out), value);
    }

    public final com.google.gson.TypeAdapter<T> nullSafe() {
        return new com.google.gson.TypeAdapter<T>() {
            public void write(com.google.gson.stream.JsonWriter out, T value) throws java.io.IOException {
                if (value == null) {
                    out.nullValue();
                } else {
                    com.google.gson.TypeAdapter.this.write(out, value);
                }
            }

            public T read(com.google.gson.stream.JsonReader reader) throws java.io.IOException {
                if (reader.peek() != com.google.gson.stream.JsonToken.NULL) {
                    return com.google.gson.TypeAdapter.this.read(reader);
                }
                reader.nextNull();
                return null;
            }
        };
    }

    public final java.lang.String toJson(T value) {
        java.io.StringWriter stringWriter = new java.io.StringWriter();
        try {
            toJson(stringWriter, value);
            return stringWriter.toString();
        } catch (java.io.IOException e) {
            throw new java.lang.AssertionError(e);
        }
    }

    public final com.google.gson.JsonElement toJsonTree(T value) {
        try {
            com.google.gson.internal.bind.JsonTreeWriter jsonWriter = new com.google.gson.internal.bind.JsonTreeWriter();
            write(jsonWriter, value);
            return jsonWriter.get();
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        }
    }

    public final T fromJson(java.io.Reader in) throws java.io.IOException {
        return read(new com.google.gson.stream.JsonReader(in));
    }

    public final T fromJson(java.lang.String json) throws java.io.IOException {
        return fromJson(new java.io.StringReader(json));
    }

    public final T fromJsonTree(com.google.gson.JsonElement jsonTree) {
        try {
            return read(new com.google.gson.internal.bind.JsonTreeReader(jsonTree));
        } catch (java.lang.Throwable e) {
            throw new com.google.gson.JsonIOException(e);
        }
    }
}
