package com.google.gson.internal;

public final class ConstructorConstructor {
    private final java.util.Map<java.lang.reflect.Type, com.google.gson.InstanceCreator<?>> instanceCreators;

    public ConstructorConstructor(java.util.Map<java.lang.reflect.Type, com.google.gson.InstanceCreator<?>> instanceCreators) {
        this.instanceCreators = instanceCreators;
    }

    public <T> com.google.gson.internal.ObjectConstructor<T> get(com.google.gson.reflect.TypeToken<T> typeToken) {
        final java.lang.reflect.Type type = typeToken.getType();
        java.lang.Class<? super T> rawType = typeToken.getRawType();
        final com.google.gson.InstanceCreator<T> typeCreator = (com.google.gson.InstanceCreator) this.instanceCreators.get(type);
        if (typeCreator != null) {
            return new com.google.gson.internal.ObjectConstructor<T>() {
                public T construct() {
                    return typeCreator.createInstance(type);
                }
            };
        }
        final com.google.gson.InstanceCreator<T> rawTypeCreator = (com.google.gson.InstanceCreator) this.instanceCreators.get(rawType);
        if (rawTypeCreator != null) {
            return new com.google.gson.internal.ObjectConstructor<T>() {
                public T construct() {
                    return rawTypeCreator.createInstance(type);
                }
            };
        }
        com.google.gson.internal.ObjectConstructor<T> defaultConstructor = newDefaultConstructor(rawType);
        if (defaultConstructor != null) {
            return defaultConstructor;
        }
        com.google.gson.internal.ObjectConstructor<T> defaultImplementation = newDefaultImplementationConstructor(type, rawType);
        if (defaultImplementation != null) {
            return defaultImplementation;
        }
        return newUnsafeAllocator(type, rawType);
    }

    private <T> com.google.gson.internal.ObjectConstructor<T> newDefaultConstructor(java.lang.Class<? super T> rawType) {
        try {
            final java.lang.reflect.Constructor<? super T> constructor = rawType.getDeclaredConstructor(new java.lang.Class[0]);
            if (!constructor.isAccessible()) {
                constructor.setAccessible(true);
            }
            return new com.google.gson.internal.ObjectConstructor<T>() {
                public T construct() {
                    java.lang.StringBuilder stringBuilder;
                    try {
                        return constructor.newInstance(null);
                    } catch (java.lang.InstantiationException e) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Failed to invoke ");
                        stringBuilder.append(constructor);
                        stringBuilder.append(" with no args");
                        throw new java.lang.RuntimeException(stringBuilder.toString(), e);
                    } catch (java.lang.reflect.InvocationTargetException e2) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Failed to invoke ");
                        stringBuilder.append(constructor);
                        stringBuilder.append(" with no args");
                        throw new java.lang.RuntimeException(stringBuilder.toString(), e2.getTargetException());
                    } catch (java.lang.IllegalAccessException e3) {
                        throw new java.lang.AssertionError(e3);
                    }
                }
            };
        } catch (java.lang.NoSuchMethodException e) {
            return null;
        }
    }

    private <T> com.google.gson.internal.ObjectConstructor<T> newDefaultImplementationConstructor(final java.lang.reflect.Type type, java.lang.Class<? super T> rawType) {
        if (java.util.Collection.class.isAssignableFrom(rawType)) {
            if (java.util.SortedSet.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.TreeSet();
                    }
                };
            }
            if (java.util.EnumSet.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        if (type instanceof java.lang.reflect.ParameterizedType) {
                            java.lang.reflect.Type elementType = ((java.lang.reflect.ParameterizedType) type).getActualTypeArguments()[0];
                            if (elementType instanceof java.lang.Class) {
                                return java.util.EnumSet.noneOf((java.lang.Class) elementType);
                            }
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Invalid EnumSet type: ");
                            stringBuilder.append(type.toString());
                            throw new com.google.gson.JsonIOException(stringBuilder.toString());
                        }
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("Invalid EnumSet type: ");
                        stringBuilder2.append(type.toString());
                        throw new com.google.gson.JsonIOException(stringBuilder2.toString());
                    }
                };
            }
            if (java.util.Set.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.LinkedHashSet();
                    }
                };
            }
            if (java.util.Queue.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.ArrayDeque();
                    }
                };
            }
            return new com.google.gson.internal.ObjectConstructor<T>() {
                public T construct() {
                    return new java.util.ArrayList();
                }
            };
        } else if (!java.util.Map.class.isAssignableFrom(rawType)) {
            return null;
        } else {
            if (java.util.concurrent.ConcurrentNavigableMap.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.concurrent.ConcurrentSkipListMap();
                    }
                };
            }
            if (java.util.concurrent.ConcurrentMap.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.concurrent.ConcurrentHashMap();
                    }
                };
            }
            if (java.util.SortedMap.class.isAssignableFrom(rawType)) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new java.util.TreeMap();
                    }
                };
            }
            if (!(type instanceof java.lang.reflect.ParameterizedType) || java.lang.String.class.isAssignableFrom(com.google.gson.reflect.TypeToken.get(((java.lang.reflect.ParameterizedType) type).getActualTypeArguments()[0]).getRawType())) {
                return new com.google.gson.internal.ObjectConstructor<T>() {
                    public T construct() {
                        return new com.google.gson.internal.LinkedTreeMap();
                    }
                };
            }
            return new com.google.gson.internal.ObjectConstructor<T>() {
                public T construct() {
                    return new java.util.LinkedHashMap();
                }
            };
        }
    }

    private <T> com.google.gson.internal.ObjectConstructor<T> newUnsafeAllocator(final java.lang.reflect.Type type, final java.lang.Class<? super T> rawType) {
        return new com.google.gson.internal.ObjectConstructor<T>() {
            private final com.google.gson.internal.UnsafeAllocator unsafeAllocator = com.google.gson.internal.UnsafeAllocator.create();

            public T construct() {
                try {
                    return this.unsafeAllocator.newInstance(rawType);
                } catch (java.lang.Exception e) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Unable to invoke no-args constructor for ");
                    stringBuilder.append(type);
                    stringBuilder.append(". Registering an InstanceCreator with Gson for this type may fix this problem.");
                    throw new java.lang.RuntimeException(stringBuilder.toString(), e);
                }
            }
        };
    }

    public java.lang.String toString() {
        return this.instanceCreators.toString();
    }
}
