package com.google.gson.internal;

public final class Primitives {
    private static final java.util.Map<java.lang.Class<?>, java.lang.Class<?>> PRIMITIVE_TO_WRAPPER_TYPE;
    private static final java.util.Map<java.lang.Class<?>, java.lang.Class<?>> WRAPPER_TO_PRIMITIVE_TYPE;

    private Primitives() {
        throw new java.lang.UnsupportedOperationException();
    }

    static {
        java.util.Map<java.lang.Class<?>, java.lang.Class<?>> primToWrap = new java.util.HashMap(16);
        java.util.HashMap wrapToPrim = new java.util.HashMap(16);
        add(primToWrap, wrapToPrim, java.lang.Boolean.TYPE, java.lang.Boolean.class);
        add(primToWrap, wrapToPrim, java.lang.Byte.TYPE, java.lang.Byte.class);
        add(primToWrap, wrapToPrim, java.lang.Character.TYPE, java.lang.Character.class);
        add(primToWrap, wrapToPrim, java.lang.Double.TYPE, java.lang.Double.class);
        add(primToWrap, wrapToPrim, java.lang.Float.TYPE, java.lang.Float.class);
        add(primToWrap, wrapToPrim, java.lang.Integer.TYPE, java.lang.Integer.class);
        add(primToWrap, wrapToPrim, java.lang.Long.TYPE, java.lang.Long.class);
        add(primToWrap, wrapToPrim, java.lang.Short.TYPE, java.lang.Short.class);
        add(primToWrap, wrapToPrim, java.lang.Void.TYPE, java.lang.Void.class);
        PRIMITIVE_TO_WRAPPER_TYPE = java.util.Collections.unmodifiableMap(primToWrap);
        WRAPPER_TO_PRIMITIVE_TYPE = java.util.Collections.unmodifiableMap(wrapToPrim);
    }

    private static void add(java.util.Map<java.lang.Class<?>, java.lang.Class<?>> forward, java.util.Map<java.lang.Class<?>, java.lang.Class<?>> backward, java.lang.Class<?> key, java.lang.Class<?> value) {
        forward.put(key, value);
        backward.put(value, key);
    }

    public static boolean isPrimitive(java.lang.reflect.Type type) {
        return PRIMITIVE_TO_WRAPPER_TYPE.containsKey(type);
    }

    public static boolean isWrapperType(java.lang.reflect.Type type) {
        return WRAPPER_TO_PRIMITIVE_TYPE.containsKey(com.google.gson.internal.C$Gson$Preconditions.checkNotNull(type));
    }

    public static <T> java.lang.Class<T> wrap(java.lang.Class<T> type) {
        java.lang.Class<T> wrapped = (java.lang.Class) PRIMITIVE_TO_WRAPPER_TYPE.get(com.google.gson.internal.C$Gson$Preconditions.checkNotNull(type));
        return wrapped == null ? type : wrapped;
    }

    public static <T> java.lang.Class<T> unwrap(java.lang.Class<T> type) {
        java.lang.Class<T> unwrapped = (java.lang.Class) WRAPPER_TO_PRIMITIVE_TYPE.get(com.google.gson.internal.C$Gson$Preconditions.checkNotNull(type));
        return unwrapped == null ? type : unwrapped;
    }
}
