package com.google.gson.internal;

public abstract class UnsafeAllocator {
    public abstract <T> T newInstance(java.lang.Class<T> cls) throws java.lang.Exception;

    public static com.google.gson.internal.UnsafeAllocator create() {
        try {
            java.lang.Class<?> unsafeClass = java.lang.Class.forName("sun.misc.Unsafe");
            java.lang.reflect.Field f = unsafeClass.getDeclaredField("theUnsafe");
            f.setAccessible(true);
            final java.lang.Object unsafe = f.get(null);
            final java.lang.reflect.Method allocateInstance = unsafeClass.getMethod("allocateInstance", new java.lang.Class[]{java.lang.Class.class});
            return new com.google.gson.internal.UnsafeAllocator() {
                public <T> T newInstance(java.lang.Class<T> c) throws java.lang.Exception {
                    com.google.gson.internal.UnsafeAllocator.assertInstantiable(c);
                    return allocateInstance.invoke(unsafe, new java.lang.Object[]{c});
                }
            };
        } catch (java.lang.Exception e) {
            try {
                java.lang.reflect.Method getConstructorId = java.io.ObjectStreamClass.class.getDeclaredMethod("getConstructorId", new java.lang.Class[]{java.lang.Class.class});
                getConstructorId.setAccessible(true);
                final int constructorId = ((java.lang.Integer) getConstructorId.invoke(null, new java.lang.Object[]{java.lang.Object.class})).intValue();
                final java.lang.reflect.Method newInstance = java.io.ObjectStreamClass.class.getDeclaredMethod("newInstance", new java.lang.Class[]{java.lang.Class.class, java.lang.Integer.TYPE});
                newInstance.setAccessible(true);
                return new com.google.gson.internal.UnsafeAllocator() {
                    public <T> T newInstance(java.lang.Class<T> c) throws java.lang.Exception {
                        com.google.gson.internal.UnsafeAllocator.assertInstantiable(c);
                        return newInstance.invoke(null, new java.lang.Object[]{c, java.lang.Integer.valueOf(constructorId)});
                    }
                };
            } catch (java.lang.Exception e2) {
                try {
                    final java.lang.reflect.Method newInstance2 = java.io.ObjectInputStream.class.getDeclaredMethod("newInstance", new java.lang.Class[]{java.lang.Class.class, java.lang.Class.class});
                    newInstance2.setAccessible(true);
                    return new com.google.gson.internal.UnsafeAllocator() {
                        public <T> T newInstance(java.lang.Class<T> c) throws java.lang.Exception {
                            com.google.gson.internal.UnsafeAllocator.assertInstantiable(c);
                            return newInstance2.invoke(null, new java.lang.Object[]{c, java.lang.Object.class});
                        }
                    };
                } catch (java.lang.Exception e3) {
                    return new com.google.gson.internal.UnsafeAllocator() {
                        public <T> T newInstance(java.lang.Class<T> c) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Cannot allocate ");
                            stringBuilder.append(c);
                            throw new java.lang.UnsupportedOperationException(stringBuilder.toString());
                        }
                    };
                }
            }
        }
    }

    static void assertInstantiable(java.lang.Class<?> c) {
        int modifiers = c.getModifiers();
        java.lang.StringBuilder stringBuilder;
        if (java.lang.reflect.Modifier.isInterface(modifiers)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Interface can't be instantiated! Interface name: ");
            stringBuilder.append(c.getName());
            throw new java.lang.UnsupportedOperationException(stringBuilder.toString());
        } else if (java.lang.reflect.Modifier.isAbstract(modifiers)) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Abstract class can't be instantiated! Class name: ");
            stringBuilder.append(c.getName());
            throw new java.lang.UnsupportedOperationException(stringBuilder.toString());
        }
    }
}
