package com.google.gson.internal.bind;

public final class CollectionTypeAdapterFactory implements com.google.gson.TypeAdapterFactory {
    private final com.google.gson.internal.ConstructorConstructor constructorConstructor;

    private static final class Adapter<E> extends com.google.gson.TypeAdapter<java.util.Collection<E>> {
        private final com.google.gson.internal.ObjectConstructor<? extends java.util.Collection<E>> constructor;
        private final com.google.gson.TypeAdapter<E> elementTypeAdapter;

        public Adapter(com.google.gson.Gson context, java.lang.reflect.Type elementType, com.google.gson.TypeAdapter<E> elementTypeAdapter, com.google.gson.internal.ObjectConstructor<? extends java.util.Collection<E>> constructor) {
            this.elementTypeAdapter = new com.google.gson.internal.bind.TypeAdapterRuntimeTypeWrapper(context, elementTypeAdapter, elementType);
            this.constructor = constructor;
        }

        public java.util.Collection<E> read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            java.util.Collection<E> collection = (java.util.Collection) this.constructor.construct();
            in.beginArray();
            while (in.hasNext()) {
                collection.add(this.elementTypeAdapter.read(in));
            }
            in.endArray();
            return collection;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.Collection<E> collection) throws java.io.IOException {
            if (collection == null) {
                out.nullValue();
                return;
            }
            out.beginArray();
            for (E element : collection) {
                this.elementTypeAdapter.write(out, element);
            }
            out.endArray();
        }
    }

    public CollectionTypeAdapterFactory(com.google.gson.internal.ConstructorConstructor constructorConstructor) {
        this.constructorConstructor = constructorConstructor;
    }

    public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
        java.lang.reflect.Type type = typeToken.getType();
        java.lang.Class<? super T> rawType = typeToken.getRawType();
        if (!java.util.Collection.class.isAssignableFrom(rawType)) {
            return null;
        }
        java.lang.reflect.Type elementType = com.google.gson.internal.C$Gson$Types.getCollectionElementType(type, rawType);
        return new com.google.gson.internal.bind.CollectionTypeAdapterFactory.Adapter(gson, elementType, gson.getAdapter(com.google.gson.reflect.TypeToken.get(elementType)), this.constructorConstructor.get(typeToken));
    }
}
