package com.google.gson.internal.bind;

public final class JsonAdapterAnnotationTypeAdapterFactory implements com.google.gson.TypeAdapterFactory {
    private final com.google.gson.internal.ConstructorConstructor constructorConstructor;

    public JsonAdapterAnnotationTypeAdapterFactory(com.google.gson.internal.ConstructorConstructor constructorConstructor) {
        this.constructorConstructor = constructorConstructor;
    }

    public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> targetType) {
        com.google.gson.annotations.JsonAdapter annotation = (com.google.gson.annotations.JsonAdapter) targetType.getRawType().getAnnotation(com.google.gson.annotations.JsonAdapter.class);
        if (annotation == null) {
            return null;
        }
        return getTypeAdapter(this.constructorConstructor, gson, targetType, annotation);
    }

    com.google.gson.TypeAdapter<?> getTypeAdapter(com.google.gson.internal.ConstructorConstructor constructorConstructor, com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<?> type, com.google.gson.annotations.JsonAdapter annotation) {
        com.google.gson.TypeAdapter<?> typeAdapter;
        com.google.gson.TypeAdapter<?> instance = constructorConstructor.get(com.google.gson.reflect.TypeToken.get(annotation.value())).construct();
        if (instance instanceof com.google.gson.TypeAdapter) {
            typeAdapter = instance;
        } else if (instance instanceof com.google.gson.TypeAdapterFactory) {
            typeAdapter = ((com.google.gson.TypeAdapterFactory) instance).create(gson, type);
        } else {
            if (!(instance instanceof com.google.gson.JsonSerializer)) {
                if (!(instance instanceof com.google.gson.JsonDeserializer)) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Invalid attempt to bind an instance of ");
                    stringBuilder.append(instance.getClass().getName());
                    stringBuilder.append(" as a @JsonAdapter for ");
                    stringBuilder.append(type.toString());
                    stringBuilder.append(". @JsonAdapter value must be a TypeAdapter, TypeAdapterFactory, JsonSerializer or JsonDeserializer.");
                    throw new java.lang.IllegalArgumentException(stringBuilder.toString());
                }
            }
            com.google.gson.JsonDeserializer<?> jsonDeserializer = null;
            com.google.gson.JsonSerializer<?> serializer = instance instanceof com.google.gson.JsonSerializer ? (com.google.gson.JsonSerializer) instance : null;
            if (instance instanceof com.google.gson.JsonDeserializer) {
                jsonDeserializer = (com.google.gson.JsonDeserializer) instance;
            }
            com.google.gson.TypeAdapter<?> treeTypeAdapter = new com.google.gson.internal.bind.TreeTypeAdapter(serializer, jsonDeserializer, gson, type, null);
            if (typeAdapter == null && annotation.nullSafe()) {
                return typeAdapter.nullSafe();
            }
        }
        return typeAdapter == null ? typeAdapter : typeAdapter;
    }
}
