package com.google.gson.internal.bind;

public final class JsonTreeReader extends com.google.gson.stream.JsonReader {
    private static final java.lang.Object SENTINEL_CLOSED = new java.lang.Object();
    private static final java.io.Reader UNREADABLE_READER = new java.io.Reader() {
        public int read(char[] buffer, int offset, int count) throws java.io.IOException {
            throw new java.lang.AssertionError();
        }

        public void close() throws java.io.IOException {
            throw new java.lang.AssertionError();
        }
    };
    private int[] pathIndices = new int[32];
    private java.lang.String[] pathNames = new java.lang.String[32];
    private java.lang.Object[] stack = new java.lang.Object[32];
    private int stackSize = 0;

    public JsonTreeReader(com.google.gson.JsonElement element) {
        super(UNREADABLE_READER);
        push(element);
    }

    public void beginArray() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.BEGIN_ARRAY);
        push(((com.google.gson.JsonArray) peekStack()).iterator());
        this.pathIndices[this.stackSize - 1] = 0;
    }

    public void endArray() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.END_ARRAY);
        popStack();
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
    }

    public void beginObject() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.BEGIN_OBJECT);
        push(((com.google.gson.JsonObject) peekStack()).entrySet().iterator());
    }

    public void endObject() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.END_OBJECT);
        popStack();
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
    }

    public boolean hasNext() throws java.io.IOException {
        com.google.gson.stream.JsonToken token = peek();
        return (token == com.google.gson.stream.JsonToken.END_OBJECT || token == com.google.gson.stream.JsonToken.END_ARRAY) ? false : true;
    }

    public com.google.gson.stream.JsonToken peek() throws java.io.IOException {
        if (this.stackSize == 0) {
            return com.google.gson.stream.JsonToken.END_DOCUMENT;
        }
        java.util.Iterator<?> o = peekStack();
        if (o instanceof java.util.Iterator) {
            boolean isObject = this.stack[this.stackSize - 2] instanceof com.google.gson.JsonObject;
            java.util.Iterator<?> iterator = o;
            if (!iterator.hasNext()) {
                return isObject ? com.google.gson.stream.JsonToken.END_OBJECT : com.google.gson.stream.JsonToken.END_ARRAY;
            } else if (isObject) {
                return com.google.gson.stream.JsonToken.NAME;
            } else {
                push(iterator.next());
                return peek();
            }
        } else if (o instanceof com.google.gson.JsonObject) {
            return com.google.gson.stream.JsonToken.BEGIN_OBJECT;
        } else {
            if (o instanceof com.google.gson.JsonArray) {
                return com.google.gson.stream.JsonToken.BEGIN_ARRAY;
            }
            if (o instanceof com.google.gson.JsonPrimitive) {
                com.google.gson.JsonPrimitive primitive = (com.google.gson.JsonPrimitive) o;
                if (primitive.isString()) {
                    return com.google.gson.stream.JsonToken.STRING;
                }
                if (primitive.isBoolean()) {
                    return com.google.gson.stream.JsonToken.BOOLEAN;
                }
                if (primitive.isNumber()) {
                    return com.google.gson.stream.JsonToken.NUMBER;
                }
                throw new java.lang.AssertionError();
            } else if (o instanceof com.google.gson.JsonNull) {
                return com.google.gson.stream.JsonToken.NULL;
            } else {
                if (o == SENTINEL_CLOSED) {
                    throw new java.lang.IllegalStateException("JsonReader is closed");
                }
                throw new java.lang.AssertionError();
            }
        }
    }

    private java.lang.Object peekStack() {
        return this.stack[this.stackSize - 1];
    }

    private java.lang.Object popStack() {
        java.lang.Object result = this.stack;
        int i = this.stackSize - 1;
        this.stackSize = i;
        result = result[i];
        this.stack[this.stackSize] = null;
        return result;
    }

    private void expect(com.google.gson.stream.JsonToken expected) throws java.io.IOException {
        if (peek() != expected) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Expected ");
            stringBuilder.append(expected);
            stringBuilder.append(" but was ");
            stringBuilder.append(peek());
            stringBuilder.append(locationString());
            throw new java.lang.IllegalStateException(stringBuilder.toString());
        }
    }

    public java.lang.String nextName() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.NAME);
        java.util.Map.Entry<?, ?> entry = (java.util.Map.Entry) ((java.util.Iterator) peekStack()).next();
        java.lang.String result = (java.lang.String) entry.getKey();
        this.pathNames[this.stackSize - 1] = result;
        push(entry.getValue());
        return result;
    }

    public java.lang.String nextString() throws java.io.IOException {
        com.google.gson.stream.JsonToken token = peek();
        if (token != com.google.gson.stream.JsonToken.STRING) {
            if (token != com.google.gson.stream.JsonToken.NUMBER) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Expected ");
                stringBuilder.append(com.google.gson.stream.JsonToken.STRING);
                stringBuilder.append(" but was ");
                stringBuilder.append(token);
                stringBuilder.append(locationString());
                throw new java.lang.IllegalStateException(stringBuilder.toString());
            }
        }
        java.lang.String result = ((com.google.gson.JsonPrimitive) popStack()).getAsString();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
        return result;
    }

    public boolean nextBoolean() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.BOOLEAN);
        boolean result = ((com.google.gson.JsonPrimitive) popStack()).getAsBoolean();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
        return result;
    }

    public void nextNull() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.NULL);
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
    }

    public double nextDouble() throws java.io.IOException {
        com.google.gson.stream.JsonToken token = peek();
        if (token != com.google.gson.stream.JsonToken.NUMBER) {
            if (token != com.google.gson.stream.JsonToken.STRING) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Expected ");
                stringBuilder.append(com.google.gson.stream.JsonToken.NUMBER);
                stringBuilder.append(" but was ");
                stringBuilder.append(token);
                stringBuilder.append(locationString());
                throw new java.lang.IllegalStateException(stringBuilder.toString());
            }
        }
        double result = ((com.google.gson.JsonPrimitive) peekStack()).getAsDouble();
        if (!isLenient()) {
            if (java.lang.Double.isNaN(result) || java.lang.Double.isInfinite(result)) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("JSON forbids NaN and infinities: ");
                stringBuilder2.append(result);
                throw new java.lang.NumberFormatException(stringBuilder2.toString());
            }
        }
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
        return result;
    }

    public long nextLong() throws java.io.IOException {
        com.google.gson.stream.JsonToken token = peek();
        if (token != com.google.gson.stream.JsonToken.NUMBER) {
            if (token != com.google.gson.stream.JsonToken.STRING) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Expected ");
                stringBuilder.append(com.google.gson.stream.JsonToken.NUMBER);
                stringBuilder.append(" but was ");
                stringBuilder.append(token);
                stringBuilder.append(locationString());
                throw new java.lang.IllegalStateException(stringBuilder.toString());
            }
        }
        long result = ((com.google.gson.JsonPrimitive) peekStack()).getAsLong();
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
        return result;
    }

    public int nextInt() throws java.io.IOException {
        com.google.gson.stream.JsonToken token = peek();
        if (token != com.google.gson.stream.JsonToken.NUMBER) {
            if (token != com.google.gson.stream.JsonToken.STRING) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Expected ");
                stringBuilder.append(com.google.gson.stream.JsonToken.NUMBER);
                stringBuilder.append(" but was ");
                stringBuilder.append(token);
                stringBuilder.append(locationString());
                throw new java.lang.IllegalStateException(stringBuilder.toString());
            }
        }
        int result = ((com.google.gson.JsonPrimitive) peekStack()).getAsInt();
        popStack();
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
        return result;
    }

    public void close() throws java.io.IOException {
        this.stack = new java.lang.Object[]{SENTINEL_CLOSED};
        this.stackSize = 1;
    }

    public void skipValue() throws java.io.IOException {
        if (peek() == com.google.gson.stream.JsonToken.NAME) {
            nextName();
            this.pathNames[this.stackSize - 2] = "null";
        } else {
            popStack();
            if (this.stackSize > 0) {
                this.pathNames[this.stackSize - 1] = "null";
            }
        }
        if (this.stackSize > 0) {
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
        }
    }

    public java.lang.String toString() {
        return getClass().getSimpleName();
    }

    public void promoteNameToValue() throws java.io.IOException {
        expect(com.google.gson.stream.JsonToken.NAME);
        java.util.Map.Entry<?, ?> entry = (java.util.Map.Entry) ((java.util.Iterator) peekStack()).next();
        push(entry.getValue());
        push(new com.google.gson.JsonPrimitive((java.lang.String) entry.getKey()));
    }

    private void push(java.lang.Object newTop) {
        java.lang.Object[] newStack;
        if (this.stackSize == this.stack.length) {
            newStack = new java.lang.Object[(this.stackSize * 2)];
            int[] newPathIndices = new int[(this.stackSize * 2)];
            java.lang.String[] newPathNames = new java.lang.String[(this.stackSize * 2)];
            java.lang.System.arraycopy(this.stack, 0, newStack, 0, this.stackSize);
            java.lang.System.arraycopy(this.pathIndices, 0, newPathIndices, 0, this.stackSize);
            java.lang.System.arraycopy(this.pathNames, 0, newPathNames, 0, this.stackSize);
            this.stack = newStack;
            this.pathIndices = newPathIndices;
            this.pathNames = newPathNames;
        }
        newStack = this.stack;
        int i = this.stackSize;
        this.stackSize = i + 1;
        newStack[i] = newTop;
    }

    public java.lang.String getPath() {
        java.lang.StringBuilder result = new java.lang.StringBuilder().append('$');
        int i = 0;
        while (i < this.stackSize) {
            if (this.stack[i] instanceof com.google.gson.JsonArray) {
                i++;
                if (this.stack[i] instanceof java.util.Iterator) {
                    result.append('[');
                    result.append(this.pathIndices[i]);
                    result.append(']');
                }
            } else if (this.stack[i] instanceof com.google.gson.JsonObject) {
                i++;
                if (this.stack[i] instanceof java.util.Iterator) {
                    result.append('.');
                    if (this.pathNames[i] != null) {
                        result.append(this.pathNames[i]);
                    }
                }
            }
            i++;
        }
        return result.toString();
    }

    private java.lang.String locationString() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" at path ");
        stringBuilder.append(getPath());
        return stringBuilder.toString();
    }
}
