package com.google.gson.internal.bind;

public final class JsonTreeWriter extends com.google.gson.stream.JsonWriter {
    private static final com.google.gson.JsonPrimitive SENTINEL_CLOSED = new com.google.gson.JsonPrimitive("closed");
    private static final java.io.Writer UNWRITABLE_WRITER = new java.io.Writer() {
        public void write(char[] buffer, int offset, int counter) {
            throw new java.lang.AssertionError();
        }

        public void flush() throws java.io.IOException {
            throw new java.lang.AssertionError();
        }

        public void close() throws java.io.IOException {
            throw new java.lang.AssertionError();
        }
    };
    private java.lang.String pendingName;
    private com.google.gson.JsonElement product = com.google.gson.JsonNull.INSTANCE;
    private final java.util.List<com.google.gson.JsonElement> stack = new java.util.ArrayList();

    public JsonTreeWriter() {
        super(UNWRITABLE_WRITER);
    }

    public com.google.gson.JsonElement get() {
        if (this.stack.isEmpty()) {
            return this.product;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected one JSON element but was ");
        stringBuilder.append(this.stack);
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    private com.google.gson.JsonElement peek() {
        return (com.google.gson.JsonElement) this.stack.get(this.stack.size() - 1);
    }

    private void put(com.google.gson.JsonElement value) {
        if (this.pendingName != null) {
            if (!value.isJsonNull() || getSerializeNulls()) {
                ((com.google.gson.JsonObject) peek()).add(this.pendingName, value);
            }
            this.pendingName = null;
        } else if (this.stack.isEmpty()) {
            this.product = value;
        } else {
            com.google.gson.JsonElement element = peek();
            if (element instanceof com.google.gson.JsonArray) {
                ((com.google.gson.JsonArray) element).add(value);
                return;
            }
            throw new java.lang.IllegalStateException();
        }
    }

    public com.google.gson.stream.JsonWriter beginArray() throws java.io.IOException {
        com.google.gson.JsonArray array = new com.google.gson.JsonArray();
        put(array);
        this.stack.add(array);
        return this;
    }

    public com.google.gson.stream.JsonWriter endArray() throws java.io.IOException {
        if (this.stack.isEmpty() || this.pendingName != null) {
            throw new java.lang.IllegalStateException();
        } else if (peek() instanceof com.google.gson.JsonArray) {
            this.stack.remove(this.stack.size() - 1);
            return this;
        } else {
            throw new java.lang.IllegalStateException();
        }
    }

    public com.google.gson.stream.JsonWriter beginObject() throws java.io.IOException {
        com.google.gson.JsonObject object = new com.google.gson.JsonObject();
        put(object);
        this.stack.add(object);
        return this;
    }

    public com.google.gson.stream.JsonWriter endObject() throws java.io.IOException {
        if (this.stack.isEmpty() || this.pendingName != null) {
            throw new java.lang.IllegalStateException();
        } else if (peek() instanceof com.google.gson.JsonObject) {
            this.stack.remove(this.stack.size() - 1);
            return this;
        } else {
            throw new java.lang.IllegalStateException();
        }
    }

    public com.google.gson.stream.JsonWriter name(java.lang.String name) throws java.io.IOException {
        if (this.stack.isEmpty() || this.pendingName != null) {
            throw new java.lang.IllegalStateException();
        } else if (peek() instanceof com.google.gson.JsonObject) {
            this.pendingName = name;
            return this;
        } else {
            throw new java.lang.IllegalStateException();
        }
    }

    public com.google.gson.stream.JsonWriter value(java.lang.String value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        put(new com.google.gson.JsonPrimitive(value));
        return this;
    }

    public com.google.gson.stream.JsonWriter nullValue() throws java.io.IOException {
        put(com.google.gson.JsonNull.INSTANCE);
        return this;
    }

    public com.google.gson.stream.JsonWriter value(boolean value) throws java.io.IOException {
        put(new com.google.gson.JsonPrimitive(java.lang.Boolean.valueOf(value)));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(java.lang.Boolean value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        put(new com.google.gson.JsonPrimitive(value));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(double value) throws java.io.IOException {
        if (!isLenient()) {
            if (java.lang.Double.isNaN(value) || java.lang.Double.isInfinite(value)) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON forbids NaN and infinities: ");
                stringBuilder.append(value);
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        put(new com.google.gson.JsonPrimitive(java.lang.Double.valueOf(value)));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(long value) throws java.io.IOException {
        put(new com.google.gson.JsonPrimitive(java.lang.Long.valueOf(value)));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(java.lang.Number value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        if (!isLenient()) {
            double d = value.doubleValue();
            if (java.lang.Double.isNaN(d) || java.lang.Double.isInfinite(d)) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON forbids NaN and infinities: ");
                stringBuilder.append(value);
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        put(new com.google.gson.JsonPrimitive(value));
        return this;
    }

    public void flush() throws java.io.IOException {
    }

    public void close() throws java.io.IOException {
        if (this.stack.isEmpty()) {
            this.stack.add(SENTINEL_CLOSED);
            return;
        }
        throw new java.io.IOException("Incomplete document");
    }
}
