package com.google.gson.internal.bind;

public final class MapTypeAdapterFactory implements com.google.gson.TypeAdapterFactory {
    final boolean complexMapKeySerialization;
    private final com.google.gson.internal.ConstructorConstructor constructorConstructor;

    private final class Adapter<K, V> extends com.google.gson.TypeAdapter<java.util.Map<K, V>> {
        private final com.google.gson.internal.ObjectConstructor<? extends java.util.Map<K, V>> constructor;
        private final com.google.gson.TypeAdapter<K> keyTypeAdapter;
        private final com.google.gson.TypeAdapter<V> valueTypeAdapter;

        public Adapter(com.google.gson.Gson context, java.lang.reflect.Type keyType, com.google.gson.TypeAdapter<K> keyTypeAdapter, java.lang.reflect.Type valueType, com.google.gson.TypeAdapter<V> valueTypeAdapter, com.google.gson.internal.ObjectConstructor<? extends java.util.Map<K, V>> constructor) {
            this.keyTypeAdapter = new com.google.gson.internal.bind.TypeAdapterRuntimeTypeWrapper(context, keyTypeAdapter, keyType);
            this.valueTypeAdapter = new com.google.gson.internal.bind.TypeAdapterRuntimeTypeWrapper(context, valueTypeAdapter, valueType);
            this.constructor = constructor;
        }

        public java.util.Map<K, V> read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            com.google.gson.stream.JsonToken peek = in.peek();
            if (peek == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            java.util.Map<K, V> map = (java.util.Map) this.constructor.construct();
            K key;
            java.lang.StringBuilder stringBuilder;
            if (peek == com.google.gson.stream.JsonToken.BEGIN_ARRAY) {
                in.beginArray();
                while (in.hasNext()) {
                    in.beginArray();
                    key = this.keyTypeAdapter.read(in);
                    if (map.put(key, this.valueTypeAdapter.read(in)) == null) {
                        in.endArray();
                    } else {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("duplicate key: ");
                        stringBuilder.append(key);
                        throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
                    }
                }
                in.endArray();
            } else {
                in.beginObject();
                while (in.hasNext()) {
                    com.google.gson.internal.JsonReaderInternalAccess.INSTANCE.promoteNameToValue(in);
                    key = this.keyTypeAdapter.read(in);
                    if (map.put(key, this.valueTypeAdapter.read(in)) != null) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("duplicate key: ");
                        stringBuilder.append(key);
                        throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
                    }
                }
                in.endObject();
            }
            return map;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.Map<K, V> map) throws java.io.IOException {
            if (map == null) {
                out.nullValue();
            } else if (com.google.gson.internal.bind.MapTypeAdapterFactory.this.complexMapKeySerialization) {
                boolean hasComplexKeys = false;
                java.util.List<com.google.gson.JsonElement> keys = new java.util.ArrayList(map.size());
                java.util.List<V> values = new java.util.ArrayList(map.size());
                for (java.util.Map.Entry<K, V> entry : map.entrySet()) {
                    int i;
                    com.google.gson.JsonElement keyElement = this.keyTypeAdapter.toJsonTree(entry.getKey());
                    keys.add(keyElement);
                    values.add(entry.getValue());
                    if (!keyElement.isJsonArray()) {
                        if (!keyElement.isJsonObject()) {
                            i = 0;
                            hasComplexKeys |= i;
                        }
                    }
                    i = 1;
                    hasComplexKeys |= i;
                }
                int size;
                int i2;
                if (hasComplexKeys) {
                    out.beginArray();
                    size = keys.size();
                    for (i2 = 0; i2 < size; i2++) {
                        out.beginArray();
                        com.google.gson.internal.Streams.write((com.google.gson.JsonElement) keys.get(i2), out);
                        this.valueTypeAdapter.write(out, values.get(i2));
                        out.endArray();
                    }
                    out.endArray();
                } else {
                    out.beginObject();
                    size = keys.size();
                    for (i2 = 0; i2 < size; i2++) {
                        out.name(keyToString((com.google.gson.JsonElement) keys.get(i2)));
                        this.valueTypeAdapter.write(out, values.get(i2));
                    }
                    out.endObject();
                }
            } else {
                out.beginObject();
                for (java.util.Map.Entry<K, V> entry2 : map.entrySet()) {
                    out.name(java.lang.String.valueOf(entry2.getKey()));
                    this.valueTypeAdapter.write(out, entry2.getValue());
                }
                out.endObject();
            }
        }

        private java.lang.String keyToString(com.google.gson.JsonElement keyElement) {
            if (keyElement.isJsonPrimitive()) {
                com.google.gson.JsonPrimitive primitive = keyElement.getAsJsonPrimitive();
                if (primitive.isNumber()) {
                    return java.lang.String.valueOf(primitive.getAsNumber());
                }
                if (primitive.isBoolean()) {
                    return java.lang.Boolean.toString(primitive.getAsBoolean());
                }
                if (primitive.isString()) {
                    return primitive.getAsString();
                }
                throw new java.lang.AssertionError();
            } else if (keyElement.isJsonNull()) {
                return "null";
            } else {
                throw new java.lang.AssertionError();
            }
        }
    }

    public MapTypeAdapterFactory(com.google.gson.internal.ConstructorConstructor constructorConstructor, boolean complexMapKeySerialization) {
        this.constructorConstructor = constructorConstructor;
        this.complexMapKeySerialization = complexMapKeySerialization;
    }

    public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
        com.google.gson.Gson gson2 = gson;
        java.lang.reflect.Type type = typeToken.getType();
        if (!java.util.Map.class.isAssignableFrom(typeToken.getRawType())) {
            return null;
        }
        java.lang.reflect.Type[] keyAndValueTypes = com.google.gson.internal.C$Gson$Types.getMapKeyAndValueTypes(type, com.google.gson.internal.C$Gson$Types.getRawType(type));
        com.google.gson.TypeAdapter<?> keyAdapter = getKeyAdapter(gson2, keyAndValueTypes[0]);
        return new com.google.gson.internal.bind.MapTypeAdapterFactory.Adapter(gson2, keyAndValueTypes[0], keyAdapter, keyAndValueTypes[1], gson2.getAdapter(com.google.gson.reflect.TypeToken.get(keyAndValueTypes[1])), this.constructorConstructor.get(typeToken));
    }

    private com.google.gson.TypeAdapter<?> getKeyAdapter(com.google.gson.Gson context, java.lang.reflect.Type keyType) {
        if (keyType != java.lang.Boolean.TYPE) {
            if (keyType != java.lang.Boolean.class) {
                return context.getAdapter(com.google.gson.reflect.TypeToken.get(keyType));
            }
        }
        return com.google.gson.internal.bind.TypeAdapters.BOOLEAN_AS_STRING;
    }
}
