package com.google.gson.internal.bind;

public final class ObjectTypeAdapter extends com.google.gson.TypeAdapter<java.lang.Object> {
    public static final com.google.gson.TypeAdapterFactory FACTORY = new com.google.gson.TypeAdapterFactory() {
        public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> type) {
            if (type.getRawType() == java.lang.Object.class) {
                return new com.google.gson.internal.bind.ObjectTypeAdapter(gson);
            }
            return null;
        }
    };
    private final com.google.gson.Gson gson;

    ObjectTypeAdapter(com.google.gson.Gson gson) {
        this.gson = gson;
    }

    public java.lang.Object read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
        switch (in.peek()) {
            case BEGIN_ARRAY:
                java.util.List<java.lang.Object> list = new java.util.ArrayList();
                in.beginArray();
                while (in.hasNext()) {
                    list.add(read(in));
                }
                in.endArray();
                return list;
            case BEGIN_OBJECT:
                java.util.Map<java.lang.String, java.lang.Object> map = new com.google.gson.internal.LinkedTreeMap();
                in.beginObject();
                while (in.hasNext()) {
                    map.put(in.nextName(), read(in));
                }
                in.endObject();
                return map;
            case STRING:
                return in.nextString();
            case NUMBER:
                return java.lang.Double.valueOf(in.nextDouble());
            case BOOLEAN:
                return java.lang.Boolean.valueOf(in.nextBoolean());
            case NULL:
                in.nextNull();
                return null;
            default:
                throw new java.lang.IllegalStateException();
        }
    }

    public void write(com.google.gson.stream.JsonWriter out, java.lang.Object value) throws java.io.IOException {
        if (value == null) {
            out.nullValue();
            return;
        }
        com.google.gson.TypeAdapter<java.lang.Object> typeAdapter = this.gson.getAdapter(value.getClass());
        if (typeAdapter instanceof com.google.gson.internal.bind.ObjectTypeAdapter) {
            out.beginObject();
            out.endObject();
            return;
        }
        typeAdapter.write(out, value);
    }
}
