package com.google.gson.internal.bind;

public final class ReflectiveTypeAdapterFactory implements com.google.gson.TypeAdapterFactory {
    private final com.google.gson.internal.ConstructorConstructor constructorConstructor;
    private final com.google.gson.internal.Excluder excluder;
    private final com.google.gson.FieldNamingStrategy fieldNamingPolicy;
    private final com.google.gson.internal.bind.JsonAdapterAnnotationTypeAdapterFactory jsonAdapterFactory;

    static abstract class BoundField {
        final boolean deserialized;
        final java.lang.String name;
        final boolean serialized;

        abstract void read(com.google.gson.stream.JsonReader jsonReader, java.lang.Object obj) throws java.io.IOException, java.lang.IllegalAccessException;

        abstract void write(com.google.gson.stream.JsonWriter jsonWriter, java.lang.Object obj) throws java.io.IOException, java.lang.IllegalAccessException;

        abstract boolean writeField(java.lang.Object obj) throws java.io.IOException, java.lang.IllegalAccessException;

        protected BoundField(java.lang.String name, boolean serialized, boolean deserialized) {
            this.name = name;
            this.serialized = serialized;
            this.deserialized = deserialized;
        }
    }

    public static final class Adapter<T> extends com.google.gson.TypeAdapter<T> {
        private final java.util.Map<java.lang.String, com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField> boundFields;
        private final com.google.gson.internal.ObjectConstructor<T> constructor;

        Adapter(com.google.gson.internal.ObjectConstructor<T> constructor, java.util.Map<java.lang.String, com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField> boundFields) {
            this.constructor = constructor;
            this.boundFields = boundFields;
        }

        public T read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            T instance = this.constructor.construct();
            try {
                in.beginObject();
                while (in.hasNext()) {
                    com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField field = (com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField) this.boundFields.get(in.nextName());
                    if (field != null) {
                        if (field.deserialized) {
                            field.read(in, instance);
                        }
                    }
                    in.skipValue();
                }
                in.endObject();
                return instance;
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            } catch (java.lang.IllegalAccessException e2) {
                throw new java.lang.AssertionError(e2);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, T value) throws java.io.IOException {
            if (value == null) {
                out.nullValue();
                return;
            }
            out.beginObject();
            try {
                for (com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField boundField : this.boundFields.values()) {
                    if (boundField.writeField(value)) {
                        out.name(boundField.name);
                        boundField.write(out, value);
                    }
                }
                out.endObject();
            } catch (java.lang.IllegalAccessException e) {
                throw new java.lang.AssertionError(e);
            }
        }
    }

    public ReflectiveTypeAdapterFactory(com.google.gson.internal.ConstructorConstructor constructorConstructor, com.google.gson.FieldNamingStrategy fieldNamingPolicy, com.google.gson.internal.Excluder excluder, com.google.gson.internal.bind.JsonAdapterAnnotationTypeAdapterFactory jsonAdapterFactory) {
        this.constructorConstructor = constructorConstructor;
        this.fieldNamingPolicy = fieldNamingPolicy;
        this.excluder = excluder;
        this.jsonAdapterFactory = jsonAdapterFactory;
    }

    public boolean excludeField(java.lang.reflect.Field f, boolean serialize) {
        return excludeField(f, serialize, this.excluder);
    }

    static boolean excludeField(java.lang.reflect.Field f, boolean serialize, com.google.gson.internal.Excluder excluder) {
        return (excluder.excludeClass(f.getType(), serialize) || excluder.excludeField(f, serialize)) ? false : true;
    }

    private java.util.List<java.lang.String> getFieldNames(java.lang.reflect.Field f) {
        com.google.gson.annotations.SerializedName annotation = (com.google.gson.annotations.SerializedName) f.getAnnotation(com.google.gson.annotations.SerializedName.class);
        if (annotation == null) {
            return java.util.Collections.singletonList(this.fieldNamingPolicy.translateName(f));
        }
        java.lang.String serializedName = annotation.value();
        java.lang.String[] alternates = annotation.alternate();
        if (alternates.length == 0) {
            return java.util.Collections.singletonList(serializedName);
        }
        java.util.List<java.lang.String> fieldNames = new java.util.ArrayList(alternates.length + 1);
        fieldNames.add(serializedName);
        for (java.lang.String alternate : alternates) {
            fieldNames.add(alternate);
        }
        return fieldNames;
    }

    public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> type) {
        java.lang.Class<? super T> raw = type.getRawType();
        if (java.lang.Object.class.isAssignableFrom(raw)) {
            return new com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.Adapter(this.constructorConstructor.get(type), getBoundFields(gson, type, raw));
        }
        return null;
    }

    private com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField createBoundField(com.google.gson.Gson context, java.lang.reflect.Field field, java.lang.String name, com.google.gson.reflect.TypeToken<?> fieldType, boolean serialize, boolean deserialize) {
        com.google.gson.Gson gson = context;
        com.google.gson.reflect.TypeToken typeToken = fieldType;
        boolean isPrimitive = com.google.gson.internal.Primitives.isPrimitive(fieldType.getRawType());
        java.lang.reflect.Field field2 = field;
        com.google.gson.annotations.JsonAdapter annotation = (com.google.gson.annotations.JsonAdapter) field2.getAnnotation(com.google.gson.annotations.JsonAdapter.class);
        com.google.gson.TypeAdapter<?> mapped = null;
        if (annotation != null) {
            mapped = this.jsonAdapterFactory.getTypeAdapter(this.constructorConstructor, gson, typeToken, annotation);
        }
        final boolean jsonAdapterPresent = mapped != null;
        if (mapped == null) {
            mapped = gson.getAdapter(typeToken);
        }
        final com.google.gson.TypeAdapter<?> typeAdapter = mapped;
        final java.lang.reflect.Field field3 = field2;
        final com.google.gson.Gson gson2 = gson;
        final com.google.gson.reflect.TypeToken typeToken2 = typeToken;
        annotation = isPrimitive;
        return new com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField(name, serialize, deserialize) {
            void write(com.google.gson.stream.JsonWriter writer, java.lang.Object value) throws java.io.IOException, java.lang.IllegalAccessException {
                com.google.gson.TypeAdapter t;
                java.lang.Object fieldValue = field3.get(value);
                if (jsonAdapterPresent) {
                    t = typeAdapter;
                } else {
                    t = new com.google.gson.internal.bind.TypeAdapterRuntimeTypeWrapper(gson2, typeAdapter, typeToken2.getType());
                }
                t.write(writer, fieldValue);
            }

            void read(com.google.gson.stream.JsonReader reader, java.lang.Object value) throws java.io.IOException, java.lang.IllegalAccessException {
                java.lang.Object fieldValue = typeAdapter.read(reader);
                if (fieldValue != null || !annotation) {
                    field3.set(value, fieldValue);
                }
            }

            public boolean writeField(java.lang.Object value) throws java.io.IOException, java.lang.IllegalAccessException {
                boolean z = false;
                if (!this.serialized) {
                    return false;
                }
                if (field3.get(value) != value) {
                    z = true;
                }
                return z;
            }
        };
    }

    private java.util.Map<java.lang.String, com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField> getBoundFields(com.google.gson.Gson context, com.google.gson.reflect.TypeToken<?> type, java.lang.Class<?> raw) {
        com.google.gson.internal.bind.ReflectiveTypeAdapterFactory reflectiveTypeAdapterFactory = this;
        java.util.LinkedHashMap result = new java.util.LinkedHashMap();
        if (raw.isInterface()) {
            return result;
        }
        java.lang.reflect.Type declaredType = type.getType();
        com.google.gson.reflect.TypeToken<?> type2 = type;
        java.lang.Class<?> raw2 = raw;
        while (true) {
            java.lang.reflect.Type declaredType2 = declaredType;
            if (raw2 == java.lang.Object.class) {
                return result;
            }
            java.lang.reflect.Field[] fields = raw2.getDeclaredFields();
            int length = fields.length;
            boolean z = false;
            int i = 0;
            while (i < length) {
                java.lang.reflect.Field field = fields[i];
                boolean serialize = reflectiveTypeAdapterFactory.excludeField(field, true);
                boolean deserialize = reflectiveTypeAdapterFactory.excludeField(field, z);
                if (serialize || deserialize) {
                    com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField previous;
                    java.util.List<java.lang.String> fieldNames;
                    java.lang.reflect.Type fieldType;
                    java.lang.reflect.Field field2;
                    field.setAccessible(true);
                    java.lang.reflect.Type fieldType2 = com.google.gson.internal.C$Gson$Types.resolve(type2.getType(), raw2, field.getGenericType());
                    java.util.List<java.lang.String> fieldNames2 = reflectiveTypeAdapterFactory.getFieldNames(field);
                    int i2 = 0;
                    int size = fieldNames2.size();
                    boolean z2 = serialize;
                    com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField previous2 = null;
                    boolean serialize2 = z2;
                    while (i2 < size) {
                        java.lang.String name = (java.lang.String) fieldNames2.get(i2);
                        if (i2 != 0) {
                            serialize2 = false;
                        }
                        boolean serialize3 = serialize2;
                        com.google.gson.internal.bind.ReflectiveTypeAdapterFactory boundField = reflectiveTypeAdapterFactory;
                        previous = previous2;
                        int i3 = i2;
                        int size2 = size;
                        fieldNames = fieldNames2;
                        fieldType = fieldType2;
                        field2 = field;
                        previous2 = (com.google.gson.internal.bind.ReflectiveTypeAdapterFactory.BoundField) result.put(name, boundField.createBoundField(context, field, name, com.google.gson.reflect.TypeToken.get(fieldType2), serialize3, deserialize));
                        if (previous == null) {
                        } else {
                            previous2 = previous;
                        }
                        i2 = i3 + 1;
                        serialize2 = serialize3;
                        fieldType2 = fieldType;
                        size = size2;
                        fieldNames2 = fieldNames;
                        field = field2;
                        reflectiveTypeAdapterFactory = this;
                    }
                    previous = previous2;
                    fieldNames = fieldNames2;
                    fieldType = fieldType2;
                    field2 = field;
                    if (previous != null) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append(declaredType2);
                        stringBuilder.append(" declares multiple JSON fields named ");
                        stringBuilder.append(previous.name);
                        throw new java.lang.IllegalArgumentException(stringBuilder.toString());
                    }
                }
                i++;
                reflectiveTypeAdapterFactory = this;
                z = false;
            }
            type2 = com.google.gson.reflect.TypeToken.get(com.google.gson.internal.C$Gson$Types.resolve(type2.getType(), raw2, raw2.getGenericSuperclass()));
            raw2 = type2.getRawType();
            declaredType = declaredType2;
            reflectiveTypeAdapterFactory = this;
        }
    }
}
