package com.google.gson.internal.bind;

public final class TreeTypeAdapter<T> extends com.google.gson.TypeAdapter<T> {
    private final com.google.gson.internal.bind.TreeTypeAdapter.GsonContextImpl context = new com.google.gson.internal.bind.TreeTypeAdapter.GsonContextImpl();
    private com.google.gson.TypeAdapter<T> delegate;
    private final com.google.gson.JsonDeserializer<T> deserializer;
    final com.google.gson.Gson gson;
    private final com.google.gson.JsonSerializer<T> serializer;
    private final com.google.gson.TypeAdapterFactory skipPast;
    private final com.google.gson.reflect.TypeToken<T> typeToken;

    private final class GsonContextImpl implements com.google.gson.JsonSerializationContext, com.google.gson.JsonDeserializationContext {
        private GsonContextImpl() {
        }

        public com.google.gson.JsonElement serialize(java.lang.Object src) {
            return com.google.gson.internal.bind.TreeTypeAdapter.this.gson.toJsonTree(src);
        }

        public com.google.gson.JsonElement serialize(java.lang.Object src, java.lang.reflect.Type typeOfSrc) {
            return com.google.gson.internal.bind.TreeTypeAdapter.this.gson.toJsonTree(src, typeOfSrc);
        }

        public <R> R deserialize(com.google.gson.JsonElement json, java.lang.reflect.Type typeOfT) throws com.google.gson.JsonParseException {
            return com.google.gson.internal.bind.TreeTypeAdapter.this.gson.fromJson(json, typeOfT);
        }
    }

    private static final class SingleTypeFactory implements com.google.gson.TypeAdapterFactory {
        private final com.google.gson.JsonDeserializer<?> deserializer;
        private final com.google.gson.reflect.TypeToken<?> exactType;
        private final java.lang.Class<?> hierarchyType;
        private final boolean matchRawType;
        private final com.google.gson.JsonSerializer<?> serializer;

        SingleTypeFactory(java.lang.Object typeAdapter, com.google.gson.reflect.TypeToken<?> exactType, boolean matchRawType, java.lang.Class<?> hierarchyType) {
            boolean z;
            com.google.gson.JsonDeserializer jsonDeserializer = null;
            this.serializer = typeAdapter instanceof com.google.gson.JsonSerializer ? (com.google.gson.JsonSerializer) typeAdapter : null;
            if (typeAdapter instanceof com.google.gson.JsonDeserializer) {
                jsonDeserializer = (com.google.gson.JsonDeserializer) typeAdapter;
            }
            this.deserializer = jsonDeserializer;
            if (this.serializer == null) {
                if (this.deserializer == null) {
                    z = false;
                    com.google.gson.internal.C$Gson$Preconditions.checkArgument(z);
                    this.exactType = exactType;
                    this.matchRawType = matchRawType;
                    this.hierarchyType = hierarchyType;
                }
            }
            z = true;
            com.google.gson.internal.C$Gson$Preconditions.checkArgument(z);
            this.exactType = exactType;
            this.matchRawType = matchRawType;
            this.hierarchyType = hierarchyType;
        }

        public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> type) {
            boolean matches;
            if (this.exactType != null) {
                if (!this.exactType.equals(type)) {
                    if (!this.matchRawType || this.exactType.getType() != type.getRawType()) {
                        matches = false;
                    }
                }
                matches = true;
            } else {
                matches = this.hierarchyType.isAssignableFrom(type.getRawType());
            }
            return matches ? new com.google.gson.internal.bind.TreeTypeAdapter(this.serializer, this.deserializer, gson, type, this) : null;
        }
    }

    public TreeTypeAdapter(com.google.gson.JsonSerializer<T> serializer, com.google.gson.JsonDeserializer<T> deserializer, com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken, com.google.gson.TypeAdapterFactory skipPast) {
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.gson = gson;
        this.typeToken = typeToken;
        this.skipPast = skipPast;
    }

    public T read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
        if (this.deserializer == null) {
            return delegate().read(in);
        }
        com.google.gson.JsonElement value = com.google.gson.internal.Streams.parse(in);
        if (value.isJsonNull()) {
            return null;
        }
        return this.deserializer.deserialize(value, this.typeToken.getType(), this.context);
    }

    public void write(com.google.gson.stream.JsonWriter out, T value) throws java.io.IOException {
        if (this.serializer == null) {
            delegate().write(out, value);
        } else if (value == null) {
            out.nullValue();
        } else {
            com.google.gson.internal.Streams.write(this.serializer.serialize(value, this.typeToken.getType(), this.context), out);
        }
    }

    private com.google.gson.TypeAdapter<T> delegate() {
        com.google.gson.TypeAdapter<T> d = this.delegate;
        if (d != null) {
            return d;
        }
        com.google.gson.TypeAdapter delegateAdapter = this.gson.getDelegateAdapter(this.skipPast, this.typeToken);
        this.delegate = delegateAdapter;
        return delegateAdapter;
    }

    public static com.google.gson.TypeAdapterFactory newFactory(com.google.gson.reflect.TypeToken<?> exactType, java.lang.Object typeAdapter) {
        return new com.google.gson.internal.bind.TreeTypeAdapter.SingleTypeFactory(typeAdapter, exactType, false, null);
    }

    public static com.google.gson.TypeAdapterFactory newFactoryWithMatchRawType(com.google.gson.reflect.TypeToken<?> exactType, java.lang.Object typeAdapter) {
        return new com.google.gson.internal.bind.TreeTypeAdapter.SingleTypeFactory(typeAdapter, exactType, exactType.getType() == exactType.getRawType(), null);
    }

    public static com.google.gson.TypeAdapterFactory newTypeHierarchyFactory(java.lang.Class<?> hierarchyType, java.lang.Object typeAdapter) {
        return new com.google.gson.internal.bind.TreeTypeAdapter.SingleTypeFactory(typeAdapter, null, false, hierarchyType);
    }
}
