package com.google.gson.internal.bind;

public final class TypeAdapters {
    public static final com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicBoolean> ATOMIC_BOOLEAN = new com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicBoolean>() {
        public java.util.concurrent.atomic.AtomicBoolean read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            return new java.util.concurrent.atomic.AtomicBoolean(in.nextBoolean());
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.concurrent.atomic.AtomicBoolean value) throws java.io.IOException {
            out.value(value.get());
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapterFactory ATOMIC_BOOLEAN_FACTORY = newFactory(java.util.concurrent.atomic.AtomicBoolean.class, ATOMIC_BOOLEAN);
    public static final com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicInteger> ATOMIC_INTEGER = new com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicInteger>() {
        public java.util.concurrent.atomic.AtomicInteger read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            try {
                return new java.util.concurrent.atomic.AtomicInteger(in.nextInt());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.concurrent.atomic.AtomicInteger value) throws java.io.IOException {
            out.value((long) value.get());
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicIntegerArray> ATOMIC_INTEGER_ARRAY = new com.google.gson.TypeAdapter<java.util.concurrent.atomic.AtomicIntegerArray>() {
        public java.util.concurrent.atomic.AtomicIntegerArray read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            java.util.List<java.lang.Integer> list = new java.util.ArrayList();
            in.beginArray();
            while (in.hasNext()) {
                try {
                    list.add(java.lang.Integer.valueOf(in.nextInt()));
                } catch (java.lang.Throwable e) {
                    throw new com.google.gson.JsonSyntaxException(e);
                }
            }
            in.endArray();
            int length = list.size();
            java.util.concurrent.atomic.AtomicIntegerArray array = new java.util.concurrent.atomic.AtomicIntegerArray(length);
            for (int i = 0; i < length; i++) {
                array.set(i, ((java.lang.Integer) list.get(i)).intValue());
            }
            return array;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.concurrent.atomic.AtomicIntegerArray value) throws java.io.IOException {
            out.beginArray();
            int length = value.length();
            for (int i = 0; i < length; i++) {
                out.value((long) value.get(i));
            }
            out.endArray();
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapterFactory ATOMIC_INTEGER_ARRAY_FACTORY = newFactory(java.util.concurrent.atomic.AtomicIntegerArray.class, ATOMIC_INTEGER_ARRAY);
    public static final com.google.gson.TypeAdapterFactory ATOMIC_INTEGER_FACTORY = newFactory(java.util.concurrent.atomic.AtomicInteger.class, ATOMIC_INTEGER);
    public static final com.google.gson.TypeAdapter<java.math.BigDecimal> BIG_DECIMAL = new com.google.gson.TypeAdapter<java.math.BigDecimal>() {
        public java.math.BigDecimal read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return new java.math.BigDecimal(in.nextString());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.math.BigDecimal value) throws java.io.IOException {
            out.value((java.lang.Number) value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.math.BigInteger> BIG_INTEGER = new com.google.gson.TypeAdapter<java.math.BigInteger>() {
        public java.math.BigInteger read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return new java.math.BigInteger(in.nextString());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.math.BigInteger value) throws java.io.IOException {
            out.value((java.lang.Number) value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.util.BitSet> BIT_SET = new com.google.gson.TypeAdapter<java.util.BitSet>() {
        public java.util.BitSet read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            java.util.BitSet bitset = new java.util.BitSet();
            in.beginArray();
            int i = 0;
            com.google.gson.stream.JsonToken tokenType = in.peek();
            while (tokenType != com.google.gson.stream.JsonToken.END_ARRAY) {
                boolean set = false;
                switch (tokenType) {
                    case NUMBER:
                        if (in.nextInt() != 0) {
                            set = true;
                        }
                        break;
                    case BOOLEAN:
                        set = in.nextBoolean();
                        break;
                    case STRING:
                        java.lang.String stringValue = in.nextString();
                        try {
                            if (java.lang.Integer.parseInt(stringValue) != 0) {
                                set = true;
                            }
                            break;
                        } catch (java.lang.NumberFormatException e) {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("Error: Expecting: bitset number value (1, 0), Found: ");
                            stringBuilder.append(stringValue);
                            throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
                        }
                    default:
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("Invalid bitset value type: ");
                        stringBuilder2.append(tokenType);
                        throw new com.google.gson.JsonSyntaxException(stringBuilder2.toString());
                }
                if (set) {
                    bitset.set(i);
                }
                i++;
                tokenType = in.peek();
            }
            in.endArray();
            return bitset;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.BitSet src) throws java.io.IOException {
            out.beginArray();
            int length = src.length();
            for (int i = 0; i < length; i++) {
                out.value((long) src.get(i));
            }
            out.endArray();
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapterFactory BIT_SET_FACTORY = newFactory(java.util.BitSet.class, BIT_SET);
    public static final com.google.gson.TypeAdapter<java.lang.Boolean> BOOLEAN = new com.google.gson.TypeAdapter<java.lang.Boolean>() {
        public java.lang.Boolean read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            } else if (in.peek() == com.google.gson.stream.JsonToken.STRING) {
                return java.lang.Boolean.valueOf(java.lang.Boolean.parseBoolean(in.nextString()));
            } else {
                return java.lang.Boolean.valueOf(in.nextBoolean());
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Boolean value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.lang.Boolean> BOOLEAN_AS_STRING = new com.google.gson.TypeAdapter<java.lang.Boolean>() {
        public java.lang.Boolean read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return java.lang.Boolean.valueOf(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Boolean value) throws java.io.IOException {
            out.value(value == null ? "null" : value.toString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory BOOLEAN_FACTORY = newFactory(java.lang.Boolean.TYPE, java.lang.Boolean.class, BOOLEAN);
    public static final com.google.gson.TypeAdapter<java.lang.Number> BYTE = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return java.lang.Byte.valueOf((byte) in.nextInt());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapterFactory BYTE_FACTORY = newFactory(java.lang.Byte.TYPE, java.lang.Byte.class, BYTE);
    public static final com.google.gson.TypeAdapter<java.util.Calendar> CALENDAR = new com.google.gson.TypeAdapter<java.util.Calendar>() {
        private static final java.lang.String DAY_OF_MONTH = "dayOfMonth";
        private static final java.lang.String HOUR_OF_DAY = "hourOfDay";
        private static final java.lang.String MINUTE = "minute";
        private static final java.lang.String MONTH = "month";
        private static final java.lang.String SECOND = "second";
        private static final java.lang.String YEAR = "year";

        public java.util.Calendar read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            in.beginObject();
            int year = 0;
            int month = 0;
            int dayOfMonth = 0;
            int hourOfDay = 0;
            int minute = 0;
            int second = 0;
            while (in.peek() != com.google.gson.stream.JsonToken.END_OBJECT) {
                java.lang.String name = in.nextName();
                int value = in.nextInt();
                if ("year".equals(name)) {
                    year = value;
                } else if ("month".equals(name)) {
                    month = value;
                } else if ("dayOfMonth".equals(name)) {
                    dayOfMonth = value;
                } else if ("hourOfDay".equals(name)) {
                    hourOfDay = value;
                } else if ("minute".equals(name)) {
                    minute = value;
                } else if ("second".equals(name)) {
                    second = value;
                }
            }
            in.endObject();
            return new java.util.GregorianCalendar(year, month, dayOfMonth, hourOfDay, minute, second);
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.Calendar value) throws java.io.IOException {
            if (value == null) {
                out.nullValue();
                return;
            }
            out.beginObject();
            out.name("year");
            out.value((long) value.get(1));
            out.name("month");
            out.value((long) value.get(2));
            out.name("dayOfMonth");
            out.value((long) value.get(5));
            out.name("hourOfDay");
            out.value((long) value.get(11));
            out.name("minute");
            out.value((long) value.get(12));
            out.name("second");
            out.value((long) value.get(13));
            out.endObject();
        }
    };
    public static final com.google.gson.TypeAdapterFactory CALENDAR_FACTORY = newFactoryForMultipleTypes(java.util.Calendar.class, java.util.GregorianCalendar.class, CALENDAR);
    public static final com.google.gson.TypeAdapter<java.lang.Character> CHARACTER = new com.google.gson.TypeAdapter<java.lang.Character>() {
        public java.lang.Character read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            java.lang.String str = in.nextString();
            if (str.length() == 1) {
                return java.lang.Character.valueOf(str.charAt(0));
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Expecting character, got: ");
            stringBuilder.append(str);
            throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Character value) throws java.io.IOException {
            out.value(value == null ? null : java.lang.String.valueOf(value));
        }
    };
    public static final com.google.gson.TypeAdapterFactory CHARACTER_FACTORY = newFactory(java.lang.Character.TYPE, java.lang.Character.class, CHARACTER);
    public static final com.google.gson.TypeAdapter<java.lang.Class> CLASS = new com.google.gson.TypeAdapter<java.lang.Class>() {
        public void write(com.google.gson.stream.JsonWriter out, java.lang.Class value) throws java.io.IOException {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Attempted to serialize java.lang.Class: ");
            stringBuilder.append(value.getName());
            stringBuilder.append(". Forgot to register a type adapter?");
            throw new java.lang.UnsupportedOperationException(stringBuilder.toString());
        }

        public java.lang.Class read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            throw new java.lang.UnsupportedOperationException("Attempted to deserialize a java.lang.Class. Forgot to register a type adapter?");
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapterFactory CLASS_FACTORY = newFactory(java.lang.Class.class, CLASS);
    public static final com.google.gson.TypeAdapter<java.util.Currency> CURRENCY = new com.google.gson.TypeAdapter<java.util.Currency>() {
        public java.util.Currency read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            return java.util.Currency.getInstance(in.nextString());
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.Currency value) throws java.io.IOException {
            out.value(value.getCurrencyCode());
        }
    }.nullSafe();
    public static final com.google.gson.TypeAdapterFactory CURRENCY_FACTORY = newFactory(java.util.Currency.class, CURRENCY);
    public static final com.google.gson.TypeAdapter<java.lang.Number> DOUBLE = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return java.lang.Double.valueOf(in.nextDouble());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapterFactory ENUM_FACTORY = new com.google.gson.TypeAdapterFactory() {
        public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
            java.lang.Class<? super T> rawType = typeToken.getRawType();
            if (java.lang.Enum.class.isAssignableFrom(rawType)) {
                if (rawType != java.lang.Enum.class) {
                    if (!rawType.isEnum()) {
                        rawType = rawType.getSuperclass();
                    }
                    return new com.google.gson.internal.bind.TypeAdapters.EnumTypeAdapter(rawType);
                }
            }
            return null;
        }
    };
    public static final com.google.gson.TypeAdapter<java.lang.Number> FLOAT = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return java.lang.Float.valueOf((float) in.nextDouble());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.net.InetAddress> INET_ADDRESS = new com.google.gson.TypeAdapter<java.net.InetAddress>() {
        public java.net.InetAddress read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return java.net.InetAddress.getByName(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.net.InetAddress value) throws java.io.IOException {
            out.value(value == null ? null : value.getHostAddress());
        }
    };
    public static final com.google.gson.TypeAdapterFactory INET_ADDRESS_FACTORY = newTypeHierarchyFactory(java.net.InetAddress.class, INET_ADDRESS);
    public static final com.google.gson.TypeAdapter<java.lang.Number> INTEGER = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return java.lang.Integer.valueOf(in.nextInt());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapterFactory INTEGER_FACTORY = newFactory(java.lang.Integer.TYPE, java.lang.Integer.class, INTEGER);
    public static final com.google.gson.TypeAdapter<com.google.gson.JsonElement> JSON_ELEMENT = new com.google.gson.TypeAdapter<com.google.gson.JsonElement>() {
        public com.google.gson.JsonElement read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            switch (in.peek()) {
                case NUMBER:
                    return new com.google.gson.JsonPrimitive(new com.google.gson.internal.LazilyParsedNumber(in.nextString()));
                case BOOLEAN:
                    return new com.google.gson.JsonPrimitive(java.lang.Boolean.valueOf(in.nextBoolean()));
                case STRING:
                    return new com.google.gson.JsonPrimitive(in.nextString());
                case NULL:
                    in.nextNull();
                    return com.google.gson.JsonNull.INSTANCE;
                case BEGIN_ARRAY:
                    com.google.gson.JsonArray array = new com.google.gson.JsonArray();
                    in.beginArray();
                    while (in.hasNext()) {
                        array.add(read(in));
                    }
                    in.endArray();
                    return array;
                case BEGIN_OBJECT:
                    com.google.gson.JsonObject object = new com.google.gson.JsonObject();
                    in.beginObject();
                    while (in.hasNext()) {
                        object.add(in.nextName(), read(in));
                    }
                    in.endObject();
                    return object;
                default:
                    throw new java.lang.IllegalArgumentException();
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, com.google.gson.JsonElement value) throws java.io.IOException {
            if (value != null) {
                if (!value.isJsonNull()) {
                    java.util.Iterator it;
                    if (value.isJsonPrimitive()) {
                        com.google.gson.JsonPrimitive primitive = value.getAsJsonPrimitive();
                        if (primitive.isNumber()) {
                            out.value(primitive.getAsNumber());
                        } else if (primitive.isBoolean()) {
                            out.value(primitive.getAsBoolean());
                        } else {
                            out.value(primitive.getAsString());
                        }
                        return;
                    } else if (value.isJsonArray()) {
                        out.beginArray();
                        it = value.getAsJsonArray().iterator();
                        while (it.hasNext()) {
                            write(out, (com.google.gson.JsonElement) it.next());
                        }
                        out.endArray();
                        return;
                    } else if (value.isJsonObject()) {
                        out.beginObject();
                        for (java.util.Map.Entry<java.lang.String, com.google.gson.JsonElement> e : value.getAsJsonObject().entrySet()) {
                            out.name((java.lang.String) e.getKey());
                            write(out, (com.google.gson.JsonElement) e.getValue());
                        }
                        out.endObject();
                        return;
                    } else {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Couldn't write ");
                        stringBuilder.append(value.getClass());
                        throw new java.lang.IllegalArgumentException(stringBuilder.toString());
                    }
                }
            }
            out.nullValue();
        }
    };
    public static final com.google.gson.TypeAdapterFactory JSON_ELEMENT_FACTORY = newTypeHierarchyFactory(com.google.gson.JsonElement.class, JSON_ELEMENT);
    public static final com.google.gson.TypeAdapter<java.util.Locale> LOCALE = new com.google.gson.TypeAdapter<java.util.Locale>() {
        public java.util.Locale read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            java.util.StringTokenizer tokenizer = new java.util.StringTokenizer(in.nextString(), "_");
            java.lang.String language = null;
            java.lang.String country = null;
            java.lang.String variant = null;
            if (tokenizer.hasMoreElements()) {
                language = tokenizer.nextToken();
            }
            if (tokenizer.hasMoreElements()) {
                country = tokenizer.nextToken();
            }
            if (tokenizer.hasMoreElements()) {
                variant = tokenizer.nextToken();
            }
            if (country == null && variant == null) {
                return new java.util.Locale(language);
            }
            if (variant == null) {
                return new java.util.Locale(language, country);
            }
            return new java.util.Locale(language, country, variant);
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.Locale value) throws java.io.IOException {
            out.value(value == null ? null : value.toString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory LOCALE_FACTORY = newFactory(java.util.Locale.class, LOCALE);
    public static final com.google.gson.TypeAdapter<java.lang.Number> LONG = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return java.lang.Long.valueOf(in.nextLong());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.lang.Number> NUMBER = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            com.google.gson.stream.JsonToken jsonToken = in.peek();
            int i = com.google.gson.internal.bind.TypeAdapters.AnonymousClass36.$SwitchMap$com$google$gson$stream$JsonToken[jsonToken.ordinal()];
            if (i != 1) {
                switch (i) {
                    case 3:
                        break;
                    case 4:
                        in.nextNull();
                        return null;
                    default:
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Expecting number, got: ");
                        stringBuilder.append(jsonToken);
                        throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
                }
            }
            return new com.google.gson.internal.LazilyParsedNumber(in.nextString());
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapterFactory NUMBER_FACTORY = newFactory(java.lang.Number.class, NUMBER);
    public static final com.google.gson.TypeAdapter<java.lang.Number> SHORT = new com.google.gson.TypeAdapter<java.lang.Number>() {
        public java.lang.Number read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                return java.lang.Short.valueOf((short) in.nextInt());
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonSyntaxException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.Number value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapterFactory SHORT_FACTORY = newFactory(java.lang.Short.TYPE, java.lang.Short.class, SHORT);
    public static final com.google.gson.TypeAdapter<java.lang.String> STRING = new com.google.gson.TypeAdapter<java.lang.String>() {
        public java.lang.String read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            com.google.gson.stream.JsonToken peek = in.peek();
            if (peek == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            } else if (peek == com.google.gson.stream.JsonToken.BOOLEAN) {
                return java.lang.Boolean.toString(in.nextBoolean());
            } else {
                return in.nextString();
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.String value) throws java.io.IOException {
            out.value(value);
        }
    };
    public static final com.google.gson.TypeAdapter<java.lang.StringBuffer> STRING_BUFFER = new com.google.gson.TypeAdapter<java.lang.StringBuffer>() {
        public java.lang.StringBuffer read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return new java.lang.StringBuffer(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.StringBuffer value) throws java.io.IOException {
            out.value(value == null ? null : value.toString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory STRING_BUFFER_FACTORY = newFactory(java.lang.StringBuffer.class, STRING_BUFFER);
    public static final com.google.gson.TypeAdapter<java.lang.StringBuilder> STRING_BUILDER = new com.google.gson.TypeAdapter<java.lang.StringBuilder>() {
        public java.lang.StringBuilder read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return new java.lang.StringBuilder(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.lang.StringBuilder value) throws java.io.IOException {
            out.value(value == null ? null : value.toString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory STRING_BUILDER_FACTORY = newFactory(java.lang.StringBuilder.class, STRING_BUILDER);
    public static final com.google.gson.TypeAdapterFactory STRING_FACTORY = newFactory(java.lang.String.class, STRING);
    public static final com.google.gson.TypeAdapterFactory TIMESTAMP_FACTORY = new com.google.gson.TypeAdapterFactory() {
        public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
            if (typeToken.getRawType() != java.sql.Timestamp.class) {
                return null;
            }
            final com.google.gson.TypeAdapter<java.util.Date> dateTypeAdapter = gson.getAdapter(java.util.Date.class);
            return new com.google.gson.TypeAdapter<java.sql.Timestamp>() {
                public java.sql.Timestamp read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                    java.util.Date date = (java.util.Date) dateTypeAdapter.read(in);
                    return date != null ? new java.sql.Timestamp(date.getTime()) : null;
                }

                public void write(com.google.gson.stream.JsonWriter out, java.sql.Timestamp value) throws java.io.IOException {
                    dateTypeAdapter.write(out, value);
                }
            };
        }
    };
    public static final com.google.gson.TypeAdapter<java.net.URI> URI = new com.google.gson.TypeAdapter<java.net.URI>() {
        public java.net.URI read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            java.net.URI uri = null;
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            try {
                java.lang.String nextString = in.nextString();
                if (!"null".equals(nextString)) {
                    uri = new java.net.URI(nextString);
                }
                return uri;
            } catch (java.lang.Throwable e) {
                throw new com.google.gson.JsonIOException(e);
            }
        }

        public void write(com.google.gson.stream.JsonWriter out, java.net.URI value) throws java.io.IOException {
            out.value(value == null ? null : value.toASCIIString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory URI_FACTORY = newFactory(java.net.URI.class, URI);
    public static final com.google.gson.TypeAdapter<java.net.URL> URL = new com.google.gson.TypeAdapter<java.net.URL>() {
        public java.net.URL read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            java.net.URL url = null;
            if (in.peek() == com.google.gson.stream.JsonToken.NULL) {
                in.nextNull();
                return null;
            }
            java.lang.String nextString = in.nextString();
            if (!"null".equals(nextString)) {
                url = new java.net.URL(nextString);
            }
            return url;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.net.URL value) throws java.io.IOException {
            out.value(value == null ? null : value.toExternalForm());
        }
    };
    public static final com.google.gson.TypeAdapterFactory URL_FACTORY = newFactory(java.net.URL.class, URL);
    public static final com.google.gson.TypeAdapter<java.util.UUID> UUID = new com.google.gson.TypeAdapter<java.util.UUID>() {
        public java.util.UUID read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return java.util.UUID.fromString(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, java.util.UUID value) throws java.io.IOException {
            out.value(value == null ? null : value.toString());
        }
    };
    public static final com.google.gson.TypeAdapterFactory UUID_FACTORY = newFactory(java.util.UUID.class, UUID);

    private static final class EnumTypeAdapter<T extends java.lang.Enum<T>> extends com.google.gson.TypeAdapter<T> {
        private final java.util.Map<T, java.lang.String> constantToName = new java.util.HashMap();
        private final java.util.Map<java.lang.String, T> nameToConstant = new java.util.HashMap();

        public EnumTypeAdapter(java.lang.Class<T> classOfT) {
            try {
                for (T constant : (java.lang.Enum[]) classOfT.getEnumConstants()) {
                    java.lang.String name = constant.name();
                    com.google.gson.annotations.SerializedName annotation = (com.google.gson.annotations.SerializedName) classOfT.getField(name).getAnnotation(com.google.gson.annotations.SerializedName.class);
                    if (annotation != null) {
                        name = annotation.value();
                        for (java.lang.String alternate : annotation.alternate()) {
                            this.nameToConstant.put(alternate, constant);
                        }
                    }
                    this.nameToConstant.put(name, constant);
                    this.constantToName.put(constant, name);
                }
            } catch (java.lang.NoSuchFieldException e) {
                throw new java.lang.AssertionError(e);
            }
        }

        public T read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
            if (in.peek() != com.google.gson.stream.JsonToken.NULL) {
                return (java.lang.Enum) this.nameToConstant.get(in.nextString());
            }
            in.nextNull();
            return null;
        }

        public void write(com.google.gson.stream.JsonWriter out, T value) throws java.io.IOException {
            out.value(value == null ? null : (java.lang.String) this.constantToName.get(value));
        }
    }

    private TypeAdapters() {
        throw new java.lang.UnsupportedOperationException();
    }

    public static <TT> com.google.gson.TypeAdapterFactory newFactory(final com.google.gson.reflect.TypeToken<TT> type, final com.google.gson.TypeAdapter<TT> typeAdapter) {
        return new com.google.gson.TypeAdapterFactory() {
            public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
                return typeToken.equals(type) ? typeAdapter : null;
            }
        };
    }

    public static <TT> com.google.gson.TypeAdapterFactory newFactory(final java.lang.Class<TT> type, final com.google.gson.TypeAdapter<TT> typeAdapter) {
        return new com.google.gson.TypeAdapterFactory() {
            public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
                return typeToken.getRawType() == type ? typeAdapter : null;
            }

            public java.lang.String toString() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Factory[type=");
                stringBuilder.append(type.getName());
                stringBuilder.append(",adapter=");
                stringBuilder.append(typeAdapter);
                stringBuilder.append("]");
                return stringBuilder.toString();
            }
        };
    }

    public static <TT> com.google.gson.TypeAdapterFactory newFactory(final java.lang.Class<TT> unboxed, final java.lang.Class<TT> boxed, final com.google.gson.TypeAdapter<? super TT> typeAdapter) {
        return new com.google.gson.TypeAdapterFactory() {
            public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
                java.lang.Class<? super T> rawType = typeToken.getRawType();
                if (rawType != unboxed) {
                    if (rawType != boxed) {
                        return null;
                    }
                }
                return typeAdapter;
            }

            public java.lang.String toString() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Factory[type=");
                stringBuilder.append(boxed.getName());
                stringBuilder.append("+");
                stringBuilder.append(unboxed.getName());
                stringBuilder.append(",adapter=");
                stringBuilder.append(typeAdapter);
                stringBuilder.append("]");
                return stringBuilder.toString();
            }
        };
    }

    public static <TT> com.google.gson.TypeAdapterFactory newFactoryForMultipleTypes(final java.lang.Class<TT> base, final java.lang.Class<? extends TT> sub, final com.google.gson.TypeAdapter<? super TT> typeAdapter) {
        return new com.google.gson.TypeAdapterFactory() {
            public <T> com.google.gson.TypeAdapter<T> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T> typeToken) {
                java.lang.Class<? super T> rawType = typeToken.getRawType();
                if (rawType != base) {
                    if (rawType != sub) {
                        return null;
                    }
                }
                return typeAdapter;
            }

            public java.lang.String toString() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Factory[type=");
                stringBuilder.append(base.getName());
                stringBuilder.append("+");
                stringBuilder.append(sub.getName());
                stringBuilder.append(",adapter=");
                stringBuilder.append(typeAdapter);
                stringBuilder.append("]");
                return stringBuilder.toString();
            }
        };
    }

    public static <T1> com.google.gson.TypeAdapterFactory newTypeHierarchyFactory(final java.lang.Class<T1> clazz, final com.google.gson.TypeAdapter<T1> typeAdapter) {
        return new com.google.gson.TypeAdapterFactory() {
            public <T2> com.google.gson.TypeAdapter<T2> create(com.google.gson.Gson gson, com.google.gson.reflect.TypeToken<T2> typeToken) {
                final java.lang.Class<? super T2> requestedType = typeToken.getRawType();
                if (clazz.isAssignableFrom(requestedType)) {
                    return new com.google.gson.TypeAdapter<T1>() {
                        public void write(com.google.gson.stream.JsonWriter out, T1 value) throws java.io.IOException {
                            typeAdapter.write(out, value);
                        }

                        public T1 read(com.google.gson.stream.JsonReader in) throws java.io.IOException {
                            T1 result = typeAdapter.read(in);
                            if (result != null) {
                                if (!requestedType.isInstance(result)) {
                                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                    stringBuilder.append("Expected a ");
                                    stringBuilder.append(requestedType.getName());
                                    stringBuilder.append(" but was ");
                                    stringBuilder.append(result.getClass().getName());
                                    throw new com.google.gson.JsonSyntaxException(stringBuilder.toString());
                                }
                            }
                            return result;
                        }
                    };
                }
                return null;
            }

            public java.lang.String toString() {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Factory[typeHierarchy=");
                stringBuilder.append(clazz.getName());
                stringBuilder.append(",adapter=");
                stringBuilder.append(typeAdapter);
                stringBuilder.append("]");
                return stringBuilder.toString();
            }
        };
    }
}
