package com.google.gson.reflect;

public class TypeToken<T> {
    final int hashCode;
    final java.lang.Class<? super T> rawType;
    final java.lang.reflect.Type type;

    protected TypeToken() {
        this.type = getSuperclassTypeParameter(getClass());
        this.rawType = com.google.gson.internal.C$Gson$Types.getRawType(this.type);
        this.hashCode = this.type.hashCode();
    }

    TypeToken(java.lang.reflect.Type type) {
        this.type = com.google.gson.internal.C$Gson$Types.canonicalize((java.lang.reflect.Type) com.google.gson.internal.C$Gson$Preconditions.checkNotNull(type));
        this.rawType = com.google.gson.internal.C$Gson$Types.getRawType(this.type);
        this.hashCode = this.type.hashCode();
    }

    static java.lang.reflect.Type getSuperclassTypeParameter(java.lang.Class<?> subclass) {
        java.lang.reflect.Type superclass = subclass.getGenericSuperclass();
        if (!(superclass instanceof java.lang.Class)) {
            return com.google.gson.internal.C$Gson$Types.canonicalize(((java.lang.reflect.ParameterizedType) superclass).getActualTypeArguments()[0]);
        }
        throw new java.lang.RuntimeException("Missing type parameter.");
    }

    public final java.lang.Class<? super T> getRawType() {
        return this.rawType;
    }

    public final java.lang.reflect.Type getType() {
        return this.type;
    }

    @java.lang.Deprecated
    public boolean isAssignableFrom(java.lang.Class<?> cls) {
        return isAssignableFrom((java.lang.reflect.Type) cls);
    }

    @java.lang.Deprecated
    public boolean isAssignableFrom(java.lang.reflect.Type from) {
        boolean z = false;
        if (from == null) {
            return false;
        }
        if (this.type.equals(from)) {
            return true;
        }
        if (this.type instanceof java.lang.Class) {
            return this.rawType.isAssignableFrom(com.google.gson.internal.C$Gson$Types.getRawType(from));
        }
        if (this.type instanceof java.lang.reflect.ParameterizedType) {
            return isAssignableFrom(from, (java.lang.reflect.ParameterizedType) this.type, new java.util.HashMap());
        }
        if (this.type instanceof java.lang.reflect.GenericArrayType) {
            if (this.rawType.isAssignableFrom(com.google.gson.internal.C$Gson$Types.getRawType(from)) && isAssignableFrom(from, (java.lang.reflect.GenericArrayType) this.type)) {
                z = true;
            }
            return z;
        }
        throw buildUnexpectedTypeError(this.type, java.lang.Class.class, java.lang.reflect.ParameterizedType.class, java.lang.reflect.GenericArrayType.class);
    }

    @java.lang.Deprecated
    public boolean isAssignableFrom(com.google.gson.reflect.TypeToken<?> token) {
        return isAssignableFrom(token.getType());
    }

    private static boolean isAssignableFrom(java.lang.reflect.Type from, java.lang.reflect.GenericArrayType to) {
        java.lang.reflect.Type toGenericComponentType = to.getGenericComponentType();
        if (!(toGenericComponentType instanceof java.lang.reflect.ParameterizedType)) {
            return true;
        }
        java.lang.reflect.Type t = from;
        if (from instanceof java.lang.reflect.GenericArrayType) {
            t = ((java.lang.reflect.GenericArrayType) from).getGenericComponentType();
        } else if (from instanceof java.lang.Class) {
            java.lang.Class<?> classType = (java.lang.Class) from;
            while (classType.isArray()) {
                classType = classType.getComponentType();
            }
            t = classType;
        }
        return isAssignableFrom(t, (java.lang.reflect.ParameterizedType) toGenericComponentType, new java.util.HashMap());
    }

    private static boolean isAssignableFrom(java.lang.reflect.Type from, java.lang.reflect.ParameterizedType to, java.util.Map<java.lang.String, java.lang.reflect.Type> typeVarMap) {
        int i = 0;
        if (from == null) {
            return false;
        }
        if (to.equals(from)) {
            return true;
        }
        java.lang.reflect.Type[] tArgs;
        java.lang.Class<?> clazz = com.google.gson.internal.C$Gson$Types.getRawType(from);
        java.lang.reflect.ParameterizedType ptype = null;
        if (from instanceof java.lang.reflect.ParameterizedType) {
            ptype = (java.lang.reflect.ParameterizedType) from;
        }
        if (ptype != null) {
            tArgs = ptype.getActualTypeArguments();
            java.lang.reflect.TypeVariable<?>[] tParams = clazz.getTypeParameters();
            for (int i2 = 0; i2 < tArgs.length; i2++) {
                java.lang.reflect.Type arg = tArgs[i2];
                java.lang.reflect.TypeVariable<?> var = tParams[i2];
                while (arg instanceof java.lang.reflect.TypeVariable) {
                    arg = (java.lang.reflect.Type) typeVarMap.get(((java.lang.reflect.TypeVariable) arg).getName());
                }
                typeVarMap.put(var.getName(), arg);
            }
            if (typeEquals(ptype, to, typeVarMap)) {
                return true;
            }
        }
        tArgs = clazz.getGenericInterfaces();
        int length = tArgs.length;
        while (i < length) {
            if (isAssignableFrom(tArgs[i], to, new java.util.HashMap(typeVarMap))) {
                return true;
            }
            i++;
        }
        return isAssignableFrom(clazz.getGenericSuperclass(), to, new java.util.HashMap(typeVarMap));
    }

    private static boolean typeEquals(java.lang.reflect.ParameterizedType from, java.lang.reflect.ParameterizedType to, java.util.Map<java.lang.String, java.lang.reflect.Type> typeVarMap) {
        if (!from.getRawType().equals(to.getRawType())) {
            return false;
        }
        java.lang.reflect.Type[] fromArgs = from.getActualTypeArguments();
        java.lang.reflect.Type[] toArgs = to.getActualTypeArguments();
        for (int i = 0; i < fromArgs.length; i++) {
            if (!matches(fromArgs[i], toArgs[i], typeVarMap)) {
                return false;
            }
        }
        return true;
    }

    private static java.lang.AssertionError buildUnexpectedTypeError(java.lang.reflect.Type token, java.lang.Class<?>... expected) {
        java.lang.StringBuilder exceptionMessage = new java.lang.StringBuilder("Unexpected type. Expected one of: ");
        for (java.lang.Class<?> clazz : expected) {
            exceptionMessage.append(clazz.getName());
            exceptionMessage.append(", ");
        }
        exceptionMessage.append("but got: ");
        exceptionMessage.append(token.getClass().getName());
        exceptionMessage.append(", for type token: ");
        exceptionMessage.append(token.toString());
        exceptionMessage.append('.');
        return new java.lang.AssertionError(exceptionMessage.toString());
    }

    private static boolean matches(java.lang.reflect.Type from, java.lang.reflect.Type to, java.util.Map<java.lang.String, java.lang.reflect.Type> typeMap) {
        if (!to.equals(from)) {
            if (!(from instanceof java.lang.reflect.TypeVariable) || !to.equals(typeMap.get(((java.lang.reflect.TypeVariable) from).getName()))) {
                return false;
            }
        }
        return true;
    }

    public final int hashCode() {
        return this.hashCode;
    }

    public final boolean equals(java.lang.Object o) {
        return (o instanceof com.google.gson.reflect.TypeToken) && com.google.gson.internal.C$Gson$Types.equals(this.type, ((com.google.gson.reflect.TypeToken) o).type);
    }

    public final java.lang.String toString() {
        return com.google.gson.internal.C$Gson$Types.typeToString(this.type);
    }

    public static com.google.gson.reflect.TypeToken<?> get(java.lang.reflect.Type type) {
        return new com.google.gson.reflect.TypeToken(type);
    }

    public static <T> com.google.gson.reflect.TypeToken<T> get(java.lang.Class<T> type) {
        return new com.google.gson.reflect.TypeToken(type);
    }

    public static com.google.gson.reflect.TypeToken<?> getParameterized(java.lang.reflect.Type rawType, java.lang.reflect.Type... typeArguments) {
        return new com.google.gson.reflect.TypeToken(com.google.gson.internal.C$Gson$Types.newParameterizedTypeWithOwner(null, rawType, typeArguments));
    }

    public static com.google.gson.reflect.TypeToken<?> getArray(java.lang.reflect.Type componentType) {
        return new com.google.gson.reflect.TypeToken(com.google.gson.internal.C$Gson$Types.arrayOf(componentType));
    }
}
