package com.google.gson.stream;

public class JsonReader implements java.io.Closeable {
    private static final long MIN_INCOMPLETE_INTEGER = -922337203685477580L;
    private static final char[] NON_EXECUTE_PREFIX = ")]}'\n".toCharArray();
    private static final int NUMBER_CHAR_DECIMAL = 3;
    private static final int NUMBER_CHAR_DIGIT = 2;
    private static final int NUMBER_CHAR_EXP_DIGIT = 7;
    private static final int NUMBER_CHAR_EXP_E = 5;
    private static final int NUMBER_CHAR_EXP_SIGN = 6;
    private static final int NUMBER_CHAR_FRACTION_DIGIT = 4;
    private static final int NUMBER_CHAR_NONE = 0;
    private static final int NUMBER_CHAR_SIGN = 1;
    private static final int PEEKED_BEGIN_ARRAY = 3;
    private static final int PEEKED_BEGIN_OBJECT = 1;
    private static final int PEEKED_BUFFERED = 11;
    private static final int PEEKED_DOUBLE_QUOTED = 9;
    private static final int PEEKED_DOUBLE_QUOTED_NAME = 13;
    private static final int PEEKED_END_ARRAY = 4;
    private static final int PEEKED_END_OBJECT = 2;
    private static final int PEEKED_EOF = 17;
    private static final int PEEKED_FALSE = 6;
    private static final int PEEKED_LONG = 15;
    private static final int PEEKED_NONE = 0;
    private static final int PEEKED_NULL = 7;
    private static final int PEEKED_NUMBER = 16;
    private static final int PEEKED_SINGLE_QUOTED = 8;
    private static final int PEEKED_SINGLE_QUOTED_NAME = 12;
    private static final int PEEKED_TRUE = 5;
    private static final int PEEKED_UNQUOTED = 10;
    private static final int PEEKED_UNQUOTED_NAME = 14;
    private final char[] buffer = new char[1024];
    private final java.io.Reader in;
    private boolean lenient = false;
    private int limit = 0;
    private int lineNumber = 0;
    private int lineStart = 0;
    private int[] pathIndices;
    private java.lang.String[] pathNames;
    int peeked = 0;
    private long peekedLong;
    private int peekedNumberLength;
    private java.lang.String peekedString;
    private int pos = 0;
    private int[] stack = new int[32];
    private int stackSize = 0;

    static {
        com.google.gson.internal.JsonReaderInternalAccess.INSTANCE = new com.google.gson.internal.JsonReaderInternalAccess() {
            public void promoteNameToValue(com.google.gson.stream.JsonReader reader) throws java.io.IOException {
                if (reader instanceof com.google.gson.internal.bind.JsonTreeReader) {
                    ((com.google.gson.internal.bind.JsonTreeReader) reader).promoteNameToValue();
                    return;
                }
                int p = reader.peeked;
                if (p == 0) {
                    p = reader.doPeek();
                }
                if (p == 13) {
                    reader.peeked = 9;
                } else if (p == 12) {
                    reader.peeked = 8;
                } else if (p == 14) {
                    reader.peeked = 10;
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Expected a name but was ");
                    stringBuilder.append(reader.peek());
                    stringBuilder.append(reader.locationString());
                    throw new java.lang.IllegalStateException(stringBuilder.toString());
                }
            }
        };
    }

    public JsonReader(java.io.Reader in) {
        int[] iArr = this.stack;
        int i = this.stackSize;
        this.stackSize = i + 1;
        iArr[i] = 6;
        this.pathNames = new java.lang.String[32];
        this.pathIndices = new int[32];
        if (in != null) {
            this.in = in;
            return;
        }
        throw new java.lang.NullPointerException("in == null");
    }

    public final void setLenient(boolean lenient) {
        this.lenient = lenient;
    }

    public final boolean isLenient() {
        return this.lenient;
    }

    public void beginArray() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 3) {
            push(1);
            this.pathIndices[this.stackSize - 1] = 0;
            this.peeked = 0;
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected BEGIN_ARRAY but was ");
        stringBuilder.append(peek());
        stringBuilder.append(locationString());
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    public void endArray() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 4) {
            this.stackSize--;
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            this.peeked = 0;
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected END_ARRAY but was ");
        stringBuilder.append(peek());
        stringBuilder.append(locationString());
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    public void beginObject() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 1) {
            push(3);
            this.peeked = 0;
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected BEGIN_OBJECT but was ");
        stringBuilder.append(peek());
        stringBuilder.append(locationString());
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    public void endObject() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 2) {
            this.stackSize--;
            this.pathNames[this.stackSize] = null;
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            this.peeked = 0;
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected END_OBJECT but was ");
        stringBuilder.append(peek());
        stringBuilder.append(locationString());
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    public boolean hasNext() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        return (p == 2 || p == 4) ? false : true;
    }

    public com.google.gson.stream.JsonToken peek() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        switch (p) {
            case 1:
                return com.google.gson.stream.JsonToken.BEGIN_OBJECT;
            case 2:
                return com.google.gson.stream.JsonToken.END_OBJECT;
            case 3:
                return com.google.gson.stream.JsonToken.BEGIN_ARRAY;
            case 4:
                return com.google.gson.stream.JsonToken.END_ARRAY;
            case 5:
            case 6:
                return com.google.gson.stream.JsonToken.BOOLEAN;
            case 7:
                return com.google.gson.stream.JsonToken.NULL;
            case 8:
            case 9:
            case 10:
            case 11:
                return com.google.gson.stream.JsonToken.STRING;
            case 12:
            case 13:
            case 14:
                return com.google.gson.stream.JsonToken.NAME;
            case 15:
            case 16:
                return com.google.gson.stream.JsonToken.NUMBER;
            case 17:
                return com.google.gson.stream.JsonToken.END_DOCUMENT;
            default:
                throw new java.lang.AssertionError();
        }
    }

    int doPeek() throws java.io.IOException {
        int c;
        int peekStack = this.stack[this.stackSize - 1];
        if (peekStack == 1) {
            this.stack[this.stackSize - 1] = 2;
        } else if (peekStack == 2) {
            c = nextNonWhitespace(true);
            if (c != 44) {
                if (c == 59) {
                    checkLenient();
                } else if (c == 93) {
                    this.peeked = 4;
                    return 4;
                } else {
                    throw syntaxError("Unterminated array");
                }
            }
        } else {
            int c2;
            if (peekStack != 3) {
                if (peekStack != 5) {
                    if (peekStack == 4) {
                        this.stack[this.stackSize - 1] = 5;
                        c = nextNonWhitespace(true);
                        if (c != 58) {
                            if (c == 61) {
                                checkLenient();
                                if ((this.pos < this.limit || fillBuffer(1)) && this.buffer[this.pos] == '>') {
                                    this.pos++;
                                }
                            } else {
                                throw syntaxError("Expected ':'");
                            }
                        }
                    } else if (peekStack == 6) {
                        if (this.lenient) {
                            consumeNonExecutePrefix();
                        }
                        this.stack[this.stackSize - 1] = 7;
                    } else if (peekStack == 7) {
                        if (nextNonWhitespace(false) == -1) {
                            this.peeked = 17;
                            return 17;
                        }
                        checkLenient();
                        this.pos--;
                    } else if (peekStack == 8) {
                        throw new java.lang.IllegalStateException("JsonReader is closed");
                    }
                }
            }
            this.stack[this.stackSize - 1] = 4;
            if (peekStack == 5) {
                c2 = nextNonWhitespace(true);
                if (c2 != 44) {
                    if (c2 == 59) {
                        checkLenient();
                    } else if (c2 == 125) {
                        this.peeked = 2;
                        return 2;
                    } else {
                        throw syntaxError("Unterminated object");
                    }
                }
            }
            c2 = nextNonWhitespace(true);
            if (c2 == 34) {
                this.peeked = 13;
                return 13;
            } else if (c2 == 39) {
                checkLenient();
                this.peeked = 12;
                return 12;
            } else if (c2 != 125) {
                checkLenient();
                this.pos--;
                if (isLiteral((char) c2)) {
                    this.peeked = 14;
                    return 14;
                }
                throw syntaxError("Expected name");
            } else if (peekStack != 5) {
                this.peeked = 2;
                return 2;
            } else {
                throw syntaxError("Expected name");
            }
        }
        c = nextNonWhitespace(true);
        if (c == 34) {
            this.peeked = 9;
            return 9;
        } else if (c != 39) {
            if (!(c == 44 || c == 59)) {
                if (c == 91) {
                    this.peeked = 3;
                    return 3;
                } else if (c != 93) {
                    if (c != 123) {
                        this.pos--;
                        int result = peekKeyword();
                        if (result != 0) {
                            return result;
                        }
                        result = peekNumber();
                        if (result != 0) {
                            return result;
                        }
                        if (isLiteral(this.buffer[this.pos])) {
                            checkLenient();
                            this.peeked = 10;
                            return 10;
                        }
                        throw syntaxError("Expected value");
                    }
                    this.peeked = 1;
                    return 1;
                } else if (peekStack == 1) {
                    this.peeked = 4;
                    return 4;
                }
            }
            if (peekStack != 1) {
                if (peekStack != 2) {
                    throw syntaxError("Unexpected value");
                }
            }
            checkLenient();
            this.pos--;
            this.peeked = 7;
            return 7;
        } else {
            checkLenient();
            this.peeked = 8;
            return 8;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:21:0x003d  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x003d  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006b  */
    private int peekKeyword() throws java.io.IOException {
        /*
        r9 = this;
        r0 = r9.buffer;
        r1 = r9.pos;
        r0 = r0[r1];
        r1 = 0;
        r2 = 116; // 0x74 float:1.63E-43 double:5.73E-322;
        if (r0 == r2) goto L_0x002f;
    L_0x000b:
        r2 = 84;
        if (r0 != r2) goto L_0x0010;
    L_0x000f:
        goto L_0x002f;
    L_0x0010:
        r2 = 102; // 0x66 float:1.43E-43 double:5.04E-322;
        if (r0 == r2) goto L_0x0029;
    L_0x0014:
        r2 = 70;
        if (r0 != r2) goto L_0x0019;
    L_0x0018:
        goto L_0x0029;
    L_0x0019:
        r2 = 110; // 0x6e float:1.54E-43 double:5.43E-322;
        if (r0 == r2) goto L_0x0023;
    L_0x001d:
        r2 = 78;
        if (r0 != r2) goto L_0x0022;
    L_0x0021:
        goto L_0x0023;
    L_0x0022:
        return r1;
    L_0x0023:
        r2 = "null";
        r3 = "NULL";
        r4 = 7;
        goto L_0x0035;
    L_0x0029:
        r2 = "false";
        r3 = "FALSE";
        r4 = 6;
        goto L_0x0035;
    L_0x002f:
        r2 = "true";
        r3 = "TRUE";
        r4 = 5;
        r5 = r2.length();
        r6 = 1;
    L_0x003b:
        if (r6 >= r5) goto L_0x0064;
    L_0x003d:
        r7 = r9.pos;
        r7 = r7 + r6;
        r8 = r9.limit;
        if (r7 < r8) goto L_0x004d;
    L_0x0044:
        r7 = r6 + 1;
        r7 = r9.fillBuffer(r7);
        if (r7 != 0) goto L_0x004d;
    L_0x004c:
        return r1;
    L_0x004d:
        r7 = r9.buffer;
        r8 = r9.pos;
        r8 = r8 + r6;
        r0 = r7[r8];
        r7 = r2.charAt(r6);
        if (r0 == r7) goto L_0x0061;
    L_0x005a:
        r7 = r3.charAt(r6);
        if (r0 == r7) goto L_0x0061;
    L_0x0060:
        return r1;
    L_0x0061:
        r6 = r6 + 1;
        goto L_0x003b;
    L_0x0064:
        r6 = r9.pos;
        r6 = r6 + r5;
        r7 = r9.limit;
        if (r6 < r7) goto L_0x0073;
    L_0x006b:
        r6 = r5 + 1;
        r6 = r9.fillBuffer(r6);
        if (r6 == 0) goto L_0x0081;
    L_0x0073:
        r6 = r9.buffer;
        r7 = r9.pos;
        r7 = r7 + r5;
        r6 = r6[r7];
        r6 = r9.isLiteral(r6);
        if (r6 == 0) goto L_0x0081;
    L_0x0080:
        return r1;
    L_0x0081:
        r1 = r9.pos;
        r1 = r1 + r5;
        r9.pos = r1;
        r9.peeked = r4;
        return r4;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.gson.stream.JsonReader.peekKeyword():int");
    }

    /* JADX WARNING: Missing block: B:85:0x00ff, code:
            r8 = r4;
     */
    private int peekNumber() throws java.io.IOException {
        /*
        r18 = this;
        r0 = r18;
        r1 = r0.buffer;
        r2 = r0.pos;
        r3 = r0.limit;
        r4 = 0;
        r6 = 0;
        r7 = 1;
        r8 = 0;
        r9 = 0;
        r10 = r4;
        r4 = r3;
        r3 = r2;
        r2 = r9;
    L_0x0012:
        r5 = r3 + r2;
        r13 = 0;
        r15 = 2;
        if (r5 != r4) goto L_0x0030;
    L_0x0019:
        r5 = r1.length;
        if (r2 != r5) goto L_0x001d;
    L_0x001c:
        return r9;
    L_0x001d:
        r5 = r2 + 1;
        r5 = r0.fillBuffer(r5);
        if (r5 != 0) goto L_0x002c;
        r16 = r3;
        r17 = r4;
        goto L_0x00b4;
    L_0x002c:
        r3 = r0.pos;
        r4 = r0.limit;
    L_0x0030:
        r5 = r3 + r2;
        r5 = r1[r5];
        r12 = 43;
        r9 = 5;
        if (r5 == r12) goto L_0x0115;
    L_0x0039:
        r12 = 69;
        if (r5 == r12) goto L_0x0107;
    L_0x003d:
        r12 = 101; // 0x65 float:1.42E-43 double:5.0E-322;
        if (r5 == r12) goto L_0x0107;
    L_0x0041:
        switch(r5) {
            case 45: goto L_0x00f5;
            case 46: goto L_0x00eb;
            default: goto L_0x0044;
        };
    L_0x0044:
        r12 = 48;
        if (r5 < r12) goto L_0x00a9;
    L_0x0048:
        r12 = 57;
        if (r5 <= r12) goto L_0x0052;
    L_0x004c:
        r16 = r3;
        r17 = r4;
        goto L_0x00ad;
    L_0x0052:
        r12 = 1;
        if (r8 == r12) goto L_0x009d;
    L_0x0055:
        if (r8 != 0) goto L_0x005c;
    L_0x0057:
        r16 = r3;
        r17 = r4;
        goto L_0x00a1;
    L_0x005c:
        if (r8 != r15) goto L_0x008b;
    L_0x005e:
        r9 = (r10 > r13 ? 1 : (r10 == r13 ? 0 : -1));
        if (r9 != 0) goto L_0x0064;
    L_0x0062:
        r9 = 0;
        return r9;
    L_0x0064:
        r13 = 10;
        r13 = r13 * r10;
        r9 = r5 + -48;
        r16 = r3;
        r17 = r4;
        r3 = (long) r9;
        r13 = r13 - r3;
        r3 = -922337203685477580; // 0xf333333333333334 float:4.1723254E-8 double:-8.390303882365713E246;
        r9 = (r10 > r3 ? 1 : (r10 == r3 ? 0 : -1));
        if (r9 > 0) goto L_0x0083;
    L_0x0078:
        r3 = (r10 > r3 ? 1 : (r10 == r3 ? 0 : -1));
        if (r3 != 0) goto L_0x0081;
    L_0x007c:
        r3 = (r13 > r10 ? 1 : (r13 == r10 ? 0 : -1));
        if (r3 >= 0) goto L_0x0081;
    L_0x0080:
        goto L_0x0083;
    L_0x0081:
        r12 = 0;
    L_0x0083:
        r3 = r7 & r12;
        r9 = r13;
        r7 = r3;
        r10 = r9;
        goto L_0x011e;
    L_0x008b:
        r16 = r3;
        r17 = r4;
        r3 = 3;
        if (r8 != r3) goto L_0x0095;
    L_0x0092:
        r3 = 4;
        goto L_0x011d;
    L_0x0095:
        if (r8 == r9) goto L_0x009a;
    L_0x0097:
        r3 = 6;
        if (r8 != r3) goto L_0x011e;
    L_0x009a:
        r3 = 7;
        goto L_0x011d;
    L_0x009d:
        r16 = r3;
        r17 = r4;
    L_0x00a1:
        r3 = r5 + -48;
        r3 = -r3;
        r3 = (long) r3;
        r8 = 2;
        r10 = r3;
        goto L_0x011e;
    L_0x00a9:
        r16 = r3;
        r17 = r4;
    L_0x00ad:
        r3 = r0.isLiteral(r5);
        if (r3 != 0) goto L_0x00e9;
    L_0x00b4:
        if (r8 != r15) goto L_0x00d7;
    L_0x00b6:
        if (r7 == 0) goto L_0x00d7;
    L_0x00b8:
        r3 = -9223372036854775808;
        r3 = (r10 > r3 ? 1 : (r10 == r3 ? 0 : -1));
        if (r3 != 0) goto L_0x00c0;
    L_0x00be:
        if (r6 == 0) goto L_0x00d7;
    L_0x00c0:
        r3 = (r10 > r13 ? 1 : (r10 == r13 ? 0 : -1));
        if (r3 != 0) goto L_0x00c6;
    L_0x00c4:
        if (r6 != 0) goto L_0x00d7;
    L_0x00c6:
        if (r6 == 0) goto L_0x00ca;
    L_0x00c8:
        r3 = r10;
        goto L_0x00cb;
    L_0x00ca:
        r3 = -r10;
    L_0x00cb:
        r0.peekedLong = r3;
        r3 = r0.pos;
        r3 = r3 + r2;
        r0.pos = r3;
        r3 = 15;
        r0.peeked = r3;
        return r3;
    L_0x00d7:
        if (r8 == r15) goto L_0x00e2;
    L_0x00d9:
        r3 = 4;
        if (r8 == r3) goto L_0x00e2;
    L_0x00dc:
        r3 = 7;
        if (r8 != r3) goto L_0x00e0;
    L_0x00df:
        goto L_0x00e2;
    L_0x00e0:
        r3 = 0;
        return r3;
    L_0x00e2:
        r0.peekedNumberLength = r2;
        r3 = 16;
        r0.peeked = r3;
        return r3;
    L_0x00e9:
        r3 = 0;
        return r3;
    L_0x00eb:
        r16 = r3;
        r17 = r4;
        r3 = 0;
        if (r8 != r15) goto L_0x00f4;
    L_0x00f2:
        r4 = 3;
        goto L_0x00ff;
    L_0x00f4:
        return r3;
    L_0x00f5:
        r16 = r3;
        r17 = r4;
        if (r8 != 0) goto L_0x0101;
    L_0x00fb:
        r3 = 1;
        r4 = 1;
        r6 = r3;
    L_0x00ff:
        r8 = r4;
        goto L_0x011e;
    L_0x0101:
        if (r8 != r9) goto L_0x0105;
    L_0x0103:
        r3 = 6;
        goto L_0x011d;
    L_0x0105:
        r3 = 0;
        return r3;
    L_0x0107:
        r16 = r3;
        r17 = r4;
        r3 = 0;
        if (r8 == r15) goto L_0x0113;
    L_0x010e:
        r4 = 4;
        if (r8 != r4) goto L_0x0112;
    L_0x0111:
        goto L_0x0113;
    L_0x0112:
        return r3;
    L_0x0113:
        r3 = 5;
        goto L_0x011d;
    L_0x0115:
        r16 = r3;
        r17 = r4;
        if (r8 != r9) goto L_0x0127;
    L_0x011b:
        r3 = 6;
    L_0x011d:
        r8 = r3;
    L_0x011e:
        r2 = r2 + 1;
        r3 = r16;
        r4 = r17;
        r9 = 0;
        goto L_0x0012;
    L_0x0127:
        r3 = 0;
        return r3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.gson.stream.JsonReader.peekNumber():int");
    }

    private boolean isLiteral(char c) throws java.io.IOException {
        switch (c) {
            case 9:
            case 10:
            case 12:
            case 13:
            case ' ':
            case ',':
            case ':':
            case '[':
            case ']':
            case '{':
            case '}':
                break;
            case '#':
            case '/':
            case ';':
            case '=':
            case '\\':
                checkLenient();
                break;
            default:
                return true;
        }
        return false;
    }

    public java.lang.String nextName() throws java.io.IOException {
        java.lang.String result;
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 14) {
            result = nextUnquotedValue();
        } else if (p == 12) {
            result = nextQuotedValue('\'');
        } else if (p == 13) {
            result = nextQuotedValue('\"');
        } else {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Expected a name but was ");
            stringBuilder.append(peek());
            stringBuilder.append(locationString());
            throw new java.lang.IllegalStateException(stringBuilder.toString());
        }
        this.peeked = 0;
        this.pathNames[this.stackSize - 1] = result;
        return result;
    }

    public java.lang.String nextString() throws java.io.IOException {
        java.lang.String result;
        int[] iArr;
        int i;
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 10) {
            result = nextUnquotedValue();
        } else if (p == 8) {
            result = nextQuotedValue('\'');
        } else if (p == 9) {
            result = nextQuotedValue('\"');
        } else {
            if (p == 11) {
                result = this.peekedString;
                this.peekedString = null;
            } else if (p == 15) {
                result = java.lang.Long.toString(this.peekedLong);
            } else if (p == 16) {
                result = new java.lang.String(this.buffer, this.pos, this.peekedNumberLength);
                this.pos += this.peekedNumberLength;
            } else {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Expected a string but was ");
                stringBuilder.append(peek());
                stringBuilder.append(locationString());
                throw new java.lang.IllegalStateException(stringBuilder.toString());
            }
            this.peeked = 0;
            iArr = this.pathIndices;
            i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return result;
        }
        this.peeked = 0;
        iArr = this.pathIndices;
        i = this.stackSize - 1;
        iArr[i] = iArr[i] + 1;
        return result;
    }

    public boolean nextBoolean() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        int[] iArr;
        if (p == 5) {
            this.peeked = 0;
            iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return true;
        } else if (p == 6) {
            this.peeked = 0;
            iArr = this.pathIndices;
            int i2 = this.stackSize - 1;
            iArr[i2] = iArr[i2] + 1;
            return false;
        } else {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Expected a boolean but was ");
            stringBuilder.append(peek());
            stringBuilder.append(locationString());
            throw new java.lang.IllegalStateException(stringBuilder.toString());
        }
    }

    public void nextNull() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        if (p == 7) {
            this.peeked = 0;
            int[] iArr = this.pathIndices;
            int i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected null but was ");
        stringBuilder.append(peek());
        stringBuilder.append(locationString());
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    public double nextDouble() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        int[] iArr;
        int i;
        if (p == 15) {
            this.peeked = 0;
            iArr = this.pathIndices;
            i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return (double) this.peekedLong;
        }
        java.lang.StringBuilder stringBuilder;
        if (p == 16) {
            this.peekedString = new java.lang.String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else {
            if (p != 8) {
                if (p != 9) {
                    if (p == 10) {
                        this.peekedString = nextUnquotedValue();
                    } else if (p != 11) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Expected a double but was ");
                        stringBuilder.append(peek());
                        stringBuilder.append(locationString());
                        throw new java.lang.IllegalStateException(stringBuilder.toString());
                    }
                }
            }
            this.peekedString = nextQuotedValue(p == 8 ? '\'' : '\"');
        }
        this.peeked = 11;
        double result = java.lang.Double.parseDouble(this.peekedString);
        if (!this.lenient) {
            if (java.lang.Double.isNaN(result) || java.lang.Double.isInfinite(result)) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("JSON forbids NaN and infinities: ");
                stringBuilder.append(result);
                stringBuilder.append(locationString());
                throw new com.google.gson.stream.MalformedJsonException(stringBuilder.toString());
            }
        }
        this.peekedString = null;
        this.peeked = 0;
        iArr = this.pathIndices;
        i = this.stackSize - 1;
        iArr[i] = iArr[i] + 1;
        return result;
    }

    public long nextLong() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        int[] iArr;
        int i;
        if (p == 15) {
            this.peeked = 0;
            iArr = this.pathIndices;
            i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return this.peekedLong;
        }
        java.lang.StringBuilder stringBuilder;
        if (p == 16) {
            this.peekedString = new java.lang.String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else {
            if (!(p == 8 || p == 9)) {
                if (p != 10) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Expected a long but was ");
                    stringBuilder.append(peek());
                    stringBuilder.append(locationString());
                    throw new java.lang.IllegalStateException(stringBuilder.toString());
                }
            }
            if (p == 10) {
                this.peekedString = nextUnquotedValue();
            } else {
                this.peekedString = nextQuotedValue(p == 8 ? '\'' : '\"');
            }
            try {
                long result = java.lang.Long.parseLong(this.peekedString);
                this.peeked = 0;
                iArr = this.pathIndices;
                int i2 = this.stackSize - 1;
                iArr[i2] = iArr[i2] + 1;
                return result;
            } catch (java.lang.NumberFormatException e) {
            }
        }
        this.peeked = 11;
        double asDouble = java.lang.Double.parseDouble(this.peekedString);
        long result2 = (long) asDouble;
        if (((double) result2) == asDouble) {
            this.peekedString = null;
            this.peeked = 0;
            iArr = this.pathIndices;
            i = this.stackSize - 1;
            iArr[i] = iArr[i] + 1;
            return result2;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Expected a long but was ");
        stringBuilder.append(this.peekedString);
        stringBuilder.append(locationString());
        throw new java.lang.NumberFormatException(stringBuilder.toString());
    }

    private java.lang.String nextQuotedValue(char quote) throws java.io.IOException {
        char[] buffer = this.buffer;
        java.lang.StringBuilder builder = null;
        while (true) {
            int start = this.pos;
            int l = this.limit;
            java.lang.StringBuilder builder2 = builder;
            int p = start;
            while (p < l) {
                int p2 = p + 1;
                char c = buffer[p];
                int len;
                if (c == quote) {
                    this.pos = p2;
                    len = (p2 - start) - 1;
                    if (builder2 == null) {
                        return new java.lang.String(buffer, start, len);
                    }
                    builder2.append(buffer, start, len);
                    return builder2.toString();
                } else if (c == '\\') {
                    this.pos = p2;
                    int len2 = (p2 - start) - 1;
                    if (builder2 == null) {
                        builder2 = new java.lang.StringBuilder(java.lang.Math.max((len2 + 1) * 2, 16));
                    }
                    builder2.append(buffer, start, len2);
                    builder2.append(readEscapeCharacter());
                    len = this.pos;
                    l = this.limit;
                    start = len;
                    p = len;
                } else {
                    if (c == 10) {
                        this.lineNumber++;
                        this.lineStart = p2;
                    }
                    p = p2;
                }
            }
            if (builder2 == null) {
                builder2 = new java.lang.StringBuilder(java.lang.Math.max((p - start) * 2, 16));
            }
            builder2.append(buffer, start, p - start);
            this.pos = p;
            if (fillBuffer(1)) {
                builder = builder2;
            } else {
                throw syntaxError("Unterminated string");
            }
        }
    }

    private java.lang.String nextUnquotedValue() throws java.io.IOException {
        java.lang.String result;
        java.lang.StringBuilder builder = null;
        int i = 0;
        while (true) {
            if (this.pos + i < this.limit) {
                switch (this.buffer[this.pos + i]) {
                    case 9:
                    case 10:
                    case 12:
                    case 13:
                    case ' ':
                    case ',':
                    case ':':
                    case '[':
                    case ']':
                    case '{':
                    case '}':
                        break;
                    case '#':
                    case '/':
                    case ';':
                    case '=':
                    case '\\':
                        checkLenient();
                        break;
                    default:
                        i++;
                        continue;
                }
            } else if (i >= this.buffer.length) {
                if (builder == null) {
                    builder = new java.lang.StringBuilder(java.lang.Math.max(i, 16));
                }
                builder.append(this.buffer, this.pos, i);
                this.pos += i;
                i = 0;
                if (fillBuffer(1)) {
                }
            } else if (fillBuffer(i + 1)) {
            }
        }
        if (builder == null) {
            result = new java.lang.String(this.buffer, this.pos, i);
        } else {
            builder.append(this.buffer, this.pos, i);
            result = builder.toString();
        }
        this.pos += i;
        return result;
    }

    private void skipQuotedValue(char quote) throws java.io.IOException {
        char[] buffer = this.buffer;
        while (true) {
            int p = this.pos;
            int l = this.limit;
            while (p < l) {
                int p2 = p + 1;
                char c = buffer[p];
                if (c == quote) {
                    this.pos = p2;
                    return;
                } else if (c == '\\') {
                    this.pos = p2;
                    readEscapeCharacter();
                    int p3 = this.pos;
                    l = this.limit;
                    p = p3;
                } else {
                    if (c == 10) {
                        this.lineNumber++;
                        this.lineStart = p2;
                    }
                    p = p2;
                }
            }
            this.pos = p;
            if (!fillBuffer(1)) {
                throw syntaxError("Unterminated string");
            }
        }
    }

    private void skipUnquotedValue() throws java.io.IOException {
        do {
            int i = 0;
            while (this.pos + i < this.limit) {
                switch (this.buffer[this.pos + i]) {
                    case 9:
                    case 10:
                    case 12:
                    case 13:
                    case ' ':
                    case ',':
                    case ':':
                    case '[':
                    case ']':
                    case '{':
                    case '}':
                        break;
                    case '#':
                    case '/':
                    case ';':
                    case '=':
                    case '\\':
                        checkLenient();
                        break;
                    default:
                        i++;
                }
                this.pos += i;
                return;
            }
            this.pos += i;
        } while (fillBuffer(1));
    }

    public int nextInt() throws java.io.IOException {
        int p = this.peeked;
        if (p == 0) {
            p = doPeek();
        }
        int result;
        int[] iArr;
        if (p == 15) {
            result = (int) this.peekedLong;
            if (this.peekedLong == ((long) result)) {
                this.peeked = 0;
                iArr = this.pathIndices;
                int i = this.stackSize - 1;
                iArr[i] = iArr[i] + 1;
                return result;
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("Expected an int but was ");
            stringBuilder.append(this.peekedLong);
            stringBuilder.append(locationString());
            throw new java.lang.NumberFormatException(stringBuilder.toString());
        }
        if (p == 16) {
            this.peekedString = new java.lang.String(this.buffer, this.pos, this.peekedNumberLength);
            this.pos += this.peekedNumberLength;
        } else {
            if (!(p == 8 || p == 9)) {
                if (p != 10) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("Expected an int but was ");
                    stringBuilder2.append(peek());
                    stringBuilder2.append(locationString());
                    throw new java.lang.IllegalStateException(stringBuilder2.toString());
                }
            }
            if (p == 10) {
                this.peekedString = nextUnquotedValue();
            } else {
                this.peekedString = nextQuotedValue(p == 8 ? '\'' : '\"');
            }
            try {
                result = java.lang.Integer.parseInt(this.peekedString);
                this.peeked = 0;
                int[] iArr2 = this.pathIndices;
                int i2 = this.stackSize - 1;
                iArr2[i2] = iArr2[i2] + 1;
                return result;
            } catch (java.lang.NumberFormatException e) {
            }
        }
        this.peeked = 11;
        double asDouble = java.lang.Double.parseDouble(this.peekedString);
        result = (int) asDouble;
        if (((double) result) == asDouble) {
            this.peekedString = null;
            this.peeked = 0;
            iArr = this.pathIndices;
            int i3 = this.stackSize - 1;
            iArr[i3] = iArr[i3] + 1;
            return result;
        }
        java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
        stringBuilder3.append("Expected an int but was ");
        stringBuilder3.append(this.peekedString);
        stringBuilder3.append(locationString());
        throw new java.lang.NumberFormatException(stringBuilder3.toString());
    }

    public void close() throws java.io.IOException {
        this.peeked = 0;
        this.stack[0] = 8;
        this.stackSize = 1;
        this.in.close();
    }

    public void skipValue() throws java.io.IOException {
        int p;
        int count = 0;
        do {
            p = this.peeked;
            if (p == 0) {
                p = doPeek();
            }
            if (p == 3) {
                push(1);
                count++;
            } else if (p == 1) {
                push(3);
                count++;
            } else if (p == 4) {
                this.stackSize--;
                count--;
            } else if (p == 2) {
                this.stackSize--;
                count--;
            } else {
                if (p != 14) {
                    if (p != 10) {
                        if (p != 8) {
                            if (p != 12) {
                                if (p != 9) {
                                    if (p != 13) {
                                        if (p == 16) {
                                            this.pos += this.peekedNumberLength;
                                        }
                                    }
                                }
                                skipQuotedValue('\"');
                            }
                        }
                        skipQuotedValue('\'');
                    }
                }
                skipUnquotedValue();
            }
            this.peeked = 0;
        } while (count != 0);
        int[] iArr = this.pathIndices;
        p = this.stackSize - 1;
        iArr[p] = iArr[p] + 1;
        this.pathNames[this.stackSize - 1] = "null";
    }

    private void push(int newTop) {
        int[] newStack;
        if (this.stackSize == this.stack.length) {
            newStack = new int[(this.stackSize * 2)];
            int[] newPathIndices = new int[(this.stackSize * 2)];
            java.lang.String[] newPathNames = new java.lang.String[(this.stackSize * 2)];
            java.lang.System.arraycopy(this.stack, 0, newStack, 0, this.stackSize);
            java.lang.System.arraycopy(this.pathIndices, 0, newPathIndices, 0, this.stackSize);
            java.lang.System.arraycopy(this.pathNames, 0, newPathNames, 0, this.stackSize);
            this.stack = newStack;
            this.pathIndices = newPathIndices;
            this.pathNames = newPathNames;
        }
        newStack = this.stack;
        int i = this.stackSize;
        this.stackSize = i + 1;
        newStack[i] = newTop;
    }

    private boolean fillBuffer(int minimum) throws java.io.IOException {
        char[] buffer = this.buffer;
        this.lineStart -= this.pos;
        if (this.limit != this.pos) {
            this.limit -= this.pos;
            java.lang.System.arraycopy(buffer, this.pos, buffer, 0, this.limit);
        } else {
            this.limit = 0;
        }
        this.pos = 0;
        do {
            int read = this.in.read(buffer, this.limit, buffer.length - this.limit);
            int total = read;
            if (read == -1) {
                return false;
            }
            this.limit += total;
            if (this.lineNumber == 0 && this.lineStart == 0 && this.limit > 0 && buffer[0] == 65279) {
                this.pos++;
                this.lineStart++;
                minimum++;
            }
        } while (this.limit < minimum);
        return true;
    }

    private int nextNonWhitespace(boolean throwOnEof) throws java.io.IOException {
        char[] buffer = this.buffer;
        int c = this.pos;
        int l = this.limit;
        while (true) {
            if (c == l) {
                this.pos = c;
                if (fillBuffer(1)) {
                    c = this.pos;
                    l = this.limit;
                } else if (!throwOnEof) {
                    return -1;
                } else {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("End of input");
                    stringBuilder.append(locationString());
                    throw new java.io.EOFException(stringBuilder.toString());
                }
            }
            int p = c + 1;
            c = buffer[c];
            if (c == 10) {
                this.lineNumber++;
                this.lineStart = p;
            } else if (!(c == 32 || c == 13)) {
                if (c != 9) {
                    int p2;
                    if (c == 47) {
                        this.pos = p;
                        if (p == l) {
                            this.pos--;
                            boolean charsLoaded = fillBuffer(2);
                            this.pos++;
                            if (!charsLoaded) {
                                return c;
                            }
                        }
                        checkLenient();
                        char peek = buffer[this.pos];
                        if (peek == '*') {
                            this.pos++;
                            if (skipTo("*/")) {
                                p2 = this.pos + 2;
                                l = this.limit;
                            } else {
                                throw syntaxError("Unterminated comment");
                            }
                        } else if (peek != '/') {
                            return c;
                        } else {
                            this.pos++;
                            skipToEndOfLine();
                            p2 = this.pos;
                            l = this.limit;
                        }
                    } else if (c == 35) {
                        this.pos = p;
                        checkLenient();
                        skipToEndOfLine();
                        p2 = this.pos;
                        l = this.limit;
                    } else {
                        this.pos = p;
                        return c;
                    }
                    c = p2;
                }
            }
            c = p;
        }
    }

    private void checkLenient() throws java.io.IOException {
        if (!this.lenient) {
            throw syntaxError("Use JsonReader.setLenient(true) to accept malformed JSON");
        }
    }

    private void skipToEndOfLine() throws java.io.IOException {
        while (true) {
            if (this.pos < this.limit || fillBuffer(1)) {
                char c = this.buffer;
                int i = this.pos;
                this.pos = i + 1;
                c = c[i];
                if (c == 10) {
                    this.lineNumber++;
                    this.lineStart = this.pos;
                    return;
                } else if (c == 13) {
                    return;
                }
            } else {
                return;
            }
        }
    }

    private boolean skipTo(java.lang.String toFind) throws java.io.IOException {
        int length = toFind.length();
        while (true) {
            int c = 0;
            if (this.pos + length > this.limit) {
                if (!fillBuffer(length)) {
                    return false;
                }
            }
            if (this.buffer[this.pos] == 10) {
                this.lineNumber++;
                this.lineStart = this.pos + 1;
            } else {
                while (true) {
                    int c2 = c;
                    if (c2 >= length) {
                        return true;
                    }
                    if (this.buffer[this.pos + c2] != toFind.charAt(c2)) {
                        break;
                    }
                    c = c2 + 1;
                }
            }
            this.pos++;
        }
    }

    public java.lang.String toString() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(getClass().getSimpleName());
        stringBuilder.append(locationString());
        return stringBuilder.toString();
    }

    java.lang.String locationString() {
        int line = this.lineNumber + 1;
        int column = (this.pos - this.lineStart) + 1;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" at line ");
        stringBuilder.append(line);
        stringBuilder.append(" column ");
        stringBuilder.append(column);
        stringBuilder.append(" path ");
        stringBuilder.append(getPath());
        return stringBuilder.toString();
    }

    public java.lang.String getPath() {
        java.lang.StringBuilder result = new java.lang.StringBuilder().append('$');
        int size = this.stackSize;
        for (int i = 0; i < size; i++) {
            switch (this.stack[i]) {
                case 1:
                case 2:
                    result.append('[');
                    result.append(this.pathIndices[i]);
                    result.append(']');
                    break;
                case 3:
                case 4:
                case 5:
                    result.append('.');
                    if (this.pathNames[i] == null) {
                        break;
                    }
                    result.append(this.pathNames[i]);
                    break;
                default:
                    break;
            }
        }
        return result.toString();
    }

    private char readEscapeCharacter() throws java.io.IOException {
        if (this.pos == this.limit) {
            if (!fillBuffer(1)) {
                throw syntaxError("Unterminated escape sequence");
            }
        }
        char escaped = this.buffer;
        int i = this.pos;
        this.pos = i + 1;
        escaped = escaped[i];
        if (escaped == 10) {
            this.lineNumber++;
            this.lineStart = this.pos;
        } else if (!(escaped == '\"' || escaped == '\'' || escaped == '/' || escaped == '\\')) {
            if (escaped == 'b') {
                return 8;
            }
            if (escaped == 'f') {
                return 12;
            }
            if (escaped == 'n') {
                return 10;
            }
            if (escaped == 'r') {
                return 13;
            }
            switch (escaped) {
                case 't':
                    return 9;
                case 'u':
                    if (this.pos + 4 > this.limit) {
                        if (!fillBuffer(4)) {
                            throw syntaxError("Unterminated escape sequence");
                        }
                    }
                    char result = 0;
                    int i2 = this.pos;
                    int end = i2 + 4;
                    while (i2 < end) {
                        int i3;
                        char c = this.buffer[i2];
                        result = (char) (result << 4);
                        if (c >= '0' && c <= '9') {
                            i3 = c - 48;
                        } else if (c >= 'a' && c <= 'f') {
                            i3 = (c - 97) + 10;
                        } else if (c < 'A' || c > 'F') {
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("\\u");
                            stringBuilder.append(new java.lang.String(this.buffer, this.pos, 4));
                            throw new java.lang.NumberFormatException(stringBuilder.toString());
                        } else {
                            i3 = (c - 65) + 10;
                        }
                        result = (char) (i3 + result);
                        i2++;
                    }
                    this.pos += 4;
                    return result;
                default:
                    throw syntaxError("Invalid escape sequence");
            }
        }
        return escaped;
    }

    private java.io.IOException syntaxError(java.lang.String message) throws java.io.IOException {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(message);
        stringBuilder.append(locationString());
        throw new com.google.gson.stream.MalformedJsonException(stringBuilder.toString());
    }

    private void consumeNonExecutePrefix() throws java.io.IOException {
        nextNonWhitespace(true);
        this.pos--;
        if (this.pos + NON_EXECUTE_PREFIX.length <= this.limit || fillBuffer(NON_EXECUTE_PREFIX.length)) {
            int i = 0;
            while (i < NON_EXECUTE_PREFIX.length) {
                if (this.buffer[this.pos + i] == NON_EXECUTE_PREFIX[i]) {
                    i++;
                } else {
                    return;
                }
            }
            this.pos += NON_EXECUTE_PREFIX.length;
        }
    }
}
