package com.google.gson.stream;

public class JsonWriter implements java.io.Closeable, java.io.Flushable {
    private static final java.lang.String[] HTML_SAFE_REPLACEMENT_CHARS = ((java.lang.String[]) REPLACEMENT_CHARS.clone());
    private static final java.lang.String[] REPLACEMENT_CHARS = new java.lang.String[128];
    private java.lang.String deferredName;
    private boolean htmlSafe;
    private java.lang.String indent;
    private boolean lenient;
    private final java.io.Writer out;
    private java.lang.String separator;
    private boolean serializeNulls;
    private int[] stack = new int[32];
    private int stackSize = 0;

    static {
        for (int i = 0; i <= 31; i++) {
            REPLACEMENT_CHARS[i] = java.lang.String.format("\\u%04x", new java.lang.Object[]{java.lang.Integer.valueOf(i)});
        }
        REPLACEMENT_CHARS[34] = "\\\"";
        REPLACEMENT_CHARS[92] = "\\\\";
        REPLACEMENT_CHARS[9] = "\\t";
        REPLACEMENT_CHARS[8] = "\\b";
        REPLACEMENT_CHARS[10] = "\\n";
        REPLACEMENT_CHARS[13] = "\\r";
        REPLACEMENT_CHARS[12] = "\\f";
        HTML_SAFE_REPLACEMENT_CHARS[60] = "\\u003c";
        HTML_SAFE_REPLACEMENT_CHARS[62] = "\\u003e";
        HTML_SAFE_REPLACEMENT_CHARS[38] = "\\u0026";
        HTML_SAFE_REPLACEMENT_CHARS[61] = "\\u003d";
        HTML_SAFE_REPLACEMENT_CHARS[39] = "\\u0027";
    }

    public JsonWriter(java.io.Writer out) {
        push(6);
        this.separator = ":";
        this.serializeNulls = true;
        if (out != null) {
            this.out = out;
            return;
        }
        throw new java.lang.NullPointerException("out == null");
    }

    public final void setIndent(java.lang.String indent) {
        if (indent.length() == 0) {
            this.indent = null;
            this.separator = ":";
            return;
        }
        this.indent = indent;
        this.separator = ": ";
    }

    public final void setLenient(boolean lenient) {
        this.lenient = lenient;
    }

    public boolean isLenient() {
        return this.lenient;
    }

    public final void setHtmlSafe(boolean htmlSafe) {
        this.htmlSafe = htmlSafe;
    }

    public final boolean isHtmlSafe() {
        return this.htmlSafe;
    }

    public final void setSerializeNulls(boolean serializeNulls) {
        this.serializeNulls = serializeNulls;
    }

    public final boolean getSerializeNulls() {
        return this.serializeNulls;
    }

    public com.google.gson.stream.JsonWriter beginArray() throws java.io.IOException {
        writeDeferredName();
        return open(1, "[");
    }

    public com.google.gson.stream.JsonWriter endArray() throws java.io.IOException {
        return close(1, 2, "]");
    }

    public com.google.gson.stream.JsonWriter beginObject() throws java.io.IOException {
        writeDeferredName();
        return open(3, "{");
    }

    public com.google.gson.stream.JsonWriter endObject() throws java.io.IOException {
        return close(3, 5, "}");
    }

    private com.google.gson.stream.JsonWriter open(int empty, java.lang.String openBracket) throws java.io.IOException {
        beforeValue();
        push(empty);
        this.out.write(openBracket);
        return this;
    }

    private com.google.gson.stream.JsonWriter close(int empty, int nonempty, java.lang.String closeBracket) throws java.io.IOException {
        int context = peek();
        if (context != nonempty) {
            if (context != empty) {
                throw new java.lang.IllegalStateException("Nesting problem.");
            }
        }
        if (this.deferredName == null) {
            this.stackSize--;
            if (context == nonempty) {
                newline();
            }
            this.out.write(closeBracket);
            return this;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("Dangling name: ");
        stringBuilder.append(this.deferredName);
        throw new java.lang.IllegalStateException(stringBuilder.toString());
    }

    private void push(int newTop) {
        int[] newStack;
        if (this.stackSize == this.stack.length) {
            newStack = new int[(this.stackSize * 2)];
            java.lang.System.arraycopy(this.stack, 0, newStack, 0, this.stackSize);
            this.stack = newStack;
        }
        newStack = this.stack;
        int i = this.stackSize;
        this.stackSize = i + 1;
        newStack[i] = newTop;
    }

    private int peek() {
        if (this.stackSize != 0) {
            return this.stack[this.stackSize - 1];
        }
        throw new java.lang.IllegalStateException("JsonWriter is closed.");
    }

    private void replaceTop(int topOfStack) {
        this.stack[this.stackSize - 1] = topOfStack;
    }

    public com.google.gson.stream.JsonWriter name(java.lang.String name) throws java.io.IOException {
        if (name == null) {
            throw new java.lang.NullPointerException("name == null");
        } else if (this.deferredName != null) {
            throw new java.lang.IllegalStateException();
        } else if (this.stackSize != 0) {
            this.deferredName = name;
            return this;
        } else {
            throw new java.lang.IllegalStateException("JsonWriter is closed.");
        }
    }

    private void writeDeferredName() throws java.io.IOException {
        if (this.deferredName != null) {
            beforeName();
            string(this.deferredName);
            this.deferredName = null;
        }
    }

    public com.google.gson.stream.JsonWriter value(java.lang.String value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        writeDeferredName();
        beforeValue();
        string(value);
        return this;
    }

    public com.google.gson.stream.JsonWriter jsonValue(java.lang.String value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        writeDeferredName();
        beforeValue();
        this.out.append(value);
        return this;
    }

    public com.google.gson.stream.JsonWriter nullValue() throws java.io.IOException {
        if (this.deferredName != null) {
            if (this.serializeNulls) {
                writeDeferredName();
            } else {
                this.deferredName = null;
                return this;
            }
        }
        beforeValue();
        this.out.write("null");
        return this;
    }

    public com.google.gson.stream.JsonWriter value(boolean value) throws java.io.IOException {
        writeDeferredName();
        beforeValue();
        this.out.write(value ? "true" : "false");
        return this;
    }

    public com.google.gson.stream.JsonWriter value(java.lang.Boolean value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        writeDeferredName();
        beforeValue();
        this.out.write(value.booleanValue() ? "true" : "false");
        return this;
    }

    public com.google.gson.stream.JsonWriter value(double value) throws java.io.IOException {
        writeDeferredName();
        if (!this.lenient) {
            if (java.lang.Double.isNaN(value) || java.lang.Double.isInfinite(value)) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Numeric values must be finite, but was ");
                stringBuilder.append(value);
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        beforeValue();
        this.out.append(java.lang.Double.toString(value));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(long value) throws java.io.IOException {
        writeDeferredName();
        beforeValue();
        this.out.write(java.lang.Long.toString(value));
        return this;
    }

    public com.google.gson.stream.JsonWriter value(java.lang.Number value) throws java.io.IOException {
        if (value == null) {
            return nullValue();
        }
        writeDeferredName();
        java.lang.String string = value.toString();
        if (!this.lenient) {
            if (string.equals("-Infinity") || string.equals("Infinity") || string.equals("NaN")) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Numeric values must be finite, but was ");
                stringBuilder.append(value);
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        beforeValue();
        this.out.append(string);
        return this;
    }

    public void flush() throws java.io.IOException {
        if (this.stackSize != 0) {
            this.out.flush();
            return;
        }
        throw new java.lang.IllegalStateException("JsonWriter is closed.");
    }

    public void close() throws java.io.IOException {
        this.out.close();
        int size = this.stackSize;
        if (size > 1 || (size == 1 && this.stack[size - 1] != 7)) {
            throw new java.io.IOException("Incomplete document");
        }
        this.stackSize = 0;
    }

    private void string(java.lang.String value) throws java.io.IOException {
        java.lang.String[] replacements = this.htmlSafe ? HTML_SAFE_REPLACEMENT_CHARS : REPLACEMENT_CHARS;
        this.out.write("\"");
        int last = 0;
        int length = value.length();
        for (int i = 0; i < length; i++) {
            java.lang.String replacement;
            char c = value.charAt(i);
            if (c < 128) {
                replacement = replacements[c];
                if (replacement == null) {
                }
            } else if (c == 8232) {
                replacement = "\\u2028";
            } else if (c == 8233) {
                replacement = "\\u2029";
            } else {
            }
            if (last < i) {
                this.out.write(value, last, i - last);
            }
            this.out.write(replacement);
            last = i + 1;
        }
        if (last < length) {
            this.out.write(value, last, length - last);
        }
        this.out.write("\"");
    }

    private void newline() throws java.io.IOException {
        if (this.indent != null) {
            this.out.write("\n");
            int size = this.stackSize;
            for (int i = 1; i < size; i++) {
                this.out.write(this.indent);
            }
        }
    }

    private void beforeName() throws java.io.IOException {
        int context = peek();
        if (context == 5) {
            this.out.write(44);
        } else if (context != 3) {
            throw new java.lang.IllegalStateException("Nesting problem.");
        }
        newline();
        replaceTop(4);
    }

    private void beforeValue() throws java.io.IOException {
        switch (peek()) {
            case 1:
                replaceTop(2);
                newline();
                return;
            case 2:
                this.out.append(',');
                newline();
                return;
            case 4:
                this.out.append(this.separator);
                replaceTop(5);
                return;
            case 6:
                break;
            case 7:
                if (this.lenient) {
                    break;
                }
                throw new java.lang.IllegalStateException("JSON must have only one top-level value.");
            default:
                throw new java.lang.IllegalStateException("Nesting problem.");
        }
        replaceTop(7);
    }
}
