package com.huawei.msdp.devicestatus;

public class HwMSDPDeviceStatus {
    private static final java.lang.String AIDL_MESSAGE_SERVICE_CLASS = "com.huawei.msdp.devicestatus.HwMSDPDeviceStatusService";
    private static final java.lang.String AIDL_MESSAGE_SERVICE_PACKAGE = "com.huawei.msdp";
    private static final java.lang.String TAG = com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.class.getSimpleName();
    private static final int sdkVersion = android.os.Build.VERSION.SDK_INT;
    private com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.ServiceDeathHandler deathHandler;
    private int mConnectCount = 0;
    private android.content.ServiceConnection mConnection = new android.content.ServiceConnection() {
        public void onServiceConnected(android.content.ComponentName name, android.os.IBinder service) {
            android.util.Log.d(com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.TAG, "Connection service OK");
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mHandler.removeMessages(1);
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mService = com.huawei.msdp.devicestatus.IMSDPDeviceStatusService.Stub.asInterface(service);
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.registerSink();
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.notifyServiceDied();
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mServiceConnection.onServiceConnected();
        }

        public void onServiceDisconnected(android.content.ComponentName name) {
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mService = null;
            com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mServiceConnection.onServiceDisconnected();
        }
    };
    private android.content.Context mContext = null;
    private android.os.Handler mHandler = new android.os.Handler() {
        public void handleMessage(android.os.Message message) {
            if (message.what == 1) {
                com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.bindService();
            }
        }
    };
    private com.huawei.msdp.devicestatus.IMSDPDeviceStatusService mService = null;
    private com.huawei.msdp.devicestatus.HwMSDPDeviceStatusServiceConnection mServiceConnection = null;
    private com.huawei.msdp.devicestatus.IMSDPDeviceStatusChangedCallBack mSink;
    private java.lang.String packageName;

    private class ServiceDeathHandler implements android.os.IBinder.DeathRecipient {
        /* synthetic */ ServiceDeathHandler(com.huawei.msdp.devicestatus.HwMSDPDeviceStatus x0, com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.AnonymousClass1 x1) {
            this();
        }

        private ServiceDeathHandler() {
        }

        public void binderDied() {
            android.util.Log.d(com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.TAG, "device status service has died!");
            if (com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mServiceConnection != null) {
                com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mServiceConnection.onServiceDisconnected();
            }
            if (com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mService != null) {
                com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mService.asBinder().unlinkToDeath(com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.deathHandler, 0);
                com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.this.mService = null;
            }
        }
    }

    public HwMSDPDeviceStatus(android.content.Context context) {
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HwdeviceStatusRecognition, android version :");
        stringBuilder.append(sdkVersion);
        android.util.Log.d(str, stringBuilder.toString());
        if (context != null) {
            this.mContext = context;
            this.packageName = context.getPackageName();
            this.deathHandler = new com.huawei.msdp.devicestatus.HwMSDPDeviceStatus.ServiceDeathHandler(this, null);
        }
    }

    private void notifyServiceDied() {
        try {
            if (this.mService != null) {
                this.mService.asBinder().linkToDeath(this.deathHandler, 0);
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e(TAG, "IBinder register linkToDeath function fail.");
        }
    }

    public boolean registerSink() {
        boolean result = false;
        android.util.Log.d(TAG, "registerSink");
        if (this.mService == null || this.mSink == null) {
            android.util.Log.e(TAG, "mService or mSink is null.");
            return false;
        }
        try {
            result = this.mService.registerDeviceStatusCallBack(this.packageName, this.mSink);
        } catch (android.os.RemoteException var3) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("registerSink error:");
            stringBuilder.append(var3.getMessage());
            android.util.Log.e(str, stringBuilder.toString());
        }
        return result;
    }

    public boolean unregisterSink() {
        boolean result = false;
        android.util.Log.d(TAG, "unregisterSink");
        if (this.mService == null || this.mSink == null) {
            android.util.Log.e(TAG, "mService or mSink is null.");
            return false;
        }
        try {
            result = this.mService.freeDeviceStatusService(this.packageName, this.mSink);
        } catch (android.os.RemoteException var3) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("unregisterSink error:");
            stringBuilder.append(var3.getMessage());
            android.util.Log.e(str, stringBuilder.toString());
        }
        return result;
    }

    public boolean connectService(com.huawei.msdp.devicestatus.HwMSDPDeviceStatusChangedCallBack sink, com.huawei.msdp.devicestatus.HwMSDPDeviceStatusServiceConnection connection) {
        android.util.Log.d(TAG, "connectService");
        if (connection == null || sink == null) {
            android.util.Log.e(TAG, "connection or sink is null");
            return false;
        }
        this.mServiceConnection = connection;
        if (this.mService == null) {
            this.mSink = createDeviceStatusRecognitionHardwareSink(sink);
            bindService();
        }
        return true;
    }

    private void bindService() {
        if (this.mConnectCount > 10) {
            android.util.Log.d(TAG, "time out, connetion fail!");
        } else if (this.mService == null) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(this.mContext.getPackageName());
            stringBuilder.append("bind device status  service");
            android.util.Log.d(str, stringBuilder.toString());
            android.content.Intent bindIntent = new android.content.Intent();
            bindIntent.setClassName("com.huawei.msdp", "com.huawei.msdp.devicestatus.HwMSDPDeviceStatusService");
            this.mContext.bindService(bindIntent, this.mConnection, 1);
            this.mConnectCount++;
            this.mHandler.sendEmptyMessageDelayed(1, 2000);
        }
    }

    public boolean disconnectService() {
        android.util.Log.d(TAG, "disconnectService");
        if (this.mService == null) {
            android.util.Log.e(TAG, "mService is null");
            return false;
        }
        this.mService.asBinder().unlinkToDeath(this.deathHandler, 0);
        unregisterSink();
        this.mContext.unbindService(this.mConnection);
        this.mServiceConnection.onServiceDisconnected();
        this.mService = null;
        this.mConnectCount = 0;
        this.mHandler.removeMessages(1);
        this.mHandler.removeMessages(0);
        return true;
    }

    public java.lang.String[] getSupportedDeviceStatus() {
        android.util.Log.d(TAG, "getSupportedDeviceStatus");
        if (this.mService == null) {
            android.util.Log.e(TAG, "mService is null");
            return new java.lang.String[0];
        }
        try {
            return this.mService.getSupportDeviceStatus();
        } catch (android.os.RemoteException var2) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getSupportDeviceStatus error :");
            stringBuilder.append(var2.getMessage());
            android.util.Log.e(str, stringBuilder.toString());
            return new java.lang.String[0];
        }
    }

    public boolean enableDeviceStatusEvent(java.lang.String deviceStatus, int eventType, long reportLatencyNs) {
        android.util.Log.d(TAG, "enableDeviceStatusEvent");
        boolean result = false;
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("deviceStatus:");
        stringBuilder.append(deviceStatus);
        android.util.Log.d(str, stringBuilder.toString());
        str = TAG;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("eventType:");
        stringBuilder.append(eventType);
        android.util.Log.d(str, stringBuilder.toString());
        str = TAG;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("reportLatencyNs:");
        stringBuilder.append(reportLatencyNs);
        android.util.Log.d(str, stringBuilder.toString());
        if (android.text.TextUtils.isEmpty(deviceStatus) || reportLatencyNs < 0) {
            android.util.Log.e(TAG, "deviceStatus is null or reportLatencyNs < 0");
            return false;
        }
        str = TAG;
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(deviceStatus);
        stringBuilder.append(",");
        stringBuilder.append(eventType);
        stringBuilder.append(",");
        stringBuilder.append(reportLatencyNs);
        android.util.Log.d(str, stringBuilder.toString());
        if (this.mService == null) {
            android.util.Log.e(TAG, "mService is null");
            return false;
        }
        try {
            result = this.mService.enableDeviceStatusService(this.packageName, deviceStatus, eventType, reportLatencyNs);
        } catch (android.os.RemoteException var7) {
            java.lang.String str2 = TAG;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("enabledeviceStatusEvent error:");
            stringBuilder2.append(var7.getMessage());
            android.util.Log.e(str2, stringBuilder2.toString());
        }
        return result;
    }

    public boolean disableDeviceStatusEvent(java.lang.String deviceStatus, int eventType) {
        boolean result = false;
        android.util.Log.d(TAG, "disableDeviceStatusEvent");
        if (android.text.TextUtils.isEmpty(deviceStatus)) {
            android.util.Log.e(TAG, "deviceStatus is null");
            return false;
        }
        java.lang.String str = TAG;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(deviceStatus);
        stringBuilder.append(",");
        stringBuilder.append(eventType);
        android.util.Log.d(str, stringBuilder.toString());
        if (this.mService == null) {
            android.util.Log.e(TAG, "mService is null");
            return false;
        }
        try {
            result = this.mService.disableDeviceStatusService(this.packageName, deviceStatus, eventType);
        } catch (android.os.RemoteException var5) {
            java.lang.String str2 = TAG;
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("disableDeviceStatusEvent error:");
            stringBuilder2.append(var5.getMessage());
            android.util.Log.e(str2, stringBuilder2.toString());
        }
        return result;
    }

    public com.huawei.msdp.devicestatus.HwMSDPDeviceStatusChangeEvent getCurrentDeviceStatus() {
        android.util.Log.d(TAG, "getCurrentDeviceStatus");
        com.huawei.msdp.devicestatus.HwMSDPDeviceStatusChangeEvent deviceStatus = null;
        if (this.mService == null) {
            android.util.Log.e(TAG, "mService is null");
            return null;
        }
        try {
            deviceStatus = this.mService.getCurrentDeviceStatus(this.packageName);
        } catch (android.os.RemoteException var3) {
            java.lang.String str = TAG;
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("getCurrentDeviceStatus error :");
            stringBuilder.append(var3.getMessage());
            android.util.Log.e(str, stringBuilder.toString());
        }
        return deviceStatus;
    }

    private com.huawei.msdp.devicestatus.IMSDPDeviceStatusChangedCallBack createDeviceStatusRecognitionHardwareSink(final com.huawei.msdp.devicestatus.HwMSDPDeviceStatusChangedCallBack sink) {
        return sink == null ? null : new com.huawei.msdp.devicestatus.IMSDPDeviceStatusChangedCallBack.Stub() {
            public void onDeviceStatusChanged(com.huawei.msdp.devicestatus.HwMSDPDeviceStatusChangeEvent event) throws android.os.RemoteException {
                sink.onDeviceStatusChanged(event);
            }
        };
    }
}
