package com.leisen.wallet.sdk.apdu;

public abstract class ApduResponseHandler {
    private static final int MESSAGE_FAILURE = 2;
    private static final int MESSAGE_SENDNEXT = 1;
    private static final int MESSAGE_SENDNEXT_ERROR = 3;
    private static final int MESSAGE_SUCCESS = 0;
    private com.leisen.wallet.sdk.apdu.ApduResponseHandler.ResponseHandler mHandler;
    private boolean useSynchronousMode;

    private static class ResponseHandler extends android.os.Handler {
        private final com.leisen.wallet.sdk.apdu.ApduResponseHandler mResponder;

        public ResponseHandler(com.leisen.wallet.sdk.apdu.ApduResponseHandler responder) {
            this.mResponder = responder;
        }

        public void handleMessage(android.os.Message msg) {
            this.mResponder.handleMessage(msg);
        }
    }

    public abstract void OnSendNextError(int i, int i2, java.lang.String str, java.lang.String str2, java.lang.Error error);

    public abstract void onFailure(int i, java.lang.Error error);

    public abstract void onSendNext(int i, int i2, java.lang.String str, java.lang.String str2);

    public abstract void onSuccess(java.lang.String str);

    public ApduResponseHandler() {
        setUseSynchronousMode(true);
    }

    public void setUseSynchronousMode(boolean useSynchronousMode) {
        if (!useSynchronousMode && android.os.Looper.myLooper() == null) {
            useSynchronousMode = true;
        }
        if (!useSynchronousMode && this.mHandler == null) {
            this.mHandler = new com.leisen.wallet.sdk.apdu.ApduResponseHandler.ResponseHandler(this);
        } else if (useSynchronousMode && this.mHandler != null) {
            this.mHandler = null;
        }
        this.useSynchronousMode = useSynchronousMode;
    }

    public boolean getUseSynchronousMode() {
        return this.useSynchronousMode;
    }

    private void sendMessage(android.os.Message msg) {
        if (!getUseSynchronousMode()) {
            if (this.mHandler != null) {
                if (!java.lang.Thread.currentThread().isInterrupted()) {
                    this.mHandler.sendMessage(msg);
                    return;
                }
                return;
            }
        }
        handleMessage(msg);
    }

    public void handleMessage(android.os.Message msg) {
        java.lang.Object[] objects;
        switch (msg.what) {
            case 0:
                objects = (java.lang.Object[]) msg.obj;
                if (objects != null && objects.length >= 1) {
                    onSuccess(objects[0] == null ? null : objects[0].toString());
                    return;
                }
                return;
            case 1:
                objects = (java.lang.Object[]) msg.obj;
                if (objects != null && objects.length >= 4) {
                    onSendNext(java.lang.Integer.parseInt(objects[0].toString()), java.lang.Integer.parseInt(objects[1].toString()), objects[2].toString(), objects[3].toString());
                    return;
                }
                return;
            case 2:
                objects = (java.lang.Object[]) msg.obj;
                if (objects != null && objects.length >= 2) {
                    onFailure(java.lang.Integer.parseInt(objects[0].toString()), (java.lang.Error) objects[1]);
                    return;
                }
                return;
            case 3:
                objects = msg.obj;
                if (objects != null && objects.length >= 5) {
                    OnSendNextError(java.lang.Integer.parseInt(objects[0].toString()), java.lang.Integer.parseInt(objects[1].toString()), objects[2].toString(), objects[3].toString(), (java.lang.Error) objects[4]);
                    return;
                }
                return;
            default:
                return;
        }
    }

    public void sendSuccessMessage(java.lang.String response) {
        sendMessage(obtainMessage(0, new java.lang.Object[]{response}));
    }

    public void sendSendNextMessage(int result, int index, java.lang.String rapdu, java.lang.String sw) {
        sendMessage(obtainMessage(1, new java.lang.Object[]{java.lang.Integer.valueOf(result), java.lang.Integer.valueOf(index), rapdu, sw}));
    }

    public void sendSendNextErrorMessage(int result, int index, java.lang.String rapdu, java.lang.String sw, java.lang.Error e) {
        sendMessage(obtainMessage(3, new java.lang.Object[]{java.lang.Integer.valueOf(result), java.lang.Integer.valueOf(index), rapdu, sw, e}));
    }

    public void sendFailureMessage(int result, java.lang.Error e) {
        sendMessage(obtainMessage(2, new java.lang.Object[]{java.lang.Integer.valueOf(result), e}));
    }

    private android.os.Message obtainMessage(int responseMessageId, java.lang.Object responseMessageData) {
        if (this.mHandler != null) {
            return android.os.Message.obtain(this.mHandler, responseMessageId, responseMessageData);
        }
        android.os.Message msg = android.os.Message.obtain();
        if (msg == null) {
            return msg;
        }
        msg.what = responseMessageId;
        msg.obj = responseMessageData;
        return msg;
    }
}
