package com.leisen.wallet.sdk.apdu;

public class ApduSmartCardRequest implements java.lang.Runnable, com.leisen.wallet.sdk.oma.SmartCardCallback {
    private static final int RESULT_FAILURE = 1;
    private static final int RESULT_SUCCESS = 0;
    private static final java.lang.String TAG = "ApduSmartCardRequest";
    private java.lang.String mApduAid;
    private java.util.List<com.leisen.wallet.sdk.business.ApduBean> mCapduList;
    private android.content.Context mContext;
    private com.leisen.wallet.sdk.business.ApduBean mCurrentExecuteApduBean;
    private int mCurrentExecuteIndex = 0;
    private int mFlag;
    private com.leisen.wallet.sdk.apdu.ApduResponseHandler mHandler;
    private boolean mIsGetLocalData = false;

    public ApduSmartCardRequest(android.content.Context context, com.leisen.wallet.sdk.apdu.ApduResponseHandler handler) {
        this.mContext = context;
        this.mHandler = handler;
    }

    public synchronized void run() {
        sendApudToSmartCard();
    }

    private void sendApudToSmartCard() {
        if (this.mCapduList != null && this.mCurrentExecuteIndex != this.mCapduList.size()) {
            this.mCurrentExecuteApduBean = (com.leisen.wallet.sdk.business.ApduBean) this.mCapduList.get(this.mCurrentExecuteIndex);
            java.lang.String apdu = this.mCurrentExecuteApduBean.getApdu();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("==>start get apdu index:");
            stringBuilder.append(this.mCurrentExecuteIndex);
            stringBuilder.append("==apdu:");
            stringBuilder.append(apdu);
            com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder.toString());
            java.lang.StringBuilder stringBuilder2;
            if (apdu.length() >= 4 && "00A4".equals(apdu.substring(0, 4))) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("==>deal with select apdu :");
                stringBuilder2.append(apdu);
                com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder2.toString());
                this.mApduAid = apdu.substring(apdu.length() - (java.lang.Integer.parseInt(apdu.substring(8, 10), 16) * 2), apdu.length());
                this.mCurrentExecuteIndex++;
                com.leisen.wallet.sdk.oma.SmartCard.getInstance().closeChannel();
                java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                stringBuilder3.append("==>has been get select aid:");
                stringBuilder3.append(this.mApduAid);
                com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder3.toString());
                sendApudToSmartCard();
            } else if (this.mApduAid != null) {
                stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("==>start execute apdu：");
                stringBuilder2.append(apdu);
                com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder2.toString());
                com.leisen.wallet.sdk.oma.SmartCardBean bean = new com.leisen.wallet.sdk.oma.SmartCardBean(1, this.mApduAid);
                bean.setCommand(apdu);
                com.leisen.wallet.sdk.oma.SmartCard.getInstance().setSmartCardCallBack(this).execute(this.mContext, this.mFlag, bean);
            }
        }
    }

    public void onOperSuccess(int flag, java.lang.String response) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("==>handle apdu response:");
        stringBuilder.append(response);
        com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder.toString());
        if (this.mIsGetLocalData) {
            sendSuccessMessage(response);
            return;
        }
        java.lang.String res_sw = response;
        java.lang.String r_apdu = "";
        if (response != null && response.length() > 4) {
            res_sw = response.substring(response.length() - 4, response.length());
            r_apdu = response.substring(0, response.length() - 4).toUpperCase(java.util.Locale.getDefault());
        }
        if (res_sw != null) {
            res_sw = res_sw.toUpperCase(java.util.Locale.getDefault());
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("==>get response res_sw:");
        stringBuilder2.append(res_sw);
        com.leisen.wallet.sdk.util.LogUtil.d("ApduSmartCardRequest", stringBuilder2.toString());
        if (java.util.Arrays.asList(this.mCurrentExecuteApduBean.getSw()).contains(res_sw)) {
            if (this.mCurrentExecuteIndex < this.mCapduList.size() - 1) {
                this.mCurrentExecuteIndex++;
                sendApudToSmartCard();
            } else {
                sendMessage(0, this.mCurrentExecuteApduBean.getIndex(), r_apdu, res_sw);
            }
            return;
        }
        sendMessage(1, this.mCurrentExecuteApduBean.getIndex(), r_apdu, res_sw);
    }

    public void onOperFailure(int flag, java.lang.Error e) {
        if (this.mIsGetLocalData) {
            sendFailureMessage(100009, e);
            return;
        }
        sendErrorMessage(1, this.mCurrentExecuteApduBean.getIndex(), "", "", e);
    }

    public void setCapduList(java.util.List<com.leisen.wallet.sdk.business.ApduBean> capduList) {
        this.mCapduList = capduList;
    }

    public void setFlag(int flag) {
        this.mFlag = flag;
    }

    public void isGetLocalData(boolean enable) {
        this.mIsGetLocalData = enable;
    }

    public void setGetLocalDataApdu(java.lang.String apdu, java.lang.String aid) {
        if (this.mCapduList == null) {
            this.mCapduList = new java.util.ArrayList();
        } else {
            this.mCapduList.clear();
        }
        this.mCapduList.add(new com.leisen.wallet.sdk.business.ApduBean(apdu));
        this.mApduAid = aid;
    }

    private void sendMessage(int result, int index, java.lang.String rapdu, java.lang.String sw) {
        clearData();
        if (this.mHandler != null) {
            this.mHandler.sendSendNextMessage(result, index, rapdu, sw);
        }
    }

    private void sendErrorMessage(int result, int index, java.lang.String rapdu, java.lang.String sw, java.lang.Error e) {
        clearData();
        if (this.mHandler != null) {
            this.mHandler.sendSendNextErrorMessage(result, index, rapdu, sw, e);
        }
    }

    private void sendSuccessMessage(java.lang.String response) {
        clearData();
        if (this.mHandler != null) {
            this.mHandler.sendSuccessMessage(response);
        }
    }

    private void sendFailureMessage(int result, java.lang.Error e) {
        clearData();
        if (this.mHandler != null) {
            this.mHandler.sendFailureMessage(result, e);
        }
    }

    private void clearData() {
        this.mCurrentExecuteIndex = 0;
        this.mCurrentExecuteApduBean = null;
        this.mIsGetLocalData = false;
    }
}
