package com.leisen.wallet.sdk.newhttp;

public class AsyncHttpClientX {
    private static final int DEFAULT_MAX_CONNECTIONS = 10;
    public static final int DEFAULT_MAX_RETRIES = 5;
    public static final int DEFAULT_RETRY_SLEEP_TIME_MILLIS = 1500;
    public static final int DEFAULT_SOCKET_BUFFER_SIZE = 8192;
    private static final int DEFAULT_SOCKET_TIMEOUT = 30000;
    private static final java.lang.String TAG = "AsyncHttpClientX";
    private java.util.Map<java.lang.String, java.lang.String> clientHeaderMap = new java.util.HashMap();
    private boolean isEncodeUrl = false;
    private int maxConnections = 10;
    private java.util.Map<android.content.Context, java.util.List<com.leisen.wallet.sdk.newhttp.RequestHandleX>> requestMap = new java.util.WeakHashMap();
    private java.util.concurrent.ExecutorService threadPool = getDefaultThreadPool();
    private int timeout = 30000;
    private boolean useSynchronousMode = false;

    public AsyncHttpClientX(boolean useSynchronousMode) {
        this.useSynchronousMode = useSynchronousMode;
    }

    protected java.util.concurrent.ExecutorService getDefaultThreadPool() {
        return java.util.concurrent.Executors.newCachedThreadPool();
    }

    public com.leisen.wallet.sdk.newhttp.RequestHandleX post(android.content.Context context, java.lang.String url, java.lang.String request, com.leisen.wallet.sdk.newhttp.ResponseHandlerInterfaceX responseHandler) {
        java.net.HttpURLConnection conn = null;
        try {
            java.net.URL mUrl = new java.net.URL(url);
            if ("https".equals(mUrl.getProtocol())) {
                conn = (javax.net.ssl.HttpsURLConnection) mUrl.openConnection();
            } else {
                conn = (java.net.HttpURLConnection) mUrl.openConnection();
            }
        } catch (java.net.MalformedURLException e) {
            e.printStackTrace();
        } catch (java.io.IOException e2) {
            e2.printStackTrace();
        }
        return sendRequest(conn, request, responseHandler, context);
    }

    protected com.leisen.wallet.sdk.newhttp.RequestHandleX sendRequest(java.net.HttpURLConnection conn, java.lang.String request, com.leisen.wallet.sdk.newhttp.ResponseHandlerInterfaceX responseHandler, android.content.Context context) {
        if (conn == null) {
            throw new java.lang.IllegalArgumentException("HttpUriRequest must not be null");
        } else if (responseHandler != null) {
            conn.setRequestProperty("Content-Type", "text/json");
            conn.addRequestProperty("Charset", "UTF-8");
            conn.setReadTimeout(this.timeout);
            conn.setDoInput(true);
            conn.setDoOutput(true);
            conn.setUseCaches(false);
            try {
                conn.setRequestMethod("POST");
                responseHandler.setUseSynchronousMode(this.useSynchronousMode);
                responseHandler.setRequestURI(conn.getURL());
                com.leisen.wallet.sdk.newhttp.AsyncHttpRequestX asyncHttpRequest = new com.leisen.wallet.sdk.newhttp.AsyncHttpRequestX(conn, request, responseHandler);
                if (this.useSynchronousMode) {
                    asyncHttpRequest.run();
                } else {
                    this.threadPool.submit(asyncHttpRequest);
                }
                com.leisen.wallet.sdk.newhttp.RequestHandleX requestHandle = new com.leisen.wallet.sdk.newhttp.RequestHandleX(asyncHttpRequest);
                if (context != null) {
                    java.util.List<com.leisen.wallet.sdk.newhttp.RequestHandleX> requestList = (java.util.List) this.requestMap.get(context);
                    if (requestList == null) {
                        requestList = new java.util.LinkedList();
                        this.requestMap.put(context, requestList);
                    }
                    requestList.add(requestHandle);
                    java.util.Iterator<com.leisen.wallet.sdk.newhttp.RequestHandleX> iterator = requestList.iterator();
                    while (iterator.hasNext()) {
                        if (((com.leisen.wallet.sdk.newhttp.RequestHandleX) iterator.next()).shouldBeGarbageCollected()) {
                            iterator.remove();
                        }
                    }
                }
                return requestHandle;
            } catch (java.net.ProtocolException e) {
                throw new java.lang.IllegalArgumentException("POST not be allowed?");
            }
        } else {
            throw new java.lang.IllegalArgumentException("ResponseHandler must not be null");
        }
    }

    public static void silentCloseInputStream(java.io.InputStream is) {
        if (is != null) {
            try {
                is.close();
            } catch (java.io.IOException e) {
                android.util.Log.w("AsyncHttpClientX", "Cannot close input stream", e);
            }
        }
    }

    public static void silentCloseOutputStream(java.io.OutputStream os) {
        if (os != null) {
            try {
                os.close();
            } catch (java.io.IOException e) {
                android.util.Log.w("AsyncHttpClientX", "Cannot close output stream", e);
            }
        }
    }

    public void cancelRequests(final android.content.Context context, final boolean mayInterruptIfRunning) {
        if (context != null) {
            java.lang.Runnable r = new java.lang.Runnable() {
                public void run() {
                    for (com.leisen.wallet.sdk.newhttp.RequestHandleX requestHandle : (java.util.List) com.leisen.wallet.sdk.newhttp.AsyncHttpClientX.this.requestMap.get(context)) {
                        requestHandle.cancel(mayInterruptIfRunning);
                    }
                    com.leisen.wallet.sdk.newhttp.AsyncHttpClientX.this.requestMap.remove(context);
                }
            };
            if (android.os.Looper.myLooper() == android.os.Looper.getMainLooper()) {
                new java.lang.Thread(r).start();
            } else {
                r.run();
            }
        }
    }

    public void cancelAllRequests(boolean mayInterruptIfRunning) {
        for (java.util.List<com.leisen.wallet.sdk.newhttp.RequestHandleX> requestList : this.requestMap.values()) {
            if (requestList != null) {
                for (com.leisen.wallet.sdk.newhttp.RequestHandleX requestHandle : requestList) {
                    requestHandle.cancel(mayInterruptIfRunning);
                }
            }
        }
        this.requestMap.clear();
    }
}
