package com.leisen.wallet.sdk.newhttp;

public class AsyncHttpRequestX implements java.lang.Runnable {
    private static final java.lang.String TAG = "AsyncHttpRequestX";
    private boolean cancelIsNotified = false;
    private int executionCount;
    private boolean isCancelled = false;
    private boolean isFinished = false;
    private final java.lang.String request;
    private final com.leisen.wallet.sdk.newhttp.ResponseHandlerInterfaceX responseHandler;
    private final java.net.HttpURLConnection urlConnection;

    public AsyncHttpRequestX(java.net.HttpURLConnection conn, java.lang.String request, com.leisen.wallet.sdk.newhttp.ResponseHandlerInterfaceX responseHandler) {
        this.urlConnection = conn;
        this.request = request;
        this.responseHandler = responseHandler;
    }

    public void run() {
        if (!isCancelled()) {
            if (this.responseHandler != null) {
                this.responseHandler.sendStartMessage();
            }
            if (!isCancelled()) {
                try {
                    makeRequestWithRetries();
                } catch (java.lang.Exception e) {
                    if (isCancelled() || this.responseHandler == null) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("makeRequestWithRetries returned error, but handler is null");
                        stringBuilder.append(e);
                        android.util.Log.e("AsyncHttpRequest", stringBuilder.toString());
                    } else {
                        this.responseHandler.sendFailureMessage(0, null, e);
                    }
                }
                if (!isCancelled()) {
                    if (this.responseHandler != null) {
                        this.responseHandler.sendFinishMessage();
                    }
                    this.isFinished = true;
                }
            }
        }
    }

    private void makeRequestWithRetries() throws java.io.IOException {
        java.lang.StringBuilder stringBuilder;
        boolean retry = true;
        int maxRetryCnt = 3;
        java.io.IOException cause = null;
        while (retry) {
            maxRetryCnt--;
            if (maxRetryCnt <= 0) {
                retry = false;
            }
            try {
                makeRequest();
                return;
            } catch (java.lang.Exception e) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("UnknownHostException exception:");
                stringBuilder.append(e.getMessage());
                cause = new java.io.IOException(stringBuilder.toString());
            } catch (java.lang.NullPointerException e2) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("NPE in HttpClient: ");
                stringBuilder.append(e2.getMessage());
                cause = new java.io.IOException(stringBuilder.toString());
            } catch (java.io.IOException e3) {
                try {
                    if (!isCancelled()) {
                        cause = e3;
                    } else {
                        return;
                    }
                } catch (java.lang.Exception e4) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("Unhandled exception: ");
                    stringBuilder.append(e4.getMessage());
                    cause = new java.io.IOException(stringBuilder.toString());
                }
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("Unhandled exception origin fcause");
        stringBuilder2.append(cause.getMessage());
        android.util.Log.e("AsyncHttpRequestX", stringBuilder2.toString());
        throw cause;
    }

    private void makeRequest() throws java.io.IOException {
        if (!isCancelled()) {
            com.leisen.wallet.sdk.util.LogUtil.e("AsyncHttpRequestX", "==>get response before");
            this.urlConnection.connect();
            java.io.DataOutputStream wr = new java.io.DataOutputStream(this.urlConnection.getOutputStream());
            wr.writeBytes(this.request);
            wr.flush();
            wr.close();
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("==>get response after = ");
            stringBuilder.append(this.urlConnection.getResponseCode());
            com.leisen.wallet.sdk.util.LogUtil.e("AsyncHttpRequestX", stringBuilder.toString());
            if (!(isCancelled() || this.responseHandler == null)) {
                this.responseHandler.sendResponseMessage(this.urlConnection);
            }
        }
    }

    public boolean isCancelled() {
        if (this.isCancelled) {
            sendCancelNotification();
        }
        return this.isCancelled;
    }

    private synchronized void sendCancelNotification() {
        if (!(this.isFinished || !this.isCancelled || this.cancelIsNotified)) {
            this.cancelIsNotified = true;
            if (this.responseHandler != null) {
                this.responseHandler.sendCancelMessage();
            }
        }
    }

    public boolean isDone() {
        if (!isCancelled()) {
            if (!this.isFinished) {
                return false;
            }
        }
        return true;
    }

    public boolean cancel(boolean mayInterruptIfRunning) {
        this.isCancelled = true;
        this.urlConnection.disconnect();
        return isCancelled();
    }
}
