package com.leisen.wallet.sdk.newhttp;

public abstract class AsyncHttpResponseHandlerX implements com.leisen.wallet.sdk.newhttp.ResponseHandlerInterfaceX {
    protected static final int BUFFER_SIZE = 4096;
    protected static final int CANCEL_MESSAGE = 6;
    public static final java.lang.String DEFAULT_CAHRSET = "UTF_8";
    protected static final int FALIURE_MESSAGE = 1;
    protected static final int FINISH_MESSAGE = 3;
    protected static final int PROGRESS_MESSAGE = 4;
    protected static final int RETRY_MESSAGE = 5;
    protected static final int START_MESSAGE = 2;
    protected static final int SUCCESS_MESSAGE = 0;
    private static final java.lang.String TAG = "AsyncHttpResHandlerX";
    private android.os.Handler handler;
    private java.net.URL requestURI = null;
    private java.lang.String responseCharset = "UTF_8";
    private boolean useSynchronousMode;

    private static class ResponderHandler extends android.os.Handler {
        private final com.leisen.wallet.sdk.newhttp.AsyncHttpResponseHandlerX mResponder;

        public ResponderHandler(com.leisen.wallet.sdk.newhttp.AsyncHttpResponseHandlerX mResponder) {
            this.mResponder = mResponder;
        }

        public void handleMessage(android.os.Message msg) {
            this.mResponder.handleMessage(msg);
        }
    }

    public abstract void onFailure(int i, byte[] bArr, java.lang.Throwable th);

    public abstract void onSuccess(int i, byte[] bArr);

    public AsyncHttpResponseHandlerX() {
        setUseSynchronousMode(true);
    }

    public java.net.URL getRequestURI() {
        return this.requestURI;
    }

    public void setRequestURI(java.net.URL requestURI) {
        this.requestURI = requestURI;
    }

    public void setUseSynchronousMode(boolean useSynchronousMode) {
        if (!useSynchronousMode && android.os.Looper.myLooper() == null) {
            useSynchronousMode = true;
        }
        if (!useSynchronousMode && this.handler == null) {
            this.handler = new com.leisen.wallet.sdk.newhttp.AsyncHttpResponseHandlerX.ResponderHandler(this);
        } else if (useSynchronousMode && this.handler != null) {
            this.handler = null;
        }
        this.useSynchronousMode = useSynchronousMode;
    }

    public boolean getUseSynchronousMode() {
        return this.useSynchronousMode;
    }

    public void setCharset(java.lang.String charset) {
        this.responseCharset = charset;
    }

    public java.lang.String getCharset() {
        return this.responseCharset == null ? "UTF_8" : this.responseCharset;
    }

    public void sendResponseMessage(java.net.HttpURLConnection urlConnection) throws java.io.IOException {
        if (!java.lang.Thread.currentThread().isInterrupted()) {
            int status = urlConnection.getResponseCode();
            byte[] responseBody = getResponseData(urlConnection);
            if (!java.lang.Thread.currentThread().isInterrupted()) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("==>");
                stringBuilder.append(status);
                stringBuilder.append("==");
                stringBuilder.append(new java.lang.String(responseBody));
                com.leisen.wallet.sdk.util.LogUtil.e("AsyncHttpResHandlerX", stringBuilder.toString());
                if (status > 300) {
                    sendFailureMessage(status, responseBody, new java.net.HttpRetryException(urlConnection.getResponseMessage(), status));
                } else {
                    sendSuccessMessage(status, responseBody);
                }
            }
        }
    }

    public void sendStartMessage() {
        sendMessage(obtainMessage(2, null));
    }

    public void sendFinishMessage() {
        sendMessage(obtainMessage(3, null));
    }

    public void sendProgressMessage(int bytesWritten, int bytesTotal) {
        sendMessage(obtainMessage(4, new java.lang.Object[]{java.lang.Integer.valueOf(bytesWritten), java.lang.Integer.valueOf(bytesTotal)}));
    }

    public void sendCancelMessage() {
        sendMessage(obtainMessage(6, null));
    }

    public void sendSuccessMessage(int statusCode, byte[] responseBody) {
        sendMessage(obtainMessage(0, new java.lang.Object[]{java.lang.Integer.valueOf(statusCode), responseBody}));
    }

    public void sendFailureMessage(int statusCode, byte[] responseBody, java.lang.Throwable error) {
        sendMessage(obtainMessage(1, new java.lang.Object[]{java.lang.Integer.valueOf(statusCode), responseBody, error}));
    }

    public void sendRetryMessage(int retryNo) {
        sendMessage(obtainMessage(5, new java.lang.Object[]{java.lang.Integer.valueOf(retryNo)}));
    }

    private void sendMessage(android.os.Message msg) {
        if (!getUseSynchronousMode()) {
            if (this.handler != null) {
                if (!java.lang.Thread.currentThread().isInterrupted()) {
                    this.handler.sendMessage(msg);
                    return;
                }
                return;
            }
        }
        handleMessage(msg);
    }

    protected void handleMessage(android.os.Message msg) {
        int i = msg.what;
        if (i != 6) {
            java.lang.Object[] response;
            switch (i) {
                case 0:
                    response = (java.lang.Object[]) msg.obj;
                    if (response == null || response.length < 2) {
                        android.util.Log.e("AsyncHttpResHandlerX", "SUCCESS_MESSAGE didn't got enough params");
                        return;
                    } else {
                        onSuccess(((java.lang.Integer) response[0]).intValue(), (byte[]) response[1]);
                        return;
                    }
                case 1:
                    response = (java.lang.Object[]) msg.obj;
                    if (response == null || response.length < 3) {
                        android.util.Log.e("AsyncHttpResHandlerX", "FAILURE_MESSAGE didn't got enough params");
                        return;
                    } else {
                        onFailure(((java.lang.Integer) response[0]).intValue(), (byte[]) response[1], (java.lang.Throwable) response[2]);
                        return;
                    }
                case 2:
                    onStart();
                    return;
                case 3:
                    onFinish();
                    return;
                case 4:
                    response = msg.obj;
                    if (response == null || response.length < 2) {
                        android.util.Log.e("AsyncHttpResHandlerX", "PROGRESS_MESSAGE didn't got enough params");
                        return;
                    }
                    try {
                        onProgress(((java.lang.Integer) response[0]).intValue(), ((java.lang.Integer) response[1]).intValue());
                    } catch (java.lang.Throwable t) {
                        android.util.Log.e("AsyncHttpResHandlerX", "custom onProgress contains an error", t);
                    }
                    return;
                default:
                    return;
            }
        }
        onCancel();
    }

    private android.os.Message obtainMessage(int responseMessageId, java.lang.Object responseMessageData) {
        if (this.handler != null) {
            return android.os.Message.obtain(this.handler, responseMessageId, responseMessageData);
        }
        android.os.Message msg = android.os.Message.obtain();
        if (msg == null) {
            return msg;
        }
        msg.what = responseMessageId;
        msg.obj = responseMessageData;
        return msg;
    }

    private byte[] getResponseData(java.net.HttpURLConnection urlConnection) throws java.io.IOException {
        java.lang.Throwable th;
        if (urlConnection != null) {
            try {
                java.io.InputStream instream = urlConnection.getInputStream();
                java.io.ByteArrayOutputStream outS = new java.io.ByteArrayOutputStream();
                long contentLength = (long) urlConnection.getContentLength();
                try {
                    byte[] buffer = new byte[(contentLength < 0 ? 4096 : (int) contentLength)];
                    int count = 0;
                    while (true) {
                        int read = instream.read(buffer);
                        int l = read;
                        if (read == -1 || java.lang.Thread.currentThread().isInterrupted()) {
                        } else {
                            count += l;
                            outS.write(buffer, 0, l);
                            try {
                                sendProgressMessage(count, (int) (contentLength <= 0 ? 1 : contentLength));
                            } catch (Throwable th2) {
                                th = th2;
                                com.leisen.wallet.sdk.newhttp.AsyncHttpClientX.silentCloseInputStream(instream);
                                throw th;
                            }
                        }
                    }
                } catch (Throwable th3) {
                    th = th3;
                    com.leisen.wallet.sdk.newhttp.AsyncHttpClientX.silentCloseInputStream(instream);
                    throw th;
                }
                try {
                    com.leisen.wallet.sdk.newhttp.AsyncHttpClientX.silentCloseInputStream(instream);
                    return outS.toByteArray();
                } catch (java.lang.OutOfMemoryError e) {
                    java.lang.System.gc();
                    throw new java.io.IOException("File too large to fit into available memory");
                }
            } catch (java.lang.OutOfMemoryError e2) {
                java.lang.System.gc();
                throw new java.io.IOException("File too large to fit into available memory");
            }
        }
        return null;
    }

    public void onProgress(int bytesWritten, int totalSize) {
    }

    public void onStart() {
    }

    public void onFinish() {
    }

    public void onCancel() {
    }
}
