package com.leisen.wallet.sdk.oma;

public class SmartCard implements android.se.omapi.SEService.OnConnectedListener {
    private static final java.lang.String BOUNDARY = "==>";
    private static final java.lang.String TAG = "SmartCard";
    private static com.leisen.wallet.sdk.oma.SmartCard mInstance;
    private final java.lang.Object lock = new java.lang.Object();
    private com.leisen.wallet.sdk.oma.SmartCardCallback mCallback;
    private int mFlag = -1;
    private android.se.omapi.SEService mSEService;
    private boolean mServiceIsConnection = false;
    private com.leisen.wallet.sdk.oma.SmartCardBean mSmartCardBean;
    private com.leisen.wallet.sdk.oma.SmartCardRequest mSmartCardRequest;

    private SmartCard() {
    }

    public static synchronized com.leisen.wallet.sdk.oma.SmartCard getInstance() {
        com.leisen.wallet.sdk.oma.SmartCard smartCard;
        synchronized (com.leisen.wallet.sdk.oma.SmartCard.class) {
            if (mInstance == null) {
                mInstance = new com.leisen.wallet.sdk.oma.SmartCard();
            }
            smartCard = mInstance;
        }
        return smartCard;
    }

    public void execute(android.content.Context context, int flag, com.leisen.wallet.sdk.oma.SmartCardBean bean) {
        this.mFlag = flag;
        if (bean == null) {
            operFailure(this.mFlag, "SmartCardBean must not allow to null");
        } else if (bean.getReaderName() == null) {
            operFailure(this.mFlag, "choose reader not exist");
        } else if (bean.getAid() == null) {
            operFailure(this.mFlag, "the aid must not allow to null");
        } else {
            this.mSmartCardBean = bean;
            if (this.mSEService == null) {
                synchronized (this.lock) {
                    this.mSEService = new android.se.omapi.SEService(context, java.util.concurrent.Executors.newSingleThreadExecutor(), this);
                }
                com.leisen.wallet.sdk.util.LogUtil.d("SmartCard", "==>start bind OMA SEService");
                if (this.mSEService.isConnected()) {
                    this.mServiceIsConnection = true;
                }
                if (!this.mServiceIsConnection) {
                    synchronized (this) {
                        try {
                            if (!this.mServiceIsConnection) {
                                com.leisen.wallet.sdk.util.LogUtil.d("SmartCard", "==>thread is waiting");
                                wait();
                            }
                        } catch (java.lang.InterruptedException e) {
                            int i = this.mFlag;
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("thread error:");
                            stringBuilder.append(e.getMessage());
                            operFailure(i, stringBuilder.toString());
                        }
                    }
                }
            }
            executeSmartCardRequest();
        }
    }

    private void executeSmartCardRequest() {
        if (this.mSEService != null) {
            if (this.mSmartCardRequest == null) {
                this.mSmartCardRequest = new com.leisen.wallet.sdk.oma.SmartCardRequest(this.mSEService);
            }
            this.mSmartCardRequest.setSmartCartBean(this.mSmartCardBean);
            this.mSmartCardRequest.setSmartCardCallback(this.mCallback);
            this.mSmartCardRequest.setFlag(this.mFlag);
            this.mSmartCardRequest.run();
        }
    }

    public void onConnected() {
        synchronized (this.lock) {
            synchronized (this) {
                if (this.mSEService == null) {
                    return;
                }
                if (this.mSEService.isConnected()) {
                    com.leisen.wallet.sdk.util.LogUtil.d("SmartCard", "==>bind SEService successed");
                } else {
                    operFailure(this.mFlag, "SEService connect failure");
                }
                com.leisen.wallet.sdk.util.LogUtil.d("SmartCard", "==>thread notifyAll");
                this.mServiceIsConnection = true;
                notifyAll();
            }
        }
    }

    public com.leisen.wallet.sdk.oma.SmartCard setSmartCardCallBack(com.leisen.wallet.sdk.oma.SmartCardCallback callback) {
        this.mCallback = callback;
        return this;
    }

    public void closeService() {
        if (this.mSmartCardRequest != null) {
            this.mSmartCardRequest.closeChannelAndSession();
            this.mSmartCardRequest = null;
        }
        try {
            if (this.mSEService != null && this.mSEService.isConnected()) {
                this.mSEService.shutdown();
                this.mSEService = null;
                this.mServiceIsConnection = false;
                com.leisen.wallet.sdk.util.LogUtil.i("SmartCard", "==>SEService正常关闭");
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("==>SEService关闭异常");
            stringBuilder.append(e.getMessage());
            com.leisen.wallet.sdk.util.LogUtil.e("SmartCard", stringBuilder.toString());
        }
        this.mCallback = null;
        this.mSmartCardBean = null;
        this.mSmartCardRequest = null;
    }

    public void closeChannel() {
        if (this.mSmartCardRequest != null) {
            this.mSmartCardRequest.closeChannelAndSession();
            this.mSmartCardRequest = null;
        }
    }

    private void operFailure(int flag, java.lang.String detailMessage) {
        if (this.mCallback != null) {
            this.mCallback.onOperFailure(flag, new java.lang.Error(detailMessage));
        }
    }
}
