package com.leisen.wallet.sdk.oma;

class SmartCardRequest implements java.lang.Runnable {
    private static final java.lang.String BOUNDARY = "==>";
    private static final java.lang.String TAG = "SmartCardRequest";
    private com.leisen.wallet.sdk.oma.SmartCardCallback mCallback;
    private android.se.omapi.Channel mChannel;
    private int mFlag = -1;
    private android.se.omapi.SEService mSEService;
    private android.se.omapi.Session mSession;
    private com.leisen.wallet.sdk.oma.SmartCardBean mSmartCardBean;

    protected SmartCardRequest(android.se.omapi.SEService seService) {
        this.mSEService = seService;
    }

    public void setSmartCartBean(com.leisen.wallet.sdk.oma.SmartCardBean bean) {
        this.mSmartCardBean = bean;
    }

    public void setSmartCardCallback(com.leisen.wallet.sdk.oma.SmartCardCallback callback) {
        this.mCallback = callback;
    }

    public void setFlag(int flag) {
        this.mFlag = flag;
    }

    public synchronized void run() {
        if (openCurrentAvailableChannel()) {
            try {
                executeApduCmd();
            } catch (java.io.IOException e) {
                closeChannelAndSession();
                int i = this.mFlag;
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("execute apdu error：");
                stringBuilder.append(e.getMessage());
                operFailure(i, stringBuilder.toString());
            }
        } else {
            return;
        }
        return;
    }

    private void executeApduCmd() throws java.io.IOException {
        java.lang.String command = this.mSmartCardBean.getCommand();
        if (command == null || "".equals(command)) {
            java.lang.String rapdu = com.leisen.wallet.sdk.util.DataConvertUtil.bytesToHexString(this.mChannel.getSelectResponse());
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("==>选择AID的结果为：");
            stringBuilder.append(rapdu);
            com.leisen.wallet.sdk.util.LogUtil.i("SmartCardRequest", stringBuilder.toString());
            operSuccess(this.mFlag, rapdu);
        }
        byte[] byteCommand = com.leisen.wallet.sdk.util.DataConvertUtil.hexStringToBytes(command);
        if (this.mChannel != null) {
            java.lang.String rapdu2 = com.leisen.wallet.sdk.util.DataConvertUtil.bytesToHexString(this.mChannel.transmit(byteCommand));
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("==>执行APDU:");
            stringBuilder2.append(command);
            stringBuilder2.append("，返回的RAPDU为：");
            stringBuilder2.append(rapdu2);
            com.leisen.wallet.sdk.util.LogUtil.i("SmartCardRequest", stringBuilder2.toString());
            operSuccess(this.mFlag, rapdu2);
        }
    }

    private boolean openCurrentAvailableChannel() {
        int i;
        java.lang.StringBuilder stringBuilder;
        if (this.mChannel == null) {
            android.se.omapi.Reader reader = getCurrentAvailableReader();
            if (reader == null) {
                operFailure(this.mFlag, "choose reader not exist");
                return false;
            } else if (reader.isSecureElementPresent()) {
                java.lang.StringBuilder stringBuilder2;
                try {
                    this.mSession = reader.openSession();
                    byte[] byteAid = com.leisen.wallet.sdk.util.DataConvertUtil.hexStringToBytes(this.mSmartCardBean.getAid());
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("==>打开通道的Aid：");
                    stringBuilder2.append(this.mSmartCardBean.getAid());
                    com.leisen.wallet.sdk.util.LogUtil.i("SmartCardRequest", stringBuilder2.toString());
                    try {
                        if (this.mSession != null) {
                            this.mChannel = this.mSession.openBasicChannel(byteAid);
                        }
                    } catch (java.io.IOException e) {
                        closeChannelAndSession();
                        i = this.mFlag;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("IOException open channel error：");
                        stringBuilder.append(e.getMessage());
                        operFailure(i, stringBuilder.toString());
                        return false;
                    } catch (java.lang.SecurityException e2) {
                        closeChannelAndSession();
                        i = this.mFlag;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("SecurityException open channel error：");
                        stringBuilder.append(e2.getMessage());
                        operFailure(i, stringBuilder.toString());
                        return false;
                    } catch (java.lang.Exception e3) {
                        e3.printStackTrace();
                        closeChannelAndSession();
                        i = this.mFlag;
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Exception open channel error：");
                        stringBuilder.append(e3.getMessage());
                        operFailure(i, stringBuilder.toString());
                        return false;
                    }
                } catch (java.io.IOException e4) {
                    closeChannelAndSession();
                    int i2 = this.mFlag;
                    stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("open session error：");
                    stringBuilder2.append(e4.getMessage());
                    operFailure(i2, stringBuilder2.toString());
                    return false;
                }
            } else {
                operFailure(this.mFlag, "choose reader can not use");
                return false;
            }
        }
        return true;
    }

    private android.se.omapi.Reader getCurrentAvailableReader() {
        android.se.omapi.Reader[] readers = this.mSEService.getReaders();
        if (readers != null) {
            if (readers.length >= 1) {
                int i = 0;
                for (android.se.omapi.Reader reader : readers) {
                    if (reader.getName().startsWith("eSE2")) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("==> first use reader name:");
                        stringBuilder.append(reader.getName());
                        com.leisen.wallet.sdk.util.LogUtil.e("SmartCardRequest", stringBuilder.toString());
                        return reader;
                    }
                }
                int length = readers.length;
                while (i < length) {
                    android.se.omapi.Reader reader2 = readers[i];
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("==>reader name:");
                    stringBuilder2.append(reader2.getName());
                    com.leisen.wallet.sdk.util.LogUtil.e("SmartCardRequest", stringBuilder2.toString());
                    if (reader2.getName().startsWith(this.mSmartCardBean.getReaderName())) {
                        return reader2;
                    }
                    i++;
                }
                return null;
            }
        }
        operFailure(this.mFlag, "your devices not support any reader");
        return null;
    }

    public void closeChannelAndSession() {
        try {
            if (this.mChannel != null) {
                this.mChannel.close();
                this.mChannel = null;
                com.leisen.wallet.sdk.util.LogUtil.i("SmartCardRequest", "==>Channel正常关闭");
            }
        } catch (java.lang.Exception e) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("==>Channel关闭异常");
            stringBuilder.append(e.getMessage());
            com.leisen.wallet.sdk.util.LogUtil.e("SmartCardRequest", stringBuilder.toString());
        }
        try {
            if (!(this.mSession == null || this.mSession.isClosed())) {
                this.mSession.close();
                this.mSession = null;
                com.leisen.wallet.sdk.util.LogUtil.i("SmartCardRequest", "==>Session正常关闭");
            }
        } catch (java.lang.Exception e2) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("==>Session关闭异常");
            stringBuilder2.append(e2.getMessage());
            com.leisen.wallet.sdk.util.LogUtil.e("SmartCardRequest", stringBuilder2.toString());
        }
    }

    private void operSuccess(int flag, java.lang.String response) {
        if (this.mCallback != null) {
            this.mCallback.onOperSuccess(flag, response);
        }
    }

    private void operFailure(int flag, java.lang.String detailMessage) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("==>");
        stringBuilder.append(detailMessage);
        com.leisen.wallet.sdk.util.LogUtil.e("SmartCardRequest", stringBuilder.toString());
        if (this.mCallback != null) {
            this.mCallback.onOperFailure(flag, new java.lang.Error(detailMessage));
        }
    }
}
