package huawei.com.android.server.fingerprint;

public class HighLightMaskView extends android.widget.FrameLayout {
    private static final java.lang.String TAG = "HighLightMaskView";
    private static int[] sSampleAlpha = new int[]{234, 229, 219, 220, 216, 211, 208, 205, 187, 176, 170, 163, 159, 142, 140, 140, 125, 121, 111, 101, 92, 81, 81, 69, 68, 58, 56, 46, 44, 35, 34, 30, 22, 23, 18, 0, 0};
    private static int[] sSampleBrightness = new int[]{4, 6, 8, 10, 12, 14, 16, 20, 24, 28, 30, 34, 40, 46, 50, 56, 64, 74, 84, 94, 104, 114, 124, 134, 144, 154, 164, 174, 184, 194, 204, 214, 224, 234, 244, 248, 255};
    private android.view.View mBlackMaskView;
    private int mCenterX;
    private int mCenterY;
    private android.view.View mCircleMaskView;
    private int mCircleOnDrawCounter;
    private int mHighLightShowType = -1;
    private boolean mIsCircleViewVisible;
    private final android.graphics.Paint mPaint = new android.graphics.Paint(1);
    private java.lang.String mPkgName;
    private int mRadius;
    private float mScale;
    private com.android.server.fingerprint.fingerprintAnimation.WaterEffectView mWaterEffectView;

    public HighLightMaskView(android.content.Context context, int brightness, int radius) {
        super(context);
        init(context, brightness, radius);
    }

    public void setAlpha(int alpha) {
        if (this.mBlackMaskView != null) {
            this.mBlackMaskView.getBackground().setAlpha(alpha);
        }
    }

    public float getAlpha() {
        if (this.mBlackMaskView != null) {
            return (float) this.mBlackMaskView.getBackground().getAlpha();
        }
        return 0.0f;
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        if ("com.android.systemui".equals(this.mPkgName) && 1 == this.mHighLightShowType) {
            this.mWaterEffectView.onResume();
            this.mWaterEffectView.playAnim(((float) this.mCenterX) * this.mScale, ((float) this.mCenterY) * this.mScale);
        }
        this.mCircleOnDrawCounter = 0;
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        if ("com.android.systemui".equals(this.mPkgName) && 1 == this.mHighLightShowType) {
            this.mWaterEffectView.onPause();
        }
        this.mCircleOnDrawCounter = 0;
    }

    private void init(android.content.Context context, int brightness, int radius) {
        this.mPaint.setDither(true);
        this.mPaint.setStyle(android.graphics.Paint.Style.FILL);
        this.mPaint.setColor(-16711681);
        this.mPaint.setMaskFilter(new android.graphics.BlurMaskFilter(20.0f, android.graphics.BlurMaskFilter.Blur.SOLID));
        this.mRadius = radius;
        this.mWaterEffectView = new com.android.server.fingerprint.fingerprintAnimation.WaterEffectView(context);
        addView(this.mWaterEffectView, -1, -1);
        this.mBlackMaskView = new android.view.View(this.mContext);
        this.mBlackMaskView.setBackgroundColor(-16777216);
        int alphaNew = 0;
        if (brightness > 0) {
            alphaNew = getMaskAlpha(brightness);
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("alphaNew:");
        stringBuilder.append(alphaNew);
        stringBuilder.append("radius = ");
        stringBuilder.append(radius);
        android.util.Log.i("HighLightMaskView", stringBuilder.toString());
        this.mBlackMaskView.getBackground().setAlpha(alphaNew);
        addView(this.mBlackMaskView, -1, -1);
        this.mCircleMaskView = new android.view.View(this.mContext) {
            public void onDraw(android.graphics.Canvas canvas) {
                super.onDraw(canvas);
                android.util.Log.i("HighLightMaskView", " mCircleMaskView onDraw");
                canvas.drawCircle(((float) huawei.com.android.server.fingerprint.HighLightMaskView.this.mCenterX) * huawei.com.android.server.fingerprint.HighLightMaskView.this.mScale, ((float) huawei.com.android.server.fingerprint.HighLightMaskView.this.mCenterY) * huawei.com.android.server.fingerprint.HighLightMaskView.this.mScale, ((float) huawei.com.android.server.fingerprint.HighLightMaskView.this.mRadius) * huawei.com.android.server.fingerprint.HighLightMaskView.this.mScale, huawei.com.android.server.fingerprint.HighLightMaskView.this.mPaint);
                if (huawei.com.android.server.fingerprint.HighLightMaskView.this.mHighLightShowType == 1) {
                    if (huawei.com.android.server.fingerprint.HighLightMaskView.this.mCircleOnDrawCounter == 1 && huawei.com.android.server.fingerprint.HighLightMaskView.this.mIsCircleViewVisible) {
                        android.util.Log.i("HighLightMaskView", " mCircleMaskView notifyCaptureImage 1");
                        huawei.com.android.server.fingerprint.FingerViewController.getInstance(this.mContext).notifyCaptureImage();
                        huawei.com.android.server.fingerprint.HighLightMaskView.this.mCircleOnDrawCounter = 0;
                        return;
                    }
                    huawei.com.android.server.fingerprint.HighLightMaskView.this.mCircleOnDrawCounter = huawei.com.android.server.fingerprint.HighLightMaskView.this.mCircleOnDrawCounter + 1;
                } else if (huawei.com.android.server.fingerprint.HighLightMaskView.this.mIsCircleViewVisible) {
                    android.util.Log.i("HighLightMaskView", " mCircleMaskView notifyCaptureImage 2");
                    huawei.com.android.server.fingerprint.FingerViewController.getInstance(this.mContext).notifyCaptureImage();
                }
            }
        };
        addView(this.mCircleMaskView, -1, -1);
    }

    public int getMaskAlpha(int currentLight) {
        int alpha = 0;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" currentLight:");
        stringBuilder.append(currentLight);
        android.util.Log.d("HighLightMaskView", stringBuilder.toString());
        if (currentLight > sSampleBrightness[sSampleBrightness.length - 1]) {
            return 0;
        }
        int i = 0;
        while (i < sSampleBrightness.length) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append(" sSampleBrightness :[");
            stringBuilder2.append(i);
            stringBuilder2.append("]");
            stringBuilder2.append(sSampleBrightness[i]);
            android.util.Log.d("HighLightMaskView", stringBuilder2.toString());
            if (currentLight == sSampleBrightness[i]) {
                alpha = sSampleAlpha[i];
                break;
            } else if (currentLight >= sSampleBrightness[i]) {
                i++;
            } else if (i == 0) {
                alpha = sSampleAlpha[0];
            } else {
                alpha = queryAlphaImpl(currentLight, sSampleBrightness[i - 1], sSampleAlpha[i - 1], sSampleBrightness[i], sSampleAlpha[i]);
            }
        }
        if (alpha > sSampleAlpha[0] || alpha < 0) {
            alpha = 0;
        }
        stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(" alpha:");
        stringBuilder.append(alpha);
        android.util.Log.d("HighLightMaskView", stringBuilder.toString());
        return alpha;
    }

    private int queryAlphaImpl(int currLight, int preLevelLight, int preLevelAlpha, int lastLevelLight, int lastLevelAlpha) {
        return (((currLight - preLevelLight) * (lastLevelAlpha - preLevelAlpha)) / (lastLevelLight - preLevelLight)) + preLevelAlpha;
    }

    public void setCenterPoints(int centerX, int centerY) {
        this.mCenterX = centerX;
        this.mCenterY = centerY;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mCenterX = ");
        stringBuilder.append(this.mCenterX);
        stringBuilder.append(",mCenterY=");
        stringBuilder.append(this.mCenterY);
        android.util.Log.d("HighLightMaskView", stringBuilder.toString());
    }

    public void setScale(float scale) {
        this.mScale = scale;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mScale = ");
        stringBuilder.append(this.mScale);
        android.util.Log.d("HighLightMaskView", stringBuilder.toString());
    }

    public void setCircleVisibility(int visibility) {
        if (this.mCircleMaskView != null) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(" mCircleMaskView setVisibility:");
            stringBuilder.append(visibility);
            android.util.Log.i("HighLightMaskView", stringBuilder.toString());
            if (visibility == 0 || this.mCircleMaskView.getVisibility() != visibility) {
                this.mCircleMaskView.setVisibility(visibility);
                if (visibility == 0) {
                    this.mIsCircleViewVisible = true;
                } else {
                    android.util.Log.i("HighLightMaskView", " mCircleMaskView notifyDismissBlueSpot ");
                    huawei.com.android.server.fingerprint.FingerViewController.getInstance(this.mContext).notifyDismissBlueSpot();
                    this.mIsCircleViewVisible = false;
                }
            } else {
                android.util.Log.i("HighLightMaskView", " visibility is already INVISIBLE skip");
            }
        }
    }

    public int getCircleVisibility() {
        if (this.mCircleMaskView != null) {
            return this.mCircleMaskView.getVisibility();
        }
        return 4;
    }

    public void setType(int type) {
        this.mHighLightShowType = type;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mHighLightShowType = ");
        stringBuilder.append(this.mScale);
        android.util.Log.i("HighLightMaskView", stringBuilder.toString());
    }

    public void setPackageName(java.lang.String pkgName) {
        this.mPkgName = pkgName;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mPkgName = ");
        stringBuilder.append(this.mPkgName);
        android.util.Log.i("HighLightMaskView", stringBuilder.toString());
    }

    public void onDraw(android.graphics.Canvas canvas) {
        super.onDraw(canvas);
        this.mPaint.setXfermode(null);
    }
}
