package huawei.com.android.server.policy;

public class BlurUtils {
    private static final java.lang.String LEFT = "left";
    private static int NAVIGATIONBAR_LAYER = 231000;
    private static final java.lang.String RIGHT = "right";
    private static final float SCALE = 0.75f;
    private static final int STATE_LEFT = 1;
    private static final int STATE_MIDDLE = 0;
    private static final int STATE_RIGHT = 2;
    private static final java.lang.String TAG = "BlurUtils";
    private static android.renderscript.RenderScript mRenderScript;
    private static android.renderscript.ScriptIntrinsicBlur mScriptIntrinsicBlur;

    public static android.graphics.Bitmap blurImage(android.content.Context ctx, android.graphics.Bitmap input, android.graphics.Bitmap output, int radius) {
        if (!(ctx == null || input == null || output == null || radius <= 0)) {
            if (radius <= 25) {
                android.content.Context c = ctx.getApplicationContext();
                if (c != null) {
                    ctx = c;
                }
                android.renderscript.RenderScript mRs = android.renderscript.RenderScript.create(ctx);
                if (mRs == null) {
                    android.util.Log.w("BlurUtils", "blurImage() mRs consturct error");
                    return null;
                }
                android.renderscript.Allocation tmpIn = android.renderscript.Allocation.createFromBitmap(mRs, input, android.renderscript.Allocation.MipmapControl.MIPMAP_NONE, 1);
                android.renderscript.Allocation tmpOut = android.renderscript.Allocation.createTyped(mRs, tmpIn.getType());
                if (output.getConfig() == android.graphics.Bitmap.Config.ARGB_8888) {
                    android.renderscript.Element elementIn = tmpIn.getType().getElement();
                    android.renderscript.Element elementOut = tmpOut.getType().getElement();
                    if (!(elementIn.isCompatible(android.renderscript.Element.RGBA_8888(mRs)) && elementOut.isCompatible(android.renderscript.Element.RGBA_8888(mRs)))) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Temp input Allocation kind is ");
                        stringBuilder.append(elementIn.getDataKind());
                        stringBuilder.append(", type ");
                        stringBuilder.append(elementIn.getDataType());
                        stringBuilder.append(" of ");
                        stringBuilder.append(elementIn.getBytesSize());
                        stringBuilder.append(" bytes.And Temp output Allocation kind is ");
                        stringBuilder.append(elementOut.getDataKind());
                        stringBuilder.append(", type ");
                        stringBuilder.append(elementOut.getDataType());
                        stringBuilder.append(" of ");
                        stringBuilder.append(elementOut.getBytesSize());
                        stringBuilder.append(" bytes. output bitmap was ARGB_8888.");
                        android.util.Log.w("BlurUtils", stringBuilder.toString());
                        return null;
                    }
                }
                android.renderscript.ScriptIntrinsicBlur mScriptIntrinsic = android.renderscript.ScriptIntrinsicBlur.create(mRs, android.renderscript.Element.U8_4(mRs));
                mScriptIntrinsic.setRadius((float) radius);
                mScriptIntrinsic.setInput(tmpIn);
                mScriptIntrinsic.forEach(tmpOut);
                tmpOut.copyTo(output);
                try {
                    tmpIn.destroy();
                } catch (android.renderscript.RSInvalidStateException e) {
                    e.printStackTrace();
                }
                try {
                    tmpOut.destroy();
                } catch (android.renderscript.RSInvalidStateException e2) {
                    e2.printStackTrace();
                }
                mRs.destroy();
                return output;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("blurImage() parameter is incorrect:");
        stringBuilder2.append(ctx);
        stringBuilder2.append(",");
        stringBuilder2.append(input);
        stringBuilder2.append(",");
        stringBuilder2.append(output);
        stringBuilder2.append(",");
        stringBuilder2.append(radius);
        android.util.Log.w("BlurUtils", stringBuilder2.toString());
        return null;
    }

    public static android.graphics.Bitmap blurMaskImage(android.content.Context ctx, android.graphics.Bitmap input, android.graphics.Bitmap output, int radius) {
        if (!(ctx == null || input == null || output == null || radius <= 0)) {
            if (radius <= 25) {
                android.content.Context c = ctx.getApplicationContext();
                if (c != null) {
                    ctx = c;
                }
                if (mRenderScript == null) {
                    mRenderScript = android.renderscript.RenderScript.create(ctx);
                }
                if (mRenderScript == null) {
                    android.util.Log.w("BlurUtils", "blurImage() mRs consturct error");
                    return null;
                }
                android.renderscript.Allocation tmpIn = android.renderscript.Allocation.createFromBitmap(mRenderScript, input, android.renderscript.Allocation.MipmapControl.MIPMAP_NONE, 1);
                android.renderscript.Allocation tmpOut = android.renderscript.Allocation.createTyped(mRenderScript, tmpIn.getType());
                if (output.getConfig() == android.graphics.Bitmap.Config.ARGB_8888) {
                    android.renderscript.Element elementIn = tmpIn.getType().getElement();
                    android.renderscript.Element elementOut = tmpOut.getType().getElement();
                    if (!(elementIn.isCompatible(android.renderscript.Element.RGBA_8888(mRenderScript)) && elementOut.isCompatible(android.renderscript.Element.RGBA_8888(mRenderScript)))) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Temp input Allocation kind is ");
                        stringBuilder.append(elementIn.getDataKind());
                        stringBuilder.append(", type ");
                        stringBuilder.append(elementIn.getDataType());
                        stringBuilder.append(" of ");
                        stringBuilder.append(elementIn.getBytesSize());
                        stringBuilder.append(" bytes.And Temp output Allocation kind is ");
                        stringBuilder.append(elementOut.getDataKind());
                        stringBuilder.append(", type ");
                        stringBuilder.append(elementOut.getDataType());
                        stringBuilder.append(" of ");
                        stringBuilder.append(elementOut.getBytesSize());
                        stringBuilder.append(" bytes. output bitmap was ARGB_8888.");
                        android.util.Log.w("BlurUtils", stringBuilder.toString());
                        return null;
                    }
                }
                if (mScriptIntrinsicBlur == null) {
                    mScriptIntrinsicBlur = android.renderscript.ScriptIntrinsicBlur.create(mRenderScript, android.renderscript.Element.U8_4(mRenderScript));
                }
                mScriptIntrinsicBlur.setRadius((float) radius);
                mScriptIntrinsicBlur.setInput(tmpIn);
                mScriptIntrinsicBlur.forEach(tmpOut);
                tmpOut.copyTo(output);
                try {
                    tmpIn.destroy();
                } catch (android.renderscript.RSInvalidStateException e) {
                    e.printStackTrace();
                }
                try {
                    tmpOut.destroy();
                } catch (android.renderscript.RSInvalidStateException e2) {
                    e2.printStackTrace();
                }
                return output;
            }
        }
        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
        stringBuilder2.append("blurImage() parameter is incorrect:");
        stringBuilder2.append(ctx);
        stringBuilder2.append(",");
        stringBuilder2.append(input);
        stringBuilder2.append(",");
        stringBuilder2.append(output);
        stringBuilder2.append(",");
        stringBuilder2.append(radius);
        android.util.Log.w("BlurUtils", stringBuilder2.toString());
        return null;
    }

    public static android.graphics.Bitmap covertToARGB888(android.graphics.Bitmap img) {
        android.graphics.Bitmap result = android.graphics.Bitmap.createBitmap(img.getWidth(), img.getHeight(), android.graphics.Bitmap.Config.ARGB_8888);
        new android.graphics.Canvas(result).drawBitmap(img, 0.0f, 0.0f, new android.graphics.Paint());
        return result;
    }

    public static android.graphics.Bitmap addBlackBoard(android.graphics.Bitmap bmp, int color) {
        android.graphics.Canvas canvas = new android.graphics.Canvas();
        android.graphics.Paint paint = new android.graphics.Paint();
        android.graphics.Bitmap newBitmap = android.graphics.Bitmap.createBitmap(bmp.getWidth(), bmp.getHeight(), android.graphics.Bitmap.Config.ARGB_8888);
        canvas.setBitmap(newBitmap);
        canvas.drawBitmap(bmp, 0.0f, 0.0f, paint);
        canvas.drawColor(color);
        return newBitmap;
    }

    public static android.graphics.Bitmap screenShotBitmap(android.content.Context ctx, int minLayer, int maxLayer, float scale, android.graphics.Rect rect) {
        android.graphics.Bitmap bitmap;
        android.content.Context context = ctx;
        ((android.view.WindowManager) context.getSystemService("window")).getDefaultDisplay().getRealMetrics(new android.util.DisplayMetrics());
        int[] dims = new int[]{(((int) (((float) displayMetrics.widthPixels) * scale)) / 2) * 2, (((int) (((float) displayMetrics.heightPixels) * scale)) / 2) * 2};
        android.graphics.Rect sourceCrop = getScreenshotRect(context);
        if (isLazyMode(context)) {
            bitmap = android.view.SurfaceControl.screenshot(sourceCrop, dims[0], dims[1], Integer.MIN_VALUE, Integer.MAX_VALUE, false, 0);
        } else {
            bitmap = android.view.SurfaceControl.screenshot(new android.graphics.Rect(), dims[0], dims[1], 0);
        }
        if (bitmap == null) {
            android.util.Log.e("BlurUtils", "screenShotBitmap error bitmap is null");
            return null;
        }
        bitmap.prepareToDraw();
        return bitmap;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x00d2  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x00c8  */
    public static android.graphics.Bitmap screenShotBitmap(android.content.Context r18, float r19) {
        /*
        r0 = new android.util.DisplayMetrics;
        r0.<init>();
        r1 = new android.util.DisplayMetrics;
        r1.<init>();
        r2 = "window";
        r3 = r18;
        r2 = r3.getSystemService(r2);
        r2 = (android.view.WindowManager) r2;
        r2 = r2.getDefaultDisplay();
        r2.getMetrics(r1);
        r2.getRealMetrics(r0);
        r4 = 2;
        r5 = new int[r4];
        r6 = r0.widthPixels;
        r6 = (float) r6;
        r6 = r6 * r19;
        r6 = (int) r6;
        r6 = r6 / r4;
        r6 = r6 * r4;
        r7 = 0;
        r5[r7] = r6;
        r6 = r0.heightPixels;
        r6 = (float) r6;
        r6 = r6 * r19;
        r6 = (int) r6;
        r6 = r6 / r4;
        r6 = r6 * r4;
        r8 = 1;
        r5[r8] = r6;
        r6 = new int[r4];
        r9 = r1.widthPixels;
        r9 = (float) r9;
        r9 = r9 * r19;
        r9 = (int) r9;
        r9 = r9 / r4;
        r9 = r9 * r4;
        r6[r7] = r9;
        r9 = r1.heightPixels;
        r9 = (float) r9;
        r9 = r9 * r19;
        r9 = (int) r9;
        r9 = r9 / r4;
        r9 = r9 * r4;
        r6[r8] = r9;
        r9 = "BlurUtils";
        r10 = new java.lang.StringBuilder;
        r10.<init>();
        r11 = "mFingerViewParams,dims[0] =";
        r10.append(r11);
        r11 = r5[r7];
        r10.append(r11);
        r11 = ",dims[1] =";
        r10.append(r11);
        r11 = r5[r8];
        r10.append(r11);
        r10 = r10.toString();
        android.util.Log.e(r9, r10);
        r9 = "BlurUtils";
        r10 = new java.lang.StringBuilder;
        r10.<init>();
        r11 = "mFingerViewParams,dims2[0] =";
        r10.append(r11);
        r11 = r6[r7];
        r10.append(r11);
        r11 = ",dims2[1] =";
        r10.append(r11);
        r11 = r6[r8];
        r10.append(r11);
        r10 = r10.toString();
        android.util.Log.e(r9, r10);
        r9 = 0;
        r10 = r2.getRotation();
        if (r10 == 0) goto L_0x00a6;
    L_0x0099:
        if (r4 != r10) goto L_0x009c;
    L_0x009b:
        goto L_0x00a6;
    L_0x009c:
        r4 = -2147483648; // 0xffffffff80000000 float:-0.0 double:NaN;
        r11 = 2147483647; // 0x7fffffff float:NaN double:1.060997895E-314;
        r4 = rotationScreenBitmap(r10, r5, r4, r11);
        goto L_0x00be;
    L_0x00a6:
        r11 = new android.graphics.Rect;
        r11.<init>();
        r12 = r5[r7];
        r13 = r5[r8];
        r14 = -2147483648; // 0xffffffff80000000 float:-0.0 double:NaN;
        r15 = 2147483647; // 0x7fffffff float:NaN double:1.060997895E-314;
        r16 = 0;
        r17 = converseRotation(r10);
        r4 = android.view.SurfaceControl.screenshot_ext_hw(r11, r12, r13, r14, r15, r16, r17);
    L_0x00be:
        r9 = r6[r7];
        r8 = r6[r8];
        r4 = android.graphics.Bitmap.createBitmap(r4, r7, r7, r9, r8);
        if (r4 != 0) goto L_0x00d2;
    L_0x00c8:
        r7 = "BlurUtils";
        r8 = "screenShotBitmap error bitmap is null";
        android.util.Log.e(r7, r8);
        r7 = 0;
        return r7;
    L_0x00d2:
        r4.prepareToDraw();
        return r4;
        */
        throw new UnsupportedOperationException("Method not decompiled: huawei.com.android.server.policy.BlurUtils.screenShotBitmap(android.content.Context, float):android.graphics.Bitmap");
    }

    private static android.graphics.Bitmap rotationScreenBitmap(int rotation, int[] srcDims, int minLayer, int maxLayer) {
        float degrees = convertRotationToDegrees(rotation);
        float[] dims = new float[]{(float) srcDims[0], (float) srcDims[1]};
        android.graphics.Matrix metrics = new android.graphics.Matrix();
        metrics.reset();
        metrics.preRotate(-degrees);
        metrics.mapPoints(dims);
        dims[0] = java.lang.Math.abs(dims[0]);
        dims[1] = java.lang.Math.abs(dims[1]);
        android.graphics.Bitmap bitmap = android.view.SurfaceControl.screenshot(new android.graphics.Rect(), (int) dims[0], (int) dims[1], minLayer, maxLayer, false, 0);
        android.graphics.Bitmap ss = android.graphics.Bitmap.createBitmap(srcDims[0], srcDims[1], android.graphics.Bitmap.Config.ARGB_8888);
        android.graphics.Canvas c = new android.graphics.Canvas(ss);
        c.translate(((float) srcDims[0]) * 0.5f, ((float) srcDims[1]) * 0.5f);
        c.rotate(degrees);
        c.translate((-dims[0]) * 0.5f, (-dims[1]) * 0.5f);
        c.drawBitmap(bitmap, 0.0f, 0.0f, null);
        bitmap.recycle();
        return ss;
    }

    private static float convertRotationToDegrees(int rotation) {
        switch (rotation) {
            case 1:
                return 270.0f;
            case 2:
                return 180.0f;
            case 3:
                return 90.0f;
            default:
                return 0.0f;
        }
    }

    private static int converseRotation(int rotation) {
        switch (rotation) {
            case 1:
                return 3;
            case 2:
                return 2;
            case 3:
                return 1;
            default:
                return 0;
        }
    }

    private static int getLazyState(android.content.Context context) {
        java.lang.String str = android.provider.Settings.Global.getString(context.getContentResolver(), "single_hand_mode");
        if (str != null) {
            if (!"".equals(str)) {
                if (str.contains("left")) {
                    return 1;
                }
                if (str.contains("right")) {
                    return 2;
                }
                return 0;
            }
        }
        return 0;
    }

    private static boolean isLazyMode(android.content.Context context) {
        return getLazyState(context) != 0;
    }

    private static android.graphics.Rect getScreenshotRect(android.content.Context context) {
        android.view.Display display = ((android.view.WindowManager) context.getSystemService("window")).getDefaultDisplay();
        android.util.DisplayMetrics displayMetrics = new android.util.DisplayMetrics();
        display.getRealMetrics(displayMetrics);
        int state = getLazyState(context);
        if (1 == state) {
            return new android.graphics.Rect(0, (int) (((float) displayMetrics.heightPixels) * 0.25f), (int) (((float) displayMetrics.widthPixels) * 0.75f), displayMetrics.heightPixels);
        }
        if (2 == state) {
            return new android.graphics.Rect((int) (((float) displayMetrics.widthPixels) * 0.25f), (int) (((float) displayMetrics.heightPixels) * 0.25f), displayMetrics.widthPixels, displayMetrics.heightPixels);
        }
        return null;
    }
}
