package huawei.com.android.server.policy;

public class HwFalseTouchMonitor {
    private static final int EDGE_WIDTH = 100;
    private static final int FALSE_TOUCH_REPORTE_CODE = 907400020;
    private static final float FLOAT_PRECISION = 1.0E-7f;
    private static final int MAX_RECORDS = 200;
    private static final float PI = 3.1415927f;
    private static final long QUICK_QUIT_WINDOW_TIMEOUT = 800;
    public static final int STATE_HAPPENED = 1;
    public static final int STATE_NOT_HAPPENED = 2;
    public static final int STATE_UNKOWN = 0;
    private static final long STATISTIC_PERIOD = 3600000;
    private static final java.lang.String TAG = "HwFalseTouchMonitor";
    private static final long TAP_RESPOND_MAX_TIME = 500;
    private static final long TAP_RESPOND_MIN_TIME = 50;
    private static final int TREMBLE_MOVE_RANGE = 20;
    private static final int TYPE_CHINA_BETA = 3;
    private static final int TYPE_NO_EFFECT_CLICK = 2;
    private static final int TYPE_QUICK_QUIT = 1;
    private static final int TYPE_TREMBLE = 3;
    private static final int WINDOW_NAME_MAX_LEN = 64;
    private android.view.DisplayInfo mDisplayInfo = new android.view.DisplayInfo();
    private boolean mEnabled = false;
    private huawei.com.android.server.policy.HwFalseTouchMonitor.MotionEventListener mEventListener = null;
    private boolean mFocusedChecked = false;
    private long mFocusedTime = 0;
    private com.android.server.policy.WindowManagerPolicy.WindowState mFocusedWindow = null;
    private huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint mLastUpPoint = new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint();
    private huawei.com.android.server.policy.HwFalseTouchMonitor.NoEffectClickChecker mNECChecker = new huawei.com.android.server.policy.HwFalseTouchMonitor.NoEffectClickChecker();
    private long mStatisticCount = 0;
    private java.lang.Object mStatisticLock = new java.lang.Object();
    private long mStatisticStartTime = 0;
    private android.util.SparseArray<huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint> mTouchingPoints = new android.util.SparseArray();
    private huawei.com.android.server.policy.HwFalseTouchMonitor.TrembleChecker mTrembleChecker = new huawei.com.android.server.policy.HwFalseTouchMonitor.TrembleChecker();

    public class FalseTouchChecker {
        public int state = 0;

        public boolean reportData() {
            if (this.state == 1) {
                if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.checkStatistic()) {
                    return true;
                }
            }
            return false;
        }

        public boolean processActionDown(huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint point) {
            reset();
            java.lang.StringBuilder stringBuilder;
            if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.edgePoint(point)) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append(point);
                stringBuilder.append(" nearby the edge, keep checking it");
                android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
                return true;
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append(point);
            stringBuilder.append(" faraway from the edge, ignore it");
            android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
            this.state = 2;
            return false;
        }

        public void reset() {
        }

        public void setState(int state_) {
            this.state = state_;
        }
    }

    public static class MonitorPoint {
        public int id = -1;
        public int orientation = 0;
        public long time = 0;
        public float x = -1.0f;
        public float y = -1.0f;

        public MonitorPoint(int id_, float x_, float y_, int orientation_, long time_) {
            this.id = id_;
            this.x = x_;
            this.y = y_;
            this.orientation = orientation_;
            this.time = time_;
        }

        public void set(int id_, float x_, float y_, int orientation_, long time_) {
            this.id = id_;
            this.x = x_;
            this.y = y_;
            this.orientation = orientation_;
            this.time = time_;
        }

        public java.lang.String toString() {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("point(");
            stringBuilder.append(this.x);
            stringBuilder.append(",");
            stringBuilder.append(this.y);
            stringBuilder.append("), orientation:");
            stringBuilder.append(this.orientation);
            return stringBuilder.toString();
        }
    }

    public class MotionEventListener implements android.view.WindowManagerPolicyConstants.PointerEventListener {
        public void onPointerEvent(android.view.MotionEvent motionEvent) {
            huawei.com.android.server.policy.HwFalseTouchMonitor.this.handleMotionEvent(motionEvent);
        }
    }

    public class NoEffectClickChecker extends huawei.com.android.server.policy.HwFalseTouchMonitor.FalseTouchChecker {
        public static final int CLICK_INTERVAL_TIMEOUT = 1000;
        public static final int CLICK_TIME = 100;
        public static final int NEARBY_CHECK_RANGE = 20;
        public huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint centralClickPoint = null;
        public huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint lastPointerDown = new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint();
        private com.android.server.policy.WindowManagerPolicy.WindowState mClickDownWindow = null;
        public huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint nearbyEdgePoint = null;
        public int repeatClickCount = 0;

        public NoEffectClickChecker() {
            super();
        }

        public boolean reportData() {
            if (this.state == 1) {
                if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.checkStatistic()) {
                    if (this.nearbyEdgePoint != null) {
                        if (this.centralClickPoint != null) {
                            android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(907400020);
                            eStream.setParam((short) 0, 2);
                            java.lang.String edgePoint = new java.lang.StringBuilder();
                            edgePoint.append(this.nearbyEdgePoint.x);
                            edgePoint.append(",");
                            edgePoint.append(this.nearbyEdgePoint.y);
                            edgePoint = edgePoint.toString();
                            java.lang.String centerPoint = new java.lang.StringBuilder();
                            centerPoint.append(this.centralClickPoint.x);
                            centerPoint.append(",");
                            centerPoint.append(this.centralClickPoint.y);
                            centerPoint = centerPoint.toString();
                            eStream.setParam((short) 2, edgePoint);
                            eStream.setParam((short) 3, centerPoint);
                            android.util.IMonitor.sendEvent(eStream);
                            android.util.IMonitor.closeEventStream(eStream);
                            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                            stringBuilder.append("NoEffectClickChecker, report data nearbyEdgePoint:");
                            stringBuilder.append(this.nearbyEdgePoint);
                            stringBuilder.append(",centralClickPoint:");
                            stringBuilder.append(this.centralClickPoint);
                            stringBuilder.append(",falseTouch window:");
                            stringBuilder.append(huawei.com.android.server.policy.HwFalseTouchMonitor.this.getWindowTitle(this.mClickDownWindow));
                            android.util.Log.i("HwFalseTouchMonitor", stringBuilder.toString());
                            return true;
                        }
                    }
                    return false;
                }
            }
            return false;
        }

        public void reset() {
            this.state = 0;
            this.centralClickPoint = null;
            this.nearbyEdgePoint = null;
            this.repeatClickCount = 0;
            this.lastPointerDown = null;
        }

        public boolean processActionDown(huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint point) {
            if (!super.processActionDown(point)) {
                return false;
            }
            this.nearbyEdgePoint = point;
            this.mClickDownWindow = huawei.com.android.server.policy.HwFalseTouchMonitor.this.mFocusedWindow;
            return true;
        }

        public void processPointerDown(android.view.MotionEvent event) {
            android.view.MotionEvent motionEvent = event;
            if (this.state == 0) {
                if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.mTouchingPoints.size() > 2) {
                    android.util.Log.d("HwFalseTouchMonitor", "more than one point touch down, no longer check no-effect click");
                    huawei.com.android.server.policy.HwFalseTouchMonitor.this.mNECChecker.setState(2);
                    return;
                }
                long interval = 0;
                if (this.lastPointerDown != null) {
                    interval = event.getEventTime() - this.lastPointerDown.time;
                }
                if (interval == 0 || interval <= 1000) {
                    float offsetX = event.getRawX() - event.getX();
                    float offsetY = event.getRawY() - event.getY();
                    int actionIndex = event.getActionIndex();
                    float x = motionEvent.getX(actionIndex) + offsetX;
                    float y = motionEvent.getY(actionIndex) + offsetY;
                    long time = event.getEventTime();
                    int id = motionEvent.getPointerId(actionIndex);
                    int orientation = huawei.com.android.server.policy.HwFalseTouchMonitor.this.transformOrientation(event.getOrientation());
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("NoEffectClickChecker processPointerDown check the no-primary point[");
                    stringBuilder.append(actionIndex);
                    stringBuilder.append("]:x=");
                    stringBuilder.append(x);
                    stringBuilder.append(",y=");
                    stringBuilder.append(y);
                    stringBuilder.append(",id=");
                    stringBuilder.append(id);
                    android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
                    if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.mTouchingPoints.get(id) == null) {
                        int id2 = id;
                        huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint curPoint = new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint(id, x, y, orientation, time);
                        huawei.com.android.server.policy.HwFalseTouchMonitor.this.mTouchingPoints.put(id2, curPoint);
                        this.lastPointerDown = curPoint;
                        if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.edgePoint(curPoint) || this.centralClickPoint != null) {
                            if (this.centralClickPoint == null) {
                                android.util.Log.d("HwFalseTouchMonitor", "NoEffectClickChecker no central point click before");
                            } else if (pointNearby(this.centralClickPoint, curPoint)) {
                                android.util.Log.d("HwFalseTouchMonitor", "NoEffectClickChecker current point click down nearby the last clicked central point");
                            } else {
                                android.util.Log.d("HwFalseTouchMonitor", "NoEffectClickChecker current point click is far from the last clicked central point!");
                                this.state = 2;
                            }
                            return;
                        }
                        this.centralClickPoint = curPoint;
                        android.util.Log.i("HwFalseTouchMonitor", "NoEffectClickChecker found the first central point!");
                        return;
                    }
                    return;
                }
                this.state = 2;
                android.util.Log.d("HwFalseTouchMonitor", "NoEffectClickChecker click time interval exceeds the limits form last click!");
            }
        }

        public void processPointerUp(android.view.MotionEvent event) {
            android.view.MotionEvent motionEvent = event;
            float offsetX = event.getRawX() - event.getX();
            float offsetY = event.getRawY() - event.getY();
            int actionIndex = event.getActionIndex();
            float x = motionEvent.getX(actionIndex) + offsetX;
            float y = motionEvent.getY(actionIndex) + offsetY;
            long time = event.getEventTime();
            int id = motionEvent.getPointerId(actionIndex);
            huawei.com.android.server.policy.HwFalseTouchMonitor.this.mTouchingPoints.remove(id);
            if (this.state == 0) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("NoEffectClickChecker processPointerUp point[");
                stringBuilder.append(actionIndex);
                stringBuilder.append("]:x=");
                stringBuilder.append(x);
                stringBuilder.append(",y=");
                stringBuilder.append(y);
                stringBuilder.append(",id=");
                stringBuilder.append(id);
                android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
                if (this.nearbyEdgePoint != null) {
                    if (this.nearbyEdgePoint.id != id) {
                        if (this.lastPointerDown != null) {
                            if (this.lastPointerDown.id == id) {
                                if (pointNearby(this.lastPointerDown.x, this.lastPointerDown.y, x, y)) {
                                    long clickTime = time - this.lastPointerDown.time;
                                    if (clickTime > 0 && clickTime <= 100) {
                                        this.repeatClickCount++;
                                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                                        stringBuilder2.append("NoEffectClickChecker ,repeatClickCount=");
                                        stringBuilder2.append(this.repeatClickCount);
                                        android.util.Log.i("HwFalseTouchMonitor", stringBuilder2.toString());
                                        if (this.repeatClickCount > 2) {
                                            android.util.Log.i("HwFalseTouchMonitor", "NoEffectClickChecker ,repeatClickCount happend");
                                            this.state = 1;
                                        }
                                    }
                                } else {
                                    android.util.Log.i("HwFalseTouchMonitor", "NoEffectClickChecker , central point swipe, not an click operation");
                                    this.state = 2;
                                }
                                return;
                            }
                        }
                        android.util.Log.i("HwFalseTouchMonitor", "NoEffectClickChecker pointer up id not matched");
                        return;
                    }
                }
                this.state = 2;
                android.util.Log.i("HwFalseTouchMonitor", "NoEffectClickChecker processPointerUp edgePoint is up!");
            }
        }

        private boolean pointNearby(float x1, float y1, float x2, float y2) {
            if (java.lang.Math.abs(x1 - x2) >= 20.0f) {
                if (java.lang.Math.abs(y1 - y2) >= 20.0f) {
                    return false;
                }
            }
            return true;
        }

        private boolean pointNearby(huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint p1, huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint p2) {
            return pointNearby(p1.x, p1.y, p2.x, p2.y);
        }
    }

    public class TrembleChecker extends huawei.com.android.server.policy.HwFalseTouchMonitor.FalseTouchChecker {
        public static final float MOVE_PRECISION = 0.1f;
        public static final int TREMBLE_MIN_COUNT = 10;
        public int aboveCount = 0;
        public int belowCount = 0;
        public int leftCount = 0;
        public huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint mDownPoint;
        private android.util.SparseArray<huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint> mLastMovePoints = new android.util.SparseArray();
        public int rightCount = 0;

        public TrembleChecker() {
            super();
        }

        public boolean reportData() {
            if (this.state != 2) {
                if (huawei.com.android.server.policy.HwFalseTouchMonitor.this.checkStatistic()) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("TrembleChecker check rightCount=");
                    stringBuilder.append(this.rightCount);
                    stringBuilder.append(" leftCount=");
                    stringBuilder.append(this.leftCount);
                    stringBuilder.append(" belowCount=");
                    stringBuilder.append(this.belowCount);
                    stringBuilder.append(" aboveCount=");
                    stringBuilder.append(this.aboveCount);
                    android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
                    if ((this.leftCount >= 10 && this.rightCount >= 10) || (this.belowCount >= 10 && this.aboveCount >= 10)) {
                        huawei.com.android.server.policy.HwFalseTouchMonitor.this.updateStatistic();
                        android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(907400020);
                        eStream.setParam((short) 0, 3);
                        java.lang.String point = new java.lang.StringBuilder();
                        point.append(huawei.com.android.server.policy.HwFalseTouchMonitor.this.mLastUpPoint.x);
                        point.append(",");
                        point.append(huawei.com.android.server.policy.HwFalseTouchMonitor.this.mLastUpPoint.y);
                        eStream.setParam((short) 2, point.toString());
                        android.util.IMonitor.sendEvent(eStream);
                        android.util.IMonitor.closeEventStream(eStream);
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("TrembleChecker tremble happened, down at");
                        stringBuilder.append(this.mDownPoint);
                        android.util.Log.i("HwFalseTouchMonitor", stringBuilder.toString());
                    }
                    return true;
                }
            }
            return false;
        }

        public void reset() {
            this.state = 0;
            this.mLastMovePoints.clear();
            this.mDownPoint = null;
            this.aboveCount = 0;
            this.belowCount = 0;
            this.rightCount = 0;
            this.leftCount = 0;
        }

        public boolean processActionDown(huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint point) {
            if (super.processActionDown(point)) {
                this.mLastMovePoints.put(point.id, point);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("point(");
                stringBuilder.append(point.x);
                stringBuilder.append(",");
                stringBuilder.append(point.y);
                stringBuilder.append(") nearby the edge, add it");
                android.util.Log.i("HwFalseTouchMonitor", stringBuilder.toString());
                this.mDownPoint = new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint(point.id, point.x, point.y, point.orientation, point.time);
                return true;
            }
            android.util.Log.d("HwFalseTouchMonitor", "tremble super.processActionDown return");
            return false;
        }

        public void processActionMove(android.view.MotionEvent event) {
            android.view.MotionEvent motionEvent = event;
            if (this.state == 0) {
                int i;
                if (event.getPointerCount() == 1) {
                    if (this.mDownPoint != null) {
                        float x = motionEvent.getX(0) + (event.getRawX() - event.getX());
                        float y = motionEvent.getY(0) + (event.getRawY() - event.getY());
                        int id = motionEvent.getPointerId(0);
                        int orientation = huawei.com.android.server.policy.HwFalseTouchMonitor.this.transformOrientation(motionEvent.getOrientation(0));
                        long eventTime = event.getEventTime();
                        float f;
                        int i2;
                        if (java.lang.Math.abs(x - this.mDownPoint.x) > 20.0f) {
                            i = 2;
                            f = y;
                            i2 = id;
                        } else if (java.lang.Math.abs(y - this.mDownPoint.y) > 20.0f) {
                            i = 2;
                            f = y;
                            i2 = id;
                        } else {
                            huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint lastPosition = (huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint) this.mLastMovePoints.get(id);
                            if (lastPosition != null) {
                                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("change to ");
                                stringBuilder.append(x);
                                stringBuilder.append(",");
                                stringBuilder.append(y);
                                android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
                                if (lastPosition.id == this.mDownPoint.id && huawei.com.android.server.policy.HwFalseTouchMonitor.this.pointMoved(lastPosition.x, lastPosition.y, x, y)) {
                                    if (x > lastPosition.x) {
                                        this.rightCount++;
                                    } else if (x < lastPosition.x) {
                                        this.leftCount++;
                                    }
                                    if (y > lastPosition.y) {
                                        this.belowCount++;
                                    } else if (y < lastPosition.y) {
                                        this.aboveCount++;
                                    }
                                }
                                lastPosition.x = x;
                                lastPosition.y = y;
                                huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint monitorPoint = lastPosition;
                                f = y;
                                lastPosition = id;
                            } else {
                                this.mLastMovePoints.put(id, new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint(id, x, y, orientation, eventTime));
                            }
                            return;
                        }
                        this.state = i;
                        android.util.Log.d("HwFalseTouchMonitor", "point move out of the tremble range!");
                        return;
                    }
                }
                i = 2;
                android.util.Log.d("HwFalseTouchMonitor", "tremble not happened");
                this.state = i;
            }
        }
    }

    public huawei.com.android.server.policy.HwFalseTouchMonitor.MotionEventListener getEventListener() {
        return this.mEventListener;
    }

    public boolean isFalseTouchFeatureOn() {
        return this.mEnabled;
    }

    public HwFalseTouchMonitor() {
        boolean z = true;
        if (android.os.SystemProperties.getInt("ro.logsystem.usertype", 1) != 3) {
            z = false;
        }
        this.mEnabled = z;
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("HwFalseTouchMonitor enabled?");
        stringBuilder.append(this.mEnabled);
        android.util.Log.d("HwFalseTouchMonitor", stringBuilder.toString());
        if (this.mEnabled) {
            this.mEventListener = new huawei.com.android.server.policy.HwFalseTouchMonitor.MotionEventListener();
            this.mDisplayInfo = android.hardware.display.DisplayManagerGlobal.getInstance().getDisplayInfo(0);
            if (this.mDisplayInfo != null) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("DisplayInfo logicalHeight=");
                stringBuilder2.append(this.mDisplayInfo.logicalHeight);
                stringBuilder2.append(",logicalWidth=");
                stringBuilder2.append(this.mDisplayInfo.logicalWidth);
                android.util.Log.d("HwFalseTouchMonitor", stringBuilder2.toString());
            }
        }
    }

    public void handleFocusChanged(com.android.server.policy.WindowManagerPolicy.WindowState lastFocus, com.android.server.policy.WindowManagerPolicy.WindowState newFocus) {
        if (this.mEnabled && newFocus != null) {
            synchronized (this) {
                this.mFocusedTime = java.lang.System.currentTimeMillis();
                this.mFocusedChecked = false;
                this.mFocusedWindow = newFocus;
            }
        }
    }

    /* JADX WARNING: Missing block: B:20:0x0039, code:
            if (r0 <= 0) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:22:0x003f, code:
            if (r0 >= 800) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:24:0x0045, code:
            if (r2 <= 50) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:26:0x004b, code:
            if (r2 >= 500) goto L_0x005e;
     */
    /* JADX WARNING: Missing block: B:27:0x004d, code:
            android.util.Log.i("HwFalseTouchMonitor", "enter current window and quit it quickly");
     */
    /* JADX WARNING: Missing block: B:28:0x0058, code:
            if (checkStatistic() == false) goto L_0x0085;
     */
    /* JADX WARNING: Missing block: B:29:0x005a, code:
            reportQuickQuitWindow();
     */
    /* JADX WARNING: Missing block: B:30:0x005e, code:
            r5 = new java.lang.StringBuilder();
            r5.append("handleKeyEvent current window enter ");
            r5.append(r0);
            r5.append("ms ago, last motion up before");
            r5.append(r2);
            r5.append(" ms ago from current window entered");
            android.util.Log.d("HwFalseTouchMonitor", r5.toString());
     */
    public void handleKeyEvent(android.view.KeyEvent r8) {
        /*
        r7 = this;
        r0 = r7.mEnabled;
        if (r0 != 0) goto L_0x0005;
    L_0x0004:
        return;
    L_0x0005:
        r0 = r8.getKeyCode();
        r1 = 4;
        if (r0 != r1) goto L_0x0085;
    L_0x000c:
        r0 = r8.getAction();
        if (r0 != 0) goto L_0x0085;
    L_0x0012:
        monitor-enter(r7);
        r0 = r7.mFocusedChecked;	 Catch:{ all -> 0x0082 }
        if (r0 == 0) goto L_0x0019;
    L_0x0017:
        monitor-exit(r7);	 Catch:{ all -> 0x0082 }
        return;
    L_0x0019:
        r0 = r7.mLastUpPoint;	 Catch:{ all -> 0x0082 }
        r0 = r7.edgePoint(r0);	 Catch:{ all -> 0x0082 }
        if (r0 != 0) goto L_0x0023;
    L_0x0021:
        monitor-exit(r7);	 Catch:{ all -> 0x0082 }
        return;
    L_0x0023:
        r0 = java.lang.System.currentTimeMillis();	 Catch:{ all -> 0x0082 }
        r2 = r7.mFocusedTime;	 Catch:{ all -> 0x0082 }
        r0 = r0 - r2;
        r2 = r7.mFocusedTime;	 Catch:{ all -> 0x0082 }
        r4 = r7.mLastUpPoint;	 Catch:{ all -> 0x0082 }
        r4 = r4.time;	 Catch:{ all -> 0x0082 }
        r2 = r2 - r4;
        r4 = 1;
        r7.mFocusedChecked = r4;	 Catch:{ all -> 0x0082 }
        monitor-exit(r7);	 Catch:{ all -> 0x0082 }
        r4 = 0;
        r4 = (r0 > r4 ? 1 : (r0 == r4 ? 0 : -1));
        if (r4 <= 0) goto L_0x005e;
    L_0x003b:
        r4 = 800; // 0x320 float:1.121E-42 double:3.953E-321;
        r4 = (r0 > r4 ? 1 : (r0 == r4 ? 0 : -1));
        if (r4 >= 0) goto L_0x005e;
    L_0x0041:
        r4 = 50;
        r4 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1));
        if (r4 <= 0) goto L_0x005e;
    L_0x0047:
        r4 = 500; // 0x1f4 float:7.0E-43 double:2.47E-321;
        r4 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1));
        if (r4 >= 0) goto L_0x005e;
    L_0x004d:
        r4 = "HwFalseTouchMonitor";
        r5 = "enter current window and quit it quickly";
        android.util.Log.i(r4, r5);
        r4 = r7.checkStatistic();
        if (r4 == 0) goto L_0x0085;
    L_0x005a:
        r7.reportQuickQuitWindow();
        goto L_0x0085;
    L_0x005e:
        r4 = "HwFalseTouchMonitor";
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r6 = "handleKeyEvent current window enter ";
        r5.append(r6);
        r5.append(r0);
        r6 = "ms ago, last motion up before";
        r5.append(r6);
        r5.append(r2);
        r6 = " ms ago from current window entered";
        r5.append(r6);
        r5 = r5.toString();
        android.util.Log.d(r4, r5);
        goto L_0x0085;
    L_0x0082:
        r0 = move-exception;
        monitor-exit(r7);	 Catch:{ all -> 0x0082 }
        throw r0;
    L_0x0085:
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: huawei.com.android.server.policy.HwFalseTouchMonitor.handleKeyEvent(android.view.KeyEvent):void");
    }

    private void reportQuickQuitWindow() {
        android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(907400020);
        eStream.setParam((short) 0, 1);
        java.lang.String windowName = getWindowTitle(this.mFocusedWindow);
        java.lang.String point = new java.lang.StringBuilder();
        point.append(this.mLastUpPoint.x);
        point.append(",");
        point.append(this.mLastUpPoint.y);
        point = point.toString();
        if (windowName.length() > 64) {
            windowName = windowName.substring(0, 64);
        }
        eStream.setParam((short) 1, windowName);
        eStream.setParam((short) 2, point);
        android.util.IMonitor.sendEvent(eStream);
        android.util.IMonitor.closeEventStream(eStream);
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("reportQuickQuitWindow point(");
        stringBuilder.append(this.mLastUpPoint.x);
        stringBuilder.append(",");
        stringBuilder.append(this.mLastUpPoint.y);
        stringBuilder.append(") click up, orientation=");
        stringBuilder.append(this.mLastUpPoint.orientation);
        stringBuilder.append(",window:");
        stringBuilder.append(getWindowTitle(this.mFocusedWindow));
        android.util.Log.i("HwFalseTouchMonitor", stringBuilder.toString());
        updateStatistic();
    }

    private void handleMotionEvent(android.view.MotionEvent event) {
        switch (event.getActionMasked()) {
            case 0:
                handleActionDown(event);
                return;
            case 1:
                handleActionUp(event);
                return;
            case 2:
                handleActionMove(event);
                return;
            case 5:
                handlePointerDown(event);
                return;
            case 6:
                handlePointerUp(event);
                return;
            default:
                return;
        }
    }

    private void handleActionDown(android.view.MotionEvent event) {
        float x = event.getRawX();
        float y = event.getRawY();
        long time = event.getEventTime();
        int id = event.getPointerId(event.getActionIndex());
        huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint downPoint = new huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint(id, x, y, transformOrientation(event.getOrientation()), time);
        this.mTouchingPoints.put(id, downPoint);
        this.mTrembleChecker.processActionDown(downPoint);
        this.mNECChecker.processActionDown(downPoint);
    }

    private void handleActionUp(android.view.MotionEvent event) {
        float x = event.getRawX();
        float y = event.getRawY();
        long time = java.lang.System.currentTimeMillis();
        int id = event.getPointerId(event.getActionIndex());
        int orientation = transformOrientation(event.getOrientation());
        this.mTouchingPoints.clear();
        this.mLastUpPoint.set(id, x, y, orientation, time);
        this.mTrembleChecker.reportData();
        this.mNECChecker.reportData();
    }

    private boolean pointMoved(float x1, float x2, float y1, float y2) {
        if (java.lang.Math.abs(x1 - x2) <= 0.1f) {
            if (java.lang.Math.abs(y1 - y2) <= 0.1f) {
                return false;
            }
        }
        return true;
    }

    private void handleActionMove(android.view.MotionEvent event) {
        this.mTrembleChecker.processActionMove(event);
    }

    private void handlePointerDown(android.view.MotionEvent event) {
        android.util.Log.d("HwFalseTouchMonitor", "more than one point touch down, no longer check tremble");
        this.mTrembleChecker.setState(2);
        this.mNECChecker.processPointerDown(event);
    }

    private void handlePointerUp(android.view.MotionEvent event) {
        this.mNECChecker.processPointerUp(event);
    }

    private int transformOrientation(float orientation) {
        if (java.lang.Math.abs(orientation - 1.5707964f) < 1.0E-7f) {
            return 1;
        }
        if (java.lang.Math.abs(1.5707964f + orientation) < 1.0E-7f) {
            return 3;
        }
        return 0;
    }

    private boolean edgePoint(huawei.com.android.server.policy.HwFalseTouchMonitor.MonitorPoint point) {
        boolean edge;
        int width = this.mDisplayInfo.logicalWidth;
        int height = this.mDisplayInfo.logicalHeight;
        float x = point.x;
        boolean z = false;
        if (point.orientation == 0) {
            if ((x >= 0.0f && x <= 100.0f) || (x >= ((float) (width - 100)) && x <= ((float) width))) {
                z = true;
            }
            edge = z;
        } else {
            if ((x >= 0.0f && x <= 100.0f) || (x >= ((float) (height - 100)) && x <= ((float) height))) {
                z = true;
            }
            edge = z;
        }
        java.lang.String str = "HwFalseTouchMonitor";
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append(point);
        stringBuilder.append(edge ? " is" : " not");
        stringBuilder.append(" a edge point");
        android.util.Log.i(str, stringBuilder.toString());
        return edge;
    }

    private java.lang.String getWindowTitle(com.android.server.policy.WindowManagerPolicy.WindowState window) {
        if (window != null) {
            if (window.getAttrs() != null) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("");
                stringBuilder.append(this.mFocusedWindow.getAttrs().getTitle());
                return stringBuilder.toString();
            }
        }
        return "unkown";
    }

    /* JADX WARNING: Missing block: B:17:0x002e, code:
            return true;
     */
    private boolean checkStatistic() {
        /*
        r11 = this;
        r0 = r11.mStatisticLock;
        monitor-enter(r0);
        r1 = r11.mStatisticStartTime;	 Catch:{ all -> 0x002f }
        r3 = 0;
        r1 = (r1 > r3 ? 1 : (r1 == r3 ? 0 : -1));
        r2 = 1;
        if (r1 == 0) goto L_0x002d;
    L_0x000c:
        r5 = r11.mStatisticCount;	 Catch:{ all -> 0x002f }
        r7 = 200; // 0xc8 float:2.8E-43 double:9.9E-322;
        r1 = (r5 > r7 ? 1 : (r5 == r7 ? 0 : -1));
        if (r1 > 0) goto L_0x0015;
    L_0x0014:
        goto L_0x002d;
    L_0x0015:
        r5 = java.lang.System.currentTimeMillis();	 Catch:{ all -> 0x002f }
        r7 = r11.mStatisticStartTime;	 Catch:{ all -> 0x002f }
        r7 = r5 - r7;
        r9 = 3600000; // 0x36ee80 float:5.044674E-39 double:1.7786363E-317;
        r1 = (r7 > r9 ? 1 : (r7 == r9 ? 0 : -1));
        if (r1 <= 0) goto L_0x002a;
    L_0x0024:
        r11.mStatisticStartTime = r5;	 Catch:{ all -> 0x002f }
        r11.mStatisticCount = r3;	 Catch:{ all -> 0x002f }
        monitor-exit(r0);	 Catch:{ all -> 0x002f }
        return r2;
    L_0x002a:
        monitor-exit(r0);	 Catch:{ all -> 0x002f }
        r0 = 0;
        return r0;
    L_0x002d:
        monitor-exit(r0);	 Catch:{ all -> 0x002f }
        return r2;
    L_0x002f:
        r1 = move-exception;
        monitor-exit(r0);	 Catch:{ all -> 0x002f }
        throw r1;
        */
        throw new UnsupportedOperationException("Method not decompiled: huawei.com.android.server.policy.HwFalseTouchMonitor.checkStatistic():boolean");
    }

    private void updateStatistic() {
        synchronized (this.mStatisticLock) {
            if (this.mStatisticCount == 0) {
                this.mStatisticStartTime = java.lang.System.currentTimeMillis();
            }
            this.mStatisticCount++;
        }
    }
}
