package huawei.com.android.server.policy.fingersense;

public class CustomGestureDetector {
    private static final boolean DEBUG_LETTER = false;
    private static final boolean DEBUG_LINE = false;
    private static final boolean DEBUG_REGION = false;
    private static final float DEFAULT_LINE_GESTURE_STROKE_LANDSCAPE_ANGLE = 0.0f;
    private static final float DEFAULT_LINE_GESTURE_STROKE_PORTRAIT_ANGLE = 0.0f;
    private static final float DEFAULT_LINE_GESTURE_STROKE_STRAIGTHNESS = 4.0f;
    private static final float DEFAULT_MAX_LINE_GESTURE_STROKE_ANGLE_DEVIATION = 90.0f;
    private static final float DEFAULT_MIN_GESTURE_STROKE_LENGTH = 200.0f;
    private static final float DEFAULT_MIN_LETTER_GESTURE_STROKE_SQUARENESS = 0.15f;
    private static final float DEFAULT_MIN_LINE_GESTURE_STROKE_LENGTH = 500.0f;
    private static final float DEFAULT_MIN_PREDICTION_SCORE = 2.0f;
    private static final float DEFAULT_NON_ENCLOSED_REGION_DIAGONAL_THRESHOLD = 0.6f;
    private static final float DEFAULT_REGION_DIAGONAL_THRESHOLD = 0.25f;
    private static final float MAX_LINE_GESTURE_STROKE_SQUARENESS = 0.1f;
    private static final java.lang.String TAG = "CustomGestureDetector";
    public static final float TOUCH_TOLERANCE = 3.0f;
    private boolean asyncNotifications;
    huawei.com.android.server.policy.fingersense.KnuckGestureSetting knuckGestureSetting;
    private android.content.Context mContext;
    private android.gesture.Gesture mCurrentGesture;
    private float mCurrentX;
    private float mCurrentY;
    private android.gesture.GestureLibrary mGestureLibraryMultipleOrientations;
    private android.gesture.GestureLibrary mGestureLibrarySingleOrientation;
    private final huawei.com.android.server.policy.fingersense.CustomGestureDetector.GesturePerformedRunnable mGesturePerformed;
    private final android.os.Handler mHandler;
    private boolean mIsGesturing;
    private boolean mIsListeningForGestures;
    private boolean mIsStylus;
    private boolean mLetterGestureStarted;
    private float mLineGestureStrokeLandscapeAngle;
    private float mLineGestureStrokePortraitAngle;
    private float mLineGestureStrokeStraightness;
    private float mMaxLineGestureStrokeAngleDeviation;
    private float mMinGestureStrokeLength;
    private float mMinLetterGestureStrokeSquareness;
    private float mMinLineGestureStrokeLength;
    private float mMinPredictionScore;
    private float mNonEnclosedRegionDiagonalThreshold;
    private final huawei.com.android.server.policy.fingersense.CustomGestureDetector.OnGesturePerformedListener mOnGesturePerformedListener;
    private huawei.com.android.server.policy.fingersense.CustomGestureDetector.OrientationFix[] mOrientationFixes;
    private float mRegionDiagonalThreshold;
    private final java.util.ArrayList<android.gesture.GesturePoint> mStrokeBuffer;
    private float mTotalLength;

    private class GesturePerformedRunnable implements java.lang.Runnable {
        boolean letterGestureStarted;

        private GesturePerformedRunnable() {
            this.letterGestureStarted = false;
        }

        public void run() {
            huawei.com.android.server.policy.fingersense.CustomGestureDetector.this.fireOnGesturePerformed(this);
            huawei.com.android.server.policy.fingersense.CustomGestureDetector.this.mCurrentGesture = null;
        }
    }

    public interface OnGesturePerformedListener {
        void onLetterGesture(java.lang.String str, android.gesture.Gesture gesture, double d);

        void onLineGesture(java.lang.String str, android.gesture.Gesture gesture, double d);

        void onRegionGesture(java.lang.String str, android.gesture.Gesture gesture, double d);
    }

    public static class OrientationFix {
        public java.lang.String multipleOrientationsGestureName;
        public java.lang.String replaceGestureWith;
        public java.lang.String singleOrientationGestureName;

        public OrientationFix(java.lang.String gestureName, java.lang.String singleOrientationGestureName, java.lang.String replaceGestureWith) {
            this.multipleOrientationsGestureName = gestureName;
            this.singleOrientationGestureName = singleOrientationGestureName;
            this.replaceGestureWith = replaceGestureWith;
        }
    }

    public CustomGestureDetector(android.content.Context context, android.gesture.GestureLibrary multipleOrientationLib, android.gesture.GestureLibrary singleOrientationLib, huawei.com.android.server.policy.fingersense.CustomGestureDetector.OnGesturePerformedListener listener) {
        this.mMinPredictionScore = 2.0f;
        this.mMinGestureStrokeLength = 200.0f;
        this.mMinLetterGestureStrokeSquareness = 0.15f;
        this.mRegionDiagonalThreshold = 0.25f;
        this.mNonEnclosedRegionDiagonalThreshold = 0.6f;
        this.mLineGestureStrokeStraightness = 4.0f;
        this.mMaxLineGestureStrokeAngleDeviation = 90.0f;
        this.mMinLineGestureStrokeLength = 500.0f;
        this.mLineGestureStrokePortraitAngle = 0.0f;
        this.mLineGestureStrokeLandscapeAngle = 0.0f;
        this.mIsGesturing = false;
        this.mLetterGestureStarted = false;
        this.mStrokeBuffer = new java.util.ArrayList(100);
        this.mGesturePerformed = new huawei.com.android.server.policy.fingersense.CustomGestureDetector.GesturePerformedRunnable();
        this.mOrientationFixes = null;
        this.asyncNotifications = true;
        this.knuckGestureSetting = huawei.com.android.server.policy.fingersense.KnuckGestureSetting.getInstance();
        this.mContext = context;
        this.mOnGesturePerformedListener = listener;
        this.mHandler = new android.os.Handler();
        if (multipleOrientationLib == null || singleOrientationLib == null) {
            throw new java.lang.IllegalArgumentException("The multipleOrientationLib and singleOrientationLib libraries must not be null");
        }
        this.mGestureLibraryMultipleOrientations = multipleOrientationLib;
        this.mGestureLibraryMultipleOrientations.setOrientationStyle(2);
        this.mGestureLibraryMultipleOrientations.setSequenceType(2);
        this.mGestureLibraryMultipleOrientations.load();
        this.mGestureLibrarySingleOrientation = singleOrientationLib;
        this.mGestureLibrarySingleOrientation.setOrientationStyle(1);
        this.mGestureLibrarySingleOrientation.setSequenceType(1);
        this.mGestureLibrarySingleOrientation.load();
    }

    public CustomGestureDetector(android.content.Context context, int gestureLibraryResourceID, huawei.com.android.server.policy.fingersense.CustomGestureDetector.OnGesturePerformedListener listener) {
        this(context, android.gesture.GestureLibraries.fromRawResource(context, gestureLibraryResourceID), android.gesture.GestureLibraries.fromRawResource(context, gestureLibraryResourceID), listener);
    }

    public CustomGestureDetector(android.content.Context context, java.lang.String gestureLibraryFilePath, huawei.com.android.server.policy.fingersense.CustomGestureDetector.OnGesturePerformedListener listener) {
        this(context, android.gesture.GestureLibraries.fromFile(gestureLibraryFilePath), android.gesture.GestureLibraries.fromFile(gestureLibraryFilePath), listener);
    }

    public void setMinLineGestureStrokeLength(int length) {
        this.mMinLineGestureStrokeLength = (float) length;
    }

    public void setMinGestureStrokeLength(float length) {
        this.mMinGestureStrokeLength = length;
    }

    public void setMinLetterGestureStrokeSquareness(float squareness) {
        this.mMinLetterGestureStrokeSquareness = squareness;
    }

    public void setLineGestureStrokeStraightness(float straightness) {
        if (straightness < 0.0f || straightness > 9.0f) {
            throw new java.lang.IllegalArgumentException("straightness must be between 1 and 10");
        }
        this.mLineGestureStrokeStraightness = straightness;
    }

    public void setMaxLineGestureStrokeAngleDeviation(float angleDeviation) {
        if (angleDeviation < 0.0f || angleDeviation > 90.0f) {
            throw new java.lang.IllegalArgumentException("angleDeviation must be between 0 and 90");
        }
        this.mMaxLineGestureStrokeAngleDeviation = angleDeviation;
    }

    public void setLineGestureStrokePortraitAngle(float angle) {
        if (angle < 0.0f || angle > 90.0f) {
            throw new java.lang.IllegalArgumentException("angle must be between 0 and 90");
        }
        this.mLineGestureStrokePortraitAngle = angle;
    }

    public void setLineGestureStrokeLandscapeAngle(float angle) {
        if (angle < 0.0f || angle > 90.0f) {
            throw new java.lang.IllegalArgumentException("angle must be between 0 and 90");
        }
        this.mLineGestureStrokeLandscapeAngle = angle;
    }

    public void setRegionDiagonalThreshold(float threshold) {
        this.mRegionDiagonalThreshold = threshold;
    }

    public void setNonEnclosedRegionDiagonalThreshold(float threshold) {
        this.mNonEnclosedRegionDiagonalThreshold = threshold;
    }

    public void setMinPredictionScore(float minScore) {
        this.mMinPredictionScore = minScore;
    }

    public void setOrientationFixes(huawei.com.android.server.policy.fingersense.CustomGestureDetector.OrientationFix[] orientationFixes) {
        this.mOrientationFixes = orientationFixes;
    }

    public void setAsyncNotifications(boolean async) {
        this.asyncNotifications = async;
    }

    public void clear() {
        clear(false);
    }

    private void clear(boolean fireActionPerformed) {
        if (fireActionPerformed) {
            this.mGesturePerformed.letterGestureStarted = this.mLetterGestureStarted;
            if (this.asyncNotifications) {
                this.mHandler.post(this.mGesturePerformed);
                return;
            } else {
                fireOnGesturePerformed(this.mGesturePerformed);
                return;
            }
        }
        android.util.Log.w("CustomGestureDetector", "Knuckle Gesture performed but not recognized as Region, Letter, or Line Gesture.");
        this.mCurrentGesture = null;
    }

    public void cancelGesture() {
        this.mIsListeningForGestures = false;
        this.mCurrentGesture.addStroke(new android.gesture.GestureStroke(this.mStrokeBuffer));
        clear();
        this.mIsGesturing = false;
        this.mLetterGestureStarted = false;
        this.mStrokeBuffer.clear();
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        boolean z = false;
        switch (event.getAction()) {
            case 0:
                if (event.getToolType(0) == 2) {
                    z = true;
                }
                this.mIsStylus = z;
                touchDown(event);
                return true;
            case 1:
                if (this.mIsListeningForGestures) {
                    touchUp(event, false);
                    return true;
                }
                break;
            case 2:
                if (this.mIsListeningForGestures) {
                    touchMove(event);
                    return true;
                }
                break;
            case 3:
                if (this.mIsListeningForGestures) {
                    touchUp(event, true);
                    return true;
                }
                break;
            default:
                break;
        }
        return false;
    }

    private void touchDown(android.view.MotionEvent event) {
        this.mIsListeningForGestures = true;
        float x = event.getX();
        float y = event.getY();
        this.mCurrentX = x;
        this.mCurrentY = y;
        this.mTotalLength = 0.0f;
        this.mIsGesturing = false;
        this.mLetterGestureStarted = false;
        this.mCurrentGesture = new android.gesture.Gesture();
        this.mStrokeBuffer.add(new android.gesture.GesturePoint(x, y, event.getEventTime()));
    }

    private void touchMove(android.view.MotionEvent event) {
        float x = event.getX();
        float y = event.getY();
        float previousX = this.mCurrentX;
        float previousY = this.mCurrentY;
        float dx = java.lang.Math.abs(x - previousX);
        float dy = java.lang.Math.abs(y - previousY);
        if (dx >= 3.0f || dy >= 3.0f) {
            this.mCurrentX = x;
            this.mCurrentY = y;
            this.mStrokeBuffer.add(new android.gesture.GesturePoint(x, y, event.getEventTime()));
            if (!this.mIsGesturing) {
                this.mTotalLength += (float) java.lang.Math.sqrt((double) ((dx * dx) + (dy * dy)));
                if (this.mTotalLength > this.mMinGestureStrokeLength) {
                    this.mIsGesturing = true;
                }
            }
            if (this.mIsGesturing && !this.mLetterGestureStarted && android.gesture.GestureUtils.computeOrientedBoundingBox(this.mStrokeBuffer).squareness > this.mMinLetterGestureStrokeSquareness) {
                this.mLetterGestureStarted = true;
            }
        }
    }

    private void touchUp(android.view.MotionEvent event, boolean cancel) {
        this.mIsListeningForGestures = false;
        if (this.mCurrentGesture != null) {
            this.mCurrentGesture.addStroke(new android.gesture.GestureStroke(this.mStrokeBuffer));
            if (cancel) {
                cancelGesture(event);
            } else {
                clear(this.mIsGesturing);
            }
        } else {
            cancelGesture(event);
        }
        this.mStrokeBuffer.clear();
        this.mIsGesturing = false;
        this.mLetterGestureStarted = false;
    }

    private void cancelGesture(android.view.MotionEvent event) {
        clear(false);
    }

    private float calculateDistanceBetweenFirstAndLastPoint() {
        float[] points = ((android.gesture.GestureStroke) this.mCurrentGesture.getStrokes().get(0)).points;
        if (points.length < 4) {
            return 0.0f;
        }
        float firstX = points[0];
        float firstY = points[1];
        float lastX = points[points.length - 2];
        float deltaX = firstX - lastX;
        float deltaY = firstY - points[points.length - 1];
        return (float) java.lang.Math.sqrt((double) ((deltaX * deltaX) + (deltaY * deltaY)));
    }

    private boolean notifyIfLineGesture() {
        android.gesture.OrientedBoundingBox box = ((android.gesture.GestureStroke) this.mCurrentGesture.getStrokes().get(0)).computeOrientedBoundingBox();
        if (box.squareness > 0.1f * ((10.0f - this.mLineGestureStrokeStraightness) / 10.0f)) {
            return false;
        }
        if (java.lang.Math.abs((this.mContext.getResources().getConfiguration().orientation == 2 ? this.mLineGestureStrokeLandscapeAngle : this.mLineGestureStrokePortraitAngle) - java.lang.Math.abs(box.orientation)) > this.mMaxLineGestureStrokeAngleDeviation) {
            return false;
        }
        float distance = calculateDistanceBetweenFirstAndLastPoint();
        if (distance >= this.mMinLineGestureStrokeLength) {
            if (distance >= box.width * 0.9f) {
                notifyLineGesture("line", (double) this.mMinPredictionScore);
                return true;
            }
        }
        return false;
    }

    private boolean notifyIfRegionGesture(float boundingBoxDiagonalThreshold) {
        float distance = calculateDistanceBetweenFirstAndLastPoint();
        android.graphics.RectF boundingBox = this.mCurrentGesture.getBoundingBox();
        float height = boundingBox.height();
        float width = boundingBox.width();
        if (distance >= ((float) java.lang.Math.sqrt((double) ((height * height) + (width * width)))) * boundingBoxDiagonalThreshold) {
            return false;
        }
        notifyRegionGesture("region", (double) this.mMinPredictionScore);
        return true;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    private boolean notifyIfLetterGesture() {
        try {
            java.util.ArrayList<android.gesture.Prediction> predMultipleOrient = this.mGestureLibraryMultipleOrientations.recognize(this.mCurrentGesture);
            java.util.ArrayList<android.gesture.Prediction> predSingleOrient = this.mGestureLibrarySingleOrientation.recognize(this.mCurrentGesture);
            if (predMultipleOrient != null) {
                if (predSingleOrient != null) {
                    if (predMultipleOrient.isEmpty()) {
                        return false;
                    }
                    android.gesture.Prediction bestPredMultOrient = (android.gesture.Prediction) predMultipleOrient.get(0);
                    if (!bestPredMultOrient.name.equals("reject")) {
                        if (bestPredMultOrient.score >= ((double) this.mMinPredictionScore)) {
                            if (predSingleOrient.isEmpty()) {
                                notifyLetterGesture(bestPredMultOrient.name, bestPredMultOrient.score);
                                return true;
                            }
                            android.gesture.Prediction bestPredSingleOrient = (android.gesture.Prediction) predSingleOrient.get(0);
                            if (bestPredSingleOrient.name.equals("reject")) {
                                return false;
                            }
                            if (bestPredMultOrient.name.equals(bestPredSingleOrient.name)) {
                                notifyLetterGesture(bestPredMultOrient.name, bestPredMultOrient.score);
                                return true;
                            }
                            if (this.mOrientationFixes != null) {
                                huawei.com.android.server.policy.fingersense.CustomGestureDetector.OrientationFix[] orientationFixArr = this.mOrientationFixes;
                                int length = orientationFixArr.length;
                                int i = 0;
                                while (i < length) {
                                    huawei.com.android.server.policy.fingersense.CustomGestureDetector.OrientationFix fix = orientationFixArr[i];
                                    if (!bestPredMultOrient.name.equals(fix.multipleOrientationsGestureName) || !bestPredSingleOrient.name.equals(fix.singleOrientationGestureName)) {
                                        i++;
                                    } else if (fix.replaceGestureWith == null) {
                                        return false;
                                    } else {
                                        notifyLetterGesture(fix.replaceGestureWith, bestPredMultOrient.score);
                                        return true;
                                    }
                                }
                            }
                            if (predSingleOrient.size() > 1) {
                                if (bestPredMultOrient.name.equals(((android.gesture.Prediction) predSingleOrient.get(1)).name)) {
                                    notifyLetterGesture(bestPredMultOrient.name, bestPredMultOrient.score);
                                    return true;
                                }
                            }
                            return false;
                        }
                    }
                    return false;
                }
            }
            android.util.Log.e("CustomGestureDetector", "The gesture library returned a null list of predictions. Ignoring gesture.");
            return false;
        } catch (java.lang.Exception excep) {
            android.util.Log.e("CustomGestureDetector", "There was an error recognizing the gesture. Ignoring gesture.");
            excep.printStackTrace();
            return false;
        }
    }

    private void notifyLetterGesture(java.lang.String gestureName, double predictionScore) {
        if (this.mOnGesturePerformedListener != null) {
            this.mOnGesturePerformedListener.onLetterGesture(gestureName, this.mCurrentGesture, predictionScore);
        }
    }

    private void notifyRegionGesture(java.lang.String gestureName, double predictionScore) {
        if (this.mOnGesturePerformedListener != null) {
            this.mOnGesturePerformedListener.onRegionGesture(gestureName, this.mCurrentGesture, predictionScore);
        }
    }

    private void notifyLineGesture(java.lang.String gestureName, double predictionScore) {
        if (this.mOnGesturePerformedListener != null) {
            this.mOnGesturePerformedListener.onLineGesture(gestureName, this.mCurrentGesture, predictionScore);
        }
    }

    private void fireOnGesturePerformed(huawei.com.android.server.policy.fingersense.CustomGestureDetector.GesturePerformedRunnable gesturePerformed) {
        if (this.mCurrentGesture != null) {
            if (this.mCurrentGesture.getStrokesCount() > 0) {
                if (notifyIfLineGesture()) {
                    android.util.Log.w("CustomGestureDetector", "Recognized Line Gesture.");
                    return;
                } else if (notifyIfRegionGesture(this.mRegionDiagonalThreshold)) {
                    android.util.Log.w("CustomGestureDetector", "Recognized Region Gesture.");
                    return;
                } else if (gesturePerformed.letterGestureStarted && notifyIfLetterGesture()) {
                    android.util.Log.w("CustomGestureDetector", "Recognized Letter Gesture.");
                    return;
                } else if (notifyIfRegionGesture(this.mNonEnclosedRegionDiagonalThreshold)) {
                    android.util.Log.w("CustomGestureDetector", "Recognized Region Gesture.");
                    return;
                } else {
                    android.util.Log.d("CustomGestureDetector", "Fingersense: Not a Region gesture or letter gesture");
                    android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(936006000);
                    if (!(eStream == null || this.mIsStylus)) {
                        eStream.setParam((short) 15, 1);
                        eStream.setParam((short) 23, this.knuckGestureSetting.getTpVendorName());
                        eStream.setParam((short) 24, this.knuckGestureSetting.getAccVendorName());
                        eStream.setParam((short) 25, this.knuckGestureSetting.getLcdInfo());
                        eStream.setParam((short) 26, this.knuckGestureSetting.getOrientation());
                        android.util.IMonitor.sendEvent(eStream);
                        this.knuckGestureSetting.setLastReportFSTime(android.os.SystemClock.uptimeMillis());
                        android.util.IMonitor.closeEventStream(eStream);
                    }
                    if (this.mIsStylus) {
                        android.util.Flog.bdReport(this.mContext, 952, "false");
                    }
                    return;
                }
            }
        }
        android.util.Log.w("CustomGestureDetector", "Ignoring empty gesture.");
    }
}
