package huawei.com.android.server.policy.fingersense;

public class KnockGestureDetector {
    private static final boolean DEBUG = false;
    private static final float DOUBLE_KNOCK_RADIUS_IN = 0.4f;
    private static final float DOUBLE_KNOCK_RADIUS_LONG_IN = 0.6f;
    private static final long DOUBLE_KNOCK_TIMEOUT_MS = 250;
    private static final long DOUBLE_KNOCK_TIMEOUT_SLOW_MS = 400;
    private static final int DOUBLE_KNOCK_TOGGLE_THRESHOLD = 5;
    private static final long KNUCKLE_POINTER_COUNT_TIMEOUT_MS = 250;
    private static final long MS_DELAY_TO_DISABLE_DOUBLE_KNOCK = 250;
    private static final long MS_DELAY_TO_ENABLE_DOUBLE_KNOCK = 550;
    private static final long MS_FILTER_TO_PRINT_DOUBLE_KNOCK_INTERVAL = 1000;
    private static final java.lang.String TAG = "KnockGestureDetector";
    private int consecutiveTouchCount = 1;
    private float doubleKnockDistanceInterval;
    private float doubleKnockDistanceMm;
    private int doubleKnockDistanceTrigger;
    private float doubleKnockRadiusLongPx;
    private float doubleKnockRadiusPx;
    private long doubleKnockTimeDiffMs;
    private long doubleKnockTimeInterval;
    private int doubleKnockTimeTrigger;
    private final huawei.com.android.server.policy.fingersense.KnockGestureDetector.MotionEventRunnable doubleKnuckleDoubleKnockRunnable = new huawei.com.android.server.policy.fingersense.KnockGestureDetector.MotionEventRunnable() {
        public void run() {
            if (huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.consecutiveTouchCount < 3) {
                huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.notifyDoubleKnuckleDoubleKnock("fingersense_knuckle_gesture_double_knock", this.event);
            } else {
                huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.dumpDebugVariables();
            }
        }
    };
    private huawei.com.android.server.policy.fingersense.KnuckGestureSetting knuckGestureSetting = huawei.com.android.server.policy.fingersense.KnuckGestureSetting.getInstance();
    private int knucklePointerCount;
    private int knucklePointerId = -1;
    private float lastKnuckleDist;
    private long lastKnuckleEventTimeDiffMs;
    private long lastKnuckleEventTimeMs;
    private float lastKnuckleMoveDist;
    private float lastKnuckleMoveX;
    private float lastKnuckleMoveY;
    private float lastKnuckleX;
    private float lastKnuckleY;
    private long lastMotionEventTimeDiffMs;
    private long lastMotionEventTimeMs;
    private android.content.Context mContext;
    private final android.os.Handler mHandler;
    private final huawei.com.android.server.policy.fingersense.KnockGestureDetector.OnKnockGestureListener mOnKnockGestureListener;
    private final huawei.com.android.server.policy.fingersense.KnockGestureDetector.MotionEventRunnable singleKnuckleDoubleKnockRunnable = new huawei.com.android.server.policy.fingersense.KnockGestureDetector.MotionEventRunnable() {
        public void run() {
            if (huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.consecutiveTouchCount < 3) {
                huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.notifySingleKnuckleDoubleKnock("fingersense_knuckle_gesture_knock", this.event);
            } else {
                huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.dumpDebugVariables();
            }
        }
    };

    private static abstract class MotionEventRunnable implements java.lang.Runnable {
        android.view.MotionEvent event;

        private MotionEventRunnable() {
            this.event = null;
        }

        /* synthetic */ MotionEventRunnable(huawei.com.android.server.policy.fingersense.KnockGestureDetector.AnonymousClass1 x0) {
            this();
        }
    }

    public interface OnKnockGestureListener {
        void onDoubleKnocksNotYetConfirmed(java.lang.String str, android.view.MotionEvent motionEvent);

        void onDoubleKnuckleDoubleKnock(java.lang.String str, android.view.MotionEvent motionEvent);

        void onSingleKnuckleDoubleKnock(java.lang.String str, android.view.MotionEvent motionEvent);
    }

    public KnockGestureDetector(android.content.Context context, huawei.com.android.server.policy.fingersense.KnockGestureDetector.OnKnockGestureListener listener) {
        this.mOnKnockGestureListener = listener;
        this.mHandler = new android.os.Handler();
        this.mContext = context;
        this.doubleKnockTimeDiffMs = android.provider.Settings.System.getLong(this.mContext.getContentResolver(), "double_knock_timeout", 250);
        android.util.DisplayMetrics metrics = context.getResources().getDisplayMetrics();
        this.doubleKnockRadiusPx = (0.4f * metrics.density) * 160.0f;
        this.doubleKnockRadiusLongPx = (0.6f * metrics.density) * 160.0f;
        this.doubleKnockDistanceMm = android.provider.Settings.System.getFloat(this.mContext.getContentResolver(), "double_knock_distance", this.doubleKnockRadiusPx);
        this.doubleKnockTimeTrigger = 0;
        this.doubleKnockDistanceTrigger = 0;
        com.huawei.itouch.HwITouchJniAdapter.getInstance().registerJniListener();
    }

    public int getKnucklePointerCount() {
        return this.knucklePointerCount;
    }

    public long getDoubleKnockTimeInterval() {
        return this.doubleKnockTimeInterval;
    }

    public float getDoubleKnockDisInterval() {
        return this.doubleKnockDistanceInterval;
    }

    public boolean onKnuckleTouchEvent(android.view.MotionEvent motionEvent) {
        long thisKnuckleEventTimeMs = motionEvent.getEventTime();
        this.lastKnuckleEventTimeDiffMs = thisKnuckleEventTimeMs - this.lastKnuckleEventTimeMs;
        this.lastKnuckleEventTimeMs = thisKnuckleEventTimeMs;
        boolean ret = false;
        switch (motionEvent.getAction()) {
            case 0:
                ret = touchDown(motionEvent);
                break;
            case 1:
                ret = touchUp(motionEvent);
                break;
            case 2:
                ret = touchMove(motionEvent);
                break;
            case 3:
                ret = touchCancel(motionEvent);
                break;
            default:
                break;
        }
        int count = motionEvent.getPointerCount();
        if (count > this.knucklePointerCount) {
            this.knucklePointerCount = count;
        } else if (this.lastKnuckleEventTimeDiffMs < 0 || this.lastKnuckleEventTimeDiffMs > 250) {
            this.knucklePointerCount = count;
        }
        if (motionEvent.getAction() == 0) {
            checkForDoubleKnocks(motionEvent);
        }
        return ret;
    }

    private boolean touchDown(android.view.MotionEvent motionEvent) {
        float thisKnuckleX = motionEvent.getX();
        float thisKnuckleY = motionEvent.getY();
        this.lastKnuckleDist = (float) java.lang.Math.sqrt(java.lang.Math.pow((double) (thisKnuckleX - this.lastKnuckleX), 2.0d) + java.lang.Math.pow((double) (thisKnuckleY - this.lastKnuckleY), 2.0d));
        this.lastKnuckleMoveX = thisKnuckleX;
        this.lastKnuckleX = thisKnuckleX;
        this.lastKnuckleMoveY = thisKnuckleY;
        this.lastKnuckleY = thisKnuckleY;
        if (this.lastKnuckleEventTimeDiffMs < 0 || this.lastKnuckleEventTimeDiffMs > this.doubleKnockTimeDiffMs) {
            this.lastKnuckleMoveDist = 0.0f;
            this.knucklePointerId = motionEvent.getPointerId(0);
        }
        return true;
    }

    private boolean touchMove(android.view.MotionEvent motionEvent) {
        int pointerIndex = motionEvent.findPointerIndex(this.knucklePointerId);
        if (pointerIndex < 0) {
            return true;
        }
        float thisKnuckleX = motionEvent.getX(pointerIndex);
        float thisKnuckleY = motionEvent.getY(pointerIndex);
        this.lastKnuckleMoveDist += (float) java.lang.Math.sqrt(java.lang.Math.pow((double) (thisKnuckleX - this.lastKnuckleMoveX), 2.0d) + java.lang.Math.pow((double) (thisKnuckleY - this.lastKnuckleMoveY), 2.0d));
        this.lastKnuckleMoveX = thisKnuckleX;
        this.lastKnuckleMoveY = thisKnuckleY;
        return true;
    }

    private boolean touchUp(android.view.MotionEvent motionEvent) {
        return true;
    }

    private boolean touchCancel(android.view.MotionEvent motionEvent) {
        return true;
    }

    private void toggleDoubleKnockSpeed() {
        long j = 400;
        if (this.doubleKnockTimeDiffMs == 400) {
            j = 250;
        }
        long newTimeDiffMs = j;
        if (android.provider.Settings.System.putLong(this.mContext.getContentResolver(), "double_knock_timeout", newTimeDiffMs)) {
            this.doubleKnockTimeDiffMs = newTimeDiffMs;
        } else {
            android.util.Log.d("KnockGestureDetector", "Write doubleKnockTimeDiffMs back to Settings failed!!");
        }
    }

    private void checkDoubleKnockSpeedToggle(long doubleKnockTime) {
        long timeInterval = doubleKnockTime;
        if (this.doubleKnockTimeDiffMs == 250) {
            if (timeInterval < 250 || timeInterval > 400) {
                return;
            }
        } else if (this.doubleKnockTimeDiffMs == 400 && timeInterval > 250) {
            return;
        }
        this.doubleKnockTimeTrigger++;
        if (this.doubleKnockTimeTrigger >= 5) {
            toggleDoubleKnockSpeed();
            this.doubleKnockTimeTrigger = 0;
        }
    }

    private void toggleDoubleKnockDistance() {
        float newDistance = this.doubleKnockDistanceMm == this.doubleKnockRadiusLongPx ? this.doubleKnockRadiusPx : this.doubleKnockRadiusLongPx;
        if (android.provider.Settings.System.putFloat(this.mContext.getContentResolver(), "double_knock_distance", newDistance)) {
            this.doubleKnockDistanceMm = newDistance;
        } else {
            android.util.Log.d("KnockGestureDetector", "Write doubleKnockDistance back to Settings failed!!");
        }
    }

    private void checkDoubleKnockDistanceToggle(float doubleKnockDistance) {
        float distanceInterval = doubleKnockDistance;
        if (this.doubleKnockDistanceMm == this.doubleKnockRadiusPx) {
            if (distanceInterval < this.doubleKnockRadiusPx || distanceInterval > this.doubleKnockRadiusLongPx) {
                return;
            }
        } else if (this.doubleKnockDistanceMm == this.doubleKnockRadiusLongPx && distanceInterval > this.doubleKnockRadiusPx) {
            return;
        }
        this.doubleKnockDistanceTrigger++;
        if (this.doubleKnockDistanceTrigger >= 5) {
            toggleDoubleKnockDistance();
            this.doubleKnockDistanceTrigger = 0;
        }
    }

    public boolean onAnyTouchEvent(android.view.MotionEvent motionEvent) {
        android.view.MotionEvent motionEvent2;
        if (motionEvent.getAction() == 0) {
            long thisMotionEventTimeMs = motionEvent.getEventTime();
            long timeDiffToLastKnuckleMs = thisMotionEventTimeMs - this.lastKnuckleEventTimeMs;
            this.lastMotionEventTimeDiffMs = thisMotionEventTimeMs - this.lastMotionEventTimeMs;
            this.lastMotionEventTimeMs = thisMotionEventTimeMs;
            if (this.lastMotionEventTimeDiffMs <= 0 || this.lastMotionEventTimeDiffMs >= 550) {
                motionEvent2 = motionEvent;
                this.consecutiveTouchCount = 1;
            } else {
                int pointCount;
                android.util.IMonitor.EventStream eStream;
                this.consecutiveTouchCount++;
                int i = 1503;
                if (this.consecutiveTouchCount == 2 && timeDiffToLastKnuckleMs < 250) {
                    pointCount = motionEvent.getPointerCount();
                    int i2 = 0;
                    while (true) {
                        int i3 = i2;
                        if (i3 >= pointCount) {
                            break;
                        } else if (motionEvent.getToolType(i3) != 7) {
                            android.util.Flog.i(i, "The second tap is finger, aborting double knuckle detecting!!");
                            if (this.lastMotionEventTimeMs - this.knuckGestureSetting.getLastReportFSTime() > 1000) {
                                eStream = android.util.IMonitor.openEventStream(936006000);
                                if (eStream != null) {
                                    eStream.setParam((short) 13, 1);
                                    eStream.setParam((short) 22, 1);
                                    eStream.setParam((short) 23, this.knuckGestureSetting.getTpVendorName());
                                    eStream.setParam((short) 24, this.knuckGestureSetting.getAccVendorName());
                                    eStream.setParam((short) 25, this.knuckGestureSetting.getLcdInfo());
                                    eStream.setParam((short) 26, this.knuckGestureSetting.getOrientation());
                                    android.util.IMonitor.sendEvent(eStream);
                                    this.knuckGestureSetting.setLastReportFSTime(android.os.SystemClock.uptimeMillis());
                                    android.util.IMonitor.closeEventStream(eStream);
                                }
                            }
                        } else {
                            i2 = i3 + 1;
                            i = 1503;
                        }
                    }
                }
                motionEvent2 = motionEvent;
                pointCount = com.huawei.itouch.HwITouchJniAdapter.getInstance().getAppType();
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("onAnyTouchEvent current appFilter=");
                stringBuilder.append(pointCount);
                android.util.Log.d("KnockGestureDetector", stringBuilder.toString());
                if (pointCount == 1 && this.consecutiveTouchCount > 2) {
                    if (timeDiffToLastKnuckleMs < 550) {
                        java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                        stringBuilder2.append("Multiple rapid taps detecting, aborting Knuckle Gestures:");
                        stringBuilder2.append(this.consecutiveTouchCount);
                        android.util.Flog.i(1503, stringBuilder2.toString());
                        if (this.lastMotionEventTimeMs - this.knuckGestureSetting.getLastReportFSTime() > 1000) {
                            eStream = android.util.IMonitor.openEventStream(936006000);
                            if (eStream != null) {
                                eStream.setParam((short) 13, 1);
                                eStream.setParam((short) 21, 1);
                                eStream.setParam((short) 23, this.knuckGestureSetting.getTpVendorName());
                                eStream.setParam((short) 24, this.knuckGestureSetting.getAccVendorName());
                                eStream.setParam((short) 25, this.knuckGestureSetting.getLcdInfo());
                                eStream.setParam((short) 26, this.knuckGestureSetting.getOrientation());
                                android.util.IMonitor.sendEvent(eStream);
                                this.knuckGestureSetting.setLastReportFSTime(android.os.SystemClock.uptimeMillis());
                                android.util.IMonitor.closeEventStream(eStream);
                            }
                        }
                    }
                    this.mHandler.removeCallbacks(this.singleKnuckleDoubleKnockRunnable);
                }
            }
        } else {
            motionEvent2 = motionEvent;
        }
        return true;
    }

    public boolean checkForDoubleKnocks(android.view.MotionEvent e) {
        this.doubleKnockTimeInterval = this.lastKnuckleEventTimeDiffMs;
        this.doubleKnockDistanceInterval = this.lastKnuckleDist;
        java.lang.StringBuilder stringBuilder;
        if (this.lastKnuckleEventTimeDiffMs < this.doubleKnockTimeDiffMs) {
            if (this.lastKnuckleMoveDist < 2.0f * this.doubleKnockDistanceMm) {
                final android.view.MotionEvent motionEvent = e;
                int appFilter = com.huawei.itouch.HwITouchJniAdapter.getInstance().getAppType();
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("checkForDoubleKnocks current appFilter=");
                stringBuilder2.append(appFilter);
                android.util.Log.d("KnockGestureDetector", stringBuilder2.toString());
                if (appFilter == 1) {
                    this.mHandler.postDelayed(new java.lang.Runnable() {
                        public void run() {
                            huawei.com.android.server.policy.fingersense.KnockGestureDetector.this.checkForDoubleKnocksInternal(motionEvent);
                        }
                    }, 25);
                } else {
                    checkForDoubleKnocksInternal(motionEvent);
                }
            } else {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("lastKnuckleMoveDist too far, not triggering knock: ");
                stringBuilder.append(this.lastKnuckleMoveDist);
                stringBuilder.append(" > ");
                stringBuilder.append(this.doubleKnockRadiusPx);
                android.util.Flog.i(1503, stringBuilder.toString());
            }
        } else if (this.lastKnuckleEventTimeDiffMs < 1000) {
            if ((this.knucklePointerCount == 1 && this.lastKnuckleDist < this.doubleKnockDistanceMm) || (this.knucklePointerCount == 2 && this.lastKnuckleMoveDist < 2.0f * this.doubleKnockDistanceMm)) {
                checkDoubleKnockSpeedToggle(this.doubleKnockTimeInterval);
            }
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("lastKnuckleEventTimeDiffMs too large, not triggering knock: ");
            stringBuilder.append(this.lastKnuckleEventTimeDiffMs);
            stringBuilder.append(" > ");
            stringBuilder.append(this.doubleKnockTimeDiffMs);
            android.util.Flog.i(1503, stringBuilder.toString());
            if (e.getEventTime() - this.knuckGestureSetting.getLastReportFSTime() > 1000) {
                android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(936006000);
                if (eStream != null) {
                    eStream.setParam((short) 19, 1);
                    if (this.knucklePointerCount == 1) {
                        eStream.setParam((short) 16, this.lastKnuckleEventTimeDiffMs);
                        eStream.setParam((short) 13, 1);
                    } else if (this.knucklePointerCount == 2) {
                        eStream.setParam((short) 17, this.lastKnuckleEventTimeDiffMs);
                        eStream.setParam((short) 14, 1);
                    }
                    eStream.setParam((short) 23, this.knuckGestureSetting.getTpVendorName());
                    eStream.setParam((short) 24, this.knuckGestureSetting.getAccVendorName());
                    eStream.setParam((short) 25, this.knuckGestureSetting.getLcdInfo());
                    eStream.setParam((short) 26, this.knuckGestureSetting.getOrientation());
                    android.util.IMonitor.sendEvent(eStream);
                    this.knuckGestureSetting.setLastReportFSTime(android.os.SystemClock.uptimeMillis());
                    android.util.IMonitor.closeEventStream(eStream);
                }
            }
        }
        return false;
    }

    private void checkForDoubleKnocksInternal(android.view.MotionEvent e) {
        if (this.knucklePointerCount == 1) {
            if (this.lastKnuckleDist < this.doubleKnockDistanceMm) {
                onDoubleKnocks(e, "fingersense_knuckle_gesture_knock");
                checkDoubleKnockSpeedToggle(this.doubleKnockTimeInterval);
            } else {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Double knock too far: ");
                stringBuilder.append(this.lastKnuckleDist);
                stringBuilder.append(" > ");
                stringBuilder.append(this.doubleKnockDistanceMm);
                stringBuilder.append(", no screenshot");
                android.util.Flog.i(1503, stringBuilder.toString());
                if (e.getEventTime() - this.knuckGestureSetting.getLastReportFSTime() > 1000) {
                    android.util.IMonitor.EventStream eStream = android.util.IMonitor.openEventStream(936006000);
                    if (eStream != null) {
                        eStream.setParam((short) 13, 1);
                        eStream.setParam((short) 18, this.lastKnuckleDist);
                        eStream.setParam((short) 20, 1);
                        eStream.setParam((short) 23, this.knuckGestureSetting.getTpVendorName());
                        eStream.setParam((short) 24, this.knuckGestureSetting.getAccVendorName());
                        eStream.setParam((short) 25, this.knuckGestureSetting.getLcdInfo());
                        eStream.setParam((short) 26, this.knuckGestureSetting.getOrientation());
                        android.util.IMonitor.sendEvent(eStream);
                        this.knuckGestureSetting.setLastReportFSTime(android.os.SystemClock.uptimeMillis());
                        android.util.IMonitor.closeEventStream(eStream);
                    }
                }
            }
            checkDoubleKnockDistanceToggle(this.doubleKnockDistanceInterval);
            return;
        }
        onDoubleKnocks(e, "fingersense_knuckle_gesture_double_knock");
        checkDoubleKnockSpeedToggle(this.doubleKnockTimeInterval);
    }

    public void onDoubleKnocks(android.view.MotionEvent event, java.lang.String knuckleGesture) {
        notifyOnDoubleKnocksNotYetConfirmed(knuckleGesture, event);
        int appFilter = com.huawei.itouch.HwITouchJniAdapter.getInstance().getAppType();
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onDoubleKnocks current appFilter=");
        stringBuilder.append(appFilter);
        android.util.Log.d("KnockGestureDetector", stringBuilder.toString());
        if (knuckleGesture != null && knuckleGesture.equals("fingersense_knuckle_gesture_knock")) {
            android.util.Flog.i(1503, "Single Knuckle Double Knock captured");
            if (appFilter == 1) {
                this.singleKnuckleDoubleKnockRunnable.event = event;
                this.mHandler.postDelayed(this.singleKnuckleDoubleKnockRunnable, 250);
            } else if (this.consecutiveTouchCount < 3) {
                notifySingleKnuckleDoubleKnock("fingersense_knuckle_gesture_knock", event);
            } else {
                dumpDebugVariables();
            }
        } else if (knuckleGesture == null || !knuckleGesture.equals("fingersense_knuckle_gesture_double_knock")) {
            android.util.Flog.w(1503, "FingerSense Gesture Unrecognized Knock Pattern.");
        } else {
            android.util.Flog.i(1503, "Double Knuckle Double Knock captured");
            if (appFilter == 1) {
                this.doubleKnuckleDoubleKnockRunnable.event = event;
                this.mHandler.postDelayed(this.doubleKnuckleDoubleKnockRunnable, 250);
            } else if (this.consecutiveTouchCount < 3) {
                notifyDoubleKnuckleDoubleKnock("fingersense_knuckle_gesture_double_knock", event);
            } else {
                dumpDebugVariables();
            }
        }
    }

    private void notifyDoubleKnuckleDoubleKnock(java.lang.String gestureName, android.view.MotionEvent event) {
        android.util.Log.w("KnockGestureDetector", "Notifying Double Knuckle Double Knock");
        if (this.mOnKnockGestureListener != null) {
            this.mOnKnockGestureListener.onDoubleKnuckleDoubleKnock(gestureName, event);
        }
    }

    private void notifySingleKnuckleDoubleKnock(java.lang.String gestureName, android.view.MotionEvent event) {
        android.util.Log.w("KnockGestureDetector", "Notifying Single Knuckle Double Knock");
        if (this.mOnKnockGestureListener != null) {
            this.mOnKnockGestureListener.onSingleKnuckleDoubleKnock(gestureName, event);
        }
    }

    private void notifyOnDoubleKnocksNotYetConfirmed(java.lang.String gestureName, android.view.MotionEvent event) {
        if (this.mOnKnockGestureListener != null) {
            this.mOnKnockGestureListener.onDoubleKnocksNotYetConfirmed(gestureName, event);
        }
    }

    private void dumpDebugVariables() {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("lastMotionEventTimeDiffMs: ");
        stringBuilder.append(this.lastMotionEventTimeDiffMs);
        stringBuilder.append(" lastKnuckleEventTimeDiffMs: ");
        stringBuilder.append(this.lastKnuckleEventTimeDiffMs);
        stringBuilder.append(" lastKnuckleDist: ");
        stringBuilder.append(this.lastKnuckleDist);
        stringBuilder.append(" lastKnuckleMoveDist: ");
        stringBuilder.append(this.lastKnuckleMoveDist);
        stringBuilder.append(" knucklePointerCount: ");
        stringBuilder.append(this.knucklePointerCount);
        stringBuilder.append(" consecutiveTouchCount: ");
        stringBuilder.append(this.consecutiveTouchCount);
        stringBuilder.append(" doubleKnockTimeDiffMs: ");
        stringBuilder.append(this.doubleKnockTimeDiffMs);
        stringBuilder.append(" doubleKnockDistanceMm: ");
        stringBuilder.append(this.doubleKnockDistanceMm);
        android.util.Flog.i(1503, stringBuilder.toString());
    }
}
