package huawei.com.android.server.policy.fingersense.pixiedust;

public class PointerLocationView extends android.view.View {
    private static final java.lang.String TAG = "PointerLocationView";
    int controlPointCounter;
    android.graphics.PointF[] controlPoints;
    huawei.com.android.server.policy.fingersense.pixiedust.GlowParticleSystem glowParticleSystem;
    long lastUpdateMs;
    private boolean mIsDrawing = false;
    huawei.com.android.server.policy.stylus.StylusGestureListener mStylusGestureListener;
    huawei.com.android.server.policy.fingersense.SystemWideActionsListener mSysWideActionsListener;
    android.graphics.Paint pathPaint = new android.graphics.Paint();
    huawei.com.android.server.policy.fingersense.pixiedust.PixieDustParticleSystem pixieParticleSystem;
    android.graphics.Path pointerPath;
    android.graphics.Bitmap sprite;

    public PointerLocationView(android.content.Context context, huawei.com.android.server.policy.fingersense.SystemWideActionsListener sysWideActionsListener) {
        super(context);
        int i = 0;
        this.pathPaint.setStyle(android.graphics.Paint.Style.STROKE);
        this.pathPaint.setStrokeJoin(android.graphics.Paint.Join.ROUND);
        this.pathPaint.setStrokeCap(android.graphics.Paint.Cap.ROUND);
        this.pathPaint.setStrokeWidth(10.0f);
        this.pathPaint.setAntiAlias(true);
        this.pathPaint.setPathEffect(new android.graphics.CornerPathEffect(10.0f));
        this.pointerPath = new android.graphics.Path();
        this.controlPoints = new android.graphics.PointF[5];
        this.controlPointCounter = 0;
        this.mSysWideActionsListener = sysWideActionsListener;
        this.sprite = android.graphics.BitmapFactory.decodeResource(getResources(), 33751446);
        this.pixieParticleSystem = new huawei.com.android.server.policy.fingersense.pixiedust.PixieDustParticleSystem(2000, this.sprite, 10);
        this.glowParticleSystem = new huawei.com.android.server.policy.fingersense.pixiedust.GlowParticleSystem(2000, this.sprite, 100);
        updateColors();
        while (i < this.controlPoints.length) {
            this.controlPoints[i] = new android.graphics.PointF();
            i++;
        }
    }

    public PointerLocationView(android.content.Context context, huawei.com.android.server.policy.stylus.StylusGestureListener stylusGestureListener) {
        super(context);
        int i = 0;
        this.pathPaint.setStyle(android.graphics.Paint.Style.STROKE);
        this.pathPaint.setStrokeJoin(android.graphics.Paint.Join.ROUND);
        this.pathPaint.setStrokeCap(android.graphics.Paint.Cap.ROUND);
        this.pathPaint.setStrokeWidth(10.0f);
        this.pathPaint.setAntiAlias(true);
        this.pathPaint.setPathEffect(new android.graphics.CornerPathEffect(10.0f));
        this.pointerPath = new android.graphics.Path();
        this.controlPoints = new android.graphics.PointF[5];
        this.controlPointCounter = 0;
        this.mStylusGestureListener = stylusGestureListener;
        this.sprite = android.graphics.BitmapFactory.decodeResource(getResources(), 33751446);
        this.pixieParticleSystem = new huawei.com.android.server.policy.fingersense.pixiedust.PixieDustParticleSystem(2000, this.sprite, 10);
        this.glowParticleSystem = new huawei.com.android.server.policy.fingersense.pixiedust.GlowParticleSystem(2000, this.sprite, 100);
        updateColors();
        while (i < this.controlPoints.length) {
            this.controlPoints[i] = new android.graphics.PointF();
            i++;
        }
    }

    protected void onDraw(android.graphics.Canvas canvas) {
        super.onDraw(canvas);
        canvas.drawPath(this.pointerPath, this.pathPaint);
        this.pixieParticleSystem.update();
        this.glowParticleSystem.update();
        if (!this.pointerPath.isEmpty()) {
            if (java.lang.System.currentTimeMillis() - this.lastUpdateMs > 500) {
                if (this.mSysWideActionsListener != null) {
                    this.mSysWideActionsListener.cancelSystemWideAction();
                }
                if (this.mStylusGestureListener != null) {
                    this.mStylusGestureListener.cancelStylusGesture();
                }
            }
            this.pixieParticleSystem.draw(canvas);
            this.glowParticleSystem.draw(canvas);
            if (!this.mIsDrawing) {
                android.util.Log.d("PointerLocationView", "Fingersense draw line");
                com.huawei.android.statistical.StatisticalUtils.reportc(getContext(), 102);
                this.mIsDrawing = true;
            }
            invalidate();
        }
    }

    private void updateColors() {
        this.pathPaint.setColor(android.provider.Settings.System.getInt(getContext().getContentResolver(), "fingersense_stroke_color", huawei.android.provider.HwSettings.System.FINGERSENSE_DEFAULT_STROKE_COLOR));
        int pixieColor = android.provider.Settings.System.getInt(getContext().getContentResolver(), "fingersense_pixie_color", huawei.android.provider.HwSettings.System.FINGERSENSE_DEFAULT_PIXIE_COLOR);
        this.pixieParticleSystem.setColor(pixieColor);
        this.glowParticleSystem.setColor(pixieColor);
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        if (event.getPointerCount() > 1) {
            this.pointerPath.reset();
            this.pixieParticleSystem.kill();
            return false;
        }
        switch (event.getAction()) {
            case 0:
                updateColors();
                this.lastUpdateMs = java.lang.System.currentTimeMillis();
                this.controlPointCounter = 0;
                this.controlPoints[this.controlPointCounter].set(event.getX(), event.getY());
                this.pixieParticleSystem.setEmitter((double) event.getX(), (double) event.getY());
                this.mIsDrawing = false;
                break;
            case 1:
            case 3:
                if (this.pointerPath.isEmpty()) {
                    this.pixieParticleSystem.setEmitter((double) event.getX(), (double) event.getY());
                }
                this.pointerPath.reset();
                this.pixieParticleSystem.kill();
                this.mIsDrawing = false;
                break;
            case 2:
                android.graphics.PointF[] pointFArr = this.controlPoints;
                int i = this.controlPointCounter + 1;
                this.controlPointCounter = i;
                pointFArr[i].set(event.getX(), event.getY());
                if (this.controlPointCounter == 4) {
                    this.controlPoints[3].set((this.controlPoints[2].x + this.controlPoints[4].x) / 2.0f, (this.controlPoints[2].y + this.controlPoints[4].y) / 2.0f);
                    this.pointerPath.moveTo(this.controlPoints[0].x, this.controlPoints[0].y);
                    this.pointerPath.cubicTo(this.controlPoints[1].x, this.controlPoints[1].y, this.controlPoints[2].x, this.controlPoints[2].y, this.controlPoints[3].x, this.controlPoints[3].y);
                    this.controlPoints[0].set(this.controlPoints[3]);
                    this.controlPoints[1].set(this.controlPoints[4]);
                    this.controlPointCounter = 1;
                    long now = java.lang.System.currentTimeMillis();
                    this.glowParticleSystem.addParticles(this.pointerPath, now - this.lastUpdateMs);
                    this.lastUpdateMs = now;
                }
                this.pixieParticleSystem.setEmitter((double) event.getX(), (double) event.getY());
                break;
            default:
                break;
        }
        postInvalidate();
        return true;
    }
}
