package huawei.com.android.server.policy.stylus;

public class StylusGestureDetector implements android.view.GestureDetector.OnGestureListener, android.view.GestureDetector.OnDoubleTapListener {
    private static final int DOUBLE_KNOCK_RADIUS = 10;
    private static final int DOUBLE_KNOCK_TIMEOUT_MS = 400;
    public static final boolean IS_TABLET = "tablet".equals(android.os.SystemProperties.get("ro.build.characteristics", "default"));
    private static final int MIN_DELAY_FOR_SCREENSHOT = 1000;
    private static final java.lang.String TAG = "StylusGestureDetector";
    private static final java.lang.String WRITE_IME_ENABLE = "support_write_ime";
    private boolean isFirstSwtich = false;
    private android.content.Context mContext;
    private final android.view.GestureDetector mGestureDetector;
    private boolean mHideMenuView = false;
    private long mLastDownTime;
    private long mLastScreenshotTime = -1;
    private float mLastX;
    private float mLastY;
    private final huawei.com.android.server.policy.stylus.StylusGestureDetector.StylusGestureRecognizeListener mStylusGestureListener;
    private int mToolType = -1;

    public interface StylusGestureRecognizeListener {
        void notifySwtichInputMethod(boolean z);

        void onStylusDoubleTapPerformed();

        void onStylusSingleTapPerformed(android.view.MotionEvent motionEvent, boolean z);
    }

    public StylusGestureDetector(android.content.Context context, huawei.com.android.server.policy.stylus.StylusGestureListener listener) {
        this.mContext = context;
        this.mStylusGestureListener = listener;
        this.mGestureDetector = new android.view.GestureDetector(this.mContext, this);
        this.mGestureDetector.setIsLongpressEnabled(true);
        this.mGestureDetector.setOnDoubleTapListener(this);
    }

    public boolean onTouchEvent(android.view.MotionEvent event) {
        if (event.getAction() == 1 || event.getAction() == 3) {
            android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onTouchEvent.ACTION_UP");
            if (this.mHideMenuView) {
                this.mStylusGestureListener.onStylusSingleTapPerformed(event, false);
                this.mHideMenuView = false;
            }
        }
        this.mGestureDetector.onTouchEvent(event);
        return false;
    }

    public void shouldSwtichInputMethod(android.view.MotionEvent motionEvent) {
        if (!(motionEvent.getAction() != 0 || motionEvent.isButtonPressed(32) || motionEvent.isButtonPressed(64))) {
            boolean z = false;
            int currentToolType = motionEvent.getToolType(0);
            boolean isStylus = currentToolType == 2;
            if (IS_TABLET) {
                if (isStylus && isHardwareKeyboardConnected()) {
                    android.provider.Settings.Secure.putInt(this.mContext.getContentResolver(), "support_write_ime", 1);
                    android.util.Log.i("StylusGestureDetector", "shouldSwtichInputMethod-showWriteIme");
                } else if (!isStylus && isHardwareKeyboardConnected()) {
                    android.provider.Settings.Secure.putInt(this.mContext.getContentResolver(), "support_write_ime", 0);
                }
                if (!this.isFirstSwtich) {
                    this.isFirstSwtich = true;
                    this.mToolType = currentToolType;
                    this.mStylusGestureListener.notifySwtichInputMethod(isStylus);
                } else if (this.mToolType != currentToolType) {
                    this.mToolType = currentToolType;
                    this.mStylusGestureListener.notifySwtichInputMethod(isStylus);
                }
            } else {
                if (!isStylus) {
                    z = true;
                }
                com.huawei.android.inputmethod.HwInputMethodManager.setInputSource(z);
            }
        }
    }

    public void setToolType() {
        this.mToolType = -1;
    }

    private boolean isHardwareKeyboardConnected() {
        android.util.Log.i("StylusGestureDetector", "isHardwareKeyboardConnected--begin");
        int[] devices = android.view.InputDevice.getDeviceIds();
        boolean isConnected = false;
        for (android.view.InputDevice device : devices) {
            android.view.InputDevice device2 = android.view.InputDevice.getDevice(device2);
            if (device2 != null) {
                if (device2.getProductId() != 4817 || device2.getVendorId() != 1455) {
                    if (device2.isExternal() && (device2.getSources() & 257) != 0) {
                        isConnected = true;
                        break;
                    }
                }
                isConnected = true;
                break;
            }
        }
        android.util.Log.i("StylusGestureDetector", "isHardwareKeyboardConnected--end");
        return isConnected;
    }

    private void preloadFloatMenuService(android.view.MotionEvent e) {
        java.lang.StringBuilder stringBuilder;
        if (e.getToolType(0) == 2) {
            if (e.getButtonState() == 32) {
                android.content.Intent intent = new android.content.Intent();
                intent.setComponent(new android.content.ComponentName("com.huawei.stylus.floatmenu", "com.huawei.stylus.floatmenu.FloatMenuService"));
                int positionY = (int) e.getRawY();
                intent.putExtra("positionX", (int) e.getRawX());
                intent.putExtra("positionY", positionY);
                intent.putExtra("prepareStatus", 0);
                try {
                    this.mContext.startServiceAsUser(intent, android.os.UserHandle.CURRENT_OR_SELF);
                } catch (java.util.ServiceConfigurationError sce) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("can not start service: ");
                    stringBuilder.append(sce);
                    android.util.Log.w("StylusGestureDetector", stringBuilder.toString());
                } catch (java.lang.Exception ex) {
                    stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("can not start service: ");
                    stringBuilder.append(ex);
                    android.util.Log.w("StylusGestureDetector", stringBuilder.toString());
                }
            }
        }
    }

    public boolean onSingleTapUp(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onSingleTapUp");
        if (IS_TABLET) {
            preloadFloatMenuService(e);
        }
        return false;
    }

    public boolean onSingleTapConfirmed(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onSingleTapConfirmed");
        if (e.getToolType(0) == 2 && e.getButtonState() == 32) {
            this.mStylusGestureListener.onStylusSingleTapPerformed(e, true);
        }
        return false;
    }

    public boolean onDoubleTap(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onDoubleTap");
        boolean isCoverOpen = android.common.HwFrameworkFactory.getCoverManager().isCoverOpen();
        if (isCoverOpen) {
            this.mStylusGestureListener.onStylusSingleTapPerformed(e, false);
            if (java.lang.System.currentTimeMillis() - this.mLastScreenshotTime > 1000) {
                if (e.getToolType(0) == 2 && e.getButtonState() == 32) {
                    this.mStylusGestureListener.onStylusDoubleTapPerformed();
                }
                this.mLastScreenshotTime = java.lang.System.currentTimeMillis();
            }
            return false;
        }
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("onDoubleTap, isCoverOpen = ");
        stringBuilder.append(isCoverOpen);
        android.util.Log.i("StylusGestureDetector", stringBuilder.toString());
        return false;
    }

    public boolean onDoubleTapEvent(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onDoubleTapEvent");
        return false;
    }

    public void onShowPress(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onShowPress");
    }

    public boolean onScroll(android.view.MotionEvent e1, android.view.MotionEvent e2, float distanceX, float distanceY) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onScroll");
        this.mHideMenuView = true;
        return false;
    }

    public void onLongPress(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onLongPress");
        this.mHideMenuView = true;
        android.util.Flog.bdReport(this.mContext, 952, "true");
    }

    public boolean onFling(android.view.MotionEvent e1, android.view.MotionEvent e2, float velocityX, float velocityY) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onFling");
        return false;
    }

    public boolean onDown(android.view.MotionEvent e) {
        android.util.Log.d("StylusGestureDetector", "StylusGestureDetector <- onDown");
        double dist = java.lang.Math.sqrt(java.lang.Math.pow((double) (e.getX() - this.mLastX), 2.0d) + java.lang.Math.pow((double) (e.getY() - this.mLastY), 2.0d));
        if (e.getEventTime() - this.mLastDownTime >= 400 || dist >= 10.0d) {
            this.mLastDownTime = e.getEventTime();
            this.mLastX = e.getX();
            this.mLastY = e.getY();
        } else {
            onDoubleTap(e);
            this.mLastDownTime = -1;
        }
        return false;
    }
}
