package huawei.com.android.server.policy.stylus;

public class StylusGestureManager {
    private static final int FLAG_STYLUS = 1;
    private static final java.lang.String KEY_STYLUS_ACTIVATE = "stylus_state_activate";
    private static final java.lang.String KEY_STYLUS_STATE_ENABLE = "stylus_enable";
    private static final java.lang.String KEY_STYLUS_STATE_INTRODUCE = "stylus_state_introduce";
    private static int STYLUS_ACTIVATE_DISABLE = 0;
    private static int STYLUS_ACTIVATE_ENABLE = 1;
    private static final int STYLUS_DISABLE = 0;
    private static final int STYLUS_ENABLE = 1;
    private static int STYLUS_INTRODUCED_NO = 0;
    private static final java.lang.String STYLUS_TP_DISABLE = "0";
    private static final java.lang.String STYLUS_TP_LOWFREQUENCY = "2";
    private static final java.lang.String STYLUS_TP_NORMAL = "1";
    private static final java.lang.String TAG = "StylusGestureManager";
    private static final int TP_HAL_DEATH_COOKIE = 1001;
    private android.content.Context mContext;
    private final java.lang.Object mLock = new java.lang.Object();
    private vendor.huawei.hardware.tp.V1_0.ITouchscreen mProxy = null;
    private final huawei.com.android.server.policy.stylus.StylusGestureManager.ServiceNotification mServiceNotification = new huawei.com.android.server.policy.stylus.StylusGestureManager.ServiceNotification();
    private android.database.ContentObserver mStylusActivateObserver;
    private android.database.ContentObserver mStylusIntroduceObserver;
    private int mStylusIntroduced = 0;
    private android.database.ContentObserver mStylusObserver;
    private int mStylusState = 0;

    final class ServiceNotification extends android.hidl.manager.V1_0.IServiceNotification.Stub {
        ServiceNotification() {
        }

        public void onRegistration(java.lang.String fqName, java.lang.String name, boolean preexisting) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("tp hal service started ");
            stringBuilder.append(fqName);
            stringBuilder.append(" ");
            stringBuilder.append(name);
            android.util.Log.d("StylusGestureManager", stringBuilder.toString());
            huawei.com.android.server.policy.stylus.StylusGestureManager.this.connectToProxy();
        }
    }

    final class DeathRecipient implements android.os.IHwBinder.DeathRecipient {
        DeathRecipient() {
        }

        public void serviceDied(long cookie) {
            if (cookie == 1001) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("tp hal service died cookie: ");
                stringBuilder.append(cookie);
                android.util.Log.d("StylusGestureManager", stringBuilder.toString());
                synchronized (huawei.com.android.server.policy.stylus.StylusGestureManager.this.mLock) {
                    huawei.com.android.server.policy.stylus.StylusGestureManager.this.mProxy = null;
                }
            }
        }
    }

    public StylusGestureManager(android.content.Context context) {
        this.mContext = context;
        getTouchService();
        connectToProxy();
        initStylusStateObserver();
        initUserSwtichObserver();
        initStylusIntroducedObserver();
        initStylusActivateObserver();
    }

    private void initStylusStateObserver() {
        if (this.mContext == null) {
            android.util.Log.w("StylusGestureManager", "mContext is null");
            return;
        }
        this.mStylusObserver = new android.database.ContentObserver(null) {
            public void onChange(boolean selfChange) {
                huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusState = android.provider.Settings.System.getIntForUser(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mContext.getContentResolver(), "stylus_enable", 1, android.app.ActivityManager.getCurrentUser());
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("stylus_enable_state onChange: ");
                stringBuilder.append(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusState);
                android.util.Log.i("StylusGestureManager", stringBuilder.toString());
                int stylusActivated = android.provider.Settings.Global.getInt(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mContext.getContentResolver(), "stylus_state_activate", huawei.com.android.server.policy.stylus.StylusGestureManager.STYLUS_ACTIVATE_DISABLE);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("isStylusActivated: ");
                stringBuilder2.append(stylusActivated);
                android.util.Log.i("StylusGestureManager", stringBuilder2.toString());
                huawei.com.android.server.policy.stylus.StylusGestureManager.this.setStylusWakeupGestureToHal(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusState, stylusActivated);
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("stylus_enable"), false, this.mStylusObserver, -1);
        this.mStylusObserver.onChange(true);
    }

    private void initStylusIntroducedObserver() {
        if (this.mContext == null) {
            android.util.Log.w("StylusGestureManager", "mContext is null");
            return;
        }
        this.mStylusIntroduceObserver = new android.database.ContentObserver(null) {
            public void onChange(boolean selfChange) {
                huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusIntroduced = android.provider.Settings.System.getIntForUser(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mContext.getContentResolver(), "stylus_state_introduce", huawei.com.android.server.policy.stylus.StylusGestureManager.STYLUS_INTRODUCED_NO, android.app.ActivityManager.getCurrentUser());
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("stylus_state_introduce onChange: ");
                stringBuilder.append(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusIntroduced);
                android.util.Log.i("StylusGestureManager", stringBuilder.toString());
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("stylus_state_introduce"), false, this.mStylusIntroduceObserver, -1);
        this.mStylusIntroduceObserver.onChange(true);
    }

    private void initStylusActivateObserver() {
        if (this.mContext == null) {
            android.util.Log.w("StylusGestureManager", "mContext is null");
            return;
        }
        this.mStylusActivateObserver = new android.database.ContentObserver(null) {
            public void onChange(boolean selfChange) {
                int stylusState = android.provider.Settings.System.getIntForUser(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mContext.getContentResolver(), "stylus_enable", 1, android.app.ActivityManager.getCurrentUser());
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("get stylus state : ");
                stringBuilder.append(stylusState);
                android.util.Log.i("StylusGestureManager", stringBuilder.toString());
                int stylusActivated = android.provider.Settings.Global.getInt(huawei.com.android.server.policy.stylus.StylusGestureManager.this.mContext.getContentResolver(), "stylus_state_activate", huawei.com.android.server.policy.stylus.StylusGestureManager.STYLUS_ACTIVATE_DISABLE);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("stylus_state_activate onChange: ");
                stringBuilder2.append(stylusActivated);
                android.util.Log.i("StylusGestureManager", stringBuilder2.toString());
                huawei.com.android.server.policy.stylus.StylusGestureManager.this.setStylusWakeupGestureToHal(stylusState, stylusActivated);
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.Global.getUriFor("stylus_state_activate"), false, this.mStylusActivateObserver);
    }

    private void initUserSwtichObserver() {
        try {
            android.app.ActivityManager.getService().registerUserSwitchObserver(new android.app.SynchronousUserSwitchObserver() {
                public void onUserSwitching(int newUserId) {
                }

                public void onUserSwitchComplete(int newUserId) throws android.os.RemoteException {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("onUserSwitchComplete: ");
                    stringBuilder.append(newUserId);
                    android.util.Log.i("StylusGestureManager", stringBuilder.toString());
                    if (huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusObserver != null) {
                        huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusObserver.onChange(true);
                    }
                    if (huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusIntroduceObserver != null) {
                        huawei.com.android.server.policy.stylus.StylusGestureManager.this.mStylusIntroduceObserver.onChange(true);
                    }
                }
            }, "StylusGestureManager");
        } catch (android.os.RemoteException e) {
            android.util.Log.e("StylusGestureManager", "registerUserSwitchObserver fail", e);
        } catch (java.lang.Exception e2) {
            android.util.Log.w("StylusGestureManager", "registerReceiverAsUser fail ", e2);
        }
    }

    public boolean isStylusEnabled() {
        return this.mStylusState == 1;
    }

    public boolean isStylusActivate() {
        return android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "stylus_state_activate", STYLUS_ACTIVATE_DISABLE) == STYLUS_ACTIVATE_ENABLE;
    }

    public boolean isStylusIntroduced() {
        boolean z = true;
        if (this.mStylusIntroduced != STYLUS_INTRODUCED_NO) {
            return true;
        }
        if (android.provider.Settings.Global.getInt(this.mContext.getContentResolver(), "device_provisioned", 0) != 0) {
            z = false;
        }
        return z;
    }

    private void getTouchService() {
        try {
            if (!android.hidl.manager.V1_0.IServiceManager.getService().registerForNotifications("vendor.huawei.hardware.tp@1.0::ITouchscreen", "", this.mServiceNotification)) {
                android.util.Log.e("StylusGestureManager", "Failed to register service start notification");
            }
        } catch (android.os.RemoteException e) {
            android.util.Log.e("StylusGestureManager", "Failed to register service start notification", e);
        }
    }

    private void connectToProxy() {
        synchronized (this.mLock) {
            if (this.mProxy != null) {
                android.util.Log.i("StylusGestureManager", "mProxy has registered, do not register again");
                return;
            }
            try {
                this.mProxy = vendor.huawei.hardware.tp.V1_0.ITouchscreen.getService();
                if (this.mProxy != null) {
                    android.util.Log.d("StylusGestureManager", "connectToProxy: mProxy get success.");
                    this.mProxy.linkToDeath(new huawei.com.android.server.policy.stylus.StylusGestureManager.DeathRecipient(), 1001);
                } else {
                    android.util.Log.d("StylusGestureManager", "connectToProxy: mProxy get failed.");
                }
            } catch (java.util.NoSuchElementException e) {
                android.util.Log.e("StylusGestureManager", "connectToProxy: tp hal service not found. Did the service fail to start?", e);
            } catch (android.os.RemoteException e2) {
                android.util.Log.e("StylusGestureManager", "connectToProxy: tp hal service not responding", e2);
            }
        }
    }

    private void setStylusWakeupGestureToHal(int status, int stylusActivated) {
        synchronized (this.mLock) {
            if (this.mProxy == null) {
                android.util.Log.d("StylusGestureManager", "mProxy is null, return");
                return;
            }
            java.lang.String tpStatus = "2";
            if (status == 0) {
                tpStatus = "0";
            } else if (stylusActivated == STYLUS_ACTIVATE_DISABLE) {
                tpStatus = "2";
            } else {
                tpStatus = "1";
            }
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("setStylusWakeupGestureToHal: ");
            stringBuilder.append(tpStatus);
            android.util.Log.i("StylusGestureManager", stringBuilder.toString());
            try {
                if (this.mProxy.hwSetFeatureConfig(1, tpStatus) == 0) {
                    android.util.Log.d("StylusGestureManager", "setStylusWakeupGestureToHal success");
                } else {
                    android.util.Log.d("StylusGestureManager", "setStylusWakeupGestureToHal error");
                }
            } catch (android.os.RemoteException e) {
                android.util.Log.e("StylusGestureManager", "Failed to set stylus mode:", e);
            }
        }
    }
}
