package com.android.server;

public class HwSmartDisplayService extends huawei.android.hwsmartdisplay.IHwSmartDisplayService.Stub {
    private static final boolean DEBUG = (1 == android.os.SystemProperties.getInt("ro.debuggable", 0));
    private static final java.lang.String KEY_AUTO_EYES_PROTECTION = "auto_eyes_protection";
    private static final java.lang.String KEY_COLOR_MODE_SWITCH = "color_mode_switch";
    private static final int LEVEL_COLOR_ENHANCEMENT_SUPPORT_HIGH = 2;
    private static final int LEVEL_COLOR_ENHANCEMENT_SUPPORT_LOW = 1;
    private static final int LEVEL_COLOR_ENHANCEMENT_SUPPORT_NONE = 0;
    private static final int MODE_COLOR_ENHANCEMENT = 2;
    private static final int MODE_COMFORT = 1;
    private static final int MSG_SET_COLOR_VALUE = 3;
    private static final int MSG_SET_COMFORT_VALUE = 2;
    private static final int MSG_SHOW_COMFORT_TOAST = 1;
    private static final java.lang.String TAG = "HwSmartDisplayService";
    private static final int VALUE_ANIMATION_MSG_INTERVAL = 40;
    private static final int VALUE_ANIMATION_MSG_TIMES = 10;
    private static final int VALUE_COLOR_ENHANCEMENT_BRIGHT = 1;
    private static final int VALUE_COLOR_ENHANCEMENT_NATURE = 0;
    private static final int VALUE_COLOR_ENHANCEMENT_SRGB = 2;
    private static final int VALUE_COMFORT_DEFAULT = 26;
    private static final int VALUE_SET_COLOR_MODE_DELAYED = 300;
    private static final int VALUE_SHOW_TOAST_DELAYED = 300;
    private static boolean mLoadLibraryFailed;
    private int mAnimationFlag = 0;
    private int mAnimationTimes = 0;
    private int mAutoComfortMode = 0;
    private int mColorEnhancementSupportLevel = 0;
    private android.database.ContentObserver mColorModeObserver = null;
    private android.database.ContentObserver mComfortModeObserver = null;
    private android.content.Context mContext;
    private int mCurrentColorEnhancementValue = 0;
    private int mCurrentComfortValue = 0;
    private com.android.server.HwSmartDisplayService.HDREnginePGPClient mHDREnginePGPClient;
    private com.android.server.HwSmartDisplayService.SmartDisplayHandler mHandler;
    private android.os.HandlerThread mHandlerThread;
    private boolean mIsComfortSupported = true;
    private boolean mIsShowToast = true;
    private int mLastSceneFlag = 0;
    private int mLastSceneMode = 0;
    private java.lang.String mLastSceneValue;
    private int mValueAnimationTarget = 0;
    private int mValueBeforeAnimation = 0;
    private android.view.IWindowManager mWindowManager;

    private final class HDREnginePGPClient implements com.huawei.pgmng.IPGPlugCallbacks {
        private com.huawei.pgmng.PGPlug mPGPlug = new com.huawei.pgmng.PGPlug(this, "HwSmartDisplayService");

        public HDREnginePGPClient() {
            new java.lang.Thread(this.mPGPlug, "HwSmartDisplayService").start();
        }

        public void onDaemonConnected() {
            android.util.Slog.i("HwSmartDisplayService", "HDREnginePGPClient connected success!");
        }

        public boolean onEvent(int actionID, java.lang.String msg) {
            com.android.server.HwSmartDisplayService.this.setDisplayEffectScene(actionID);
            return true;
        }

        public void onConnectedTimeout() {
            android.util.Slog.e("HwSmartDisplayService", "Client connect timeout!");
        }
    }

    private final class IPGPClient implements com.huawei.pgmng.IPGPlugCallbacks {
        private com.huawei.pgmng.PGPlug mPGPlug = new com.huawei.pgmng.PGPlug(this, "HwSmartDisplayService");

        public IPGPClient() {
            new java.lang.Thread(this.mPGPlug, "HwSmartDisplayService").start();
        }

        public void onDaemonConnected() {
            android.util.Slog.i("HwSmartDisplayService", "IPGPClient connected success!");
        }

        /* JADX WARNING: Removed duplicated region for block: B:58:0x016b  */
        /* JADX WARNING: Removed duplicated region for block: B:54:0x014d  */
        public boolean onEvent(int r10, java.lang.String r11) {
            /*
            r9 = this;
            r0 = 0;
            r1 = 0;
            r2 = com.huawei.pgmng.PGAction.checkActionType(r10);
            r3 = 1;
            if (r3 == r2) goto L_0x0026;
        L_0x0009:
            r2 = com.android.server.HwSmartDisplayService.DEBUG;
            if (r2 == 0) goto L_0x0025;
        L_0x000f:
            r2 = "HwSmartDisplayService";
            r4 = new java.lang.StringBuilder;
            r4.<init>();
            r5 = "Filter application event id : ";
            r4.append(r5);
            r4.append(r10);
            r4 = r4.toString();
            android.util.Slog.i(r2, r4);
        L_0x0025:
            return r3;
        L_0x0026:
            r2 = com.huawei.pgmng.PGAction.checkActionFlag(r10);
            r4 = com.android.server.HwSmartDisplayService.DEBUG;
            if (r4 == 0) goto L_0x0056;
        L_0x0030:
            r4 = "HwSmartDisplayService";
            r5 = new java.lang.StringBuilder;
            r5.<init>();
            r6 = "IPGP onEvent actionID=";
            r5.append(r6);
            r5.append(r10);
            r6 = ", value=";
            r5.append(r6);
            r5.append(r11);
            r6 = ",  subFlag=";
            r5.append(r6);
            r5.append(r2);
            r5 = r5.toString();
            android.util.Slog.i(r4, r5);
        L_0x0056:
            r4 = 10017; // 0x2721 float:1.4037E-41 double:4.949E-320;
            r5 = 3;
            if (r2 == r5) goto L_0x0079;
        L_0x005b:
            if (r10 == r4) goto L_0x0079;
        L_0x005d:
            r6 = 10007; // 0x2717 float:1.4023E-41 double:4.944E-320;
            if (r10 == r6) goto L_0x0079;
        L_0x0061:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.mLastSceneFlag = r2;
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.mLastSceneValue = r11;
            r4 = com.android.server.HwSmartDisplayService.DEBUG;
            if (r4 == 0) goto L_0x0078;
        L_0x0071:
            r4 = "HwSmartDisplayService";
            r5 = "Not used non-parent scene , ignore it";
            android.util.Slog.i(r4, r5);
        L_0x0078:
            return r3;
        L_0x0079:
            r6 = com.android.server.HwSmartDisplayService.DEBUG;
            if (r6 == 0) goto L_0x00f2;
        L_0x007f:
            r6 = "default";
            switch(r10) {
                case 10001: goto L_0x00e8;
                case 10002: goto L_0x00de;
                case 10003: goto L_0x00d4;
                case 10004: goto L_0x00ca;
                case 10005: goto L_0x0084;
                case 10006: goto L_0x0084;
                case 10007: goto L_0x00c0;
                case 10008: goto L_0x00b6;
                case 10009: goto L_0x00ac;
                case 10010: goto L_0x00a2;
                case 10011: goto L_0x0098;
                case 10012: goto L_0x0084;
                case 10013: goto L_0x008e;
                default: goto L_0x0084;
            };
        L_0x0084:
            r6 = "default";
            r7 = "HwSmartDisplayService";
            r8 = "default";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x008e:
            r6 = "MMS";
            r7 = "HwSmartDisplayService";
            r8 = "MMS";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x0098:
            r6 = "2DGame";
            r7 = "HwSmartDisplayService";
            r8 = "2DGame";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00a2:
            r6 = "Launcher";
            r7 = "HwSmartDisplayService";
            r8 = "Launcher";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00ac:
            r6 = "Video";
            r7 = "HwSmartDisplayService";
            r8 = "Video";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00b6:
            r6 = "Office";
            r7 = "HwSmartDisplayService";
            r8 = "Office";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00c0:
            r6 = "Camera";
            r7 = "HwSmartDisplayService";
            r8 = "Camera";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00ca:
            r6 = "Gallery";
            r7 = "HwSmartDisplayService";
            r8 = "Gallery";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00d4:
            r6 = "Ebook";
            r7 = "HwSmartDisplayService";
            r8 = "Ebook";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00de:
            r6 = "3D Game";
            r7 = "HwSmartDisplayService";
            r8 = "3D Game";
            android.util.Slog.i(r7, r8);
            goto L_0x00f2;
        L_0x00e8:
            r6 = "Browser";
            r7 = "HwSmartDisplayService";
            r8 = "Browser";
            android.util.Slog.i(r7, r8);
        L_0x00f2:
            r6 = 10003; // 0x2713 float:1.4017E-41 double:4.942E-320;
            if (r10 == r6) goto L_0x011b;
        L_0x00f6:
            r6 = 300; // 0x12c float:4.2E-43 double:1.48E-321;
            if (r10 == r4) goto L_0x010d;
        L_0x00fa:
            switch(r10) {
                case 10007: goto L_0x00fe;
                case 10008: goto L_0x011b;
                default: goto L_0x00fd;
            };
        L_0x00fd:
            goto L_0x011e;
        L_0x00fe:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mColorEnhancementSupportLevel;
            if (r4 != r3) goto L_0x011e;
        L_0x0106:
            r4 = com.android.server.HwSmartDisplayService.this;
            r7 = 0;
            r4.setColorEnhancementValue(r7, r6);
            goto L_0x011e;
        L_0x010d:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mColorEnhancementSupportLevel;
            if (r4 != r3) goto L_0x011e;
        L_0x0115:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.setColorEnhancementValue(r3, r6);
            goto L_0x011e;
        L_0x011b:
            r0 = r0 | 1;
        L_0x011e:
            if (r2 != r5) goto L_0x013b;
        L_0x0120:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mLastSceneFlag;
            if (r2 != r4) goto L_0x013b;
        L_0x0128:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mLastSceneValue;
            r4 = r11.equals(r4);
            if (r4 == 0) goto L_0x013b;
        L_0x0134:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mLastSceneMode;
            r0 = r0 | r4;
        L_0x013b:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.mLastSceneFlag = r2;
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.mLastSceneValue = r11;
            r4 = com.android.server.HwSmartDisplayService.this;
            r4 = r4.mLastSceneMode;
            if (r0 != r4) goto L_0x016b;
        L_0x014d:
            r4 = com.android.server.HwSmartDisplayService.DEBUG;
            if (r4 == 0) goto L_0x016a;
        L_0x0153:
            r4 = "HwSmartDisplayService";
            r5 = new java.lang.StringBuilder;
            r5.<init>();
            r6 = "the current scene is the same as the last one,mode:";
            r5.append(r6);
            r5.append(r0);
            r5 = r5.toString();
            android.util.Slog.i(r4, r5);
        L_0x016a:
            return r3;
        L_0x016b:
            r4 = com.android.server.HwSmartDisplayService.this;
            r4.mLastSceneMode = r0;
            return r3;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.android.server.HwSmartDisplayService.IPGPClient.onEvent(int, java.lang.String):boolean");
        }

        public void onConnectedTimeout() {
            android.util.Slog.e("HwSmartDisplayService", "Client connect timeout!");
        }
    }

    private class ScreenStateReceiver extends android.content.BroadcastReceiver {
        public ScreenStateReceiver() {
            android.content.IntentFilter filter = new android.content.IntentFilter();
            filter.addAction("android.intent.action.SCREEN_OFF");
            filter.addAction("android.intent.action.SCREEN_ON");
            filter.setPriority(1000);
            com.android.server.HwSmartDisplayService.this.mContext.registerReceiver(this, filter);
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (com.android.server.HwSmartDisplayService.DEBUG) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Receiver broadcast action=");
                stringBuilder.append(intent.getAction());
                android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
            }
            if ("android.intent.action.SCREEN_OFF".equals(intent.getAction()) && com.android.server.HwSmartDisplayService.this.mAutoComfortMode != 0) {
                com.android.server.HwSmartDisplayService.this.animationTo(0, 0);
                com.android.server.HwSmartDisplayService.this.mLastSceneMode = 0;
                com.android.server.HwSmartDisplayService.this.mLastSceneFlag = 0;
                com.android.server.HwSmartDisplayService.this.mIsShowToast = false;
                com.android.server.HwSmartDisplayService.this.mLastSceneValue = null;
            }
            if ("android.intent.action.SCREEN_ON".equals(intent.getAction())) {
                com.android.server.HwSmartDisplayService.this.mAutoComfortMode = android.provider.Settings.System.getIntForUser(com.android.server.HwSmartDisplayService.this.mContext.getContentResolver(), "auto_eyes_protection", 0, 0);
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("Comfort mode in Settings changed to = ");
                stringBuilder2.append(com.android.server.HwSmartDisplayService.this.mAutoComfortMode);
                android.util.Slog.i("HwSmartDisplayService", stringBuilder2.toString());
                if (com.android.server.HwSmartDisplayService.this.mAutoComfortMode != 0) {
                    com.android.server.HwSmartDisplayService.this.animationTo(26, 0);
                }
            }
        }
    }

    private final class SmartDisplayHandler extends android.os.Handler {
        public SmartDisplayHandler(android.os.Looper looper) {
            super(looper, null, true);
        }

        public void handleMessage(android.os.Message msg) {
            int value = msg.arg1;
            switch (msg.what) {
                case 1:
                    android.widget.Toast.makeText(com.android.server.HwSmartDisplayService.this.mContext, 33685786, 0).show();
                    return;
                case 2:
                    if (msg.arg2 > 0) {
                        if (msg.arg2 != com.android.server.HwSmartDisplayService.this.mAnimationFlag) {
                            android.util.Slog.i("HwSmartDisplayService", "drop the old animation msg when the new one is coming");
                            return;
                        }
                        int value2;
                        if (com.android.server.HwSmartDisplayService.this.mValueAnimationTarget > 0) {
                            value2 = (com.android.server.HwSmartDisplayService.this.mValueAnimationTarget * com.android.server.HwSmartDisplayService.this.mAnimationTimes) / 10;
                        } else {
                            value2 = (com.android.server.HwSmartDisplayService.this.mValueBeforeAnimation * (10 - com.android.server.HwSmartDisplayService.this.mAnimationTimes)) / 10;
                        }
                        value = value2;
                        com.android.server.HwSmartDisplayService.this.mAnimationTimes = com.android.server.HwSmartDisplayService.this.mAnimationTimes + 1;
                    }
                    com.android.server.HwSmartDisplayService.this.mCurrentComfortValue = value;
                    com.android.server.HwSmartDisplayService.nativeSetSmartDisplay(1, com.android.server.HwSmartDisplayService.this.mCurrentComfortValue);
                    if (com.android.server.HwSmartDisplayService.DEBUG) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("Process comfort msg value =");
                        stringBuilder.append(com.android.server.HwSmartDisplayService.this.mCurrentComfortValue);
                        android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
                    }
                    if (msg.arg2 > 0 && com.android.server.HwSmartDisplayService.this.mAnimationTimes <= 10) {
                        com.android.server.HwSmartDisplayService.this.mHandler.sendMessageDelayed(com.android.server.HwSmartDisplayService.this.mHandler.obtainMessage(2, value, msg.arg2), 40);
                        return;
                    } else if (com.android.server.HwSmartDisplayService.this.mCurrentComfortValue > 0 && com.android.server.HwSmartDisplayService.this.mIsShowToast) {
                        com.android.server.HwSmartDisplayService.this.mHandler.sendMessageDelayed(com.android.server.HwSmartDisplayService.this.mHandler.obtainMessage(1, 0, 0), 300);
                        com.android.server.HwSmartDisplayService.this.mIsShowToast = true;
                        return;
                    } else {
                        return;
                    }
                case 3:
                    com.android.server.HwSmartDisplayService.this.mCurrentColorEnhancementValue = value;
                    com.android.server.HwSmartDisplayService.nativeSetSmartDisplay(2, value);
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("Process colorEnhancement msg value =");
                    stringBuilder2.append(value);
                    android.util.Slog.i("HwSmartDisplayService", stringBuilder2.toString());
                    return;
                default:
                    android.util.Slog.e("HwSmartDisplayService", "Invalid message");
                    return;
            }
        }
    }

    private final class UserSwitchedReceiver extends android.content.BroadcastReceiver {
        private UserSwitchedReceiver() {
        }

        /* synthetic */ UserSwitchedReceiver(com.android.server.HwSmartDisplayService x0, com.android.server.HwSmartDisplayService.AnonymousClass1 x1) {
            this();
        }

        public void onReceive(android.content.Context context, android.content.Intent intent) {
            if (android.provider.Settings.System.getIntForUser(com.android.server.HwSmartDisplayService.this.mContext.getContentResolver(), "color_mode_switch", 0, -2) == 0) {
                com.android.server.HwSmartDisplayService.this.setColorEnhancementValue(0, 0);
            } else {
                com.android.server.HwSmartDisplayService.this.setColorEnhancementValue(1, 0);
            }
            com.android.server.HwSmartDisplayService.this.initColorContentObserver();
        }
    }

    private static native void finalize_native();

    private static native void init_native();

    private static native int nativeGetDisplayEffectSupported(int i);

    private static native int nativeGetFeatureSupported(int i);

    private static native int nativeSetDisplayEffectParam(int i, int[] iArr, int i2);

    private static native int nativeSetDisplayEffectScene(int i);

    private static native void nativeSetSmartDisplay(int i, int i2);

    static {
        mLoadLibraryFailed = false;
        try {
            java.lang.System.loadLibrary("hwsmartdisplay_jni");
        } catch (java.lang.UnsatisfiedLinkError e) {
            mLoadLibraryFailed = true;
            android.util.Slog.d("HwSmartDisplayService", "hwsmartdisplay_jni library not found!");
        }
    }

    private void initColorContentObserver() {
        if (this.mColorModeObserver != null) {
            this.mContext.getContentResolver().unregisterContentObserver(this.mColorModeObserver);
        }
        this.mColorModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
            public void onChange(boolean selfChange) {
                if (android.provider.Settings.System.getIntForUser(com.android.server.HwSmartDisplayService.this.mContext.getContentResolver(), "color_mode_switch", 0, -2) == 0) {
                    android.util.Slog.i("HwSmartDisplayService", "content observer onChange 0");
                    com.android.server.HwSmartDisplayService.this.setColorEnhancementValue(0, 0);
                    return;
                }
                android.util.Slog.i("HwSmartDisplayService", "content observer onChange 1");
                com.android.server.HwSmartDisplayService.this.setColorEnhancementValue(1, 0);
            }
        };
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("mColorModeObserver this ");
        stringBuilder.append(this.mColorModeObserver);
        android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("color_mode_switch"), true, this.mColorModeObserver, -2);
    }

    private void initComfortContentObserver(int id) {
        this.mComfortModeObserver = new android.database.ContentObserver(new android.os.Handler()) {
            public void onChange(boolean selfChange) {
                com.android.server.HwSmartDisplayService.this.mAutoComfortMode = android.provider.Settings.System.getIntForUser(com.android.server.HwSmartDisplayService.this.mContext.getContentResolver(), "auto_eyes_protection", 0, 0);
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("Comfort mode in Settings changed to = ");
                stringBuilder.append(com.android.server.HwSmartDisplayService.this.mAutoComfortMode);
                android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
                if (com.android.server.HwSmartDisplayService.this.mAutoComfortMode != 0) {
                    com.android.server.HwSmartDisplayService.this.animationTo(26, 0);
                } else {
                    com.android.server.HwSmartDisplayService.this.animationTo(0, 0);
                }
            }
        };
        this.mContext.getContentResolver().registerContentObserver(android.provider.Settings.System.getUriFor("auto_eyes_protection"), true, this.mComfortModeObserver, id);
    }

    public HwSmartDisplayService(android.content.Context context) {
        this.mContext = context;
        this.mCurrentColorEnhancementValue = 0;
        if (!mLoadLibraryFailed) {
            init_native();
            this.mIsComfortSupported = isFeatureSupported(1);
            this.mColorEnhancementSupportLevel = nativeGetFeatureSupported(2);
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("comfort support = ");
            stringBuilder.append(this.mIsComfortSupported);
            android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
            if ("true".equals(android.os.SystemProperties.get("ro.config.eyesprotect_support", "false")) && this.mIsComfortSupported) {
                this.mAutoComfortMode = android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "auto_eyes_protection", 0, 0);
                initComfortContentObserver(0);
            }
            this.mHDREnginePGPClient = new com.android.server.HwSmartDisplayService.HDREnginePGPClient();
            this.mHandlerThread = new android.os.HandlerThread("HwSmartDisplayService");
            this.mHandlerThread.start();
            this.mHandler = new com.android.server.HwSmartDisplayService.SmartDisplayHandler(this.mHandlerThread.getLooper());
            if (this.mColorEnhancementSupportLevel == 2) {
                android.content.IntentFilter filter = new android.content.IntentFilter();
                filter.addAction("android.intent.action.USER_SWITCHED");
                this.mContext.registerReceiver(new com.android.server.HwSmartDisplayService.UserSwitchedReceiver(this, null), filter, null, this.mHandler);
                if (android.provider.Settings.System.getIntForUser(this.mContext.getContentResolver(), "color_mode_switch", 0, -2) == 0) {
                    setColorEnhancementValue(0, 0);
                } else {
                    setColorEnhancementValue(1, 0);
                }
                initColorContentObserver();
            }
            this.mWindowManager = android.view.IWindowManager.Stub.asInterface(android.os.ServiceManager.getService("window"));
            if (this.mAutoComfortMode != 0) {
                animationTo(26, 0);
            }
        }
    }

    protected void finalize() {
        finalize_native();
        try {
            super.finalize();
        } catch (Throwable th) {
        }
    }

    private void setColorEnhancementValue(int value, int delayed) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("set color enhancement value to: ");
        stringBuilder.append(value);
        stringBuilder.append(",delayed=");
        stringBuilder.append(delayed);
        android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
        android.os.Message msg = this.mHandler.obtainMessage(3, value, 0);
        if (delayed > 0) {
            this.mHandler.sendMessageDelayed(msg, (long) delayed);
        } else {
            this.mHandler.sendMessage(msg);
        }
    }

    public boolean isFeatureSupported(int feature) {
        if (mLoadLibraryFailed) {
            android.util.Slog.e("HwSmartDisplayService", "Comfort feature not supported because of library not found");
            return false;
        }
        boolean z = true;
        if (2 == feature) {
            if (2 != nativeGetFeatureSupported(feature)) {
                z = false;
            }
            return z;
        }
        if (nativeGetFeatureSupported(feature) == 0) {
            z = false;
        }
        return z;
    }

    public int setDisplayEffectScene(int scene) {
        try {
            if (!mLoadLibraryFailed) {
                return nativeSetDisplayEffectScene(scene);
            }
            android.util.Slog.d("HwSmartDisplayService", "nativeSetDisplayEffectScene not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwSmartDisplayService", "nativeSetDisplayEffectScene not found!");
            return -1;
        }
    }

    public int setDisplayEffectParam(int type, int[] buffer, int length) {
        try {
            if (!mLoadLibraryFailed) {
                return nativeSetDisplayEffectParam(type, buffer, length);
            }
            android.util.Slog.d("HwSmartDisplayService", "nativesetDisplayEffetParam not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwSmartDisplayService", "nativesetDisplayEffetParam not found!");
            return -1;
        }
    }

    public int getDisplayEffectSupported(int type) {
        try {
            if (!mLoadLibraryFailed) {
                return nativeGetDisplayEffectSupported(type);
            }
            android.util.Slog.d("HwSmartDisplayService", "nativesetDisplayEffectSupported not valid!");
            return 0;
        } catch (java.lang.UnsatisfiedLinkError e) {
            android.util.Slog.d("HwSmartDisplayService", "nativesetDisplayEffetSupported not found!");
            return 0;
        }
    }

    private void animationTo(int target, int delayed) {
        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
        stringBuilder.append("animationTo target = ");
        stringBuilder.append(target);
        stringBuilder.append(", delayed time = ");
        stringBuilder.append(delayed);
        android.util.Slog.i("HwSmartDisplayService", stringBuilder.toString());
        this.mHandler.removeMessages(2);
        if (this.mAnimationTimes < 10) {
            this.mAnimationFlag++;
        } else {
            this.mAnimationFlag = 1;
        }
        this.mAnimationTimes = 1;
        this.mValueBeforeAnimation = this.mCurrentComfortValue;
        this.mValueAnimationTarget = target;
        this.mHandler.sendMessageDelayed(this.mHandler.obtainMessage(2, this.mValueAnimationTarget, this.mAnimationFlag), (long) delayed);
    }
}
