package com.android.server.devicepolicy.plugins;

public class DeviceApplicationPlugin extends com.android.server.devicepolicy.DevicePolicyPlugin {
    private static final java.lang.String INSTALL_APKS_BLACK_LIST = "install-packages-black-list";
    private static final java.lang.String INSTALL_APKS_BLACK_LIST_ITEM = "install-packages-black-list/install-packages-black-list-item";
    public static final java.lang.String TAG = com.android.server.devicepolicy.plugins.DeviceApplicationPlugin.class.getSimpleName();

    public DeviceApplicationPlugin(android.content.Context context) {
        super(context);
    }

    public boolean onInit(final com.android.server.devicepolicy.PolicyStruct struct) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onInit");
        if (struct != null && struct.containsPolicyName("policy-single-app")) {
            android.content.IntentFilter filter = new android.content.IntentFilter("android.intent.action.BOOT_COMPLETED");
            filter.setPriority(1000);
            this.mContext.registerReceiver(new android.content.BroadcastReceiver() {
                public void onReceive(android.content.Context context, android.content.Intent intent) {
                    com.android.server.devicepolicy.plugins.DeviceApplicationPlugin.this.mContext.unregisterReceiver(this);
                    java.lang.String packageName = struct.getPolicyItem("policy-single-app").getAttrValue("value");
                    if (packageName != null && !packageName.isEmpty()) {
                        android.content.Intent launchIntent = com.android.server.devicepolicy.plugins.DeviceApplicationPlugin.this.mContext.getPackageManager().getLaunchIntentForPackage(packageName);
                        if (launchIntent != null) {
                            com.android.server.devicepolicy.plugins.DeviceApplicationPlugin.this.mContext.startActivity(launchIntent);
                        }
                    }
                }
            }, filter);
        }
        return true;
    }

    public java.lang.String getPluginName() {
        return getClass().getSimpleName();
    }

    public com.android.server.devicepolicy.PolicyStruct getPolicyStruct() {
        com.android.server.devicepolicy.HwLog.i(TAG, "getPolicyStruct");
        com.android.server.devicepolicy.PolicyStruct struct = new com.android.server.devicepolicy.PolicyStruct(this);
        struct.addStruct("install-packages-black-list/install-packages-black-list-item", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value"});
        struct.addStruct("ignore-frequent-relaunch-app", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[0]);
        struct.addStruct("ignore-frequent-relaunch-app/ignore-frequent-relaunch-app-item", com.android.server.devicepolicy.PolicyStruct.PolicyType.LIST, new java.lang.String[]{"value"});
        struct.addStruct("policy-single-app", com.android.server.devicepolicy.PolicyStruct.PolicyType.CONFIGURATION, new java.lang.String[]{"value"});
        return struct;
    }

    public boolean checkCallingPermission(android.content.ComponentName who, java.lang.String policyName) {
        com.android.server.devicepolicy.HwLog.i(TAG, "checkCallingPermission");
        this.mContext.enforceCallingOrSelfPermission("com.huawei.permission.sec.MDM_APP_MANAGEMENT", "does not have app_management MDM permission!");
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x0028  */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x0020  */
    public boolean onSetPolicy(android.content.ComponentName r6, java.lang.String r7, android.os.Bundle r8, boolean r9) {
        /*
        r5 = this;
        r0 = TAG;
        r1 = "onSetPolicy";
        com.android.server.devicepolicy.HwLog.i(r0, r1);
        r0 = r7.hashCode();
        r1 = 0;
        r2 = -414055785; // 0xffffffffe7520297 float:-9.917447E23 double:NaN;
        if (r0 == r2) goto L_0x0012;
    L_0x0011:
        goto L_0x001c;
    L_0x0012:
        r0 = "policy-single-app";
        r0 = r7.equals(r0);
        if (r0 == 0) goto L_0x001c;
    L_0x001a:
        r0 = r1;
        goto L_0x001d;
    L_0x001c:
        r0 = -1;
    L_0x001d:
        r2 = 1;
        if (r0 == 0) goto L_0x0028;
    L_0x0020:
        r0 = r5.isNotEffective(r6, r7, r8, r9);
        if (r0 == 0) goto L_0x0027;
    L_0x0026:
        return r1;
    L_0x0027:
        return r2;
    L_0x0028:
        r0 = TAG;
        r3 = "onSetPolicy POLICY_SINGLE_APP";
        com.android.server.devicepolicy.HwLog.i(r0, r3);
        r0 = "value";
        r0 = r8.getString(r0);
        r3 = r5.mContext;
        r3 = r3.getPackageManager();
        r4 = r3.getLaunchIntentForPackage(r0);
        if (r4 != 0) goto L_0x0043;
    L_0x0042:
        return r1;
    L_0x0043:
        r1 = r5.mContext;
        r1.startActivity(r4);
        return r2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.devicepolicy.plugins.DeviceApplicationPlugin.onSetPolicy(android.content.ComponentName, java.lang.String, android.os.Bundle, boolean):boolean");
    }

    public boolean onRemovePolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onRemovePolicy");
        if (isNotEffective(who, policyName, policyData, effective)) {
            return false;
        }
        return true;
    }

    public boolean onGetPolicy(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onGetPolicy");
        if (isNotEffective(who, policyName, policyData, true)) {
            return false;
        }
        return true;
    }

    public boolean onActiveAdminRemoved(android.content.ComponentName who, java.util.ArrayList<com.android.server.devicepolicy.PolicyStruct.PolicyItem> arrayList) {
        com.android.server.devicepolicy.HwLog.i(TAG, "onActiveAdminRemoved");
        return true;
    }

    public boolean isNotEffective(android.content.ComponentName who, java.lang.String policyName, android.os.Bundle policyData, boolean effective) {
        if (policyData != null && ("install-packages-black-list".equals(policyName) || "ignore-frequent-relaunch-app".equals(policyName))) {
            java.util.ArrayList<java.lang.String> packageNames = policyData.getStringArrayList("value");
            if (!com.android.server.devicepolicy.HwDevicePolicyManagerServiceUtil.isValidatePackageNames(packageNames)) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("packageName:");
                stringBuilder.append(packageNames);
                stringBuilder.append(" is invalid.");
                throw new java.lang.IllegalArgumentException(stringBuilder.toString());
            }
        }
        return false;
    }
}
