package com.android.server.mtm.iaware.appmng.appstart.datamgr;

public class AppStartupDataMgr {
    private static final java.lang.String TAG = "AppStartupDataMgr";
    private boolean DEBUG_DATAMGR = false;
    private java.util.Set<java.lang.String> mAllowedReceiverSet = new java.util.HashSet();
    private java.util.Set<java.lang.String> mAutoAppPkgSet = new java.util.HashSet();
    private int[] mBigDataThreshold = new int[com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.values().length];
    private com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache mCacheMgr = new com.android.server.mtm.iaware.appmng.appstart.datamgr.HsmDataCache();
    private java.util.Set<java.lang.String> mPGForbidRestartSet = new java.util.HashSet();
    private java.util.Set<java.lang.String> mPgCleanPkgSet = new java.util.HashSet();
    private com.android.server.mtm.iaware.appmng.appstart.datamgr.SystemUnremoveUidCache mSpecialUidSet = null;

    /* renamed from: com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr$1 */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource = new int[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.values().length];

        static {
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.THIRD_BROADCAST.ordinal()] = 1;
            } catch (java.lang.NoSuchFieldError e) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.SYSTEM_BROADCAST.ordinal()] = 2;
            } catch (java.lang.NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.JOB_SCHEDULE.ordinal()] = 3;
            } catch (java.lang.NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.ACCOUNT_SYNC.ordinal()] = 4;
            } catch (java.lang.NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.SCHEDULE_RESTART.ordinal()] = 5;
            } catch (java.lang.NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.ALARM.ordinal()] = 6;
            } catch (java.lang.NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.BIND_SERVICE.ordinal()] = 7;
            } catch (java.lang.NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource[android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.THIRD_ACTIVITY.ordinal()] = 8;
            } catch (java.lang.NoSuchFieldError e8) {
            }
        }
    }

    private enum ThresholdType {
        BETA,
        COMMERCIAL
    }

    public void initData(android.content.Context context) {
        com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.initCtsPkgList();
        this.mSpecialUidSet = com.android.server.mtm.iaware.appmng.appstart.datamgr.SystemUnremoveUidCache.getInstance(context);
        this.mCacheMgr.loadStartupSettingCache();
        this.mCacheMgr.loadBootCache();
        loadAllowedReceivers();
        loadBigDataThreshold();
        loadPGForbidPkgs();
        loadAutoMngPkgs();
        synchronized (this.mPgCleanPkgSet) {
            this.mPgCleanPkgSet.clear();
        }
    }

    public void initSystemUidCache(android.content.Context context) {
        if (this.mSpecialUidSet != null) {
            this.mSpecialUidSet.loadSystemUid(context);
            if (this.DEBUG_DATAMGR) {
                android.rms.iaware.AwareLog.i("AppStartupDataMgr", "initSystemUidCache called");
            }
        }
    }

    public void initStartupSetting() {
        this.mCacheMgr.loadStartupSettingCache();
    }

    public void unInitData() {
        synchronized (this.mAllowedReceiverSet) {
            this.mAllowedReceiverSet.clear();
        }
    }

    public void updateCloudData() {
        loadAllowedReceivers();
        loadBigDataThreshold();
        loadPGForbidPkgs();
        loadAutoMngPkgs();
    }

    public int getBigdataThreshold(boolean beta) {
        return this.mBigDataThreshold[(beta ? com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.BETA : com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.COMMERCIAL).ordinal()];
    }

    private boolean isAllowedReceiver(java.lang.String action) {
        boolean result;
        synchronized (this.mAllowedReceiverSet) {
            result = this.mAllowedReceiverSet.contains(action);
        }
        return result;
    }

    public boolean isSystemBaseApp(android.content.pm.ApplicationInfo applicationInfo) {
        if (android.os.UserHandle.getAppId(applicationInfo.uid) >= 10000) {
            if (!com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.isSystemUnRemovablePkg(applicationInfo)) {
                return false;
            }
        }
        return true;
    }

    /* JADX WARNING: Missing block: B:3:0x0027, code:
            r18 = r0;
            r17 = r1;
     */
    /* JADX WARNING: Missing block: B:29:0x0068, code:
            r18 = r0;
            r17 = r1;
            r4 = 2;
     */
    /* JADX WARNING: Missing block: B:38:0x009b, code:
            if (r17 == false) goto L_0x00e2;
     */
    /* JADX WARNING: Missing block: B:39:0x009d, code:
            r19 = r4;
            r20 = 1;
            r21 = r6;
     */
    /* JADX WARNING: Missing block: B:40:0x00b3, code:
            if (isTargetAndCallerSameApp(r9, r25, r11, r12, r28, r29, r30) == false) goto L_0x00e6;
     */
    /* JADX WARNING: Missing block: B:42:0x00b7, code:
            if (r8.DEBUG_DATAMGR == false) goto L_0x00e1;
     */
    /* JADX WARNING: Missing block: B:43:0x00b9, code:
            r1 = new java.lang.StringBuilder();
            r1.append("same app ");
            r1.append(r9.packageName);
            r1.append(",caller:");
            r1.append(r11);
            r1.append(",");
            r1.append(r12);
            android.rms.iaware.AwareLog.i("AppStartupDataMgr", r1.toString());
     */
    /* JADX WARNING: Missing block: B:44:0x00e1, code:
            return r20;
     */
    /* JADX WARNING: Missing block: B:45:0x00e2, code:
            r19 = r4;
            r21 = r6;
     */
    /* JADX WARNING: Missing block: B:46:0x00e6, code:
            if (r18 == false) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:48:0x00ec, code:
            if (isSpecialCaller(r11) == false) goto L_0x00ef;
     */
    /* JADX WARNING: Missing block: B:49:0x00ee, code:
            return r19;
     */
    /* JADX WARNING: Missing block: B:51:0x00f5, code:
            if (com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.isCtsPackage(r9.packageName) != false) goto L_0x00ff;
     */
    /* JADX WARNING: Missing block: B:53:0x00fb, code:
            if (isCtsCaller(r12) == false) goto L_0x00fe;
     */
    /* JADX WARNING: Missing block: B:55:0x00fe, code:
            return 0;
     */
    /* JADX WARNING: Missing block: B:56:0x00ff, code:
            return r19;
     */
    public int getDefaultAllowedRequestType(android.content.pm.ApplicationInfo r23, java.lang.String r24, int r25, int r26, com.android.server.am.ProcessRecord r27, android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource r28, boolean r29, boolean r30, boolean[] r31, boolean[] r32, int r33, boolean r34, com.android.server.rms.iaware.appmng.AwareAppStartStatusCacheExt r35) {
        /*
        r22 = this;
        r8 = r22;
        r9 = r23;
        r10 = r24;
        r11 = r26;
        r12 = r27;
        r13 = r31;
        r14 = r32;
        r15 = r33;
        r0 = 0;
        r1 = 0;
        r7 = r35;
        r6 = r7.mGmsNeedCtrl;
        r2 = com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.AnonymousClass1.$SwitchMap$android$app$mtm$iaware$appmng$AppMngConstant$AppStartSource;
        r3 = r28.ordinal();
        r2 = r2[r3];
        r5 = 1;
        r16 = 0;
        r4 = 2;
        switch(r2) {
            case 1: goto L_0x006e;
            case 2: goto L_0x006e;
            case 3: goto L_0x0067;
            case 4: goto L_0x0067;
            case 5: goto L_0x0067;
            case 6: goto L_0x0058;
            case 7: goto L_0x0033;
            case 8: goto L_0x002d;
            default: goto L_0x0025;
        };
    L_0x0025:
        r1 = 1;
        r0 = 1;
    L_0x0027:
        r18 = r0;
        r17 = r1;
        goto L_0x009b;
    L_0x002d:
        if (r34 == 0) goto L_0x0030;
    L_0x002f:
        return r4;
    L_0x0030:
        r1 = 1;
        r0 = 1;
        goto L_0x0027;
    L_0x0033:
        r2 = com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance();
        r2 = r2.isBtMediaBrowserCaller(r11, r10);
        if (r13 == 0) goto L_0x0042;
    L_0x003d:
        r3 = r13.length;
        if (r3 <= 0) goto L_0x0042;
    L_0x0040:
        r13[r16] = r2;
    L_0x0042:
        r3 = com.android.server.rms.iaware.appmng.AwareIntelligentRecg.getInstance();
        r3 = r3.isNotifyListenerCaller(r11, r10, r12);
        if (r14 == 0) goto L_0x0051;
    L_0x004c:
        r4 = r14.length;
        if (r4 <= 0) goto L_0x0051;
    L_0x004f:
        r14[r16] = r3;
    L_0x0051:
        if (r2 != 0) goto L_0x0056;
    L_0x0053:
        if (r3 != 0) goto L_0x0056;
    L_0x0055:
        r0 = 1;
    L_0x0056:
        r1 = 1;
        goto L_0x0068;
    L_0x0058:
        if (r6 != 0) goto L_0x005d;
    L_0x005a:
        if (r15 == r5) goto L_0x005d;
    L_0x005c:
        r0 = 1;
    L_0x005d:
        r2 = 2;
        if (r15 != r2) goto L_0x0061;
    L_0x0060:
        return r5;
    L_0x0061:
        r18 = r0;
        r17 = r1;
        r4 = r2;
        goto L_0x009b;
    L_0x0068:
        r18 = r0;
        r17 = r1;
        r4 = 2;
        goto L_0x009b;
    L_0x006e:
        r2 = r8.isAllowedReceiver(r10);
        if (r2 == 0) goto L_0x0098;
    L_0x0074:
        r2 = r8.DEBUG_DATAMGR;
        if (r2 == 0) goto L_0x0096;
    L_0x0078:
        r2 = "AppStartupDataMgr";
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r4 = "isAllowReceiver action=";
        r3.append(r4);
        r3.append(r10);
        r4 = ", callerUid=";
        r3.append(r4);
        r3.append(r11);
        r3 = r3.toString();
        android.rms.iaware.AwareLog.i(r2, r3);
    L_0x0096:
        r4 = 2;
        return r4;
    L_0x0098:
        r4 = 2;
        r1 = 1;
        goto L_0x0027;
    L_0x009b:
        if (r17 == 0) goto L_0x00e2;
    L_0x009d:
        r0 = r8;
        r1 = r9;
        r2 = r25;
        r3 = r11;
        r19 = r4;
        r4 = r12;
        r20 = r5;
        r5 = r28;
        r21 = r6;
        r6 = r29;
        r7 = r30;
        r0 = r0.isTargetAndCallerSameApp(r1, r2, r3, r4, r5, r6, r7);
        if (r0 == 0) goto L_0x00e6;
    L_0x00b5:
        r0 = r8.DEBUG_DATAMGR;
        if (r0 == 0) goto L_0x00e1;
    L_0x00b9:
        r0 = "AppStartupDataMgr";
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = "same app ";
        r1.append(r2);
        r2 = r9.packageName;
        r1.append(r2);
        r2 = ",caller:";
        r1.append(r2);
        r1.append(r11);
        r2 = ",";
        r1.append(r2);
        r1.append(r12);
        r1 = r1.toString();
        android.rms.iaware.AwareLog.i(r0, r1);
    L_0x00e1:
        return r20;
    L_0x00e2:
        r19 = r4;
        r21 = r6;
    L_0x00e6:
        if (r18 == 0) goto L_0x00ef;
    L_0x00e8:
        r0 = r8.isSpecialCaller(r11);
        if (r0 == 0) goto L_0x00ef;
    L_0x00ee:
        return r19;
    L_0x00ef:
        r0 = r9.packageName;
        r0 = com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.isCtsPackage(r0);
        if (r0 != 0) goto L_0x00ff;
    L_0x00f7:
        r0 = r8.isCtsCaller(r12);
        if (r0 == 0) goto L_0x00fe;
    L_0x00fd:
        goto L_0x00ff;
    L_0x00fe:
        return r16;
    L_0x00ff:
        return r19;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.getDefaultAllowedRequestType(android.content.pm.ApplicationInfo, java.lang.String, int, int, com.android.server.am.ProcessRecord, android.app.mtm.iaware.appmng.AppMngConstant$AppStartSource, boolean, boolean, boolean[], boolean[], int, boolean, com.android.server.rms.iaware.appmng.AwareAppStartStatusCacheExt):int");
    }

    private boolean isCtsCaller(com.android.server.am.ProcessRecord callerApp) {
        if (callerApp != null) {
            if (!callerApp.pkgList.isEmpty()) {
                return com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.isCtsPackage((java.lang.String) callerApp.pkgList.keyAt(0));
            }
        }
        return false;
    }

    public boolean isWidgetExistPkg(java.lang.String pkg) {
        return this.mCacheMgr.isWidgetExistPkg(pkg);
    }

    public boolean isBlindAssistPkg(java.lang.String pkg) {
        return this.mCacheMgr.isBlindAssistPkg(pkg);
    }

    private boolean isTargetAndCallerSameApp(android.content.pm.ApplicationInfo applicationInfo, int callerPid, int callerUid, com.android.server.am.ProcessRecord callerApp, android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource requestSource, boolean isAppStop, boolean isSysApp) {
        if (applicationInfo.uid != callerUid) {
            return false;
        }
        boolean z = true;
        if (com.android.server.rms.iaware.appmng.AwareAppAssociate.isDealAsPkgUid(callerUid)) {
            if (callerApp == null) {
                com.android.server.am.HwActivityManagerService hwAMS = com.android.server.am.HwActivityManagerService.self();
                if (hwAMS != null) {
                    callerApp = hwAMS.getProcessRecordLocked(callerPid);
                }
                if (this.DEBUG_DATAMGR) {
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("isTargetAndCallerSameApp req=");
                    stringBuilder.append(requestSource.getDesc());
                    stringBuilder.append(", target=");
                    stringBuilder.append(applicationInfo.packageName);
                    stringBuilder.append(", callerPid=");
                    stringBuilder.append(callerPid);
                    stringBuilder.append(", ");
                    stringBuilder.append(callerApp);
                    android.rms.iaware.AwareLog.i("AppStartupDataMgr", stringBuilder.toString());
                }
            }
            if (callerApp != null) {
                z = callerApp.pkgList.containsKey(applicationInfo.packageName);
            }
            return z;
        } else if (isSysApp || !android.app.mtm.iaware.appmng.AppMngConstant.AppStartSource.START_SERVICE.equals(requestSource)) {
            return true;
        } else {
            return isAppStop ^ 1;
        }
    }

    public boolean isSpecialCaller(int callerUid) {
        callerUid = android.os.UserHandle.getAppId(callerUid);
        java.lang.StringBuilder stringBuilder;
        if (callerUid < 10000) {
            if (this.DEBUG_DATAMGR) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("isSpecialCaller uid=");
                stringBuilder.append(callerUid);
                android.rms.iaware.AwareLog.d("AppStartupDataMgr", stringBuilder.toString());
            }
            return true;
        } else if (this.mSpecialUidSet == null || !this.mSpecialUidSet.checkUidExist(callerUid)) {
            return false;
        } else {
            if (this.DEBUG_DATAMGR) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("isSpecialCaller un-removable uid=");
                stringBuilder.append(callerUid);
                android.rms.iaware.AwareLog.d("AppStartupDataMgr", stringBuilder.toString());
            }
            return true;
        }
    }

    private void loadAllowedReceivers() {
        java.util.ArrayList<java.lang.String> whiteReceiverList = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.APP_START.getDesc(), "receiver");
        if (whiteReceiverList != null) {
            synchronized (this.mAllowedReceiverSet) {
                this.mAllowedReceiverSet.clear();
                this.mAllowedReceiverSet.addAll(whiteReceiverList);
            }
        }
    }

    private void loadPGForbidPkgs() {
        java.util.ArrayList<java.lang.String> pgForbidRestart = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.APP_START.getDesc(), "PGForbidRestart");
        if (pgForbidRestart != null) {
            synchronized (this.mPGForbidRestartSet) {
                this.mPGForbidRestartSet.clear();
                this.mPGForbidRestartSet.addAll(pgForbidRestart);
            }
        }
    }

    private void loadAutoMngPkgs() {
        java.util.ArrayList<java.lang.String> autoMng = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.APP_START.getDesc(), "automanage");
        if (autoMng != null) {
            synchronized (this.mAutoAppPkgSet) {
                this.mAutoAppPkgSet.clear();
                this.mAutoAppPkgSet.addAll(autoMng);
            }
        }
    }

    private void loadBigDataThreshold() {
        java.util.ArrayList<java.lang.String> thresholdList = com.android.server.mtm.iaware.appmng.DecisionMaker.getInstance().getRawConfig(android.app.mtm.iaware.appmng.AppMngConstant.AppMngFeature.APP_START.getDesc(), "bigdata_threshold");
        if (thresholdList != null) {
            int size = thresholdList.size();
            for (int i = 0; i < size; i++) {
                java.lang.String thr = (java.lang.String) thresholdList.get(i);
                if (thr != null) {
                    java.lang.String[] thrList = thr.split(":");
                    if (thrList.length == 2) {
                        int v = 0;
                        try {
                            v = java.lang.Integer.parseInt(thrList[1]);
                        } catch (java.lang.NumberFormatException e) {
                            android.rms.iaware.AwareLog.e("AppStartupDataMgr", "loadBigDataThreshold catch NumberFormatException");
                        }
                        java.lang.String key = thrList[0];
                        if ("beta".equals(key)) {
                            this.mBigDataThreshold[com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.BETA.ordinal()] = v;
                        } else if ("commercial".equals(key)) {
                            this.mBigDataThreshold[com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.COMMERCIAL.ordinal()] = v;
                        }
                    }
                }
            }
        }
    }

    public boolean updateWidgetList(java.util.Set<java.lang.String> pkgList) {
        if (pkgList == null) {
            return false;
        }
        if (this.DEBUG_DATAMGR) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("updateWidgetList pkgList=");
            stringBuilder.append(pkgList);
            android.rms.iaware.AwareLog.i("AppStartupDataMgr", stringBuilder.toString());
        }
        this.mCacheMgr.updateWidgetPkgList(pkgList);
        return true;
    }

    public void updateWidgetUpdateTime(java.lang.String pkgName) {
        if (pkgName != null) {
            this.mCacheMgr.updateWidgetUpdateTime(pkgName);
        }
    }

    public int getWidgetCnt() {
        return this.mCacheMgr.getWidgetExistPkgCnt();
    }

    public long getWidgetExistPkgUpdateTime(java.lang.String pkgName) {
        return this.mCacheMgr.getWidgetExistPkgUpdateTime(pkgName);
    }

    public void updateBlind(java.util.Set<java.lang.String> pkgSet) {
        this.mCacheMgr.updateBlindPkg(pkgSet);
    }

    public void flushStartupSettingToDisk() {
        this.mCacheMgr.flushStartupSettingToDisk();
    }

    public void flushBootCacheDataToDisk() {
        this.mCacheMgr.flushBootCacheDataToDisk();
    }

    public android.app.mtm.iaware.HwAppStartupSetting getAppStartupSetting(java.lang.String pkgName) {
        return this.mCacheMgr.getAppStartupSetting(pkgName);
    }

    public java.util.List<android.app.mtm.iaware.HwAppStartupSetting> retrieveAppStartupSettings(java.util.List<java.lang.String> pkgList, android.app.mtm.iaware.HwAppStartupSettingFilter filter) {
        return this.mCacheMgr.retrieveStartupSettings(pkgList, filter);
    }

    public boolean updateAppStartupSettings(java.util.List<android.app.mtm.iaware.HwAppStartupSetting> settingList, boolean clearFirst) {
        return this.mCacheMgr.updateStartupSettings(settingList, clearFirst);
    }

    public boolean removeAppStartupSetting(java.lang.String pkgName) {
        return this.mCacheMgr.removeStartupSetting(pkgName);
    }

    public boolean isPGForbidRestart(java.lang.String pkg) {
        boolean contains;
        synchronized (this.mPGForbidRestartSet) {
            contains = this.mPGForbidRestartSet.contains(pkg);
        }
        return contains;
    }

    public void addPgCleanApp(java.lang.String pkg) {
        synchronized (this.mPgCleanPkgSet) {
            this.mPgCleanPkgSet.add(pkg);
        }
    }

    public void removePgCleanApp(java.lang.String pkg) {
        synchronized (this.mPgCleanPkgSet) {
            if (this.mPgCleanPkgSet.contains(pkg)) {
                this.mPgCleanPkgSet.remove(pkg);
            }
        }
    }

    public boolean isPgCleanApp(java.lang.String pkg) {
        boolean contains;
        synchronized (this.mPgCleanPkgSet) {
            contains = this.mPgCleanPkgSet.contains(pkg);
        }
        return contains;
    }

    public boolean isAutoMngPkg(java.lang.String pkg) {
        boolean contains;
        synchronized (this.mAutoAppPkgSet) {
            contains = this.mAutoAppPkgSet.contains(pkg);
        }
        return contains;
    }

    public void dump(java.io.PrintWriter pw, java.lang.String[] args) {
        if (args != null) {
            if (pw != null) {
                java.lang.String strBadCmd = "Bad command";
                java.lang.String strOn = "1";
                java.lang.String strOff = "0";
                java.lang.String cmd;
                if (args.length < 3) {
                    pw.println("Bad command");
                } else if (args.length == 3) {
                    cmd = args[2];
                    java.lang.StringBuilder stringBuilder;
                    if ("cache".equals(cmd)) {
                        if (com.android.server.rms.iaware.srms.AppStartupFeature.isAppStartupEnabled()) {
                            java.lang.StringBuilder stringBuilder2;
                            java.lang.StringBuilder stringBuilder3;
                            synchronized (this.mAllowedReceiverSet) {
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("Receiver(");
                                stringBuilder2.append(this.mAllowedReceiverSet.size());
                                stringBuilder2.append("):");
                                pw.println(stringBuilder2.toString());
                                for (java.lang.String receiver : this.mAllowedReceiverSet) {
                                    stringBuilder3 = new java.lang.StringBuilder();
                                    stringBuilder3.append("  ");
                                    stringBuilder3.append(receiver);
                                    pw.println(stringBuilder3.toString());
                                }
                            }
                            synchronized (this.mPGForbidRestartSet) {
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("PGForbidRestart(");
                                stringBuilder.append(this.mPGForbidRestartSet.size());
                                stringBuilder.append("):");
                                pw.println(stringBuilder.toString());
                                for (java.lang.String receiver2 : this.mPGForbidRestartSet) {
                                    stringBuilder3 = new java.lang.StringBuilder();
                                    stringBuilder3.append("  ");
                                    stringBuilder3.append(receiver2);
                                    pw.println(stringBuilder3.toString());
                                }
                            }
                            if (this.mSpecialUidSet != null) {
                                pw.println("SystemUid:");
                                stringBuilder = new java.lang.StringBuilder();
                                stringBuilder.append("  ");
                                stringBuilder.append(this.mSpecialUidSet.toString());
                                pw.println(stringBuilder.toString());
                            }
                            synchronized (this.mAutoAppPkgSet) {
                                stringBuilder2 = new java.lang.StringBuilder();
                                stringBuilder2.append("AutoAppPkgSet(");
                                stringBuilder2.append(this.mAutoAppPkgSet.size());
                                stringBuilder2.append("):");
                                pw.println(stringBuilder2.toString());
                                for (java.lang.String receiver22 : this.mAutoAppPkgSet) {
                                    stringBuilder3 = new java.lang.StringBuilder();
                                    stringBuilder3.append("  ");
                                    stringBuilder3.append(receiver22);
                                    pw.println(stringBuilder3.toString());
                                }
                            }
                        }
                        pw.println(com.android.server.mtm.iaware.appmng.appstart.comm.AppStartupUtil.getDumpCtsPackages());
                        pw.println(this.mCacheMgr.toString());
                    } else if ("info".equals(cmd)) {
                        stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("BigdataThreshold: beta=");
                        stringBuilder.append(this.mBigDataThreshold[com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.BETA.ordinal()]);
                        stringBuilder.append(", commercial=");
                        stringBuilder.append(this.mBigDataThreshold[com.android.server.mtm.iaware.appmng.appstart.datamgr.AppStartupDataMgr.ThresholdType.COMMERCIAL.ordinal()]);
                        pw.println(stringBuilder.toString());
                    } else {
                        pw.println("Bad command");
                    }
                } else {
                    cmd = args[2];
                    java.lang.String param = args[3];
                    if ("log".equals(cmd)) {
                        if ("0".equals(param)) {
                            this.DEBUG_DATAMGR = false;
                        } else if ("1".equals(param)) {
                            this.DEBUG_DATAMGR = true;
                        } else {
                            pw.println("Bad command");
                        }
                    }
                }
            }
        }
    }
}
