package com.android.server.rms.iaware.memory.utils;

public final class PackageTracker {
    private static int INDEX_KILL_AVG = 3;
    private static int INDEX_KILL_CUR = 2;
    private static int INDEX_KILL_MAX = 4;
    private static int INDEX_KILL_MINUTE = 1;
    static final long INTERVAL_DAY = 86400000;
    static final long INTERVAL_HOUR = 9000000;
    static final long INTERVAL_MINUTE = 30000;
    static final long INTERVAL_TRIGGER = 1800000;
    private static final java.lang.String TAG = "AwareMem_PkgTracker";
    static final int[][] mKillThresHold = new int[][]{new int[]{0, 2, 5, 30, 45}, new int[]{0, 2, 5, 30, 40}, new int[]{0, 2, 5, 20, 30}, new int[]{1, 2, 5, 20, 30}, new int[]{1, 2, 5, 20, 30}, new int[]{1, 2, 5, 20, 30}};
    private static final java.lang.Object mLock = new java.lang.Object();
    private static com.android.server.rms.iaware.memory.utils.PackageTracker sPackageTracker;
    private boolean mDebug = false;
    private boolean mEnable = true;
    private com.android.server.rms.iaware.memory.utils.PackageStats mPackageStats = new com.android.server.rms.iaware.memory.utils.PackageStats();
    private long mlastTriggerTime = android.os.SystemClock.elapsedRealtime();

    public enum KilledFrequency {
        FREQUENCY_NORMAL,
        FREQUENCY_HIGH,
        FREQUENCY_CRITICAL
    }

    public static com.android.server.rms.iaware.memory.utils.PackageTracker getInstance() {
        com.android.server.rms.iaware.memory.utils.PackageTracker packageTracker;
        synchronized (mLock) {
            if (sPackageTracker == null) {
                sPackageTracker = new com.android.server.rms.iaware.memory.utils.PackageTracker();
            }
            packageTracker = sPackageTracker;
        }
        return packageTracker;
    }

    public boolean isEnabled() {
        return this.mEnable;
    }

    @android.annotation.SuppressLint({"PreferForInArrayList"})
    public void trackKillEvent(int uid, java.util.List<com.android.server.mtm.iaware.appmng.AwareProcessInfo> processList) {
        if (getInstance().isEnabled()) {
            long timeStamp = android.os.SystemClock.uptimeMillis();
            for (com.android.server.mtm.iaware.appmng.AwareProcessInfo info : processList) {
                if (info.mProcInfo != null) {
                    if (info.mProcInfo.mPackageName != null) {
                        java.util.Iterator it = info.mProcInfo.mPackageName.iterator();
                        while (it.hasNext()) {
                            java.lang.String packageName = (java.lang.String) it.next();
                            getInstance().addKillRecord(packageName, uid, info.mProcInfo.mProcessName, timeStamp);
                        }
                    }
                }
            }
        }
    }

    public void addKillRecord(java.lang.String packageName, int uid, java.lang.String processName, long timeStamp) {
        addRecord(2, "kill", packageName, uid, processName, timeStamp);
    }

    public void addStartRecord(java.lang.String reason, java.lang.String packageName, int uid, java.lang.String processName, long timeStamp) {
        int recordValue = 0;
        if ("restart".equalsIgnoreCase(reason)) {
            recordValue = 1;
        }
        addRecord(recordValue, reason, packageName, uid, processName, timeStamp);
    }

    public void addExitRecord(java.lang.String reason, java.lang.String packageName, int uid, java.lang.String processName, long timeStamp) {
        int recordValue = -1;
        if ("died".equalsIgnoreCase(reason)) {
            recordValue = 3;
        }
        if ("crash".equalsIgnoreCase(reason)) {
            recordValue = 4;
        }
        if ("anr".equalsIgnoreCase(reason)) {
            recordValue = 5;
        }
        if (recordValue > -1) {
            addRecord(recordValue, reason, packageName, uid, processName, timeStamp);
        }
    }

    /* JADX WARNING: Missing block: B:18:0x0084, code:
            r0 = new java.lang.StringBuilder();
            r0.append(" addRecord, reason=");
            r0.append(r2);
            r0.append(", packageName=");
            r0.append(r10);
            r0.append(", processName=");
            r0.append(r11);
            checkTime(r14, r0.toString());
     */
    /* JADX WARNING: Missing block: B:19:0x00a8, code:
            return;
     */
    private void addRecord(int r17, java.lang.String r18, java.lang.String r19, int r20, java.lang.String r21, long r22) {
        /*
        r16 = this;
        r1 = r16;
        r2 = r18;
        r10 = r19;
        r11 = r21;
        r0 = r1.mEnable;
        if (r0 != 0) goto L_0x000d;
    L_0x000c:
        return;
    L_0x000d:
        r0 = android.text.TextUtils.isEmpty(r19);
        if (r0 == 0) goto L_0x0034;
    L_0x0013:
        r0 = "AwareMem_PkgTracker";
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r4 = "addRecord, empty packageName, uid=";
        r3.append(r4);
        r12 = r20;
        r3.append(r12);
        r4 = ", packageName=";
        r3.append(r4);
        r3.append(r10);
        r3 = r3.toString();
        android.rms.iaware.AwareLog.w(r0, r3);
        return;
    L_0x0034:
        r12 = r20;
        r3 = 0;
        r13 = mLock;
        monitor-enter(r13);
        r0 = 0;
        r1.update(r0);	 Catch:{ all -> 0x00ac }
        r5 = android.os.SystemClock.elapsedRealtime();	 Catch:{ all -> 0x00ac }
        r14 = r5;
        r3 = r1.mPackageStats;	 Catch:{ all -> 0x00a9 }
        r4 = r17;
        r5 = r10;
        r6 = r12;
        r7 = r11;
        r8 = r22;
        r3 = r3.addRecord(r4, r5, r6, r7, r8);	 Catch:{ all -> 0x00a9 }
        r0 = r1.mDebug;	 Catch:{ all -> 0x00a9 }
        if (r0 == 0) goto L_0x0083;
    L_0x0055:
        r0 = "AwareMem_PkgTracker";
        r5 = new java.lang.StringBuilder;	 Catch:{ all -> 0x00a9 }
        r5.<init>();	 Catch:{ all -> 0x00a9 }
        r6 = "addRecord, reason=";
        r5.append(r6);	 Catch:{ all -> 0x00a9 }
        r5.append(r2);	 Catch:{ all -> 0x00a9 }
        r6 = ", totalCount=";
        r5.append(r6);	 Catch:{ all -> 0x00a9 }
        r5.append(r3);	 Catch:{ all -> 0x00a9 }
        r6 = ", packageName=";
        r5.append(r6);	 Catch:{ all -> 0x00a9 }
        r5.append(r10);	 Catch:{ all -> 0x00a9 }
        r6 = ", processName=";
        r5.append(r6);	 Catch:{ all -> 0x00a9 }
        r5.append(r11);	 Catch:{ all -> 0x00a9 }
        r5 = r5.toString();	 Catch:{ all -> 0x00a9 }
        android.rms.iaware.AwareLog.d(r0, r5);	 Catch:{ all -> 0x00a9 }
    L_0x0083:
        monitor-exit(r13);	 Catch:{ all -> 0x00a9 }
        r0 = new java.lang.StringBuilder;
        r0.<init>();
        r3 = " addRecord, reason=";
        r0.append(r3);
        r0.append(r2);
        r3 = ", packageName=";
        r0.append(r3);
        r0.append(r10);
        r3 = ", processName=";
        r0.append(r3);
        r0.append(r11);
        r0 = r0.toString();
        r1.checkTime(r14, r0);
        return;
    L_0x00a9:
        r0 = move-exception;
        r3 = r14;
        goto L_0x00ad;
    L_0x00ac:
        r0 = move-exception;
    L_0x00ad:
        monitor-exit(r13);	 Catch:{ all -> 0x00ac }
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.rms.iaware.memory.utils.PackageTracker.addRecord(int, java.lang.String, java.lang.String, int, java.lang.String, long):void");
    }

    private void update(boolean quickUpdated) {
        long nowTime = android.os.SystemClock.elapsedRealtime();
        if ((quickUpdated ? 30000 : 1800000) <= nowTime - this.mlastTriggerTime) {
            this.mPackageStats.cleanRange(android.os.SystemClock.uptimeMillis(), 9000000);
            checkTime(nowTime, " cleanRange");
            this.mPackageStats.calcMax();
            checkTime(nowTime, " calcMax");
            this.mlastTriggerTime = nowTime;
        }
    }

    public boolean isPackageCriticalFrequency(java.lang.String packageName, int uid) {
        return getPackageKilledFrequency(packageName, uid) == com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_CRITICAL;
    }

    public boolean isPackageHighFrequency(java.lang.String packageName, int uid) {
        return getPackageKilledFrequency(packageName, uid) == com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_HIGH;
    }

    private com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency getPackageKilledFrequency(java.lang.String packageName, int uid) {
        if (!this.mEnable) {
            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
        }
        synchronized (mLock) {
            com.android.server.rms.iaware.memory.utils.RecordTable state = this.mPackageStats.getPackageState(packageName, uid);
            com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency killedFrequency;
            if (state == null) {
                killedFrequency = com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
                return killedFrequency;
            }
            if (this.mDebug) {
                java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("getPackageKilledFrequency:");
                stringBuilder.append(state.mPackageName);
                stringBuilder.append(", uid:");
                stringBuilder.append(state.mUid);
                android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder.toString());
            }
            update(true);
            long now = android.os.SystemClock.uptimeMillis();
            int[] array = new int[]{2, 1, 0};
            int i = 0;
            while (true) {
                int i2 = i;
                if (i2 < array.length) {
                    int index = array[i2];
                    killedFrequency = compareRecordThreshold(state, index, mKillThresHold[index], now, state.mProcesses.size());
                    if (killedFrequency != com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL) {
                        return killedFrequency;
                    }
                    i = i2 + 1;
                } else {
                    return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
                }
            }
        }
    }

    public boolean isProcessCriticalFrequency(java.lang.String packageName, java.lang.String processName, int uid) {
        return getProcessKilledFrequency(packageName, processName, uid) == com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_CRITICAL;
    }

    public boolean isProcessHighFrequency(java.lang.String packageName, java.lang.String processName, int uid) {
        return getProcessKilledFrequency(packageName, processName, uid) == com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_HIGH;
    }

    private com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency getProcessKilledFrequency(java.lang.String packageName, java.lang.String processName, int uid) {
        java.lang.Throwable th;
        java.lang.String str = processName;
        if (!this.mEnable) {
            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
        }
        synchronized (mLock) {
            try {
                try {
                    com.android.server.rms.iaware.memory.utils.PackageStats.PackageState state = this.mPackageStats.getPackageState(packageName, uid);
                    com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency killedFrequency;
                    if (state == null) {
                        killedFrequency = com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
                        return killedFrequency;
                    }
                    com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState processState = (com.android.server.rms.iaware.memory.utils.PackageStats.ProcessState) state.mProcesses.get(str);
                    if (processState == null) {
                        killedFrequency = com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
                        return killedFrequency;
                    }
                    if (this.mDebug) {
                        java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                        stringBuilder.append("getProcessKilledFrequency:");
                        stringBuilder.append(str);
                        stringBuilder.append(" ");
                        stringBuilder.append(state.mPackageName);
                        stringBuilder.append(", uid:");
                        stringBuilder.append(state.mUid);
                        android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder.toString());
                    }
                    update(true);
                    long now = android.os.SystemClock.uptimeMillis();
                    int[] array = new int[]{2, 1, 0};
                    int i = 0;
                    while (true) {
                        int i2 = i;
                        if (i2 < array.length) {
                            int index = array[i2];
                            killedFrequency = compareRecordThreshold(processState.getRecordTable(), index, mKillThresHold[index], now, 1);
                            if (killedFrequency != com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL) {
                                return killedFrequency;
                            }
                            i = i2 + 1;
                        } else {
                            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
                        }
                    }
                } catch (Throwable th2) {
                    th = th2;
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                java.lang.String str2 = packageName;
                int i3 = uid;
                throw th;
            }
        }
    }

    private com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency compareRecordThreshold(com.android.server.rms.iaware.memory.utils.RecordTable state, int record, int[] threshold, long now, int processSize) {
        int i;
        com.android.server.rms.iaware.memory.utils.RecordTable recordTable = state;
        int i2 = record;
        int processSize2 = processSize > 0 ? processSize : 1;
        java.util.List<java.lang.Long> timeList = recordTable.mRecordTimeStamps[i2].mTimeStamps;
        int criticalCount = 0;
        int i3 = timeList.size() - 1;
        while (true) {
            i = i3;
            if (i < 0) {
                break;
            }
            if (30000 * ((long) state.getScaleTimes()) < now - ((java.lang.Long) timeList.get(i)).longValue()) {
                break;
            }
            criticalCount++;
            i3 = i - 1;
        }
        criticalCount /= processSize2;
        java.lang.StringBuilder stringBuilder;
        if (threshold[INDEX_KILL_MINUTE] <= criticalCount) {
            if (this.mDebug) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("compareThresHold critical, index=");
                stringBuilder.append(i2);
                stringBuilder.append(", critical Count=");
                stringBuilder.append(criticalCount);
                stringBuilder.append(", timeScale=");
                stringBuilder.append(state.getScaleTimes());
                android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder.toString());
            }
            state.updateScaleTimes();
            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_CRITICAL;
        }
        i = timeList.size() / processSize2;
        if (threshold[INDEX_KILL_CUR] <= i) {
            if (this.mDebug) {
                java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                stringBuilder2.append("compareThresHold high, index=");
                stringBuilder2.append(i2);
                stringBuilder2.append(", curCount=");
                stringBuilder2.append(i);
                android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder2.toString());
            }
            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_HIGH;
        }
        long firstTime = recordTable.mFirstTimes[i2];
        long totalCount = recordTable.mTotalRecordCounts[i2];
        long avgCount = totalCount / ((long) processSize2);
        if (86400000 < now - firstTime) {
            avgCount = (86400000 * totalCount) / (now - firstTime);
            if (((long) threshold[INDEX_KILL_AVG]) <= avgCount) {
                if (this.mDebug) {
                    java.lang.StringBuilder stringBuilder3 = new java.lang.StringBuilder();
                    stringBuilder3.append("compareThresHold high, index=");
                    stringBuilder3.append(i2);
                    stringBuilder3.append(", avgCount=");
                    stringBuilder3.append(avgCount);
                    android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder3.toString());
                }
                return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_HIGH;
            }
        }
        long maxCount = recordTable.mMaxRecordCounts[i2];
        maxCount = (maxCount == 0 ? recordTable.mDayRecordCounts[i2] : maxCount) / ((long) processSize2);
        if (((long) threshold[INDEX_KILL_MAX]) <= maxCount) {
            if (this.mDebug) {
                stringBuilder = new java.lang.StringBuilder();
                stringBuilder.append("compareThresHold high, index=");
                stringBuilder.append(i2);
                stringBuilder.append(", maxCount=");
                stringBuilder.append(maxCount);
                android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder.toString());
            }
            return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_HIGH;
        }
        if (this.mDebug) {
            stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("compareThresHold normal, index=");
            stringBuilder.append(i2);
            stringBuilder.append(", curCount=");
            stringBuilder.append(i);
            stringBuilder.append(", avgCount=");
            stringBuilder.append(avgCount);
            stringBuilder.append(", maxCount=");
            stringBuilder.append(maxCount);
            stringBuilder.append(", criticalCount=");
            stringBuilder.append(criticalCount);
            stringBuilder.append(", processSize=");
            stringBuilder.append(processSize2);
            android.rms.iaware.AwareLog.d("AwareMem_PkgTracker", stringBuilder.toString());
        }
        return com.android.server.rms.iaware.memory.utils.PackageTracker.KilledFrequency.FREQUENCY_NORMAL;
    }

    private void checkTime(long startTime, java.lang.String action) {
        long now = android.os.SystemClock.elapsedRealtime();
        if (now - startTime > 10) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("[");
            stringBuilder.append(action);
            stringBuilder.append("] takes too much time:");
            stringBuilder.append(now - startTime);
            android.rms.iaware.AwareLog.w("AwareMem_PkgTracker", stringBuilder.toString());
        }
    }
}
