package com.android.server.security.ukey;

public class UKeyApplicationScanner {
    private static final java.lang.String APK_NAME_CN = "apkNameCn";
    private static final java.lang.String APK_NAME_EN = "apkNameEn";
    private static final java.lang.String CERT_MGR_NAME = "certMgrName";
    private static final int CERT_MGR_RESULT_DISABLE = 0;
    private static final int CERT_MGR_RESULT_ENABLE = 1;
    private static final int CERT_MGR_RESULT_HIDE = 2;
    private static final java.lang.String CERT_MGR_SIGN = "certMgrSign";
    private static final java.lang.String CERT_MGR_TYPE_DISABLE = "disable";
    private static final java.lang.String CERT_MGR_TYPE_HIDE = "hide";
    private static final java.lang.String KEY_ALGORITHM = "RSA";
    private static final java.lang.String PACKAGE_NAME = "packageName";
    private static final java.lang.String SIGN = "sign";
    private static final java.lang.String SIGNATURE_ALGORITHM = "SHA256withRSA";
    private static final java.lang.String TAG = "UKeyApplicationScanner";
    private static final java.lang.String UKEY_APK_WHITE_LIST_NAME = "ukeyapp.xml";
    private static final java.lang.String UKEY_ID = "ukeyId";
    private static java.util.HashMap<java.lang.String, java.lang.String> mPackageNameMap = new java.util.HashMap();
    private static java.util.HashMap<java.lang.String, com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo> mUKeyApkList = new java.util.HashMap();
    private android.content.Context mContext;

    public static class UKeyApkInfo {
        public final java.lang.String mApkNameCn;
        public final java.lang.String mApkNameEn;
        public final java.lang.String mCertMgrType;
        public final java.lang.String[] mCertPkgHashCode;
        public final java.lang.String[] mHashCode;
        public final java.lang.String mPackageName;
        public final java.lang.String mUKeyId;

        UKeyApkInfo(java.lang.String packageName, java.lang.String apkNameCn, java.lang.String apkNameEn, java.lang.String ukeyId, java.lang.String[] hashCodeArray, java.lang.String certMgrType, java.lang.String[] certPkgSign) {
            this.mPackageName = packageName;
            this.mApkNameCn = apkNameCn;
            this.mApkNameEn = apkNameEn;
            this.mUKeyId = ukeyId;
            this.mHashCode = hashCodeArray;
            this.mCertMgrType = certMgrType;
            this.mCertPkgHashCode = certPkgSign;
        }
    }

    public UKeyApplicationScanner(android.content.Context context) {
        this.mContext = context;
    }

    public void loadUKeyApkWhitelist() {
        mUKeyApkList.clear();
        if (parsePackagelist()) {
            android.util.Slog.i("UKeyApplicationScanner", "parsing whitelist succeeded!!!");
        } else {
            android.util.Slog.i("UKeyApplicationScanner", "parsing whitelist failed!!!");
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0047 A:{SYNTHETIC, Splitter: B:22:0x0047} */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x002c A:{SYNTHETIC, Splitter: B:12:0x002c} */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x0103 A:{ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:43:0x00ad} */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x0103 A:{ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:43:0x00ad} */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x0120 A:{PHI: r1 r2 , ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:4:0x0009} */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x0120 A:{PHI: r1 r2 , ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:4:0x0009} */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x012a A:{ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:1:0x0003} */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x012a A:{ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:1:0x0003} */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x003d A:{PHI: r1 , ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:12:0x002c} */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x003d A:{PHI: r1 , ExcHandler: org.xmlpull.v1.XmlPullParserException (e org.xmlpull.v1.XmlPullParserException), Splitter: B:12:0x002c} */
    /* JADX WARNING: Missing block: B:18:0x003d, code:
            r0 = e;
     */
    /* JADX WARNING: Missing block: B:19:0x003e, code:
            r20 = r1;
     */
    /* JADX WARNING: Missing block: B:58:0x0103, code:
            r0 = e;
     */
    /* JADX WARNING: Missing block: B:67:0x0120, code:
            r0 = e;
     */
    /* JADX WARNING: Missing block: B:72:0x012a, code:
            r0 = e;
     */
    /* JADX WARNING: Missing block: B:73:0x012b, code:
            r4 = r21;
     */
    /* JADX WARNING: Missing block: B:74:0x012d, code:
            r20 = r1;
     */
    /* JADX WARNING: Missing block: B:76:?, code:
            r3 = new java.lang.StringBuilder();
            r3.append("parsePackagelist Error reading Pkg white list: ");
            r3.append(r0);
            android.util.Slog.e("UKeyApplicationScanner", r3.toString());
            r1 = false;
     */
    private boolean parsePackagelist() {
        /*
        r21 = this;
        r1 = 1;
        r0 = 0;
        r2 = r0;
        r3 = android.util.Xml.newPullParser();	 Catch:{ FileNotFoundException -> 0x0147, XmlPullParserException -> 0x012a, XmlPullParserException -> 0x012a, XmlPullParserException -> 0x012a, all -> 0x0124 }
        r4 = r21;
        r5 = r4.mContext;	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r5 = r5.getAssets();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r6 = "ukeyapp.xml";
        r5 = r5.open(r6);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r2 = r5;
        r5 = "UTF-8";
        r3.setInput(r2, r5);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r5 = 0;
        r6 = r5;
    L_0x001e:
        r7 = r3.next();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r6 = r7;
        r8 = 1;
        r9 = 2;
        if (r7 == r9) goto L_0x002a;
    L_0x0027:
        if (r6 == r8) goto L_0x002a;
    L_0x0029:
        goto L_0x001e;
    L_0x002a:
        if (r6 == r9) goto L_0x0047;
    L_0x002c:
        r0 = "UKeyApplicationScanner";
        r7 = "No start tag found in Package white list.";
        android.util.Slog.i(r0, r7);	 Catch:{ FileNotFoundException -> 0x0042, XmlPullParserException -> 0x003d, XmlPullParserException -> 0x003d, XmlPullParserException -> 0x003d, all -> 0x0038 }
        libcore.io.IoUtils.closeQuietly(r2);
        return r5;
    L_0x0038:
        r0 = move-exception;
        r20 = r1;
        goto L_0x0169;
    L_0x003d:
        r0 = move-exception;
        r20 = r1;
        goto L_0x012f;
    L_0x0042:
        r0 = move-exception;
        r20 = r1;
        goto L_0x014c;
    L_0x0047:
        r7 = r3.getDepth();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
    L_0x004b:
        r9 = r3.next();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r6 = r9;
        if (r9 == r8) goto L_0x0115;
    L_0x0052:
        r9 = 3;
        if (r6 != r9) goto L_0x0060;
    L_0x0055:
        r10 = r3.getDepth();	 Catch:{ FileNotFoundException -> 0x0042, XmlPullParserException -> 0x003d, XmlPullParserException -> 0x003d, XmlPullParserException -> 0x003d, all -> 0x0038 }
        if (r10 <= r7) goto L_0x005c;
    L_0x005b:
        goto L_0x0060;
    L_0x005c:
        r20 = r1;
        goto L_0x0117;
    L_0x0060:
        if (r6 == r9) goto L_0x010b;
    L_0x0062:
        r9 = 4;
        if (r6 != r9) goto L_0x006b;
        r20 = r1;
        r0 = r5;
        goto L_0x010e;
    L_0x006b:
        r9 = r3.getName();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r10 = "package";
        r10 = r9.equals(r10);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        if (r10 == 0) goto L_0x0107;
    L_0x0077:
        r10 = "packageName";
        r10 = r3.getAttributeValue(r0, r10);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r11 = "apkNameCn";
        r13 = r3.getAttributeValue(r0, r11);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r11 = "apkNameEn";
        r14 = r3.getAttributeValue(r0, r11);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r11 = "ukeyId";
        r15 = r3.getAttributeValue(r0, r11);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r11 = "sign";
        r11 = r3.getAttributeValue(r0, r11);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r12 = r11;
        r11 = "certMgrName";
        r11 = r3.getAttributeValue(r0, r11);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r8 = "certMgrSign";
        r8 = r3.getAttributeValue(r0, r8);	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r0 = "UKeyApplicationScanner";
        r5 = new java.lang.StringBuilder;	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r5.<init>();	 Catch:{ FileNotFoundException -> 0x0122, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, XmlPullParserException -> 0x0120, all -> 0x011e }
        r20 = r1;
        r1 = "PARSER from xml packageName : ";
        r5.append(r1);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r5.append(r10);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r1 = r5.toString();	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        android.util.Slog.i(r0, r1);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r0 = android.text.TextUtils.isEmpty(r10);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        if (r0 != 0) goto L_0x0101;
    L_0x00c2:
        r0 = android.text.TextUtils.isEmpty(r12);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        if (r0 == 0) goto L_0x00c9;
    L_0x00c8:
        goto L_0x0101;
    L_0x00c9:
        r0 = ",";
        r16 = r12.split(r0);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        if (r8 != 0) goto L_0x00d7;
    L_0x00d1:
        r0 = 0;
        r1 = new java.lang.String[r0];	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
    L_0x00d4:
        r18 = r1;
        goto L_0x00df;
    L_0x00d7:
        r0 = 0;
        r1 = ",";
        r1 = r8.split(r1);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        goto L_0x00d4;
    L_0x00df:
        r1 = new com.android.server.security.ukey.UKeyApplicationScanner$UKeyApkInfo;	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r5 = r11;
        r11 = r1;
        r19 = r12;
        r12 = r10;
        r17 = r5;
        r11.<init>(r12, r13, r14, r15, r16, r17, r18);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11 = mUKeyApkList;	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11.put(r10, r1);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11 = mPackageNameMap;	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11.put(r10, r10);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11 = android.text.TextUtils.isEmpty(r5);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        if (r11 != 0) goto L_0x010a;
    L_0x00fb:
        r11 = mPackageNameMap;	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        r11.put(r5, r10);	 Catch:{ FileNotFoundException -> 0x0105, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103, XmlPullParserException -> 0x0103 }
        goto L_0x010a;
    L_0x0101:
        r0 = 0;
        goto L_0x010e;
    L_0x0103:
        r0 = move-exception;
        goto L_0x012f;
    L_0x0105:
        r0 = move-exception;
        goto L_0x014c;
    L_0x0107:
        r20 = r1;
        r0 = r5;
    L_0x010a:
        goto L_0x010e;
    L_0x010b:
        r20 = r1;
        r0 = r5;
    L_0x010e:
        r5 = r0;
        r1 = r20;
        r0 = 0;
        r8 = 1;
        goto L_0x004b;
    L_0x0115:
        r20 = r1;
    L_0x0117:
        libcore.io.IoUtils.closeQuietly(r2);
        r1 = r20;
        goto L_0x0167;
    L_0x011e:
        r0 = move-exception;
        goto L_0x0127;
    L_0x0120:
        r0 = move-exception;
        goto L_0x012d;
    L_0x0122:
        r0 = move-exception;
        goto L_0x014a;
    L_0x0124:
        r0 = move-exception;
        r4 = r21;
    L_0x0127:
        r20 = r1;
        goto L_0x0169;
    L_0x012a:
        r0 = move-exception;
        r4 = r21;
    L_0x012d:
        r20 = r1;
    L_0x012f:
        r1 = "UKeyApplicationScanner";
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0168 }
        r3.<init>();	 Catch:{ all -> 0x0168 }
        r5 = "parsePackagelist Error reading Pkg white list: ";
        r3.append(r5);	 Catch:{ all -> 0x0168 }
        r3.append(r0);	 Catch:{ all -> 0x0168 }
        r3 = r3.toString();	 Catch:{ all -> 0x0168 }
        android.util.Slog.e(r1, r3);	 Catch:{ all -> 0x0168 }
        r1 = 0;
        goto L_0x0163;
    L_0x0147:
        r0 = move-exception;
        r4 = r21;
    L_0x014a:
        r20 = r1;
    L_0x014c:
        r1 = "UKeyApplicationScanner";
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0168 }
        r3.<init>();	 Catch:{ all -> 0x0168 }
        r5 = "parsePackagelist Error reading Pkg white list: ";
        r3.append(r5);	 Catch:{ all -> 0x0168 }
        r3.append(r0);	 Catch:{ all -> 0x0168 }
        r3 = r3.toString();	 Catch:{ all -> 0x0168 }
        android.util.Slog.e(r1, r3);	 Catch:{ all -> 0x0168 }
        r1 = 0;
    L_0x0163:
        libcore.io.IoUtils.closeQuietly(r2);
    L_0x0167:
        return r1;
    L_0x0168:
        r0 = move-exception;
    L_0x0169:
        libcore.io.IoUtils.closeQuietly(r2);
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.android.server.security.ukey.UKeyApplicationScanner.parsePackagelist():boolean");
    }

    public boolean isWhiteListedUKeyApp(java.lang.String packageName) {
        if (packageName != null) {
            if (!packageName.isEmpty()) {
                java.lang.String realPkgName = getRealUKeyPkgName(packageName);
                com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo apkSign = (com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo) mUKeyApkList.get(realPkgName);
                if (apkSign == null || apkSign.mPackageName == null) {
                    return false;
                }
                try {
                    return compareHashcode(apkSign.mHashCode, this.mContext.getPackageManager().getPackageInfo(realPkgName, 64).signatures);
                } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                    return false;
                }
            }
        }
        return false;
    }

    public android.os.Bundle getUKeyApkInfoData(java.lang.String packageName) {
        com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo uKeyApkInfo = (com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo) mUKeyApkList.get(packageName);
        if (uKeyApkInfo == null || uKeyApkInfo.mPackageName == null) {
            return null;
        }
        android.os.Bundle bundle = new android.os.Bundle();
        bundle.putString("packageName", uKeyApkInfo.mPackageName);
        bundle.putString("apkNameCn", uKeyApkInfo.mApkNameCn);
        bundle.putString("apkNameEn", uKeyApkInfo.mApkNameEn);
        if (compareCertMgrApkResult(uKeyApkInfo.mPackageName) == 0) {
            bundle.putString("certMgrName", "disable");
        } else if (android.text.TextUtils.isEmpty(uKeyApkInfo.mCertMgrType)) {
            bundle.putString("certMgrName", uKeyApkInfo.mPackageName);
        } else {
            bundle.putString("certMgrName", uKeyApkInfo.mCertMgrType);
        }
        return bundle;
    }

    public com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo getUKeyApkInfo(java.lang.String packageName) {
        if (mUKeyApkList == null) {
            return null;
        }
        return (com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo) mUKeyApkList.get(packageName);
    }

    private boolean compareHashcode(java.lang.String[] hashcode, android.content.pm.Signature[] signatures) {
        if (signatures != null) {
            if (signatures.length != 0) {
                java.lang.String[] apkSignHashAry = new java.lang.String[signatures.length];
                int i = 0;
                while (i < signatures.length) {
                    try {
                        apkSignHashAry[i] = sha256(((java.security.cert.X509Certificate) java.security.cert.CertificateFactory.getInstance("X.509").generateCertificate(new java.io.ByteArrayInputStream(signatures[i].toByteArray()))).getSignature());
                        i++;
                    } catch (java.security.cert.CertificateException e) {
                        android.util.Slog.e("UKeyApplicationScanner", "compareHashcode Error !!!");
                        return false;
                    }
                }
                return compareSignatures(hashcode, apkSignHashAry);
            }
        }
        return false;
    }

    private boolean compareSignatures(java.lang.String[] s1, java.lang.String[] s2) {
        if (s1.length != s2.length) {
            return false;
        }
        if (s1.length == 1) {
            return s1[0].equals(s2[0]);
        }
        android.util.ArraySet<java.lang.String> set1 = new android.util.ArraySet();
        for (java.lang.String sig : s1) {
            java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
            stringBuilder.append("sig 1 = ");
            stringBuilder.append(sig);
            android.util.Slog.e("UKeyApplicationScanner", stringBuilder.toString());
            set1.add(sig);
        }
        android.util.ArraySet<java.lang.String> set2 = new android.util.ArraySet();
        for (java.lang.String sig2 : s2) {
            java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
            stringBuilder2.append("sig 2 = ");
            stringBuilder2.append(sig2);
            android.util.Slog.e("UKeyApplicationScanner", stringBuilder2.toString());
            set2.add(sig2);
        }
        if (set1.equals(set2)) {
            return true;
        }
        return false;
    }

    private java.lang.String sha256(byte[] data) {
        if (data == null) {
            return null;
        }
        try {
            java.security.MessageDigest md = java.security.MessageDigest.getInstance("SHA-256");
            md.update(data);
            return bytesToString(md.digest());
        } catch (java.security.NoSuchAlgorithmException e) {
            return null;
        }
    }

    private java.lang.String bytesToString(byte[] bytes) {
        if (bytes == null) {
            return null;
        }
        char[] hexChars = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
        char[] chars = new char[(bytes.length * 2)];
        for (int j = 0; j < bytes.length; j++) {
            int byteValue = bytes[j] & 255;
            chars[j * 2] = hexChars[byteValue >>> 4];
            chars[(j * 2) + 1] = hexChars[byteValue & 15];
        }
        return new java.lang.String(chars).toUpperCase(java.util.Locale.US);
    }

    public java.lang.String getRealUKeyPkgName(java.lang.String packageName) {
        return (java.lang.String) mPackageNameMap.get(packageName);
    }

    private int compareCertMgrApkResult(java.lang.String packageName) {
        if (packageName != null) {
            if (!packageName.isEmpty()) {
                com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo apkSign = (com.android.server.security.ukey.UKeyApplicationScanner.UKeyApkInfo) mUKeyApkList.get(packageName);
                if (apkSign == null) {
                    return 0;
                }
                if (android.text.TextUtils.isEmpty(apkSign.mCertMgrType)) {
                    return 1;
                }
                if ("disable".equals(apkSign.mCertMgrType)) {
                    return 0;
                }
                if ("hide".equals(apkSign.mCertMgrType)) {
                    return 2;
                }
                try {
                    android.content.pm.PackageInfo packageInfo = compareHashcode(apkSign.mCertPkgHashCode, this.mContext.getPackageManager().getPackageInfo(apkSign.mCertMgrType, 64).signatures);
                    java.lang.StringBuilder stringBuilder = new java.lang.StringBuilder();
                    stringBuilder.append("The compare Hashcode result of cert manager apk ");
                    stringBuilder.append(apkSign.mCertMgrType);
                    stringBuilder.append("result is ");
                    stringBuilder.append(packageInfo);
                    android.util.Slog.i("UKeyApplicationScanner", stringBuilder.toString());
                    return packageInfo;
                } catch (android.content.pm.PackageManager.NameNotFoundException e) {
                    java.lang.StringBuilder stringBuilder2 = new java.lang.StringBuilder();
                    stringBuilder2.append("ukey cert manager apk");
                    stringBuilder2.append(apkSign.mCertMgrType);
                    stringBuilder2.append(" does not install!!!");
                    android.util.Slog.i("UKeyApplicationScanner", stringBuilder2.toString());
                    return 0;
                }
            }
        }
        return 0;
    }
}
